/////////////////////////////////////////////////////////////
//                                                         //
//    "The twelve colonies of Kobol" planetary system      //
//                for SpaceEngine v0.974                   //
//                                                         //
//                     Version 1.2b                        //
//                                                         //
// Data are taken from "The twelve colonies of Kobol" map. //
// Semimajor axis of binary systems are corrected using    //
// actual mass ratio data. For missing data (Luminosity,   //
// MeanAnomaly etc) used some typical values. Radii of     //
// most planets are measured on the bottom-right chart,    //
// assumed Caprica radius of 6370 km. Surface colors of    //
// planets are picked from the map.                        //
//                                                         //
/////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////
//                                                   //
//  Full version with all asteroid belts and comets  //
//                                                   //
//  Put this file in 'catalogs\planets'              //
//                                                   //
//  and add in the 'universe.cfg' under:             //
//                                                   //
//  PlanetsCatalogs	// planets catalogs              //
//                                                   //
//  the line:                                        //
//      "catalogs/planets/CyrannusFull.sc"           //
//                                                   //
///////////////////////////////////////////////////////

// Cyrannus A ------------------------------------------------------------------
Barycenter "Cyrannus A"
{
	ParentBody     "Cyrannus"
	
	Orbit
	{
		// Barycenter summary mass: 1.79
		// SemiMajorAxis = 10091/2 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 10091/2 * 2 * 1.63/(1.79+1.63)
		SemiMajorAxis   4809.45
		Period          54689
		Eccentricity    0.33	// use typical value
		Inclination     0.0 	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericenter 98.2	// no data
		MeanAnomaly     48.5	// no data
	}
}

// Helios Alpha ----------------------------------------------------------------
Star "Helios ALF"
{
	ParentBody  "Cyrannus A"
	Class       "G2V"
	MassSol        1.0
	Luminosity  1.0	// no data, use typical value of K1V star
	
	Oblateness  0.0
	
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 2 * 63 * 0.79/(1.0+0.79)
		SemiMajorAxis   55.6089
		Period          333
		Eccentricity    0.0 	// no data
		Inclination     0.0 	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericenter 158.2	// no data
		MeanAnomaly     228.5	// no data
	}
}

Planet "Icarus"
{
	ParentBody     "Helios ALF"
	Class          "Desert" // SpaceEngine 0.94 don't support melted planets

	Radius          3098	// no data

	Albedo          0.32	// no data

	Atmosphere
	{
		Height      130
		Pressure    3.6
		Density	    5.8
		Model      "Venus"
		Bright      5.0
		Opacity     0.5
	}

	Clouds
	{
		Coverage    0.06
		mainFreq    1.0
		twistMagn   3.8
		Velocity    220
		Height      16
		BumpHeight  0.5
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.12 	// no data
		Eccentricity   0.0  	// no data
		Inclination    0.13 	// no data
		AscendingNode  0		// no data
		ArgOfPericen   68.3 	// no data
		MeanAnomaly    76.2 	// no data
	}
}

Planet "Picon"
{
	ParentBody     "Helios ALF"
	Class          "Terra"

	Radius          6250	// no data

	RotationPeriod  23.5	// no data
	Obliquity       8.5 	// no data
	EqAscendNode    3.2 	// no data

	Albedo          0.4
	Color         ( 0.70 0.85 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.50
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.95
		BumpHeight      6.5
		//BumpHeight      18.4659512859
		//BumpOffset      11.0252972274
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          3.25
		// Height          9.23297564294	//3.25
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.10
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	NoRings  true

	Atmosphere
	{
		Height      55
		Pressure    0.76
		Density	    1.10
		Greenhouse  11.908
		Model      "Earth"
		
		Composition
		{
			N2  79.076269953
			O2  20.291443439
			Kr  0.135134418713
			H2O 0.225835084113
			CO2 0.271317105124
		}
	}

	Orbit
	{
		SemiMajorAxis   0.75	// no data
		Eccentricity    0.02	// no data
		// Extreme inclination visible on the map
		Inclination     16.6	// no data
		AscendingNode   0		// no data
		ArgOfPericen    51.1	// no data
		MeanAnomaly     134.5	// no data
	}
}

Barycenter "Caprica-Gemenon"
{
	ParentBody     "Helios ALF"
	
	Orbit
	{
		SemiMajorAxis   1.0 	// no data
		Eccentricity    0.005	// no data
		Inclination     0.0 	// no data
		AscendingNode   0		// no data
		ArgOfPericen    117.2	// no data
		MeanAnomaly     236.5	// no data
	}
}

Planet "Caprica"
{
	ParentBody     "Caprica-Gemenon"
	Class          "Terra"

	Radius          6370	// no data
	Mass            0.98	// no data

	RotationPeriod  28.3	// no data
	Obliquity       0.0 	// no data
	EqAscendNode    28.6	// no data

	Albedo          0.3
	Color         ( 0.85 0.95 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.86, 0.33, 0.39)
		seaLevel        0.46
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.87
		BumpHeight      8.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          3.91
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.14
		mainFreq    1.0
		twistMagn   3.5
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      60
		Greenhouse  35.714		// 15
		Pressure    1.0
		Density	    1.29
		Model      "Earth"
		
		Composition
		{
			N2  76.3364426704
			O2  21.1466348645
			Kr  0.200232986696
			H2O 1.16438488948
			CO2 1.15230458902
		}
	}

	NoRings  true

	Orbit
	{
		// 493000/2 km with mass ratio 0.84:0.98
		SemiMajorAxis   0.0015206
		Period          0.0772	// 28.2 days
		Eccentricity    0.02	// no data
		Inclination     24.5	// no data
		AscendingNode   28.6	// no data
		ArgOfPericen    68.5	// no data
		MeanAnomaly     233.2	// no data
	}
}

Planet "Gemenon"
{
	ParentBody     "Caprica-Gemenon"
	Class          "Terra"

	Radius          6051	// no data
	Mass            0.84	// no data

	RotationPeriod  24.0	// no data
	Obliquity       0.0 	// no data
	EqAscendNode    28.6	// no data

	Albedo          0.3
	Color         ( 1.00 0.95 0.70 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.20
		Randomize      (0.86, 0.33, 0.39)
		seaLevel        0.40
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.91
		colorLowPlants  (0.69, 0.58, 0.38, 0.00)
		colorUpPlants   (0.59, 0.50, 0.31, 0.00)
		BumpHeight      13.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          5.4
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.06
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      60
		Greenhouse  35.714		// 8
		Pressure    0.9
		Density	    1.2
		Model      "Earth"
		
		Composition
		{
			N2  77.8655085497
			O2  20.065220845
			Xe  0.406453634458
			H2O 0.663106611621
			CO2 0.999710359149
		}
	}

	NoRings  true

	Orbit
	{
		// 493000/2 km with mass ratio 0.84:0.98
		SemiMajorAxis   0.0017745
		Period          0.0772	// 28.2 days
		Eccentricity    0.02	// no data
		Inclination     24.5	// no data
		AscendingNode   28.6	// no data
		ArgOfPericen    248.5	// no data
		MeanAnomaly     233.2	// no data
	}
}

Planet "Tauron"
{
	ParentBody     "Helios ALF"
	Class          "Terra"

	Radius          7962.5	// no data

	RotationPeriod  22.1	// no data
	Obliquity       18.5	// no data
	EqAscendNode    2.1 	// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.75
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.38
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.85
		colorLowPlants  (0.44, 0.29, 0.22, 0.00)
		colorUpPlants   (0.47, 0.32, 0.28, 0.00)
		BumpHeight      12.3
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          4.674
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.08
		mainFreq    1.0
		twistMagn   3.5
		Velocity    40
		Height      12
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      52
		Greenhouse  68.479		// 34
		Pressure    0.76
		Density	    1.10
		Model      "Earth"
		
		Composition
		{
			N2  66.2377141358
			O2  22.6557772848
			Ne  1.13633274942
			H2O 2.89049259905
			CO2 7.07968323094
		}
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.42	// no data
		Eccentricity    0.003	// no data
		Inclination     0.6 	// no data
		AscendingNode   0		// no data
		ArgOfPericen    26.5	// no data
		MeanAnomaly     324.1	// no data
	}
}

Moon "Minos"
{
	ParentBody     "Tauron"
	Class          "Desert"

	Radius          2728	// no data

	Obliquity       4.5 	// no data
	EqAscendNode    18.3	// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	NoLife          true

	Surface
	{
		Style           0.75
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.1
		icecapLatitude  0.89
		mareFreq        2.5
		mareDensity     0.25
		craterFreq      50.0
		craterDensity   0.4
		craterOctaves   10
		craterMagn      0.2
		BumpHeight      22.6
	}

	Atmosphere
	{
		Height      150
		Pressure    0.2
		Model      "Mars"
	}
	
	Rings
	{
		InnerRadius     4072
		OuterRadius     5615
		FrontBright     1.0
		BackBright      5.0
		Density         0.03
		Exposure        2.5
	}

	Orbit
	{
		SemiMajorAxis   0.00187 // no data
		Eccentricity    0.006	// no data
		Inclination     22.6	// no data
		AscendingNode   18.2	// no data
		ArgOfPericen    126.5	// no data
		MeanAnomaly     34.7	// no data
	}
}

Planet "Zeus"
{
	ParentBody     "Helios ALF"
	Class          "GasGiant"

	Radius          76500

	RotationPeriod  8.75	// no data
	Obliquity       3.5 	// no data
	EqAscendNode    2.3 	// no data

	Albedo          0.66	// no data
	Color         ( 1.00 0.93 0.80 )

	Surface
	{
		Style           0.80
		Randomize      (0.13, 0.0087, 0.26)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      5
		twistMagn       0.3
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   1000.0
		Model   "Jupiter"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   5.2 	// no data
		Eccentricity    0.0 	// no data
		Inclination     1.2 	// no data
		AscendingNode   0		// no data
		ArgOfPericenter 254.2	// no data
		MeanAnomaly     135.9	// no data
	}
}

Moon "Hebe"
{
	ParentBody     "Zeus"
	Class          "Desert"

	Radius          1327	// no data

	Albedo          0.2
	Color         ( 1.00 1.00 0.75 )

	Surface
	{
		Style           0.75
		BumpHeight      32.6
	}

	Atmosphere
	{
		Height      150
		Pressure    0.06
		Density	    0.16
		Model      "Mars"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.0019	// no data
		Eccentricity    0.001	// no data
		Inclination     3.5 	// no data
		AscendingNode   2.3 	// no data
		ArgOfPericen    126.5	// no data
		MeanAnomaly     346.2	// no data
	}
}

Moon "Nike"
{
	ParentBody     "Zeus"
	Class          "IceWorld"

	Radius          1622	// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	Surface
	{
		Style           0.66
		BumpHeight      30.0
	}

	Atmosphere
	{
		Height      150
		Pressure    0.36
		Density	    2.65
		Model      "Titan"
	}

	Orbit
	{
		SemiMajorAxis   0.0026	// no data
		Eccentricity    0.005	// no data
		Inclination     3.5 	// no data
		AscendingNode   2.2 	// no data
		ArgOfPericen    62.7	// no data
		MeanAnomaly     134.7	// no data
	}
}

DwarfPlanet "Persephone"
{
	ParentBody     "Helios ALF"
	Class          "IceWorld"

	Radius          550

	Albedo          0.72
	Color         ( 1.00 1.00 1.00 )

	Atmosphere
	{
		Height      50
		Pressure    0.01
		Density	    0.23
		Model      "Earth"
		Bright      2.0
		Opacity     0.2
	}

	Orbit
	{
		SemiMajorAxis   6.3 	// no data
		Eccentricity    0.11	// no data
		Inclination     2.2 	// no data
		AscendingNode   12.3	// no data
		ArgOfPericenter 65.4	// no data
		MeanAnomaly     61.1	// no data
	}
}

// Helios Beta -----------------------------------------------------------------
Star "Helios BET"
{
	ParentBody  "Cyrannus A"
	Class       "K1V"
	MassSol        0.79
	Luminosity  0.34	// no data, use typical value of K1V star
	
	Oblateness  0.0
	
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 63 * 2 * 1.0/(1.0+0.79)
		SemiMajorAxis   70.3911
		Period          333
		Eccentricity    0.0 	// no data
		Inclination     0.0 	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericenter 338.2	// no data
		MeanAnomaly     228.5	// no data
	}
}

Planet "Troy"
{
	ParentBody     "Helios BET"
	Class          "Desert" // SpaceEngine 0.94 don't support melted planets

	Radius          3822	// no data

	RotationPeriod  23.5	// no data
	Obliquity       8.5 	// no data
	EqAscendNode    3.2 	// no data

	Albedo          0.22	// no data
	Color          (1.00, 0.90, 0.50)

	Surface
	{
		Style           0.3
		Randomize      (0.61, 0.35, 0.88)
		mareFreq        2.5
		mareDensity     0.25
		craterFreq      50.0
		craterDensity   0.4
		craterOctaves   10
		craterMagn      0.2
		// Yellow colors picked form the map
		colorSea       (0.44, 0.32, 0.27, 0.00)
		colorShelf     (0.56, 0.42, 0.32, 0.00)
		colorBeach     (0.74, 0.57, 0.40, 0.00)
		colorDesert    (0.53, 0.46, 0.35, 0.00)
		colorLowland   (0.67, 0.64, 0.64, 0.20)
		colorUpland    (0.69, 0.61, 0.49, 0.50)
		colorRock      (0.48, 0.41, 0.33, 0.10)
		colorSnow      (0.35, 0.29, 0.22, 1.00)
		BumpHeight      8.5
	}

	Atmosphere
	{
		Height      130
		Pressure    0.6
		Density	    1.8
		Model      "Venus"
		Bright      5.0
		Opacity     0.5
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.37 	// no data
		Eccentricity   0.0  	// no data
		Inclination    0.03 	// no data
		AscendingNode  0		// no data
		ArgOfPericen   17.2 	// no data
		MeanAnomaly    28.1 	// no data
	}
}

Planet "Leonis"
{
	ParentBody     "Helios BET"
	Class          "Terra"

	Radius          8281	// no data

	RotationPeriod  18.9	// no data
	// Leonis have nearly zero obliquity
	Obliquity       0.1 	// no data
	EqAscendNode    0.0 	// no data

	Albedo          0.28
	Color         ( 0.70 0.90 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.32
		mareDensity     0.0
		craterDensity   0.0
		climatePole     1.0
		climateTropic   0.625	// soft climate
		climateEquator  0.625
		icecapLatitude  0.95
		BumpHeight      6.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          2.08
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.12
		mainFreq    1.0
		twistMagn   3.3
		Velocity    80
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  67.460		// 5
		Pressure    1.35
		Density	    1.55
		Model      "Earth"
		
		Composition
		{
			N2  63.608031609
			O2  35.7983022172
			Xe  0.146041204989
			H2O 0.0166755939695
			CO2 0.430949374816
		}
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.75	// no data
		Eccentricity    0.006	// no data
		Inclination     0.6 	// no data
		AscendingNode   0		// no data
		ArgOfPericen    151.8	// no data
		MeanAnomaly     215.2	// no data
	}
}

Planet "Pallas"
{
	ParentBody     "Helios BET"
	Class          "Desert"

	Radius          5414.5	// no data

	RotationPeriod  26.3	// no data
	Obliquity       31.5	// no data
	EqAscendNode    1.3 	// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	NoLife          true

	Surface
	{
		Style           0.75
		Randomize      (0.66, 0.28, 0.56)
		seaLevel        0.18
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.85
		colorSea       (0.18, 0.24, 0.15, 0.00)
		colorShelf     (0.15, 0.17, 0.13, 0.00)
		BumpHeight      13.2
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Atmosphere
	{
		Height      70
		Pressure    0.08
		Density	    0.11
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.98	// no data
		Eccentricity    0.003	// no data
		// Extreme inclination visible on the map
		Inclination     -18.6	// no data
		AscendingNode   6.6 	// no data
		ArgOfPericen    158.2	// no data
		MeanAnomaly     121.8	// no data
	}
}

Planet "Virgon"
{
	ParentBody     "Helios BET"
	Class          "Terra"

	Radius          7962.5	// no data

	RotationPeriod  19.6	// no data
	Obliquity       12.7	// no data
	EqAscendNode    2.4 	// no data

	Albedo          0.28
	Color         ( 0.70 0.80 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.66, 0.89, 0.51)
		seaLevel        0.42
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.88
		// blue plants colors
		colorLowPlants  (0.18, 0.33, 0.39, 0.00)
		colorUpPlants   (0.15, 0.26, 0.33, 0.00)
		BumpHeight      6.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          2.73
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.12
		mainFreq    1.0
		Velocity    80
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  114.079		// 55
		Pressure    1.3
		Density	    1.5
		Model      "Neptune"
		
		Composition
		{
			N2  76.8136318672
			O2  21.5008749574
			Kr  0.343723382161
			H2O 0.824429926689
			CO2 0.517339866521
		}
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.23	// no data
		Eccentricity    0.003	// no data
		Inclination     0.9 	// no data
		ArgOfPericen    15.2	// no data
		AscendingNode   0		// no data
		MeanAnomaly     312.6	// no data
	}
}

Moon "Hibernia"
{
	ParentBody     "Virgon"
	Class          "Desert"

	Radius          4459	// no data

	Albedo          0.15
	Color         ( 1.00 1.00 0.90 )

	NoLife          true

	Surface
	{
		Style           0.25
		Randomize      (0.77, 0.38, 0.12)
		seaLevel        0.1
		icecapLatitude  1.0
		mareFreq        2.5
		mareDensity     0.25
		craterFreq      50.0
		craterDensity   0.4
		craterOctaves   10
		craterMagn      0.2
		BumpHeight      16.9
	}

	Atmosphere
	{
		Height      150
		Pressure    0.02
		Density	    0.04
		Model      "Mars"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.00211	// no data
		Eccentricity    0.001	// no data
		Inclination     12.6	// no data
		AscendingNode   2.2 	// no data
		ArgOfPericen    61.5	// no data
		MeanAnomaly     44.6	// no data
	}
}

Planet "Hera"
{
	ParentBody     "Helios BET"
	Class          "GasGiant"

	Radius          37500

	RotationPeriod  10.1	// no data
	Obliquity       5.8 	// no data
	EqAscendNode    3.6 	// no data

	Albedo          0.66	// no data
	Color         ( 1.00 0.93 0.80 )

	Surface
	{
		Style           0.66
		Randomize      (0.13, 0.0087, 0.26)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      3
		twistMagn       0.1
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   1000.0
		Model   "Jupiter"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   3.8 	// no data
		Eccentricity    0.0 	// no data
		Inclination     0.6 	// no data
		AscendingNode   0		// no data
		ArgOfPericenter 51.3	// no data
		MeanAnomaly     93.9	// no data
	}
}

Moon "Euboea"
{
	ParentBody     "Hera"
	Class          "IceWorld"

	Radius          991	// no data

	Albedo          0.65
	Color         ( 1.00 1.00 1.00 )

	Surface
	{
		Style           0.25
		BumpHeight      32.6
	}

	Orbit
	{
		SemiMajorAxis   0.0016	// no data
		Eccentricity    0.001	// no data
		Inclination     0.03	// no data
		AscendingNode   2.3 	// no data
		ArgOfPericen    26.5	// no data
		MeanAnomaly     34.5	// no data
	}
}

Moon "Iris"
{
	ParentBody     "Hera"
	Class          "IceWorld"

	Radius          1366	// no data

	Albedo          0.59
	Color         ( 1.00 1.00 0.95 )

	Surface
	{
		Style           0.66
		BumpHeight      30.0
	}

	Orbit
	{
		SemiMajorAxis   0.0022	// no data
		Eccentricity    0.005	// no data
		Inclination     0.05	// no data
		AscendingNode   2.2 	// no data
		ArgOfPericen    162.3	// no data
		MeanAnomaly     74.5	// no data
	}
}

// Cyrannus B ------------------------------------------------------------------
Barycenter "Cyrannus B"
{
	ParentBody  "Cyrannus"
	
	Orbit
	{
		// Barycenter summary mass: 1.63
		// SemiMajorAxis = 10091/2 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 10091/2 * 2 * 1.79/(1.79+1.63)
		SemiMajorAxis   5281.55
		Period          54689
		Eccentricity    0.33	// use typical value
		Inclination     0.0 	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericenter 278.2	// no data
		MeanAnomaly     48.5	// no data
	}
}

// Helios Gamma ----------------------------------------------------------------
Star "Helios GAM"
{
	ParentBody  "Cyrannus B"
	Class       "G9V"
	MassSol        0.89
	Luminosity  0.43	// no data, use typical value of K1V star
	
	Oblateness  0.0
	
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 70 * 2 * 0.74/(0.89+0.74)
		SemiMajorAxis   63.5583
		Period          434
		Eccentricity    0.0 	// no data
		Inclination     0.0 	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericenter 86.3	// no data
		MeanAnomaly     228.5	// no data
	}
}

Planet "Tanatos"
{
	ParentBody     "Helios GAM"
	Class          "Desert"	// SpaceEngine 0.94 don't support melted planets

	Radius          5096	// no data

	Albedo          0.16	// no data

	Atmosphere
	{
		Height      110
		Pressure    40.0
		Density	    26.3
		Model      "Venus"
		Bright      10.0
		Opacity     1.0
	}

	Clouds
	{
		Coverage    0.25
		mainFreq    1.0
		twistMagn   3.8
		Velocity    220
		Height      16
		BumpHeight  0.5
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.3		// no data
		Eccentricity   0.0		// no data
		Inclination    0.0		// no data
		AscendingNode  0		// no data
		ArgOfPericen   37.2		// no data
		MeanAnomaly    17.8		// no data
	}
}

Planet "Libran"
{
	ParentBody     "Helios GAM"
	Class          "Terra"

	Radius          6051.5	// no data

	RotationPeriod  26.3	// no data
	Obliquity       31.8	// no data
	EqAscendNode    2.9 	// no data

	Albedo          0.4
	Color         ( 0.70 1.00 0.86 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.2
		Randomize      (0.14, 0.18, 0.96)
		seaLevel        0.42
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.95
		BumpHeight      9.8
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		// Green colors visible on the map
		colorSea       (0.04, 0.20, 0.10, 1.00)
		colorShelf     (0.15, 0.46, 0.28, 1.00)
		colorBeach     (0.82, 0.72, 0.54, 0.00)
		colorDesert    (0.13, 0.17, 0.10, 0.00)
		colorLowland   (0.10, 0.16, 0.07, 0.00)
		colorUpland    (0.09, 0.11, 0.04, 0.00)
		colorRock      (0.22, 0.20, 0.20, 0.00)
		colorSnow      (1.00, 1.00, 1.00, 0.25)
		colorLowPlants (0.18, 0.24, 0.09, 0.00)
		colorUpPlants  (0.15, 0.17, 0.07, 0.00)
	}

	Ocean
	{
		Height          4.116
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.15
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      65
		Greenhouse  22.491		// 25
		Pressure    1.25
		Density	    1.35
		Model      "Earth"
		
		Composition
		{
			N2  75.3207830053
			O2  20.2982091494
			Ar  0.211541975028
			H2O 0.762057231147
			CO2 3.40740863913
		}
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.60	// no data
		Eccentricity    0.03	// no data
		// Extreme inclination visible on the map
		Inclination     12.61	// no data
		AscendingNode   0		// no data
		ArgOfPericen    118.7	// no data
		MeanAnomaly     41.3	// no data
	}
}

DwarfMoon "Hersa"
{
	ParentBody     "Libran"
	Class          "Asteroid"

	Radius          14.3	// no data

	Albedo          0.12
	Color         ( 1.000 1.000 1.000 )

	Orbit
	{
		SemiMajorAxis  8.20e-5	// no data
		Eccentricity   0.0		// no data
		Inclination    0.0		// no data
		AscendingNode  0		// no data
		ArgOfPericen   21.7 	// no data
		MeanAnomaly    17.3 	// no data
	}
}

DwarfMoon "Pandrossas"
{
	ParentBody     "Libran"
	Class          "Asteroid"

	Radius          18.3	// no data

	Albedo          0.12
	Color         ( 1.000 1.000 1.000 )

	Orbit
	{
		SemiMajorAxis  8.38e-5	// no data
		Eccentricity   0.0		// no data
		Inclination    0.0		// no data
		AscendingNode  0		// no data
		ArgOfPericen   91.2 	// no data
		MeanAnomaly    65.7 	// no data
	}
}

Planet "Scorpia"
{
	ParentBody     "Helios GAM"
	Class          "Terra"

	Radius          8281	// no data

	RotationPeriod  22.7	// no data
	Obliquity       16.1	// no data
	EqAscendNode    3.2 	// no data

	Albedo          0.31
	Color         ( 0.70 0.85 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.5
		Randomize      (0.64, 0.37, 0.82)
		seaLevel        0.45
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.90
		BumpHeight      5.9
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		colorLowPlants (0.18, 0.24, 0.09, 0.00)
		colorUpPlants  (0.15, 0.17, 0.07, 0.00)
	}

	Ocean
	{
		Height          2.655
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.11
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      50
		Greenhouse  45.619		// 15
		Pressure    1.40
		Density	    1.95
		Model      "Earth"
		
		Composition
		{
			N2  64.8470825283
			O2  30.5156061532
			Kr  0.417093685413
			H2O 0.638029671051
			CO2 3.58218796207
		}
	}

	Rings
	{
		InnerRadius     16200
		OuterRadius     18800
		FrontBright     1.0
		BackBright      5.0
		Density         0.3
		Exposure        2.5
	}

	Orbit
	{
		SemiMajorAxis   0.778	// no data
		Eccentricity    0.03	// no data
		Inclination     0.77	// no data
		AscendingNode   0		// no data
		ArgOfPericen    18.77	// no data
		MeanAnomaly     313.6	// no data
	}
}

Planet "Sagittarion"
{
	ParentBody     "Helios GAM"
	Class          "Terra"

	Radius          7325.5	// no data

	RotationPeriod  23.1	// no data
	Obliquity       8.3 	// no data
	EqAscendNode    0.16	// no data

	Albedo          0.28
	Color         ( 0.86 0.93 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.64, 0.37, 0.82)
		seaLevel        0.39
		mareDensity     0.0
		craterDensity   0.0
		montesDensity   0.36
		icecapLatitude  0.85
		BumpHeight      7.3
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		colorSea       (0.04, 0.10, 0.20, 1.00)
		colorShelf     (0.15, 0.28, 0.43, 1.00)
		colorBeach     (0.82, 0.73, 0.57, 0.00)
		colorDesert    (0.38, 0.32, 0.22, 0.00)
		colorLowland   (0.34, 0.29, 0.18, 0.00)
		colorUpland    (0.57, 0.54, 0.42, 0.00)
		colorRock      (0.10, 0.10, 0.10, 0.00)
		colorSnow      (1.00, 1.00, 1.00, 0.50)
		colorLowPlants (0.09, 0.12, 0.05, 0.00)
		colorUpPlants  (0.08, 0.08, 0.03, 0.00)
	}

	Ocean
	{
		Height          2.847
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.16
		mainFreq    3.0
		twistMagn   3.5
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      50
		Greenhouse  81.333		// 40
		Pressure    1.35
		Density	    1.10
		Model      "Earth"
		
		Composition
		{
			N2  67.1935004829
			O2  30.5633029887
			Xe  0.228768366412
			H2O 0.604107550945
			CO2 1.41032061105
		}
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.05	// no data
		Eccentricity    0.01	// no data
		Inclination     0.21	// no data
		AscendingNode   0		// no data
		ArgOfPericen    48.33	// no data
		MeanAnomaly     229.6	// no data
	}
}

Planet "Ophion"
{
	ParentBody     "Helios GAM"
	Class          "GasGiant"

	Radius          22500
	Mass            12.6

	RotationPeriod  17.8	// no data
	Obliquity       29.3	// no data
	EqAscendNode    0.0 	// no data

	Albedo          0.66	// no data
	Color         ( 1.00 0.95 0.66 )

	Surface
	{
		Style           0.80
		Randomize      (0.81, 0.76, 0.31)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      5
		twistMagn       0.29
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   1000.0
		Model   "Venus"
		Bright   10.0
		Opacity  1.0
	}

	Rings
	{
		InnerRadius     38500
		OuterRadius     63200
		FrontBright     1.0
		BackBright      5.0
		Density         0.03
		Exposure        2.5
	}

	Orbit
	{
		SemiMajorAxis   2.15	// no data
		Eccentricity    0.06	// no data
		// Extreme inclination visible on the map
		Inclination     -28.6	// no data
		AscendingNode   0		// no data
		ArgOfPericenter 11.3	// no data
		MeanAnomaly     38.9	// no data
	}
}

// Helios Delta ----------------------------------------------------------------
Star "Helios DEL"
{
	ParentBody  "Cyrannus B"
	Class       "K2V"
	MassSol        0.74
	Luminosity  0.26	// no data, use typical value of K1V star
	
	Oblateness  0.0
	
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 70 * 2 * 0.89/(0.89+0.74)
		SemiMajorAxis   76.4417
		Period          434
		Eccentricity    0.0 	// no data
		Inclination     0.0 	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericenter 266.3	// no data
		MeanAnomaly     228.5	// no data
	}
}

Planet "Phoebe"
{
	ParentBody     "Helios DEL"
	Class          "Desert"	// SpaceEngine 0.94 don't support melted planets

	Radius          4968.6	// no data

	Albedo          0.18	// no data

	Atmosphere
	{
		Height      110
		Pressure    0.09
		Density	    0.13
		Model      "Venus"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.27 	// no data
		Eccentricity   0.09 	// no data
		Inclination    2.13 	// no data
		AscendingNode  0		// no data
		ArgOfPericen   27.1 	// no data
		MeanAnomaly    161.5	// no data
	}
}

Planet "Styx"
{
	ParentBody     "Helios DEL"
	Class          "Desert"

	Radius          6956	// no data

	RotationPeriod  26.3	// no data
	Obliquity       1.5 	// no data
	EqAscendNode    1.3 	// no data

	Albedo          0.21
	Color         ( 1.00 0.88 0.75 )

	Surface
	{
		Style           0.75
		Randomize      (0.36, 0.84, 0.66)
		seaLevel        0.36
		mareDensity     0.0
		craterDensity   0.0
		montesDensity   0.33
		BumpHeight      10.5
	}

	Clouds
	{
		Coverage    0.18
		mainFreq    1.6
		twistMagn   1.3
		Velocity    65
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      65
		Pressure    0.12
		Density	    0.19
		Model      "Venus"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.42	// no data
		Eccentricity    0.07	// no data
		// Extreme inclination visible on the map
		Inclination     32.2	// no data
		AscendingNode   48.2	// no data
		ArgOfPericen    38.74	// no data
		MeanAnomaly     118.2	// no data
	}
}

// Helios Delta - Hestia lagrange system ---------------------------------------
Planet "Hestia/Helios DEL 3"
{
	ParentBody     "Helios DEL"
	Class          "GasGiant"

	//Mass            9.86
	Radius          21000

	RotationPeriod  16.8	// no data
	Obliquity       1.1 	// no data
	EqAscendNode    0.7 	// no data

	Albedo          0.64	// no data
	Color         ( 1.00 0.93 0.80 )

	Surface
	{
		Style           0.66
		Randomize      (0.31, 0.87, 0.62)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      5
		twistMagn       0.1
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   800.0
		Model   "Jupiter"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true
    
	Orbit
	{
		// Enter Period to equalize it with Aerilon and Canceron
		Period          0.60919
		SemiMajorAxis   0.65	// no data
		Eccentricity    0.00	// no data
		Inclination     0.8 	// no data
		AscendingNode   0		// no data
		ArgOfPericen    120.7	// no data
		MeanAnomaly     21.31	// no data
	}
}

Moon "Kronos"
{
	ParentBody     "Helios DEL 3"
	Class          "Selena"

	Radius          1223	// no data

	Albedo          0.11
	Color         ( 1.00 1.00 1.00 )

	Surface
	{
		Style           0.25
		BumpHeight      21.2
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.0012	// no data
		Eccentricity    0.001	// no data
		Inclination     0.088	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericen    66.25	// no data
		MeanAnomaly     112.7	// no data
	}
}

DwarfMoon "Rhea"
{
	ParentBody     "Helios DEL 3"
	Class          "Asteroid"

	Radius          121.6	// no data

	Albedo          0.12
	Color         ( 1.000 1.000 1.000 )

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.0012	// no data
		Eccentricity    0.001	// no data
		Inclination     0.088	// no data
		AscendingNode   0.0 	// no data
		ArgOfPericen    66.25	// no data
		MeanAnomaly     172.7	// no data
	}
}

Barycenter "Helios DEL L4"
{
    ParentBody     "Helios DEL"
    
	Orbit
	{
		// Enter Period to equalize it with Canceron and Hestia
		Period          0.60919
		SemiMajorAxis   0.65	// no data
		Eccentricity    0.00	// no data
		Inclination     0.8 	// no data
		AscendingNode   0		// no data
		ArgOfPericen    180.7	// no data
		MeanAnomaly     21.31	// no data
	}
}

Planet "Aerilon"       // Hestia L4
{
	ParentBody     "Helios DEL L4"
	Class          "Terra"

	Radius          7007	// no data

	RotationPeriod  23.75	// no data
	Obliquity       1.8 	// no data
	EqAscendNode    2.1 	// no data

	Albedo          0.4
	Color         ( 0.70 0.85 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.64, 0.77, 0.82)
		seaLevel        0.48
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.85
		BumpHeight      7.3
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          3.504
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.20
		mainFreq    2.5
		twistMagn   3.5
		Velocity    80
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  72.414		// 45
		Pressure    1.3
		Density	    2.1
		Model      "Earth"
		
		Composition
		{
			N2  78.7654025175
			O2  20.0587689181
			Ne  0.305402451473
			H2O 0.210053917414
			CO2 0.66037219556
		}
	}

	NoRings  true
    
    //NoLighting      true
    FixedPosPolar   (0.000000 0.000000 0.000000)
}

Barycenter "Helios DEL L5"
{
    ParentBody     "Helios DEL"
    
	Orbit
	{
		// Enter Period to equalize it with Aerilon and Hestia
		Period          0.60919
		SemiMajorAxis   0.65	// no data
		Eccentricity    0.00	// no data
		Inclination     0.8 	// no data
		AscendingNode   0		// no data
		ArgOfPericen    60.7	// no data
		MeanAnomaly     21.31	// no data
	}
}

Planet "Canceron"      // Hestia L5"
{
	ParentBody     "Helios DEL L5"
	Class          "Terra"

	Radius          8281	// no data

	RotationPeriod  22.12	// no data
	Obliquity       3.8 	// no data
	EqAscendNode    1.2 	// no data

	Albedo          0.4
	Color         ( 0.70 0.85 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.39, 0.77, 0.16)
		seaLevel        0.40
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.95
		BumpHeight      6.2
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		colorSea       (0.02, 0.02, 0.04, 1.00)
		colorShelf     (0.08, 0.08, 0.12, 1.00)
		colorLowPlants (0.08, 0.10, 0.05, 0.00)
		colorUpPlants  (0.09, 0.09, 0.07, 0.00)
	}

	Ocean
	{
		Height          2.48
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.18
		mainFreq    2.1
		twistMagn   3.2
		Velocity    75
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  72.429		// 36
		Pressure    0.81
		Density	    1.05
		Model      "Earth"
		Bright      5.0
		Opacity     0.5
		
		Composition
		{
			N2  68.0364138566
			O2  23.3093283835
			Kr  1.61582349035
			H2O 3.63138529204
			CO2 3.40704897751
		}
	}

	NoRings  true

    //NoLighting      true
    FixedPosPolar   (0.000000 0.000000 0.000000)
}

Planet "Aquaria"
{
	ParentBody     "Helios DEL"
	Class          "Terra"

	Radius          6051.5	// no data

	RotationPeriod  25.2	// no data
	Obliquity       12.2	// no data
	EqAscendNode    2.0 	// no data

	Albedo          0.28
	Color         ( 0.70 0.80 1.00 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
	}

	Surface
	{
		Style           0.0
		Randomize      (0.667, 0.349, 0.571)
		seaLevel        0.55
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.67
		BumpHeight      12.5
	}

	Ocean
	{
		//Height          11.4125
		Height          9.12686
		Hapke           0
		SpotBright      2
		SpotWidth       0.15
		DayAmbient      2
	}

	Clouds
	{
		Coverage    0.18
		mainFreq    1.5
		twistMagn   3.5
		Velocity    80
		Height      15
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      65
		Greenhouse  84.537		// 8
		Pressure    0.9
		Density	    1.2
		Model      "Neptune"
		
		Composition
		{
			N2  74.6537241328
			O2  21.6007343109
			He  0.684479612004
			H2O 1.58171855451
			CO2 1.47934338979
		}
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.83	// no data
		Eccentricity    0.05	// no data
		// Extreme inclination visible on the map
		Inclination     -17.4	// no data
		AscendingNode   0		// no data
		ArgOfPericen    115.6	// no data
		MeanAnomaly     28.37	// no data
	}
}

// Ragnar Sigard ---------------------------------------------------------------
Barycenter "Ragnar-Sigard"
{
	ParentBody     "Cyrannus B"

	Orbit
	{
		// IRL orbit with SMA 110 a.u. must be unstable
		SemiMajorAxis   580		// 110
		Period          889.75
		Eccentricity    0.0 	// no data
		Inclination     0		// no data
		AscendingNode   0		// no data
		ArgOfPericenter 168.5	// no data
		MeanAnomaly     229.3	// no data
	}
}

Planet "Ragnar"
{
	ParentBody     "Ragnar-Sigard"
	Class          "GasGiant"

	Radius          69222
	Mass            24.522

	RotationPeriod  10.27	// no data
	Obliquity       8.5 	// no data
	EqAscendNode    3.2 	// no data

	Albedo          0.66	// no data
	Color         ( 0.75 0.75 1.0 )

	Surface
	{
		Randomize      (0.13, 0.0087, 0.26)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      4
		twistMagn       0.3
	}
	
	Clouds
	{
		Coverage  0.12
	}

	Atmosphere
	{
		Height   1000.0
		Model   "Earth"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.339535e-6
		Eccentricity    0.0
		Inclination     0.04
		AscendingNode   0
		ArgOfPericen    113.0
		MeanAnomaly     315.7
	}
}

Moon "Sigard"
{
	ParentBody     "Ragnar-Sigard"
	Class          "Selena"

	Radius          2011	// no data
	Mass            0.014106

	Albedo          0.3
	Color         ( 0.850 0.850 1.000 )

	Orbit
	{
		SemiMajorAxis  0.002329	// no data
		Eccentricity   0.0		// no data
		Inclination    0.04 	// no data
		AscendingNode  0		// no data
		ArgOfPericen   293.0	// no data
		MeanAnomaly    315.7	// no data
	}
}

//------------------------------------------------------------------------------
// Acheron asteroid belt -------------------------------------------------------
//------------------------------------------------------------------------------
Asteroid "Acheron 1"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.675341051736451e-07
	Radius		49.90261177518093

	RotationPeriod	6.760670822907119

	Obliquity		301.8862485640621

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5378210457436311
		Eccentricity	0.06531370682023399
		Inclination		-2.061225760346482
		AscendingNode	346.4777401079137
		ArgOfPericen	61.72834512741009
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 2"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.9187313753638264e-07
	Radius		50.97636983303981

	RotationPeriod	6.383991419655628

	Obliquity		61.429768783277034

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.539348501873684
		Eccentricity	0.06518645742612543
		Inclination		0.6450950422101086
		AscendingNode	44.476244798542204
		ArgOfPericen	159.83919965713847
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 3"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.345823809200089e-08
	Radius		19.131944482684684

	RotationPeriod	1.3742318622643763

	Obliquity		126.72193851432026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5326420881956571
		Eccentricity	0.08697437583967277
		Inclination		-0.9988943044347153
		AscendingNode	150.09125721078712
		ArgOfPericen	112.16481599821536
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 4"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1563880280576904e-06
	Radius		82.55120495311498

	RotationPeriod	6.3038036833012185

	Obliquity		219.7655410524928

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5497182430890263
		Eccentricity	0.039412922019442555
		Inclination		0.1957989279781968
		AscendingNode	302.6854726495867
		ArgOfPericen	359.45275472504426
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 4.1"
{
	ParentBody	"Acheron 4"
	Class		"Asteroid"
	Mass		1.039205563673317e-08
	Radius		17.162848764267164

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.486640384951687e-06
		Eccentricity	0.0046361363272414465
		Inclination		-2.550450023469092
		AscendingNode	331.11495479549666
		ArgOfPericen	33.825319112236286
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 5"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.406808315884501e-07
	Radius		49.60837419785387

	RotationPeriod	5.92781339769063

	Obliquity		272.63602682920856

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5129959399401159
		Eccentricity	0.0687237755282807
		Inclination		-0.33175417832394083
		AscendingNode	148.16147947470986
		ArgOfPericen	284.3508730128383
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 6"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5535927835773249
		Eccentricity	0.050927720018640335
		Inclination		-1.7103816817007242
		AscendingNode	108.57288301857474
		ArgOfPericen	305.63020645412354
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 6 A"
{
	ParentBody	"Acheron 6"
	Class		"Asteroid"
	Mass		5.675839881354122e-07
	Radius		68.45520899066118

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005960261125829035
		Eccentricity	0.003472168911835911
		Inclination		248.2982789467139
		AscendingNode	285.139117857445
		ArgOfPericen	306.16876108512616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 6 B"
{
	ParentBody	"Acheron 6"
	Class		"Asteroid"
	Mass		4.349494168467584e-07
	Radius		62.64350366144206

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005960261125829035
		Eccentricity	0.003472168911835911
		Inclination		248.2982789467139
		AscendingNode	285.139117857445
		ArgOfPericen	126.16876108512616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 7"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5439933234876737
		Eccentricity	0.05097512620739401
		Inclination		-1.9895368741861879
		AscendingNode	10.536940062284694
		ArgOfPericen	186.5853955536531
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 7 A"
{
	ParentBody	"Acheron 7"
	Class		"Asteroid"
	Mass		1.6181459549502885e-07
	Radius		41.48052611131316

	Orbit
	{
		Epoch			2457395.5
		Period			0.007155269461227516
		Eccentricity	0.004985973087075605
		Inclination		312.8957098079606
		AscendingNode	317.42011411816054
		ArgOfPericen	200.1836699698178
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 7 B"
{
	ParentBody	"Acheron 7"
	Class		"Asteroid"
	Mass		4.87798938845271e-08
	Radius		27.813265135824686

	Orbit
	{
		Epoch			2457395.5
		Period			0.007155269461227516
		Eccentricity	0.004985973087075605
		Inclination		312.8957098079606
		AscendingNode	317.42011411816054
		ArgOfPericen	20.1836699698178
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 8"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5466037212861279
		Eccentricity	0.05996609878100054
		Inclination		-1.8732640425315992
		AscendingNode	127.47029196186084
		ArgOfPericen	333.07405392683125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 8 A"
{
	ParentBody	"Acheron 8"
	Class		"Asteroid"
	Mass		3.1454022377287264e-07
	Radius		51.80761978543201

	Orbit
	{
		Epoch			2457395.5
		Period			0.0077690201483456775
		Eccentricity	0.007332267520892437
		Inclination		68.1071870922386
		AscendingNode	306.83851765112104
		ArgOfPericen	290.659885764246
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 8 B"
{
	ParentBody	"Acheron 8"
	Class		"Asteroid"
	Mass		4.0003463413419784e-08
	Radius		26.053581958587735

	Orbit
	{
		Epoch			2457395.5
		Period			0.0077690201483456775
		Eccentricity	0.007332267520892437
		Inclination		68.1071870922386
		AscendingNode	306.83851765112104
		ArgOfPericen	110.65988576424598
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 9"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5558028307522792
		Eccentricity	0.04004356721003235
		Inclination		-2.0203152523216508
		AscendingNode	6.91214762944147
		ArgOfPericen	9.687410009795148
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 9 A"
{
	ParentBody	"Acheron 9"
	Class		"Asteroid"
	Mass		7.12217397219323e-07
	Radius		71.52445161073602

	Orbit
	{
		Epoch			2457395.5
		Period			0.006268563595430079
		Eccentricity	0.004677001099297116
		Inclination		50.303379832634995
		AscendingNode	43.10948064819137
		ArgOfPericen	151.08065910492857
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 9 B"
{
	ParentBody	"Acheron 9"
	Class		"Asteroid"
	Mass		2.1423511727705623e-07
	Radius		47.923356862482066

	Orbit
	{
		Epoch			2457395.5
		Period			0.006268563595430079
		Eccentricity	0.004677001099297116
		Inclination		50.303379832634995
		AscendingNode	43.10948064819137
		ArgOfPericen	331.0806591049286
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 10"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1715526886755425e-07
	Radius		36.63584087860246

	RotationPeriod	8.688000131999221

	Obliquity		7.263923811466104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.554034790094959
		Eccentricity	0.07857594351603767
		Inclination		-1.2410300452147918
		AscendingNode	51.12737682001948
		ArgOfPericen	152.9674926073384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 11"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2293185611678875e-07
	Radius		49.38036230589428

	RotationPeriod	8.515837189422859

	Obliquity		170.366144607712

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4916036582084683
		Eccentricity	0.04625024597969484
		Inclination		1.2975385185510648
		AscendingNode	322.77925325806433
		ArgOfPericen	253.46575214515985
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 11.1"
{
	ParentBody	"Acheron 11"
	Class		"Asteroid"
	Mass		1.8325132571911934e-10
	Radius		4.625719242653236

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.470069294056699e-06
		Eccentricity	0.004284109153459441
		Inclination		-6.125888761165206
		AscendingNode	206.63849539753656
		ArgOfPericen	226.9930352510878
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 12"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.726662905899835e-07
	Radius		74.86006199471936

	RotationPeriod	7.836443513680221

	Obliquity		249.950039233813

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5261340830147297
		Eccentricity	0.03421983715132702
		Inclination		0.36831747191512226
		AscendingNode	273.55092918766394
		ArgOfPericen	249.75452354000032
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 13"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.691916538840292e-07
	Radius		65.3328615190007

	RotationPeriod	8.187113206807622

	Obliquity		18.429715446244437

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5332211333956476
		Eccentricity	0.0777917265540083
		Inclination		-1.4080781098020012
		AscendingNode	305.8117698323177
		ArgOfPericen	114.90356389129533
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 14"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.1639804956274415e-07
	Radius		47.68748320522456

	RotationPeriod	3.2067079891916284

	Obliquity		294.5786803242359

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5484943814632732
		Eccentricity	0.08280681654672414
		Inclination		-0.9096881254164337
		AscendingNode	305.4797895252798
		ArgOfPericen	136.58229553748555
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 15"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.987063939905306e-07
	Radius		75.46984909937031

	RotationPeriod	7.5728939552551475

	Obliquity		98.44401263594797

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5452040432655831
		Eccentricity	0.04116216057322197
		Inclination		0.18109834585872867
		AscendingNode	121.6391471783358
		ArgOfPericen	156.23258776216875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 16"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5825718554647062
		Eccentricity	0.05315573273581437
		Inclination		0.5557074827757522
		AscendingNode	258.8696469817629
		ArgOfPericen	74.93005656591654
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 16 A"
{
	ParentBody	"Acheron 16"
	Class		"Asteroid"
	Mass		4.832992365870653e-07
	Radius		58.499318339727175

	Orbit
	{
		Epoch			2457395.5
		Period			0.004088089596135853
		Eccentricity	0.004676664302996427
		Inclination		343.015022234404
		AscendingNode	348.073385922208
		ArgOfPericen	238.7779228513235
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 16 B"
{
	ParentBody	"Acheron 16"
	Class		"Asteroid"
	Mass		3.1531997671068257e-07
	Radius		50.73752337551965

	Orbit
	{
		Epoch			2457395.5
		Period			0.004088089596135853
		Eccentricity	0.004676664302996427
		Inclination		343.015022234404
		AscendingNode	348.073385922208
		ArgOfPericen	58.777922851323524
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 17"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.457454464446252e-08
	Radius		31.20108863581623

	RotationPeriod	6.895338594333432

	Obliquity		255.80862583786705

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5449538715065148
		Eccentricity	0.053679392221301164
		Inclination		-2.0651097067152815
		AscendingNode	341.31611343121466
		ArgOfPericen	349.617652198488
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 17.1"
{
	ParentBody	"Acheron 17"
	Class		"Asteroid"
	Mass		3.814202766403849e-11
	Radius		2.61788494386105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8663448791064196e-06
		Eccentricity	0.004215859789880247
		Inclination		-23.051089944453896
		AscendingNode	215.0177038282758
		ArgOfPericen	288.0480196986888
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 17.2"
{
	ParentBody	"Acheron 17"
	Class		"Asteroid"
	Mass		6.946192402152889e-10
	Radius		6.887552136213506

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.0367274893369277e-06
		Eccentricity	0.005983596312480422
		Inclination		-1.7007181321098692
		AscendingNode	167.42656623342558
		ArgOfPericen	179.8542656720224
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 17.3"
{
	ParentBody	"Acheron 17"
	Class		"Asteroid"
	Mass		5.68298403085555e-10
	Radius		6.441812923525948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.841750384944182e-06
		Eccentricity	0.005676586685526035
		Inclination		24.061168003256164
		AscendingNode	298.95197940197295
		ArgOfPericen	48.73613900789421
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 18"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.0751379329260015e-07
	Radius		55.287912837742276

	RotationPeriod	9.120354681741707

	Obliquity		316.05618779218935

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5477667498512826
		Eccentricity	0.06551296720618868
		Inclination		3.3682909062021125
		AscendingNode	255.96004213106238
		ArgOfPericen	263.37462965086195
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 19"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.943457453647099e-07
	Radius		49.337844660427145

	RotationPeriod	5.67491690357051

	Obliquity		269.7175238747855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5286396323680167
		Eccentricity	0.059791869357425684
		Inclination		0.25941266299026733
		AscendingNode	56.18308894869913
		ArgOfPericen	42.66386485970389
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 19.1"
{
	ParentBody	"Acheron 19"
	Class		"Asteroid"
	Mass		1.0675460026526783e-10
	Radius		3.5184910605812263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.628988914609535e-07
		Eccentricity	0.006437101589760122
		Inclination		-19.0048192585624
		AscendingNode	269.4956955403124
		ArgOfPericen	245.7770671065195
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 19.2"
{
	ParentBody	"Acheron 19"
	Class		"Asteroid"
	Mass		1.394675161786014e-09
	Radius		8.286769798063485

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.4346775503578827e-06
		Eccentricity	0.004284226135143954
		Inclination		-11.361191810356738
		AscendingNode	129.1982293302322
		ArgOfPericen	12.587215110857933
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 19.3"
{
	ParentBody	"Acheron 19"
	Class		"Asteroid"
	Mass		3.4819234054344055e-10
	Radius		5.217958934242103

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.778806008659772e-07
		Eccentricity	0.003858917356156548
		Inclination		-24.333501396147586
		AscendingNode	213.7742213831126
		ArgOfPericen	137.60714039496364
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 20"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5608888405290601e-07
	Radius		41.940315344936394

	RotationPeriod	2.662851382112842

	Obliquity		164.34080780964683

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5519866191366145
		Eccentricity	0.059288390045576296
		Inclination		0.17971474080876157
		AscendingNode	187.65070490109045
		ArgOfPericen	287.22488063086945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 20.1"
{
	ParentBody	"Acheron 20"
	Class		"Asteroid"
	Mass		1.24548431588093e-10
	Radius		3.890037494287377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.689390565234041e-06
		Eccentricity	0.0026458963644296414
		Inclination		-29.437604584806852
		AscendingNode	147.83025166751423
		ArgOfPericen	148.9853428182612
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 21"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.756190335008472e-07
	Radius		71.79182844661909

	RotationPeriod	3.86514669488047

	Obliquity		128.02572190100616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5306895691245351
		Eccentricity	0.041605920261550924
		Inclination		-3.2999862700965528
		AscendingNode	264.92121646009264
		ArgOfPericen	163.3576091517893
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 22"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.38673054403864e-07
	Radius		50.64771000104888

	RotationPeriod	7.174593946333785

	Obliquity		193.8466689581753

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5304949021038675
		Eccentricity	0.037026562654858305
		Inclination		1.752077724765575
		AscendingNode	121.62441885626325
		ArgOfPericen	7.7451406150950675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 23"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1912768512135805e-07
	Radius		38.18297429926945

	RotationPeriod	7.530086289796167

	Obliquity		351.48822927995184

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5118936595082253
		Eccentricity	0.03835980048551586
		Inclination		1.5223862784034088
		AscendingNode	238.95645271533672
		ArgOfPericen	304.5606302576765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 24"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5039890800846206
		Eccentricity	0.06192793624292368
		Inclination		-0.3425489268101982
		AscendingNode	2.1700531263367173
		ArgOfPericen	52.516141205898215
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 24 A"
{
	ParentBody	"Acheron 24"
	Class		"Asteroid"
	Mass		6.344375377382033e-07
	Radius		65.21033201541425

	Orbit
	{
		Epoch			2457395.5
		Period			0.004245195153458533
		Eccentricity	0.0061519023519666675
		Inclination		168.95824371690478
		AscendingNode	26.083776805867764
		ArgOfPericen	298.2995641847558
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 24 B"
{
	ParentBody	"Acheron 24"
	Class		"Asteroid"
	Mass		1.988175196432664e-08
	Radius		20.55914288621341

	Orbit
	{
		Epoch			2457395.5
		Period			0.004245195153458533
		Eccentricity	0.0061519023519666675
		Inclination		168.95824371690478
		AscendingNode	26.083776805867764
		ArgOfPericen	118.29956418475581
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 25"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.605729313474695e-07
	Radius		52.57335919441128

	RotationPeriod	4.050725320797736

	Obliquity		129.02706206814727

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5465891549904793
		Eccentricity	0.02826407401933262
		Inclination		0.7833166411430398
		AscendingNode	57.55575880015111
		ArgOfPericen	187.85261309712763
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 26"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.991082856980162e-08
	Radius		37.82608731868906

	RotationPeriod	9.728223202927513

	Obliquity		3.7587356449210585

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5266903254875143
		Eccentricity	0.035755082295704045
		Inclination		2.6860624738596117
		AscendingNode	223.8160783788407
		ArgOfPericen	264.7665743788634
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 27"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5258871815829865e-07
	Radius		40.951061570809955

	RotationPeriod	3.884482304058704

	Obliquity		10.261269457860859

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5360231418433664
		Eccentricity	0.04539344612465322
		Inclination		-0.7323963416091377
		AscendingNode	73.5540548192384
		ArgOfPericen	259.0198497021712
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 28"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5490781758530305
		Eccentricity	0.04934982736187151
		Inclination		-1.9828951236566232
		AscendingNode	358.17890279002944
		ArgOfPericen	162.99762072519317
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 28 A"
{
	ParentBody	"Acheron 28"
	Class		"Asteroid"
	Mass		1.6204135536492663e-07
	Radius		43.9010189450583

	Orbit
	{
		Epoch			2457395.5
		Period			0.00489170577790133
		Eccentricity	0.004042657644031727
		Inclination		258.17381840422547
		AscendingNode	254.62868368393987
		ArgOfPericen	85.24510432703076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 28 B"
{
	ParentBody	"Acheron 28"
	Class		"Asteroid"
	Mass		1.1284198999124467e-08
	Radius		18.061600145116785

	Orbit
	{
		Epoch			2457395.5
		Period			0.00489170577790133
		Eccentricity	0.004042657644031727
		Inclination		258.17381840422547
		AscendingNode	254.62868368393987
		ArgOfPericen	265.24510432703073
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 29"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.5031169300221787e-07
	Radius		53.69655869562846

	RotationPeriod	5.5231809814632715

	Obliquity		70.5832619035336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5307588616278771
		Eccentricity	0.038505746732356946
		Inclination		2.187206806527058
		AscendingNode	119.41686527858005
		ArgOfPericen	101.54508431661003
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 30"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.991230807179232e-07
	Radius		59.27614106555734

	RotationPeriod	5.430623762197162

	Obliquity		134.58780105918692

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5373751202412905
		Eccentricity	0.06827979286032898
		Inclination		0.648266421993841
		AscendingNode	288.41900368013756
		ArgOfPericen	214.08554828008138
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 30.1"
{
	ParentBody	"Acheron 30"
	Class		"Asteroid"
	Mass		5.169270518780824e-10
	Radius		5.997272630715652

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.645524559015154e-06
		Eccentricity	0.001541876209318197
		Inclination		24.24314007779978
		AscendingNode	291.1685221836373
		ArgOfPericen	256.97968268673816
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 30.2"
{
	ParentBody	"Acheron 30"
	Class		"Asteroid"
	Mass		1.7661363022211773e-10
	Radius		4.1926194456199415

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.294024081745613e-06
		Eccentricity	0.005490009089686306
		Inclination		-2.681657227297922
		AscendingNode	51.274418318977354
		ArgOfPericen	50.636563264277854
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 31"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5269797307330615
		Eccentricity	0.06366609773377375
		Inclination		-0.9229187480026335
		AscendingNode	71.16282044628907
		ArgOfPericen	136.7900521940575
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 31 A"
{
	ParentBody	"Acheron 31"
	Class		"Asteroid"
	Mass		3.217711520711674e-07
	Radius		52.518252003585914

	Orbit
	{
		Epoch			2457395.5
		Period			0.0053789436880869
		Eccentricity	0.004479057770979123
		Inclination		181.89883842698853
		AscendingNode	105.21812404404213
		ArgOfPericen	278.1657797256075
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 31 B"
{
	ParentBody	"Acheron 31"
	Class		"Asteroid"
	Mass		1.1527730613256201e-07
	Radius		37.300028815285

	Orbit
	{
		Epoch			2457395.5
		Period			0.0053789436880869
		Eccentricity	0.004479057770979123
		Inclination		181.89883842698853
		AscendingNode	105.21812404404213
		ArgOfPericen	98.16577972560748
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 32"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.671180282657642e-09
	Radius		13.967491392385043

	RotationPeriod	5.992894701925016

	Obliquity		75.9006145585554

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5278954222652557
		Eccentricity	0.04040943112169779
		Inclination		-1.0248116151923021
		AscendingNode	27.848359897187155
		ArgOfPericen	62.92134210239439
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 33"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5223111914215255
		Eccentricity	0.059737501177250886
		Inclination		-1.0970440804529564
		AscendingNode	272.4267957695785
		ArgOfPericen	163.2614601777753
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 33 A"
{
	ParentBody	"Acheron 33"
	Class		"Asteroid"
	Mass		4.3356787748549945e-07
	Radius		62.80727530800046

	Orbit
	{
		Epoch			2457395.5
		Period			0.002286890033332204
		Eccentricity	0.002188910687450102
		Inclination		42.95033245577854
		AscendingNode	52.17048349867031
		ArgOfPericen	186.53390018299234
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 33 B"
{
	ParentBody	"Acheron 33"
	Class		"Asteroid"
	Mass		3.257842007334373e-07
	Radius		57.09975702116319

	Orbit
	{
		Epoch			2457395.5
		Period			0.002286890033332204
		Eccentricity	0.002188910687450102
		Inclination		42.95033245577854
		AscendingNode	52.17048349867031
		ArgOfPericen	6.53390018299234
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 34"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.451580624994695e-08
	Radius		18.023756133135294

	RotationPeriod	5.403572300971702

	Obliquity		190.04769537701983

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5158325834224846
		Eccentricity	0.06036665610082792
		Inclination		-1.72947623821394
		AscendingNode	71.85606410236825
		ArgOfPericen	317.00518527079186
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 35"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.43341603812823e-07
	Radius		63.0093800417513

	RotationPeriod	5.284549936720023

	Obliquity		223.9757823086842

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.573948610219866
		Eccentricity	0.06193575229255642
		Inclination		-0.2368397440607077
		AscendingNode	27.420117565559146
		ArgOfPericen	302.1551233703895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 36"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.49291312458347436
		Eccentricity	0.05159915276134583
		Inclination		0.12410355120015845
		AscendingNode	340.8944214825068
		ArgOfPericen	247.9482482870719
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 36 A"
{
	ParentBody	"Acheron 36"
	Class		"Asteroid"
	Mass		1.8276447796402484e-07
	Radius		44.888569728349204

	Orbit
	{
		Epoch			2457395.5
		Period			0.004478521705410357
		Eccentricity	0.00834555589735557
		Inclination		163.16131373750537
		AscendingNode	139.56770555106746
		ArgOfPericen	182.3554492048343
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 36 B"
{
	ParentBody	"Acheron 36"
	Class		"Asteroid"
	Mass		1.520872027537893e-07
	Radius		42.22173365767725

	Orbit
	{
		Epoch			2457395.5
		Period			0.004478521705410357
		Eccentricity	0.00834555589735557
		Inclination		163.16131373750537
		AscendingNode	139.56770555106746
		ArgOfPericen	2.355449204834258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 37"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.665325754989528e-07
	Radius		48.630791886725845

	RotationPeriod	3.862337377331669

	Obliquity		217.25316087662358

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5311427624507842
		Eccentricity	0.0433204765864849
		Inclination		-1.520366594660663
		AscendingNode	293.6426188953143
		ArgOfPericen	251.1607498133398
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 38"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8959877829605042e-07
	Radius		44.15951652276841

	RotationPeriod	6.492541986618837

	Obliquity		109.28420263054862

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5221829408826429
		Eccentricity	0.0867268691703591
		Inclination		-0.5501257240727475
		AscendingNode	171.2300216130134
		ArgOfPericen	2.971415275657261
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 39"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.573842576608045e-11
	Radius		3.2269904252550035

	RotationPeriod	6.932301237940241

	Obliquity		323.8989121912062

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5426192529999705
		Eccentricity	0.053886178167775654
		Inclination		2.7179467946898868
		AscendingNode	211.266642594199
		ArgOfPericen	8.514877069087937
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 40"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.525922410765687
		Eccentricity	0.03334815981977228
		Inclination		0.5027500104367533
		AscendingNode	28.116065524626947
		ArgOfPericen	325.541109271714
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 40 A"
{
	ParentBody	"Acheron 40"
	Class		"Asteroid"
	Mass		3.573699411113818e-07
	Radius		54.26032952869207

	Orbit
	{
		Epoch			2457395.5
		Period			0.0068916265143928205
		Eccentricity	0.005332132467631959
		Inclination		2.4569402860736655
		AscendingNode	0.4356611319380477
		ArgOfPericen	329.1900369010827
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 40 B"
{
	ParentBody	"Acheron 40"
	Class		"Asteroid"
	Mass		7.764707843124226e-09
	Radius		15.14089193999257

	Orbit
	{
		Epoch			2457395.5
		Period			0.0068916265143928205
		Eccentricity	0.005332132467631959
		Inclination		2.4569402860736655
		AscendingNode	0.4356611319380477
		ArgOfPericen	149.1900369010827
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 41"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.073392996852448e-07
	Radius		53.73462577341413

	RotationPeriod	6.579138424518495

	Obliquity		137.70431882959753

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5347284585944828
		Eccentricity	0.03978800232407154
		Inclination		-0.896316277353511
		AscendingNode	229.36446683200026
		ArgOfPericen	200.46401919406654
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 42"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5308058301071338
		Eccentricity	0.06500779119041933
		Inclination		0.9949224687196111
		AscendingNode	84.94733608291693
		ArgOfPericen	320.00427509878824
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 42 A"
{
	ParentBody	"Acheron 42"
	Class		"Asteroid"
	Mass		7.085485190697625e-07
	Radius		66.98804658255672

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033116564779652963
		Eccentricity	0.007099252491352759
		Inclination		285.6397343298336
		AscendingNode	334.63850986889923
		ArgOfPericen	255.80331212493522
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 42 B"
{
	ParentBody	"Acheron 42"
	Class		"Asteroid"
	Mass		5.541119116113965e-07
	Radius		61.71725629783799

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033116564779652963
		Eccentricity	0.007099252491352759
		Inclination		285.6397343298336
		AscendingNode	334.63850986889923
		ArgOfPericen	75.80331212493525
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 43"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1712713658955824e-07
	Radius		36.34800227568449

	RotationPeriod	9.440049419284538

	Obliquity		9.457566870802783

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5616139575377354
		Eccentricity	0.08625986134177416
		Inclination		1.071975249019987
		AscendingNode	44.09044500870708
		ArgOfPericen	237.3350232194353
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 44"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.67197624179894e-07
	Radius		52.83799030582618

	RotationPeriod	6.988937149095909

	Obliquity		120.75693068241151

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.542167836770047
		Eccentricity	0.004294789739947527
		Inclination		0.28654530298388103
		AscendingNode	81.66654693982215
		ArgOfPericen	244.11856802316342
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 45"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.492555154488085e-08
	Radius		32.62898567310628

	RotationPeriod	6.335797195300203

	Obliquity		281.62063703834997

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5868
		Eccentricity	0.02744735707024389
		Inclination		-5.0
		AscendingNode	262.0713727587791
		ArgOfPericen	273.62578278768433
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 46"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5602698975374081
		Eccentricity	0.04581553104601217
		Inclination		-1.8331505439073845
		AscendingNode	287.3674062613429
		ArgOfPericen	311.0125890165072
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 46 A"
{
	ParentBody	"Acheron 46"
	Class		"Asteroid"
	Mass		3.847904093432235e-08
	Radius		26.370915183390743

	Orbit
	{
		Epoch			2457395.5
		Period			0.006254062009892048
		Eccentricity	0.0037314286947738268
		Inclination		301.94522204597087
		AscendingNode	153.08651489877968
		ArgOfPericen	340.5989513385727
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 46 B"
{
	ParentBody	"Acheron 46"
	Class		"Asteroid"
	Mass		3.74555475777861e-09
	Radius		12.130792454612774

	Orbit
	{
		Epoch			2457395.5
		Period			0.006254062009892048
		Eccentricity	0.0037314286947738268
		Inclination		301.94522204597087
		AscendingNode	153.08651489877968
		ArgOfPericen	160.59895133857276
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 47"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.166512024050477e-07
	Radius		61.0782414243799

	RotationPeriod	3.4198686562455403

	Obliquity		332.5053684967805

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5544217037547775
		Eccentricity	0.05319603220051403
		Inclination		1.5368719617426283
		AscendingNode	118.890165677523
		ArgOfPericen	68.01699465075718
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 48"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.345031151622535e-07
	Radius		69.3904170349539

	RotationPeriod	5.217111804029493

	Obliquity		353.6444234364295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5456811418715718
		Eccentricity	0.0436997213096495
		Inclination		0.4658807065855372
		AscendingNode	97.23297557297661
		ArgOfPericen	45.91847055056545
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 49"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.534463740366709
		Eccentricity	0.0735983198240104
		Inclination		1.6996237281983477
		AscendingNode	129.74563826760263
		ArgOfPericen	186.06209452739006
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 49 A"
{
	ParentBody	"Acheron 49"
	Class		"Asteroid"
	Mass		8.595514829145703e-08
	Radius		35.49471403661915

	Orbit
	{
		Epoch			2457395.5
		Period			0.002216295505387827
		Eccentricity	0.005053011305096773
		Inclination		59.172741738367726
		AscendingNode	310.61119563839543
		ArgOfPericen	329.64210091968204
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 49 B"
{
	ParentBody	"Acheron 49"
	Class		"Asteroid"
	Mass		1.3450540546419503e-08
	Radius		19.12726888083389

	Orbit
	{
		Epoch			2457395.5
		Period			0.002216295505387827
		Eccentricity	0.005053011305096773
		Inclination		59.172741738367726
		AscendingNode	310.61119563839543
		ArgOfPericen	149.64210091968204
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 50"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.065456022413623e-08
	Radius		31.944795223254907

	RotationPeriod	6.0642267288171

	Obliquity		201.37264387709192

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5252320908453998
		Eccentricity	0.0980008361631426
		Inclination		0.9498300033947514
		AscendingNode	273.531716085923
		ArgOfPericen	117.28135917864653
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 50.1"
{
	ParentBody	"Acheron 50"
	Class		"Asteroid"
	Mass		3.546435932535616e-10
	Radius		5.233447102578415

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0377886635675994e-06
		Eccentricity	0.0028865537076341223
		Inclination		2.2266486777565944
		AscendingNode	64.32149268906743
		ArgOfPericen	170.49816448145307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 51"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6426419018098067e-07
	Radius		54.86667871224897

	RotationPeriod	6.789507482039273

	Obliquity		190.85014224537645

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5605256614804682
		Eccentricity	0.07598125890197813
		Inclination		-0.2483430286153683
		AscendingNode	307.16432392547233
		ArgOfPericen	154.65256882078086
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 51.1"
{
	ParentBody	"Acheron 51"
	Class		"Asteroid"
	Mass		5.241300644977245e-10
	Radius		6.194166415102078

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.2040005952746665e-06
		Eccentricity	0.0037871449260984107
		Inclination		22.918831844059234
		AscendingNode	36.21313107893326
		ArgOfPericen	349.7515030739899
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 52"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.341415655373741e-08
	Radius		23.73460136787145

	RotationPeriod	5.307095968633993

	Obliquity		151.87492481451264

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5292816463392087
		Eccentricity	0.04204387469051192
		Inclination		-0.7535886898469653
		AscendingNode	225.63701982923382
		ArgOfPericen	154.29225181197208
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 53"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4111760585029747e-07
	Radius		39.94389536706852

	RotationPeriod	3.567952513380009

	Obliquity		24.910721338620196

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5365815375669852
		Eccentricity	0.04623071738231392
		Inclination		-0.701603707579304
		AscendingNode	296.9773054252506
		ArgOfPericen	37.32909360452616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 54"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.653298335074889e-08
	Radius		35.58659389732388

	RotationPeriod	8.751262090568964

	Obliquity		148.67023210521012

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5221200187453585
		Eccentricity	0.0487855024110713
		Inclination		-0.3485871074196324
		AscendingNode	331.5975210803486
		ArgOfPericen	101.23773089799488
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 55"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.88162671047134e-07
	Radius		63.8021411798519

	RotationPeriod	6.746309565316121

	Obliquity		119.15166653680336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5270623857393224
		Eccentricity	0.06166265029585526
		Inclination		0.9318821579690033
		AscendingNode	59.816380400213745
		ArgOfPericen	270.35707586221815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 56"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.6236222659220176e-07
	Radius		49.55490665732345

	RotationPeriod	6.434719180061111

	Obliquity		5.7638556326216595

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5447798863949711
		Eccentricity	0.03864919339320921
		Inclination		-1.3675859796412746
		AscendingNode	284.2127517187759
		ArgOfPericen	42.91994395136431
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 57"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8671178482107144e-07
	Radius		42.25065933045608

	RotationPeriod	6.605605270936443

	Obliquity		141.40147180544193

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5517716649210295
		Eccentricity	0.06383040030306208
		Inclination		-1.0815544584985057
		AscendingNode	252.0118239132745
		ArgOfPericen	84.20798652192477
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 58"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.046542372388263e-06
	Radius		82.38385982087135

	RotationPeriod	2.241599210050836

	Obliquity		233.39038303768237

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5465111650094135
		Eccentricity	0.07647185593177484
		Inclination		0.5106514673371769
		AscendingNode	195.90609796388566
		ArgOfPericen	347.7006897191037
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 59"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.3492081447160615e-07
	Radius		65.41905665492429

	RotationPeriod	6.651987828136964

	Obliquity		254.65403446159655

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5493654638234017
		Eccentricity	0.034113832161917136
		Inclination		2.9602922355676675
		AscendingNode	160.99996234168287
		ArgOfPericen	148.5109188952324
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 60"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5418605637071473
		Eccentricity	0.08122211681585183
		Inclination		0.8112541104700937
		AscendingNode	17.569364238885285
		ArgOfPericen	148.48737542452997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 60 A"
{
	ParentBody	"Acheron 60"
	Class		"Asteroid"
	Mass		1.223484515527714e-07
	Radius		37.01758084977335

	Orbit
	{
		Epoch			2457395.5
		Period			0.005213725854617708
		Eccentricity	0.006086135390852604
		Inclination		62.586961204160325
		AscendingNode	315.0285574665023
		ArgOfPericen	156.6517355186681
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 60 B"
{
	ParentBody	"Acheron 60"
	Class		"Asteroid"
	Mass		2.54040021920152e-08
	Radius		21.92010289085445

	Orbit
	{
		Epoch			2457395.5
		Period			0.005213725854617708
		Eccentricity	0.006086135390852604
		Inclination		62.586961204160325
		AscendingNode	315.0285574665023
		ArgOfPericen	336.6517355186681
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 61"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5533634632328006
		Eccentricity	0.06392921524814607
		Inclination		0.12055527465063032
		AscendingNode	196.6695669420637
		ArgOfPericen	113.33364113353232
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 61 A"
{
	ParentBody	"Acheron 61"
	Class		"Asteroid"
	Mass		3.12505808999191e-07
	Radius		52.90541143621104

	Orbit
	{
		Epoch			2457395.5
		Period			0.007465519996370091
		Eccentricity	0.004152238269305022
		Inclination		31.38386380603722
		AscendingNode	223.54070837027115
		ArgOfPericen	357.6337398790766
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 61 B"
{
	ParentBody	"Acheron 61"
	Class		"Asteroid"
	Mass		8.504220643648723e-09
	Radius		15.913250688604153

	Orbit
	{
		Epoch			2457395.5
		Period			0.007465519996370091
		Eccentricity	0.004152238269305022
		Inclination		31.38386380603722
		AscendingNode	223.54070837027115
		ArgOfPericen	177.63373987907653
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 62"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.319030312188598e-07
	Radius		62.14217234483885

	RotationPeriod	3.474802793834472

	Obliquity		137.9463004249547

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5267820820310962
		Eccentricity	0.045391638055387894
		Inclination		1.1302111547159062
		AscendingNode	0.889429066643963
		ArgOfPericen	325.28217985657454
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 62.1"
{
	ParentBody	"Acheron 62"
	Class		"Asteroid"
	Mass		2.0612090453978086e-10
	Radius		4.530536384534216

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.607586166171858e-06
		Eccentricity	0.004519127400803762
		Inclination		26.60727460282631
		AscendingNode	115.07016811897947
		ArgOfPericen	337.92764922203037
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 62.2"
{
	ParentBody	"Acheron 62"
	Class		"Asteroid"
	Mass		1.3455139370623694e-09
	Radius		8.46717123706518

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.95131207942998e-06
		Eccentricity	0.006999664300713278
		Inclination		-26.264558894705736
		AscendingNode	349.62486025643915
		ArgOfPericen	241.93188736522026
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 63"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1239630630531491e-07
	Radius		36.65394340270835

	RotationPeriod	3.133873427341716

	Obliquity		71.86012989189031

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5246885811834112
		Eccentricity	0.07157902856004739
		Inclination		-1.3994120846705702
		AscendingNode	167.31650564052214
		ArgOfPericen	90.74204194034822
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 64"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.4423100595551336e-07
	Radius		55.536450223919296

	RotationPeriod	6.071855619934772

	Obliquity		47.54526977335658

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5245301066748372
		Eccentricity	0.030300104876166828
		Inclination		-1.613530064373886
		AscendingNode	257.4574000482248
		ArgOfPericen	236.40513305115675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 64.1"
{
	ParentBody	"Acheron 64"
	Class		"Asteroid"
	Mass		1.4473591071416886e-09
	Radius		8.963691224133203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.635719331317918e-06
		Eccentricity	0.005634988647908805
		Inclination		-24.226548519532425
		AscendingNode	201.00685429726525
		ArgOfPericen	83.44614644451386
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 65"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6406151787848616e-07
	Radius		41.51716622196691

	RotationPeriod	5.743495564779684

	Obliquity		150.86504443008303

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5491400437871669
		Eccentricity	0.058751959141746204
		Inclination		-0.5010496180586081
		AscendingNode	131.16980310004502
		ArgOfPericen	174.9014237538469
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 66"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.881753617145931e-08
	Radius		25.6477292568628

	RotationPeriod	7.683001363455425

	Obliquity		110.7498748881871

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5500638199554491
		Eccentricity	0.07789739418963906
		Inclination		-1.1082816948162442
		AscendingNode	287.3109749073938
		ArgOfPericen	359.7684805645385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 67"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.511828437680048e-07
	Radius		63.15644984566665

	RotationPeriod	5.1793197994608775

	Obliquity		101.2408063163764

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5190221510893753
		Eccentricity	0.04143288257532886
		Inclination		-0.38310801064547223
		AscendingNode	13.173519885689068
		ArgOfPericen	88.18628300086652
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 67.1"
{
	ParentBody	"Acheron 67"
	Class		"Asteroid"
	Mass		3.940701959371982e-09
	Radius		12.166817926423231

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3377967642768432e-06
		Eccentricity	0.003623436666551967
		Inclination		4.520628358288179
		AscendingNode	225.0136658252481
		ArgOfPericen	183.77459101516436
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 67.2"
{
	ParentBody	"Acheron 67"
	Class		"Asteroid"
	Mass		4.2943545689481315e-10
	Radius		5.811458117831495

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.996716308402326e-06
		Eccentricity	0.005593138450846626
		Inclination		-9.443743370357378
		AscendingNode	238.35798476400456
		ArgOfPericen	176.52073586787614
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 68"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.26920541779834e-07
	Radius		49.884152276514996

	RotationPeriod	7.60142979719641

	Obliquity		315.3979203804872

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5143387542564248
		Eccentricity	0.06540467358655655
		Inclination		-0.8836849343453498
		AscendingNode	14.197571681833235
		ArgOfPericen	323.81944628667986
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 69"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.0512658724031033e-07
	Radius		51.030235328842764

	RotationPeriod	3.8314219304963713

	Obliquity		315.14327963080683

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5298996964889263
		Eccentricity	0.07790253679427721
		Inclination		0.6324512024402603
		AscendingNode	343.0586099126095
		ArgOfPericen	15.595386952669115
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 70"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5166984039412493
		Eccentricity	0.03145833640097752
		Inclination		1.8026828921608817
		AscendingNode	62.51648241007601
		ArgOfPericen	189.0436333136446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 70 A"
{
	ParentBody	"Acheron 70"
	Class		"Asteroid"
	Mass		6.012199800576677e-07
	Radius		66.87902949015997

	Orbit
	{
		Epoch			2457395.5
		Period			0.0064105742794799865
		Eccentricity	0.004779436950084152
		Inclination		282.4937913849453
		AscendingNode	344.29595074429534
		ArgOfPericen	248.5517172246821
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 70 B"
{
	ParentBody	"Acheron 70"
	Class		"Asteroid"
	Mass		2.113552950756343e-07
	Radius		47.20085564832332

	Orbit
	{
		Epoch			2457395.5
		Period			0.0064105742794799865
		Eccentricity	0.004779436950084152
		Inclination		282.4937913849453
		AscendingNode	344.29595074429534
		ArgOfPericen	68.55171722468208
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 71"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1087729419530065e-08
	Radius		18.628478579349224

	RotationPeriod	3.559475444876093

	Obliquity		22.933337523513817

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5319638968274933
		Eccentricity	0.047771268342156566
		Inclination		3.6804919782577183
		AscendingNode	263.3376112485552
		ArgOfPericen	78.10962633502899
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 72"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5201919855635105
		Eccentricity	0.021591651219150902
		Inclination		-0.5058018085667446
		AscendingNode	242.54879336355435
		ArgOfPericen	298.4065558884781
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 72 A"
{
	ParentBody	"Acheron 72"
	Class		"Asteroid"
	Mass		1.3498424293783108e-07
	Radius		39.90589580689635

	Orbit
	{
		Epoch			2457395.5
		Period			0.004816938554961844
		Eccentricity	0.007827751031430828
		Inclination		265.21309973056964
		AscendingNode	280.2859803790096
		ArgOfPericen	249.53841397859304
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 72 B"
{
	ParentBody	"Acheron 72"
	Class		"Asteroid"
	Mass		5.975681985685419e-09
	Radius		14.116873778138512

	Orbit
	{
		Epoch			2457395.5
		Period			0.004816938554961844
		Eccentricity	0.007827751031430828
		Inclination		265.21309973056964
		AscendingNode	280.2859803790096
		ArgOfPericen	69.53841397859304
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 73"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.542437651102146
		Eccentricity	0.048342911862698665
		Inclination		-0.8095710788463177
		AscendingNode	333.4025213690314
		ArgOfPericen	56.101095380053955
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 73 A"
{
	ParentBody	"Acheron 73"
	Class		"Asteroid"
	Mass		5.742908750903269e-07
	Radius		60.25817082935999

	Orbit
	{
		Epoch			2457395.5
		Period			0.005687427423628404
		Eccentricity	0.0026335416288043737
		Inclination		214.6799548395795
		AscendingNode	39.442527955720465
		ArgOfPericen	298.8880508072931
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 73 B"
{
	ParentBody	"Acheron 73"
	Class		"Asteroid"
	Mass		3.977113059052271e-07
	Radius		53.312365316602865

	Orbit
	{
		Epoch			2457395.5
		Period			0.005687427423628404
		Eccentricity	0.0026335416288043737
		Inclination		214.6799548395795
		AscendingNode	39.442527955720465
		ArgOfPericen	118.8880508072931
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 74"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.913791604757251e-07
	Radius		66.34499095643442

	RotationPeriod	3.705414559361759

	Obliquity		138.06025487430418

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.541212048681606
		Eccentricity	0.06767539036591877
		Inclination		1.1258357537597072
		AscendingNode	298.65595490863683
		ArgOfPericen	198.25858517975468
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 74.1"
{
	ParentBody	"Acheron 74"
	Class		"Asteroid"
	Mass		6.370567764657229e-09
	Radius		14.652515191637804

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.672948837563319e-06
		Eccentricity	0.005778466975176548
		Inclination		73.07371179798659
		AscendingNode	240.45694068826066
		ArgOfPericen	152.12705741979545
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 75"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4329184713668768e-07
	Radius		40.46692701096816

	RotationPeriod	3.4971660142776573

	Obliquity		86.55632543067311

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5538572680171429
		Eccentricity	0.06460836253795073
		Inclination		-2.983779363706103
		AscendingNode	199.20124646292365
		ArgOfPericen	176.73352599920435
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 76"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6778265858133806e-09
	Radius		12.427514129353483

	RotationPeriod	6.097144680595876

	Obliquity		236.30922064921154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5668509274165682
		Eccentricity	0.05690118734067273
		Inclination		-3.0176616235723674
		AscendingNode	52.830338460039414
		ArgOfPericen	240.35475113150366
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 76.1"
{
	ParentBody	"Acheron 76"
	Class		"Asteroid"
	Mass		1.6842418466652605e-12
	Radius		0.957904031003527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7502237042460197e-06
		Eccentricity	0.004637101429947493
		Inclination		35.58047677138961
		AscendingNode	313.41157490705945
		ArgOfPericen	146.29399896288828
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 77"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.672804122795659e-07
	Radius		54.70887360854884

	RotationPeriod	9.949054019241991

	Obliquity		343.02055142327373

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5187643364664485
		Eccentricity	0.07022538135838394
		Inclination		-3.5880239104456813
		AscendingNode	135.4559609639163
		ArgOfPericen	254.13860894146754
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 78"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2651412147202753e-06
	Radius		82.58452063265767

	RotationPeriod	1.9958228300142178

	Obliquity		30.568345505616932

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5424564295837031
		Eccentricity	0.0608059156156232
		Inclination		-0.40850771217995263
		AscendingNode	339.0383270584386
		ArgOfPericen	154.0192085358798
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 79"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.092170480437078e-07
	Radius		52.86868771161626

	RotationPeriod	5.154566188917962

	Obliquity		204.68080480655829

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5604143427944863
		Eccentricity	0.04686938303363421
		Inclination		-0.8700789453718244
		AscendingNode	190.235939118835
		ArgOfPericen	267.84475452446276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 80"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.139708782609209e-07
	Radius		52.745812238110865

	RotationPeriod	7.698015107295773

	Obliquity		12.188063123640905

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5367089187825499
		Eccentricity	0.06438906369841646
		Inclination		-1.3090536343967016
		AscendingNode	358.7539815016376
		ArgOfPericen	100.19020913767659
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 81"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5141057352915211
		Eccentricity	0.0773290364112989
		Inclination		-1.2938050616772232
		AscendingNode	311.8766877189898
		ArgOfPericen	295.49678174976987
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 81 A"
{
	ParentBody	"Acheron 81"
	Class		"Asteroid"
	Mass		2.9199088880976604e-07
	Radius		50.962994482553526

	Orbit
	{
		Epoch			2457395.5
		Period			0.0064654507997082685
		Eccentricity	0.005600731807750914
		Inclination		105.841403841441
		AscendingNode	131.42187714492107
		ArgOfPericen	132.01478360835046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 81 B"
{
	ParentBody	"Acheron 81"
	Class		"Asteroid"
	Mass		8.42725487547899e-08
	Radius		33.67910547264177

	Orbit
	{
		Epoch			2457395.5
		Period			0.0064654507997082685
		Eccentricity	0.005600731807750914
		Inclination		105.841403841441
		AscendingNode	131.42187714492107
		ArgOfPericen	312.01478360835046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 82"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5354839626969609
		Eccentricity	0.053905190999545764
		Inclination		-0.16915318855089315
		AscendingNode	150.92286649067947
		ArgOfPericen	92.81080154067537
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 82 A"
{
	ParentBody	"Acheron 82"
	Class		"Asteroid"
	Mass		3.2186902812817353e-07
	Radius		53.54673093217779

	Orbit
	{
		Epoch			2457395.5
		Period			0.006159182431803426
		Eccentricity	0.004696023575257504
		Inclination		329.3139341131121
		AscendingNode	319.7638947035556
		ArgOfPericen	305.2048634637911
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 82 B"
{
	ParentBody	"Acheron 82"
	Class		"Asteroid"
	Mass		3.1869228335368394e-08
	Radius		24.772152696753786

	Orbit
	{
		Epoch			2457395.5
		Period			0.006159182431803426
		Eccentricity	0.004696023575257504
		Inclination		329.3139341131121
		AscendingNode	319.7638947035556
		ArgOfPericen	125.20486346379113
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 83"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.948818228691514e-07
	Radius		49.250914265229156

	RotationPeriod	6.0274508985884845

	Obliquity		202.97826892402358

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5409917862772912
		Eccentricity	0.06039938338677123
		Inclination		1.402495683627759
		AscendingNode	187.30732248424445
		ArgOfPericen	350.56628518659767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 84"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.795542445926739e-07
	Radius		43.09668640803602

	RotationPeriod	4.729363072164146

	Obliquity		282.4994517159848

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5511298853655267
		Eccentricity	0.06136353078089052
		Inclination		-0.5428930448802557
		AscendingNode	225.82712131226378
		ArgOfPericen	125.17216584903643
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 85"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.507335724629812e-07
	Radius		65.57244795819801

	RotationPeriod	5.493737616465153

	Obliquity		145.917632153813

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5507263383054535
		Eccentricity	0.0033754306490243816
		Inclination		-0.2292841247096791
		AscendingNode	133.718613848219
		ArgOfPericen	129.65678379491095
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 86"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1802288730920352e-08
	Radius		17.097302650860243

	RotationPeriod	7.5361544542048895

	Obliquity		28.108480620261357

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5295126542647249
		Eccentricity	0.05649472661371633
		Inclination		-0.07502445460537373
		AscendingNode	3.423535773495332
		ArgOfPericen	75.68722255791421
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 86.1"
{
	ParentBody	"Acheron 86"
	Class		"Asteroid"
	Mass		1.7007374200305115e-10
	Radius		4.16055509033352

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.140303635341653e-06
		Eccentricity	0.0033058834141720915
		Inclination		-1.3622546475110036
		AscendingNode	282.3414187953414
		ArgOfPericen	208.90503262362913
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 87"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5188730659955636
		Eccentricity	0.049665430211204585
		Inclination		-0.2876467004304251
		AscendingNode	82.14972660615273
		ArgOfPericen	38.40132968426402
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 87 A"
{
	ParentBody	"Acheron 87"
	Class		"Asteroid"
	Mass		1.3714809324829797e-07
	Radius		39.14756609595899

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066550016785399384
		Eccentricity	0.005720377997630315
		Inclination		300.312859054172
		AscendingNode	340.13930992833116
		ArgOfPericen	285.3424599636328
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 87 B"
{
	ParentBody	"Acheron 87"
	Class		"Asteroid"
	Mass		7.962764228352416e-08
	Radius		32.65849196641539

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066550016785399384
		Eccentricity	0.005720377997630315
		Inclination		300.312859054172
		AscendingNode	340.13930992833116
		ArgOfPericen	105.34245996363279
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 88"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2985037992702368e-07
	Radius		38.828927787820405

	RotationPeriod	5.2863113490776685

	Obliquity		338.8979156411066

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5343367581638093
		Eccentricity	0.05559924283686701
		Inclination		1.2084405047344164
		AscendingNode	324.9931704136967
		ArgOfPericen	134.9356056470779
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 89"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.106981889165986e-07
	Radius		64.80367815595106

	RotationPeriod	5.207115609888093

	Obliquity		38.527301455135294

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5212637758945992
		Eccentricity	0.057217904218403025
		Inclination		-1.3351964503363287
		AscendingNode	153.5867825781101
		ArgOfPericen	216.75453049273932
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 90"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.112895492264976e-07
	Radius		60.400724022023994

	RotationPeriod	6.917881826339288

	Obliquity		330.52549223108065

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5301848537627345
		Eccentricity	0.08389192585219257
		Inclination		1.5849379789032823
		AscendingNode	340.3872527989635
		ArgOfPericen	12.178618867367238
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 90.1"
{
	ParentBody	"Acheron 90"
	Class		"Asteroid"
	Mass		7.378950666657824e-10
	Radius		6.825765671232827

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.978776921352047e-06
		Eccentricity	0.0035904076130486725
		Inclination		65.98217557116519
		AscendingNode	101.58508188045992
		ArgOfPericen	56.20000397103202
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 91"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2254225515034444e-07
	Radius		37.812192313635244

	RotationPeriod	6.828235302331557

	Obliquity		232.85904892332235

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5598475960615066
		Eccentricity	0.06644716349131098
		Inclination		-1.8072473941042009
		AscendingNode	75.85825768213867
		ArgOfPericen	164.47810594390464
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 91.1"
{
	ParentBody	"Acheron 91"
	Class		"Asteroid"
	Mass		1.3531454520210675e-10
	Radius		3.908271532714296

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.865596647490771e-06
		Eccentricity	0.003879984176904385
		Inclination		-18.374025019586107
		AscendingNode	263.4237292961378
		ArgOfPericen	286.46199234410443
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 91.2"
{
	ParentBody	"Acheron 91"
	Class		"Asteroid"
	Mass		8.401062003798367e-10
	Radius		7.183144978091595

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.758279598957508e-06
		Eccentricity	0.004025365515748941
		Inclination		-9.775257106357817
		AscendingNode	333.8475572585733
		ArgOfPericen	144.05125419677813
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 92"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.635996158587882e-08
	Radius		23.870599265324717

	RotationPeriod	7.441570870328752

	Obliquity		157.3252262795295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5583407417944158
		Eccentricity	0.03574780338638867
		Inclination		0.7892189212872619
		AscendingNode	168.38197708863538
		ArgOfPericen	119.70793905221065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 93"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9788727955224545e-07
	Radius		44.05989537924771

	RotationPeriod	3.6857219798872687

	Obliquity		170.9991808502689

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5416221676600385
		Eccentricity	0.05502435338831177
		Inclination		1.1067016495547923
		AscendingNode	292.50961054932986
		ArgOfPericen	47.90579119594201
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 94"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.169462235942284e-07
	Radius		53.19499433916301

	RotationPeriod	4.767744120396367

	Obliquity		181.1879092173839

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5567939403455641
		Eccentricity	0.060198699557930405
		Inclination		-0.09546499783319859
		AscendingNode	125.7218843610928
		ArgOfPericen	106.05568365378724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 94.1"
{
	ParentBody	"Acheron 94"
	Class		"Asteroid"
	Mass		4.15680000092839e-09
	Radius		12.54474823311292

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.7556979133494495e-06
		Eccentricity	0.008264536859513217
		Inclination		47.01499423782695
		AscendingNode	117.15791509157145
		ArgOfPericen	285.2289230573271
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 94.2"
{
	ParentBody	"Acheron 94"
	Class		"Asteroid"
	Mass		1.5154210481322e-09
	Radius		8.96162316969315

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.612368049576963e-06
		Eccentricity	0.007302266108104443
		Inclination		33.749309466651056
		AscendingNode	9.447521973571785
		ArgOfPericen	218.33245039009003
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 95"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5548454880849599
		Eccentricity	0.051291502141475
		Inclination		-0.9707144824056307
		AscendingNode	292.16717516306426
		ArgOfPericen	357.3047850671661
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 95 A"
{
	ParentBody	"Acheron 95"
	Class		"Asteroid"
	Mass		1.4384962091216968e-07
	Radius		39.106564723117756

	Orbit
	{
		Epoch			2457395.5
		Period			0.004115787470516703
		Eccentricity	0.01
		Inclination		188.55599028822328
		AscendingNode	117.12400008053285
		ArgOfPericen	148.31586185636905
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 95 B"
{
	ParentBody	"Acheron 95"
	Class		"Asteroid"
	Mass		9.610937788539227e-08
	Radius		34.18760537196801

	Orbit
	{
		Epoch			2457395.5
		Period			0.004115787470516703
		Eccentricity	0.01
		Inclination		188.55599028822328
		AscendingNode	117.12400008053285
		ArgOfPericen	328.31586185636905
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 96"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.0299074009722205e-07
	Radius		45.570002296388594

	RotationPeriod	2.6744872600092693

	Obliquity		224.16269804502753

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5275435097592532
		Eccentricity	0.053360998771457384
		Inclination		2.4536192046851175
		AscendingNode	61.530313483552135
		ArgOfPericen	240.66234167196052
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 97"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.136756123186687e-07
	Radius		66.26514107283822

	RotationPeriod	8.04971905017944

	Obliquity		49.23259686687123

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5345338879096474
		Eccentricity	0.04899454396378338
		Inclination		0.5613712352105942
		AscendingNode	59.83421499798443
		ArgOfPericen	226.30294480835073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 98"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5624121740316994
		Eccentricity	0.06701053876528232
		Inclination		-2.235467702192452
		AscendingNode	208.35759150852937
		ArgOfPericen	318.90401078304455
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 98 A"
{
	ParentBody	"Acheron 98"
	Class		"Asteroid"
	Mass		1.2070189440471928e-07
	Radius		37.84662916019264

	Orbit
	{
		Epoch			2457395.5
		Period			0.0031259769938571757
		Eccentricity	0.004804234175328688
		Inclination		265.63397031800355
		AscendingNode	305.06337413854413
		ArgOfPericen	319.76625707970646
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 98 B"
{
	ParentBody	"Acheron 98"
	Class		"Asteroid"
	Mass		2.0720861180629885e-08
	Radius		21.034156928686794

	Orbit
	{
		Epoch			2457395.5
		Period			0.0031259769938571757
		Eccentricity	0.004804234175328688
		Inclination		265.63397031800355
		AscendingNode	305.06337413854413
		ArgOfPericen	139.76625707970646
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 99"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1820774749587597e-07
	Radius		39.20160663964995

	RotationPeriod	10.409369159283411

	Obliquity		358.5088404051203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5419944332604949
		Eccentricity	0.04523270923239559
		Inclination		1.0694285128620131
		AscendingNode	132.71627869773855
		ArgOfPericen	16.17292463940867
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 100"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.189723427319888e-08
	Radius		22.193522926489084

	RotationPeriod	5.047650012988845

	Obliquity		41.57716722027578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5325848481702221
		Eccentricity	0.0705565771507223
		Inclination		-1.9489389766598775
		AscendingNode	245.031668874417
		ArgOfPericen	142.32169136318774
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 101"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.516717574626378e-07
	Radius		43.672612688544405

	RotationPeriod	5.02189646753671

	Obliquity		347.7424494585628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5203884963321261
		Eccentricity	0.0709317469613251
		Inclination		0.3986676999440069
		AscendingNode	323.46217182097575
		ArgOfPericen	310.406693236972
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 102"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2201768009837888e-06
	Radius		78.44520036778091

	RotationPeriod	6.877936057922771

	Obliquity		39.709326419397144

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5629642829370937
		Eccentricity	0.02566699484475887
		Inclination		-0.7807661258123573
		AscendingNode	92.36561995421918
		ArgOfPericen	208.9521315383363
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 103"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.4000554499087547e-07
	Radius		51.57229444455405

	RotationPeriod	9.270583823730039

	Obliquity		112.68520314009848

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5527274008382606
		Eccentricity	0.038017529437346806
		Inclination		2.6044675913125683
		AscendingNode	24.63719744837658
		ArgOfPericen	48.821597766047354
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 103.1"
{
	ParentBody	"Acheron 103"
	Class		"Asteroid"
	Mass		2.2775400498036906e-09
	Radius		10.918543345827054

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.200528508705678e-06
		Eccentricity	0.004528888528392189
		Inclination		43.046219947552025
		AscendingNode	147.84509068757234
		ArgOfPericen	275.2667739198782
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 104"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.837951568886542e-07
	Radius		63.987414342123856

	RotationPeriod	4.634064672799168

	Obliquity		3.4196917874845534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.555403644931634
		Eccentricity	0.07029098726106922
		Inclination		1.8344453867886106
		AscendingNode	238.4965700716411
		ArgOfPericen	276.12133997486217
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 105"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.705387786703863e-07
	Radius		78.02447674475516

	RotationPeriod	5.682907485244831

	Obliquity		207.58996533527608

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5521598058915261
		Eccentricity	0.05726724040872465
		Inclination		-0.02191248239534298
		AscendingNode	107.39838419298381
		ArgOfPericen	354.37413409771267
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 106"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5208523616324982
		Eccentricity	0.05171515005150605
		Inclination		-0.1669956340558966
		AscendingNode	59.5668582170104
		ArgOfPericen	282.17418959993586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 106 A"
{
	ParentBody	"Acheron 106"
	Class		"Asteroid"
	Mass		8.354408472675417e-08
	Radius		32.19459499981872

	Orbit
	{
		Epoch			2457395.5
		Period			0.004553457539766932
		Eccentricity	0.004238829527293366
		Inclination		257.17919482510376
		AscendingNode	344.5292267611796
		ArgOfPericen	273.3033349713336
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 106 B"
{
	ParentBody	"Acheron 106"
	Class		"Asteroid"
	Mass		3.3530114711002287e-09
	Radius		11.022736120926625

	Orbit
	{
		Epoch			2457395.5
		Period			0.004553457539766932
		Eccentricity	0.004238829527293366
		Inclination		257.17919482510376
		AscendingNode	344.5292267611796
		ArgOfPericen	93.30333497133358
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 107"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.006021569097014e-07
	Radius		75.92511530488854

	RotationPeriod	6.149058220308771

	Obliquity		136.51218936043094

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5707083888270805
		Eccentricity	0.06520955352742677
		Inclination		-1.2084828663553557
		AscendingNode	312.1232112869754
		ArgOfPericen	297.84133066335414
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 108"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2374627111158624e-07
	Radius		46.342223985972254

	RotationPeriod	6.280407265619199

	Obliquity		55.5388282908255

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5396889549668957
		Eccentricity	0.04456899324913021
		Inclination		0.34887666327526146
		AscendingNode	298.6948368308724
		ArgOfPericen	341.05589959993165
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 108.1"
{
	ParentBody	"Acheron 108"
	Class		"Asteroid"
	Mass		3.044431979560311e-10
	Radius		5.135235460466021

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.652965410050683e-06
		Eccentricity	0.007345579316517482
		Inclination		-5.469624182049105
		AscendingNode	49.79899351801515
		ArgOfPericen	90.1714517152855
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 109"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.950079787462181e-07
	Radius		64.84425839613648

	RotationPeriod	8.617168707193542

	Obliquity		31.459263828747986

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5595836850344149
		Eccentricity	0.04665193698397705
		Inclination		-2.047501733693716
		AscendingNode	33.00107269615351
		ArgOfPericen	101.87338866577257
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 110"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5426249508791184
		Eccentricity	0.051269295343179276
		Inclination		-0.7190989671967096
		AscendingNode	244.83622919179507
		ArgOfPericen	58.36735806261244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 110 A"
{
	ParentBody	"Acheron 110"
	Class		"Asteroid"
	Mass		7.267015528508803e-08
	Radius		31.354023664524714

	Orbit
	{
		Epoch			2457395.5
		Period			0.003074154453356628
		Eccentricity	0.004788076131122953
		Inclination		23.11081054756339
		AscendingNode	95.30475923827743
		ArgOfPericen	213.15722922617792
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 110 B"
{
	ParentBody	"Acheron 110"
	Class		"Asteroid"
	Mass		6.927757823500841e-09
	Radius		14.323159171342217

	Orbit
	{
		Epoch			2457395.5
		Period			0.003074154453356628
		Eccentricity	0.004788076131122953
		Inclination		23.11081054756339
		AscendingNode	95.30475923827743
		ArgOfPericen	33.15722922617795
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 111"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.7977271185214777e-07
	Radius		51.81974032094557

	RotationPeriod	6.087856073085388

	Obliquity		215.86090193479643

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5375469112390121
		Eccentricity	0.03920432667985528
		Inclination		1.4758864450004374
		AscendingNode	242.15440415155666
		ArgOfPericen	271.2348954162221
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 112"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.245591446161149e-08
	Radius		36.050632965714314

	RotationPeriod	6.020935014138371

	Obliquity		119.64668385758569

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5149051484162843
		Eccentricity	0.09111228521263245
		Inclination		-0.15021414911333433
		AscendingNode	265.2891249122481
		ArgOfPericen	336.60477321698056
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 112.1"
{
	ParentBody	"Acheron 112"
	Class		"Asteroid"
	Mass		1.3373374420233922e-09
	Radius		8.783784307568656

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6325070577250645e-06
		Eccentricity	0.004012480836558053
		Inclination		-47.31535855950424
		AscendingNode	176.45892695150238
		ArgOfPericen	275.34731594247427
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 113"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5558757660398084e-06
	Radius		89.49278911380986

	RotationPeriod	5.469554878192295

	Obliquity		350.07488353481017

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5104794430977925
		Eccentricity	0.020487716585681874
		Inclination		-2.470871868068161
		AscendingNode	327.4947820436783
		ArgOfPericen	69.21932972824753
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 114"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.792184707018516e-07
	Radius		64.75528017497145

	RotationPeriod	6.287675130897744

	Obliquity		105.96159896642523

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5441830135475869
		Eccentricity	0.07028286293145627
		Inclination		2.206328654928882
		AscendingNode	225.23691895448908
		ArgOfPericen	314.313737108641
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 115"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2740634115862742e-07
	Radius		40.848209152715036

	RotationPeriod	3.8162541011695996

	Obliquity		195.8590364896338

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5122447260859108
		Eccentricity	0.058619218095152595
		Inclination		2.8136724712774535
		AscendingNode	73.192088939714
		ArgOfPericen	188.2474071283291
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 116"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.161285014111451e-07
	Radius		56.01871637212283

	RotationPeriod	4.939728729370357

	Obliquity		34.1817932670683

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5570504230033684
		Eccentricity	0.030330551350039273
		Inclination		-2.131896565809453
		AscendingNode	230.17611758952793
		ArgOfPericen	103.57966012755477
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 117"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5870246780468753e-07
	Radius		43.47333723357782

	RotationPeriod	4.849633241444175

	Obliquity		307.4483102621688

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5378992612511718
		Eccentricity	0.054471322216696254
		Inclination		-3.3862210432810733
		AscendingNode	190.14293030354713
		ArgOfPericen	270.7502141064845
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 118"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.9362345244948664e-07
	Radius		52.88189269499394

	RotationPeriod	7.016845927015819

	Obliquity		59.21618867440367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5445115780290873
		Eccentricity	0.04267567725202289
		Inclination		-3.0469410648886273
		AscendingNode	120.54040878278258
		ArgOfPericen	299.03710260333366
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 119"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.50960701915354e-07
	Radius		52.27080911429339

	RotationPeriod	6.690224399575705

	Obliquity		270.95836469237327

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5097262885008897
		Eccentricity	0.04434015445327275
		Inclination		1.0004282110763874
		AscendingNode	113.90920659282901
		ArgOfPericen	202.40570496718354
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 120"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.423033612210752e-07
	Radius		55.522999948384175

	RotationPeriod	4.70700937599188

	Obliquity		100.10863488461635

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5509425258280647
		Eccentricity	0.042440746936291074
		Inclination		-0.748185060254225
		AscendingNode	68.69689485015698
		ArgOfPericen	180.55229882472605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 121"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.9317555692907064e-07
	Radius		49.80019974156377

	RotationPeriod	7.502520396696026

	Obliquity		204.07170303712502

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5232584080698741
		Eccentricity	0.028944774085834728
		Inclination		-0.645119674085364
		AscendingNode	259.242854103491
		ArgOfPericen	350.06856862640063
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 122"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.953076357595752e-09
	Radius		15.473335390859305

	RotationPeriod	3.3470417495453546

	Obliquity		277.6381793505259

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.56163019865884
		Eccentricity	0.0671693018777774
		Inclination		-0.2756030542040269
		AscendingNode	277.3365110675506
		ArgOfPericen	336.14970602620855
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 123"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.755985680559179e-07
	Radius		66.90228575008061

	RotationPeriod	5.573440266580624

	Obliquity		293.7862169763123

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5534133619214983
		Eccentricity	0.05626720968379792
		Inclination		-1.136753556600115
		AscendingNode	92.74726815213711
		ArgOfPericen	224.9804861160758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 123.1"
{
	ParentBody	"Acheron 123"
	Class		"Asteroid"
	Mass		9.73977458486776e-09
	Radius		16.282747355156612

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.99357683124991e-06
		Eccentricity	0.007445541136255429
		Inclination		-4.608402649552191
		AscendingNode	267.44878309696213
		ArgOfPericen	263.1232874694053
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 123.2"
{
	ParentBody	"Acheron 123"
	Class		"Asteroid"
	Mass		4.178252606997006e-09
	Radius		12.280318009506072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.506093621850069e-06
		Eccentricity	0.007089069145643158
		Inclination		-7.825379704085807
		AscendingNode	269.2037230042806
		ArgOfPericen	140.42364443993722
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 124"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5312394953298528
		Eccentricity	0.06744764234658632
		Inclination		-1.3619808266925995
		AscendingNode	311.2799839895402
		ArgOfPericen	26.26786878474548
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 124 A"
{
	ParentBody	"Acheron 124"
	Class		"Asteroid"
	Mass		7.952100165240262e-07
	Radius		72.44410795828327

	Orbit
	{
		Epoch			2457395.5
		Period			0.006049716757320519
		Eccentricity	0.004373900542446764
		Inclination		242.46424173633045
		AscendingNode	67.37865174100537
		ArgOfPericen	23.214390168378486
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 124 B"
{
	ParentBody	"Acheron 124"
	Class		"Asteroid"
	Mass		5.118243591643849e-07
	Radius		62.54838570832387

	Orbit
	{
		Epoch			2457395.5
		Period			0.006049716757320519
		Eccentricity	0.004373900542446764
		Inclination		242.46424173633045
		AscendingNode	67.37865174100537
		ArgOfPericen	203.2143901683785
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 125"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.226937161849143e-08
	Radius		21.473645488433277

	RotationPeriod	7.350190777966425

	Obliquity		348.81634588710153

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5396270788515062
		Eccentricity	0.04855954075116485
		Inclination		1.5085638799040229
		AscendingNode	78.1161450527949
		ArgOfPericen	101.35342461994595
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 126"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.954918130468851e-07
	Radius		73.2416800401621

	RotationPeriod	6.2400150443718765

	Obliquity		66.73233160331577

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5375439800114443
		Eccentricity	0.03457185989763815
		Inclination		0.5425540712063788
		AscendingNode	16.491158049003126
		ArgOfPericen	217.47603445896635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 126.1"
{
	ParentBody	"Acheron 126"
	Class		"Asteroid"
	Mass		2.097883905301333e-09
	Radius		10.11906090744316

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.967734423682268e-06
		Eccentricity	0.004808492696509923
		Inclination		-25.290353007463157
		AscendingNode	62.35211643374709
		ArgOfPericen	333.53705163159293
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 127"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.281970592001123e-06
	Radius		83.94831434776879

	RotationPeriod	3.582909666978388

	Obliquity		283.9838629467819

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5300745227736023
		Eccentricity	0.05775556484047261
		Inclination		-3.3569690408890613
		AscendingNode	109.1947090043796
		ArgOfPericen	329.2799519094649
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 128"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.427693793463666e-07
	Radius		73.89298163639532

	RotationPeriod	4.507530138564697

	Obliquity		74.79584978864428

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5440012470876747
		Eccentricity	0.04311949448743779
		Inclination		-2.1759417513739634
		AscendingNode	291.339771116569
		ArgOfPericen	302.017281496448
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 129"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.571394063848336e-07
	Radius		50.62042099540594

	RotationPeriod	4.564341224172383

	Obliquity		301.79469960879305

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5499644567180824
		Eccentricity	0.04504211343932679
		Inclination		0.47467809441972386
		AscendingNode	207.05478110280026
		ArgOfPericen	317.5748616361184
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 130"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.703269207714786e-07
	Radius		52.44326692515868

	RotationPeriod	6.511634564354305

	Obliquity		8.536959394281705

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.547930104940822
		Eccentricity	0.05142756365077567
		Inclination		-1.9792931472141984
		AscendingNode	194.63363306361128
		ArgOfPericen	179.50630398007587
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 131"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.866527307929898e-07
	Radius		66.3503223491427

	RotationPeriod	8.76600464198281

	Obliquity		77.40318157302562

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5329706981915485
		Eccentricity	0.07018641457753823
		Inclination		-4.631751165077536
		AscendingNode	130.84910953771268
		ArgOfPericen	229.63692949258882
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 132"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4863082751912813e-07
	Radius		41.34682929903178

	RotationPeriod	6.708607447965166

	Obliquity		116.33837841642092

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5451179086508244
		Eccentricity	0.04432894727030419
		Inclination		2.840264512514624
		AscendingNode	347.14626069029345
		ArgOfPericen	279.8423012099224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 133"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.788554020294424e-08
	Radius		20.499540025493538

	RotationPeriod	5.79217565650102

	Obliquity		182.57191206511894

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.547957605095638
		Eccentricity	0.06131473028138222
		Inclination		0.31576843287529266
		AscendingNode	98.79003809644814
		ArgOfPericen	210.2272330877472
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 133.1"
{
	ParentBody	"Acheron 133"
	Class		"Asteroid"
	Mass		7.662590596748542e-12
	Radius		1.5453800561676303

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.5266147378164496e-06
		Eccentricity	0.004039298189653175
		Inclination		6.6305755541492895
		AscendingNode	155.81107311229354
		ArgOfPericen	276.94990851640796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 133.2"
{
	ParentBody	"Acheron 133"
	Class		"Asteroid"
	Mass		6.364958668264194e-11
	Radius		3.12974262711693

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.1176060377219676e-06
		Eccentricity	0.00627508489935514
		Inclination		39.943898286010665
		AscendingNode	309.68275416326327
		ArgOfPericen	335.83203744775597
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 134"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.984698319774177e-07
	Radius		63.290267306187886

	RotationPeriod	4.554280758943644

	Obliquity		268.4923891412955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5256794243514246
		Eccentricity	0.058034107047412485
		Inclination		-1.6669309812344473
		AscendingNode	57.823987482060396
		ArgOfPericen	127.34580881156026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 135"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.297152707389007e-08
	Radius		28.52918156248005

	RotationPeriod	6.669517915379135

	Obliquity		142.1057747985467

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5701785071990653
		Eccentricity	0.06252503752745998
		Inclination		1.8958684343486552
		AscendingNode	102.568829435951
		ArgOfPericen	66.63819227373008
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 136"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.097938877886119e-07
	Radius		39.26463464770853

	RotationPeriod	6.9785773192638345

	Obliquity		91.72416147994636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5364529475116766
		Eccentricity	0.03924598833444366
		Inclination		0.979499912367367
		AscendingNode	177.46328290750984
		ArgOfPericen	314.0995994872637
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 136.1"
{
	ParentBody	"Acheron 136"
	Class		"Asteroid"
	Mass		1.3273928245913842e-10
	Radius		4.182879253837602

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.52026683229275e-06
		Eccentricity	0.004629183034036125
		Inclination		27.652636003794306
		AscendingNode	8.720539888221023
		ArgOfPericen	84.63557321046895
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 137"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.49151515935957e-07
	Radius		70.24981507209301

	RotationPeriod	4.776803230995422

	Obliquity		201.17012191401557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5292758754181643
		Eccentricity	0.05235519292842389
		Inclination		0.7597282653326203
		AscendingNode	309.65196918974016
		ArgOfPericen	334.1649551701953
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 137.1"
{
	ParentBody	"Acheron 137"
	Class		"Asteroid"
	Mass		6.5840959689367405e-09
	Radius		15.206474719576834

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.42931285830249e-06
		Eccentricity	0.005593817218992698
		Inclination		-74.41484572260646
		AscendingNode	355.1543548892803
		ArgOfPericen	13.272802559921736
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 138"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.844964542586488e-07
	Radius		63.62234321510401

	RotationPeriod	5.428938895339893

	Obliquity		150.41127421562751

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.540758395032069
		Eccentricity	0.04483208706515026
		Inclination		-0.5702394774305753
		AscendingNode	258.602684642827
		ArgOfPericen	82.99836986124133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 139"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0728991938837264e-07
	Radius		39.19765716699819

	RotationPeriod	8.498554271572633

	Obliquity		190.43024230295669

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5026828391918297
		Eccentricity	0.059008868283399685
		Inclination		-0.3505905254757545
		AscendingNode	306.6657626374483
		ArgOfPericen	288.7939686849222
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 140"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.950031348700676e-07
	Radius		63.118940363270255

	RotationPeriod	7.231416283524565

	Obliquity		283.180131329746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.576788302774254
		Eccentricity	0.04061924541568586
		Inclination		2.6005798154536883
		AscendingNode	88.95252748733822
		ArgOfPericen	144.02067318350356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 141"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.6794154489805693e-07
	Radius		50.54772189551318

	RotationPeriod	7.7271253406564195

	Obliquity		140.96631531401465

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5342596864639758
		Eccentricity	0.04377770366811214
		Inclination		1.7576119016180995
		AscendingNode	261.3039793959978
		ArgOfPericen	290.61729171647653
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 142"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.1441623342083447e-07
	Radius		59.92463655332571

	RotationPeriod	6.478280326980826

	Obliquity		142.71871816087722

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5191858850812607
		Eccentricity	0.05245408208628544
		Inclination		0.27982124997405455
		AscendingNode	165.9820611350682
		ArgOfPericen	179.05411114059524
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 143"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5520743167801956
		Eccentricity	0.039554258328333564
		Inclination		1.2633859706999733
		AscendingNode	196.16349862080577
		ArgOfPericen	20.070095808010112
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 143 A"
{
	ParentBody	"Acheron 143"
	Class		"Asteroid"
	Mass		6.119476332064371e-08
	Radius		29.379735136292968

	Orbit
	{
		Epoch			2457395.5
		Period			0.002267251344268476
		Eccentricity	0.00540222490348731
		Inclination		301.8935070381026
		AscendingNode	314.2945643990837
		ArgOfPericen	76.0743634507732
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 143 B"
{
	ParentBody	"Acheron 143"
	Class		"Asteroid"
	Mass		1.4740104526843155e-09
	Radius		8.484833233669976

	Orbit
	{
		Epoch			2457395.5
		Period			0.002267251344268476
		Eccentricity	0.00540222490348731
		Inclination		301.8935070381026
		AscendingNode	314.2945643990837
		ArgOfPericen	256.0743634507732
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 144"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.913240539822904e-07
	Radius		50.61519468072524

	RotationPeriod	2.7567980464149318

	Obliquity		16.409125027954772

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5063511937893902
		Eccentricity	0.0599130716634082
		Inclination		0.7598325204525601
		AscendingNode	144.7085851271095
		ArgOfPericen	17.422609757556394
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 145"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5457729044134387
		Eccentricity	0.01719826914071905
		Inclination		3.071626055581387
		AscendingNode	61.360831566935055
		ArgOfPericen	241.6542934554948
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 145 A"
{
	ParentBody	"Acheron 145"
	Class		"Asteroid"
	Mass		6.352141140035575e-07
	Radius		72.44015815595436

	Orbit
	{
		Epoch			2457395.5
		Period			0.00802120864934001
		Eccentricity	0.007315641977887682
		Inclination		231.91226187237655
		AscendingNode	93.43508428057116
		ArgOfPericen	137.57517367959923
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 145 B"
{
	ParentBody	"Acheron 145"
	Class		"Asteroid"
	Mass		1.6148272837284372e-07
	Radius		45.88964551705867

	Orbit
	{
		Epoch			2457395.5
		Period			0.00802120864934001
		Eccentricity	0.007315641977887682
		Inclination		231.91226187237655
		AscendingNode	93.43508428057116
		ArgOfPericen	317.57517367959923
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 146"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2973205208592698e-07
	Radius		39.60180557554497

	RotationPeriod	6.605617179363974

	Obliquity		196.18486823771892

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5229972691692597
		Eccentricity	0.07134816240940285
		Inclination		1.1777966648081604
		AscendingNode	298.7890926166703
		ArgOfPericen	212.71791785514404
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 147"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.972981662799542e-07
	Radius		63.74257972998247

	RotationPeriod	7.193668008535888

	Obliquity		23.216130225129056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5285232379017325
		Eccentricity	0.042127365548884306
		Inclination		2.598801653491225
		AscendingNode	296.75544268327207
		ArgOfPericen	18.659039246913775
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 147.1"
{
	ParentBody	"Acheron 147"
	Class		"Asteroid"
	Mass		4.1951548448015624e-10
	Radius		6.022914273372029

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.7370548941235726e-06
		Eccentricity	0.004062669348326676
		Inclination		-69.79257622686058
		AscendingNode	67.41216112605943
		ArgOfPericen	211.42855445574918
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 148"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5161005124848438
		Eccentricity	0.04002465681883467
		Inclination		0.08611319664833679
		AscendingNode	259.57447188245953
		ArgOfPericen	296.80951123688794
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 148 A"
{
	ParentBody	"Acheron 148"
	Class		"Asteroid"
	Mass		3.028035224754627e-07
	Radius		53.49735087727507

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021512380053093135
		Eccentricity	0.007509849041221873
		Inclination		178.43906877758363
		AscendingNode	174.7610397590071
		ArgOfPericen	325.60613602728876
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 148 B"
{
	ParentBody	"Acheron 148"
	Class		"Asteroid"
	Mass		2.2652273239646296e-07
	Radius		48.56416206169676

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021512380053093135
		Eccentricity	0.007509849041221873
		Inclination		178.43906877758363
		AscendingNode	174.7610397590071
		ArgOfPericen	145.60613602728876
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 149"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.35244288895646e-07
	Radius		59.857778204147515

	RotationPeriod	2.3573254044714718

	Obliquity		89.2483850285103

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5470410082765559
		Eccentricity	0.06841840057291582
		Inclination		-0.1275122501927185
		AscendingNode	339.6118677771706
		ArgOfPericen	109.62694196415703
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 149.1"
{
	ParentBody	"Acheron 149"
	Class		"Asteroid"
	Mass		1.6686644204667149e-09
	Radius		9.368410258124534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.087117299082575e-06
		Eccentricity	0.006244459103460917
		Inclination		10.919052715779813
		AscendingNode	19.21037278713635
		ArgOfPericen	267.318753528387
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 150"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5503471392459783
		Eccentricity	0.054611601640065593
		Inclination		0.6673053392386938
		AscendingNode	64.6899943818143
		ArgOfPericen	327.60957293345444
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 150 A"
{
	ParentBody	"Acheron 150"
	Class		"Asteroid"
	Mass		1.882584070900935e-07
	Radius		44.71169140542731

	Orbit
	{
		Epoch			2457395.5
		Period			0.0004441524398398731
		Eccentricity	0.005946479369657995
		Inclination		162.69633625266374
		AscendingNode	332.9426205772306
		ArgOfPericen	233.19471039921123
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 150 B"
{
	ParentBody	"Acheron 150"
	Class		"Asteroid"
	Mass		1.4404309047220287e-07
	Radius		40.894708435045246

	Orbit
	{
		Epoch			2457395.5
		Period			0.0004441524398398731
		Eccentricity	0.005946479369657995
		Inclination		162.69633625266374
		AscendingNode	332.9426205772306
		ArgOfPericen	53.1947103992112
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 151"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.536824534146003
		Eccentricity	0.056887692959397246
		Inclination		0.5972793385169429
		AscendingNode	85.05333292131988
		ArgOfPericen	232.79898832752056
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 151 A"
{
	ParentBody	"Acheron 151"
	Class		"Asteroid"
	Mass		5.970017140362627e-07
	Radius		65.39909208802116

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033569526583888277
		Eccentricity	0.004767430122483474
		Inclination		137.7196501721593
		AscendingNode	321.3292331978397
		ArgOfPericen	238.12192927413122
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 151 B"
{
	ParentBody	"Acheron 151"
	Class		"Asteroid"
	Mass		4.955862027727993e-07
	Radius		61.46382668243598

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033569526583888277
		Eccentricity	0.004767430122483474
		Inclination		137.7196501721593
		AscendingNode	321.3292331978397
		ArgOfPericen	58.12192927413122
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 152"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.303036778925985e-07
	Radius		48.657174063680884

	RotationPeriod	6.713347867878548

	Obliquity		74.48915376086646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.538623901582602
		Eccentricity	0.07488142325498687
		Inclination		3.796331418992348
		AscendingNode	251.7746287168239
		ArgOfPericen	86.0706782459129
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 152.1"
{
	ParentBody	"Acheron 152"
	Class		"Asteroid"
	Mass		1.5932394237191956e-09
	Radius		9.271292276021024

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.480826165768613e-06
		Eccentricity	0.005315295104501819
		Inclination		-18.364626669715033
		AscendingNode	235.2850347553971
		ArgOfPericen	218.17241254358308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 153"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.4260226350483255e-07
	Radius		56.050400836404066

	RotationPeriod	4.855148107697386

	Obliquity		139.16995281551056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5371094255198943
		Eccentricity	0.06825595809114869
		Inclination		-1.9647050204239
		AscendingNode	100.18916670176836
		ArgOfPericen	211.65068873666758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 154"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.539352854293222e-07
	Radius		61.900164698756285

	RotationPeriod	7.692078982721016

	Obliquity		295.54942177499754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5374241891346256
		Eccentricity	0.039738789692741305
		Inclination		2.8180704261446183
		AscendingNode	134.40696195529176
		ArgOfPericen	345.37870710561157
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 155"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0428342880863501e-07
	Radius		37.436139880399324

	RotationPeriod	7.433703183447965

	Obliquity		314.5026799037402

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5575357229068919
		Eccentricity	0.06885057793598706
		Inclination		0.7024028680116305
		AscendingNode	310.30604200464285
		ArgOfPericen	110.30647754698381
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 155.1"
{
	ParentBody	"Acheron 155"
	Class		"Asteroid"
	Mass		1.1868123995331503e-10
	Radius		3.9085288231254927

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.032020461664772e-06
		Eccentricity	0.002495441751881776
		Inclination		-1.0685885693927057
		AscendingNode	227.29601035224596
		ArgOfPericen	341.04551105481744
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 155.2"
{
	ParentBody	"Acheron 155"
	Class		"Asteroid"
	Mass		9.562562160182874e-11
	Radius		3.637006280684766

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.7593805419901963e-06
		Eccentricity	0.007247952401354248
		Inclination		-26.523541307392755
		AscendingNode	166.36771637533164
		ArgOfPericen	236.47134561320607
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 156"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.6790273068536134e-08
	Radius		22.8886530855845

	RotationPeriod	4.216423583747042

	Obliquity		334.07807963414285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5398235756920625
		Eccentricity	0.05231781611739845
		Inclination		0.06977965547418961
		AscendingNode	212.24938864406818
		ArgOfPericen	126.00332895042683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 156.1"
{
	ParentBody	"Acheron 156"
	Class		"Asteroid"
	Mass		1.0932416963958055e-10
	Radius		3.6576312489661906

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.419679846345498e-07
		Eccentricity	0.005370338179557201
		Inclination		-9.71773717439433
		AscendingNode	273.55212545630326
		ArgOfPericen	66.10245741484799
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 157"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3629310831125057e-07
	Radius		54.62972121214079

	RotationPeriod	5.8053606364451245

	Obliquity		0.7043066849821455

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5468270074968877
		Eccentricity	0.049505279036218486
		Inclination		0.7545386999293474
		AscendingNode	169.84557055504186
		ArgOfPericen	343.3515108084136
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 158"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4819753313050892e-07
	Radius		41.54447160011816

	RotationPeriod	5.879816158500544

	Obliquity		130.58616364396

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.518156260122702
		Eccentricity	0.0396226118463722
		Inclination		1.5539788294395398
		AscendingNode	230.10424523750106
		ArgOfPericen	260.1384182327196
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 159"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5507547619142951
		Eccentricity	0.023378792739701053
		Inclination		-0.4206706545630606
		AscendingNode	30.059273171080036
		ArgOfPericen	93.27270713100009
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 159 A"
{
	ParentBody	"Acheron 159"
	Class		"Asteroid"
	Mass		2.1138292983677013e-07
	Radius		46.7049387399768

	Orbit
	{
		Epoch			2457395.5
		Period			0.00041953577844271633
		Eccentricity	0.0059692428508386795
		Inclination		259.4309843092317
		AscendingNode	135.50721270791266
		ArgOfPericen	136.6424977221909
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 159 B"
{
	ParentBody	"Acheron 159"
	Class		"Asteroid"
	Mass		1.1983544048432361e-07
	Radius		38.65460692045385

	Orbit
	{
		Epoch			2457395.5
		Period			0.00041953577844271633
		Eccentricity	0.0059692428508386795
		Inclination		259.4309843092317
		AscendingNode	135.50721270791266
		ArgOfPericen	316.6424977221909
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 160"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.8858163404001977e-07
	Radius		57.86372231056977

	RotationPeriod	11.122633345724227

	Obliquity		295.74959028147083

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5634102764130824
		Eccentricity	0.07412458476171013
		Inclination		2.10250780879932
		AscendingNode	323.2181168910395
		ArgOfPericen	265.8714150023568
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 161"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6472800725125238e-07
	Radius		43.21694959522706

	RotationPeriod	8.168710956694108

	Obliquity		311.6801813206629

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5475130493090996
		Eccentricity	0.06403839879186042
		Inclination		-1.0733964262935964
		AscendingNode	177.75372488876948
		ArgOfPericen	266.6400141449405
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 162"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5332198698766243
		Eccentricity	0.06536231760887483
		Inclination		-1.5025118452359505
		AscendingNode	93.3532912824774
		ArgOfPericen	5.875361965743937
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 162 A"
{
	ParentBody	"Acheron 162"
	Class		"Asteroid"
	Mass		4.393687043888354e-08
	Radius		27.47202654542492

	Orbit
	{
		Epoch			2457395.5
		Period			0.003134913020449794
		Eccentricity	0.005487345876528437
		Inclination		47.06142514592002
		AscendingNode	94.41928421273472
		ArgOfPericen	102.63669789451467
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 162 B"
{
	ParentBody	"Acheron 162"
	Class		"Asteroid"
	Mass		2.7924629026358217e-08
	Radius		23.619831497795836

	Orbit
	{
		Epoch			2457395.5
		Period			0.003134913020449794
		Eccentricity	0.005487345876528437
		Inclination		47.06142514592002
		AscendingNode	94.41928421273472
		ArgOfPericen	282.63669789451467
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 163"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6151686666229616e-07
	Radius		53.978932388441606

	RotationPeriod	3.997590556619756

	Obliquity		253.61479503921444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5426583056594807
		Eccentricity	0.050474575400287984
		Inclination		-4.457971064553755
		AscendingNode	242.16501084948052
		ArgOfPericen	283.3089240562903
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 164"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5321370188673685
		Eccentricity	0.06450092072365657
		Inclination		2.546457913890153
		AscendingNode	141.67290999223286
		ArgOfPericen	263.094861081413
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 164 A"
{
	ParentBody	"Acheron 164"
	Class		"Asteroid"
	Mass		3.0728511396125444e-07
	Radius		47.86016844477918

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010000460933401612
		Eccentricity	0.005404072370792843
		Inclination		188.47096461899292
		AscendingNode	187.47106228721066
		ArgOfPericen	166.22951806310692
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 164 B"
{
	ParentBody	"Acheron 164"
	Class		"Asteroid"
	Mass		2.3949043010459284e-08
	Radius		20.44355583829787

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010000460933401612
		Eccentricity	0.005404072370792843
		Inclination		188.47096461899292
		AscendingNode	187.47106228721066
		ArgOfPericen	346.2295180631069
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 165"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.994099326412411e-08
	Radius		28.29810162958691

	RotationPeriod	6.213939426050237

	Obliquity		83.83089742695022

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5480336792630616
		Eccentricity	0.06034924138275524
		Inclination		-0.5190946829314881
		AscendingNode	54.487311346482116
		ArgOfPericen	101.63837802691643
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 165.1"
{
	ParentBody	"Acheron 165"
	Class		"Asteroid"
	Mass		8.108592900332981e-11
	Radius		3.3259833874251994

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6469367660416905e-06
		Eccentricity	0.005188853655522578
		Inclination		-29.629737940617385
		AscendingNode	108.73496070546645
		ArgOfPericen	50.42291167302798
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 166"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5406479205399566
		Eccentricity	0.06749992904525759
		Inclination		0.4289129397584393
		AscendingNode	185.2789084245714
		ArgOfPericen	91.96329380431567
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 166 A"
{
	ParentBody	"Acheron 166"
	Class		"Asteroid"
	Mass		3.782743497335498e-07
	Radius		56.52513103864232

	Orbit
	{
		Epoch			2457395.5
		Period			0.004403617923090773
		Eccentricity	0.0022036834763029247
		Inclination		257.51531925760975
		AscendingNode	204.54593904873522
		ArgOfPericen	71.89923269376023
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 166 B"
{
	ParentBody	"Acheron 166"
	Class		"Asteroid"
	Mass		7.518278815635945e-08
	Radius		32.987197640999334

	Orbit
	{
		Epoch			2457395.5
		Period			0.004403617923090773
		Eccentricity	0.0022036834763029247
		Inclination		257.51531925760975
		AscendingNode	204.54593904873522
		ArgOfPericen	251.8992326937602
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 167"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.294178013806386e-08
	Radius		30.02003741511206

	RotationPeriod	10.08807409912589

	Obliquity		261.5266579217413

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5428403407299518
		Eccentricity	0.04818824635738458
		Inclination		-3.579744253566501
		AscendingNode	33.300176246911356
		ArgOfPericen	215.3172281574078
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 168"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.818025190452727e-07
	Radius		65.63294644242734

	RotationPeriod	1.5353919572162251

	Obliquity		38.63210404049974

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5610565216245496
		Eccentricity	0.04343783299234259
		Inclination		-0.48360616281197893
		AscendingNode	136.37921474441245
		ArgOfPericen	207.62993885150186
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 169"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5484294677298829
		Eccentricity	0.07439916190990017
		Inclination		0.6673759428356543
		AscendingNode	157.988235178232
		ArgOfPericen	67.96886237074617
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 169 A"
{
	ParentBody	"Acheron 169"
	Class		"Asteroid"
	Mass		1.606479632802592e-07
	Radius		41.14964334983347

	Orbit
	{
		Epoch			2457395.5
		Period			0.007310937037033003
		Eccentricity	0.0060655019948889595
		Inclination		162.92394987040362
		AscendingNode	273.23912236221804
		ArgOfPericen	153.05116087801315
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 169 B"
{
	ParentBody	"Acheron 169"
	Class		"Asteroid"
	Mass		2.1991699447383562e-08
	Radius		21.20771758130034

	Orbit
	{
		Epoch			2457395.5
		Period			0.007310937037033003
		Eccentricity	0.0060655019948889595
		Inclination		162.92394987040362
		AscendingNode	273.23912236221804
		ArgOfPericen	333.05116087801315
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 170"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6069180929738727e-07
	Radius		54.276015230534675

	RotationPeriod	3.9100069458976776

	Obliquity		49.37956566591778

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.532447164482734
		Eccentricity	0.047663944879210336
		Inclination		-2.7002127400605476
		AscendingNode	326.0324860509823
		ArgOfPericen	223.78884065951706
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 170.1"
{
	ParentBody	"Acheron 170"
	Class		"Asteroid"
	Mass		2.6858279111587924e-09
	Radius		10.59876484235456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.0315313646685536e-06
		Eccentricity	0.004786952890885186
		Inclination		2.4573485827826653
		AscendingNode	332.2919917883995
		ArgOfPericen	316.98692799423725
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 170.2"
{
	ParentBody	"Acheron 170"
	Class		"Asteroid"
	Mass		1.7195054824055253e-09
	Radius		9.134758085876918

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.2615774578497625e-06
		Eccentricity	0.004144270694740281
		Inclination		33.40444258748577
		AscendingNode	281.31739030000574
		ArgOfPericen	175.30355690238602
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 170.3"
{
	ParentBody	"Acheron 170"
	Class		"Asteroid"
	Mass		3.6492567295651817e-09
	Radius		11.738988254229259

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.051726913865002e-07
		Eccentricity	0.0011636449760470697
		Inclination		-24.344336699828983
		AscendingNode	141.0237105497366
		ArgOfPericen	308.05642542274023
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 171"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5441911312444675
		Eccentricity	0.055819273978098716
		Inclination		2.619981327616791
		AscendingNode	128.7347784274442
		ArgOfPericen	164.07459620547888
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 171 A"
{
	ParentBody	"Acheron 171"
	Class		"Asteroid"
	Mass		2.697312183957883e-07
	Radius		51.58852650766076

	Orbit
	{
		Epoch			2457395.5
		Period			0.007665973527192506
		Eccentricity	0.00505259888690242
		Inclination		126.52272166290996
		AscendingNode	25.73199440641064
		ArgOfPericen	160.77266955070522
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 171 B"
{
	ParentBody	"Acheron 171"
	Class		"Asteroid"
	Mass		2.7537962401650073e-08
	Radius		24.11126445115205

	Orbit
	{
		Epoch			2457395.5
		Period			0.007665973527192506
		Eccentricity	0.00505259888690242
		Inclination		126.52272166290996
		AscendingNode	25.73199440641064
		ArgOfPericen	340.77266955070525
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 172"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.58372690252622e-07
	Radius		70.43183260943549

	RotationPeriod	9.73094056092122

	Obliquity		242.1210328060124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5372274750950096
		Eccentricity	0.05905737918058716
		Inclination		1.871420649750387
		AscendingNode	16.339717185137125
		ArgOfPericen	91.87709249936671
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 173"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.2619304661552724e-08
	Radius		29.185321296125434

	RotationPeriod	11.591209124128408

	Obliquity		15.37337450473046

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5559515980000147
		Eccentricity	0.07259172491605433
		Inclination		1.6589422849208357
		AscendingNode	68.57697419268023
		ArgOfPericen	166.47538251859265
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 174"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.363940343617582e-07
	Radius		68.73653082840102

	RotationPeriod	5.86826645558658

	Obliquity		349.0664332722587

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5705267363829072
		Eccentricity	0.05468690135831674
		Inclination		1.2819736386494505
		AscendingNode	238.68715975927034
		ArgOfPericen	159.58337085491308
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 174.1"
{
	ParentBody	"Acheron 174"
	Class		"Asteroid"
	Mass		3.654705851747105e-09
	Radius		11.724697994444476

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.6244367139336144e-06
		Eccentricity	0.0034819602928297592
		Inclination		25.90675623642138
		AscendingNode	332.6422851656644
		ArgOfPericen	300.2468895423433
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 175"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.182888277372813e-09
	Radius		14.80419124733389

	RotationPeriod	6.947376624170292

	Obliquity		325.5105258821165

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5594630754937163
		Eccentricity	0.038728424947761186
		Inclination		1.774546087323454
		AscendingNode	81.9895977083072
		ArgOfPericen	284.63805412425376
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 175.1"
{
	ParentBody	"Acheron 175"
	Class		"Asteroid"
	Mass		4.240910305043866e-11
	Radius		2.675703656530189

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7409750745788114e-06
		Eccentricity	0.0032953573645849664
		Inclination		-6.916588749590431
		AscendingNode	277.57652977672785
		ArgOfPericen	242.63409961665147
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 176"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.571868058521751
		Eccentricity	0.04650415892169297
		Inclination		-1.4285166408012242
		AscendingNode	155.73921245373262
		ArgOfPericen	294.5886258122986
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 176 A"
{
	ParentBody	"Acheron 176"
	Class		"Asteroid"
	Mass		1.7285120227744417e-07
	Radius		42.65712258203568

	Orbit
	{
		Epoch			2457395.5
		Period			0.002999702323366886
		Eccentricity	0.0028223786244807804
		Inclination		124.61444189945281
		AscendingNode	180.5218751623053
		ArgOfPericen	48.04700740203256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 176 B"
{
	ParentBody	"Acheron 176"
	Class		"Asteroid"
	Mass		1.8646496241123856e-08
	Radius		20.30641081468449

	Orbit
	{
		Epoch			2457395.5
		Period			0.002999702323366886
		Eccentricity	0.0028223786244807804
		Inclination		124.61444189945281
		AscendingNode	180.5218751623053
		ArgOfPericen	228.04700740203256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 177"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.976688874506103e-07
	Radius		60.41478868622837

	RotationPeriod	7.208606241917387

	Obliquity		59.85416297033262

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5498726498971135
		Eccentricity	0.05502092583602524
		Inclination		0.026392266413736525
		AscendingNode	1.045212021692934
		ArgOfPericen	170.99645827718078
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 178"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.096597346440326e-07
	Radius		63.824352104245555

	RotationPeriod	5.279266937696787

	Obliquity		321.0380042940161

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5330858745577272
		Eccentricity	0.03326405897230783
		Inclination		0.14589800768695402
		AscendingNode	27.96968665259884
		ArgOfPericen	223.43221550059792
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 179"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.8235209038881464e-08
	Radius		24.11655943375994

	RotationPeriod	3.1012286687058097

	Obliquity		108.65234482251

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5365486592533829
		Eccentricity	0.05320805385562144
		Inclination		-0.43518817052243775
		AscendingNode	328.65535367823617
		ArgOfPericen	274.70973202916514
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 179.1"
{
	ParentBody	"Acheron 179"
	Class		"Asteroid"
	Mass		2.4060224793245567e-10
	Radius		4.925892246145837

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7755843126253867e-06
		Eccentricity	0.00463979689144787
		Inclination		9.065334238600514
		AscendingNode	67.5925636167775
		ArgOfPericen	154.265206057546
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 180"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.9503272139545383e-08
	Radius		31.95645123792989

	RotationPeriod	7.034827802594408

	Obliquity		40.37404881962038

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5192398949668907
		Eccentricity	0.06009957522898905
		Inclination		-1.4998307148919074
		AscendingNode	130.87455045478862
		ArgOfPericen	214.8449917973269
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 180.1"
{
	ParentBody	"Acheron 180"
	Class		"Asteroid"
	Mass		8.899197251792915e-10
	Radius		7.873391972372957

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.367827674960991e-06
		Eccentricity	0.004435859246147129
		Inclination		-9.14007696106064
		AscendingNode	43.003363116395896
		ArgOfPericen	49.14538802330846
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 180.2"
{
	ParentBody	"Acheron 180"
	Class		"Asteroid"
	Mass		3.320465624173309e-11
	Radius		2.6309419042668782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3091710073002296e-06
		Eccentricity	0.006283063754178073
		Inclination		-23.3947917364166
		AscendingNode	192.08965676784644
		ArgOfPericen	201.98993044423014
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 181"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5464503817569806
		Eccentricity	0.03378855450426799
		Inclination		-2.1301257342315085
		AscendingNode	302.26154463785144
		ArgOfPericen	270.1888901579751
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 181 A"
{
	ParentBody	"Acheron 181"
	Class		"Asteroid"
	Mass		6.470137060408169e-07
	Radius		69.55225848080633

	Orbit
	{
		Epoch			2457395.5
		Period			0.003489640244890691
		Eccentricity	0.004355416794102661
		Inclination		228.158290261333
		AscendingNode	335.5964206305715
		ArgOfPericen	159.51258636406246
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 181 B"
{
	ParentBody	"Acheron 181"
	Class		"Asteroid"
	Mass		5.289340743532864e-07
	Radius		65.03401873657496

	Orbit
	{
		Epoch			2457395.5
		Period			0.003489640244890691
		Eccentricity	0.004355416794102661
		Inclination		228.158290261333
		AscendingNode	335.5964206305715
		ArgOfPericen	339.5125863640625
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 182"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.67080714926723e-07
	Radius		42.04875970658885

	RotationPeriod	6.987531854678625

	Obliquity		249.6169101668673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5552009584804529
		Eccentricity	0.05511105327794194
		Inclination		-1.09627063724192
		AscendingNode	15.998016075410892
		ArgOfPericen	326.3053618916814
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 183"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5378032684427466
		Eccentricity	0.06285158300516265
		Inclination		-2.3939373890892153
		AscendingNode	208.5368783565487
		ArgOfPericen	326.7266663061314
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 183 A"
{
	ParentBody	"Acheron 183"
	Class		"Asteroid"
	Mass		3.0827866373700625e-07
	Radius		57.32445457008892

	Orbit
	{
		Epoch			2457395.5
		Period			0.005984220707097973
		Eccentricity	0.0024818700320444636
		Inclination		294.7519756119391
		AscendingNode	112.9224310456346
		ArgOfPericen	124.03153349250566
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 183 B"
{
	ParentBody	"Acheron 183"
	Class		"Asteroid"
	Mass		3.875826520844087e-08
	Radius		28.717516898624854

	Orbit
	{
		Epoch			2457395.5
		Period			0.005984220707097973
		Eccentricity	0.0024818700320444636
		Inclination		294.7519756119391
		AscendingNode	112.9224310456346
		ArgOfPericen	304.0315334925057
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 184"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.359529468980821e-07
	Radius		44.3719116217112

	RotationPeriod	6.672748400731669

	Obliquity		341.1370646645436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5484199606976725
		Eccentricity	0.04569482992110818
		Inclination		1.021725995820024
		AscendingNode	181.776994002488
		ArgOfPericen	77.83267526879737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 185"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.585089137596561e-07
	Radius		66.81463068788403

	RotationPeriod	5.236717114713387

	Obliquity		117.41905108241835

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5492004242780569
		Eccentricity	0.03435683503081398
		Inclination		-1.7328174793039335
		AscendingNode	55.1698241307633
		ArgOfPericen	248.18287142340188
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 186"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.1059733569823545e-07
	Radius		48.52427628670464

	RotationPeriod	5.943775462403244

	Obliquity		178.0116501012639

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5152877337503823
		Eccentricity	0.025344325832142363
		Inclination		0.5617577504711532
		AscendingNode	253.345197517179
		ArgOfPericen	322.36921510900055
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 187"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.375203953303746e-08
	Radius		35.250351974167145

	RotationPeriod	5.08132999881408

	Obliquity		67.24464476936546

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5393022870702845
		Eccentricity	0.0809468534941769
		Inclination		-2.102598070176109
		AscendingNode	207.058093360488
		ArgOfPericen	67.9769863492281
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 187.1"
{
	ParentBody	"Acheron 187"
	Class		"Asteroid"
	Mass		7.070393102052717e-10
	Radius		6.912753484837924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.284689151892349e-06
		Eccentricity	0.004558060146523454
		Inclination		-3.5973372385589504
		AscendingNode	139.38041017824153
		ArgOfPericen	142.15965998625222
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 188"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.891250929678725e-07
	Radius		74.7189986564265

	RotationPeriod	8.350089534877231

	Obliquity		238.9542705234969

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5417961878279801
		Eccentricity	0.06288000486188608
		Inclination		1.190703271651644
		AscendingNode	348.4382795127737
		ArgOfPericen	107.1783677168574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 189"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.916869980776411e-08
	Radius		26.834626721325517

	RotationPeriod	3.9693301789532542

	Obliquity		216.64234190499943

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4982174029344284
		Eccentricity	0.03192134742243613
		Inclination		-2.4002608989996164
		AscendingNode	222.0167403907579
		ArgOfPericen	53.081926712317305
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 189.1"
{
	ParentBody	"Acheron 189"
	Class		"Asteroid"
	Mass		8.724093495842666e-12
	Radius		1.626631870148676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9936973993364886e-06
		Eccentricity	0.006351053432132886
		Inclination		-32.33904549654273
		AscendingNode	44.77374088003843
		ArgOfPericen	59.11765843792458
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 190"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5330574096901873
		Eccentricity	0.06921634919407206
		Inclination		-1.1782251526465974
		AscendingNode	32.74145848297393
		ArgOfPericen	329.72620334838774
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 190 A"
{
	ParentBody	"Acheron 190"
	Class		"Asteroid"
	Mass		7.3812739945410006e-09
	Radius		15.058925857430054

	Orbit
	{
		Epoch			2457395.5
		Period			0.003592241266983456
		Eccentricity	0.003244025754176444
		Inclination		99.5386299681135
		AscendingNode	261.2469542902578
		ArgOfPericen	281.19962228834265
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 190 B"
{
	ParentBody	"Acheron 190"
	Class		"Asteroid"
	Mass		5.081549575074654e-09
	Radius		13.296855272147905

	Orbit
	{
		Epoch			2457395.5
		Period			0.003592241266983456
		Eccentricity	0.003244025754176444
		Inclination		99.5386299681135
		AscendingNode	261.2469542902578
		ArgOfPericen	101.19962228834265
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 191"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5445767790613315
		Eccentricity	0.042663979221041065
		Inclination		-1.152191727576011
		AscendingNode	89.19334604620812
		ArgOfPericen	283.51154148746303
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 191 A"
{
	ParentBody	"Acheron 191"
	Class		"Asteroid"
	Mass		4.0975159570195345e-08
	Radius		26.4119039080286

	Orbit
	{
		Epoch			2457395.5
		Period			0.006438733103703689
		Eccentricity	0.0030329267150216105
		Inclination		182.51167295828293
		AscendingNode	60.184774505065235
		ArgOfPericen	273.4043559965002
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 191 B"
{
	ParentBody	"Acheron 191"
	Class		"Asteroid"
	Mass		2.3996542891631322e-08
	Radius		22.097461383728625

	Orbit
	{
		Epoch			2457395.5
		Period			0.006438733103703689
		Eccentricity	0.0030329267150216105
		Inclination		182.51167295828293
		AscendingNode	60.184774505065235
		ArgOfPericen	93.40435599650021
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 192"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.276710269637606e-07
	Radius		69.61903277678576

	RotationPeriod	6.610267608768256

	Obliquity		153.31215677281708

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5346807666970079
		Eccentricity	0.0522268294779408
		Inclination		1.457513627851009
		AscendingNode	69.41855786170757
		ArgOfPericen	337.3403475928464
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 192.1"
{
	ParentBody	"Acheron 192"
	Class		"Asteroid"
	Mass		1.1085725865674853e-10
	Radius		3.9060578362402647

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.661665305357696e-06
		Eccentricity	0.004061816467406378
		Inclination		8.120378750305857
		AscendingNode	178.08365241720418
		ArgOfPericen	220.11641327043884
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 193"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5794178670392556e-07
	Radius		42.67303842776103

	RotationPeriod	4.964202705177414

	Obliquity		356.21353788177447

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5418981497721613
		Eccentricity	0.057256119432199
		Inclination		0.8971503865975583
		AscendingNode	177.4667995224121
		ArgOfPericen	179.04428338422446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 194"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.686760165427454e-07
	Radius		57.07455753899026

	RotationPeriod	5.386691248446862

	Obliquity		241.3732862186106

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5323891887025054
		Eccentricity	0.057528622648252925
		Inclination		-2.7586423585543742
		AscendingNode	310.682460953346
		ArgOfPericen	130.42286501077115
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 195"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.192644489556583e-07
	Radius		47.836006488055546

	RotationPeriod	6.487345345037706

	Obliquity		112.26211251437394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5406613572790596
		Eccentricity	0.014493022085681484
		Inclination		-1.0808041492719909
		AscendingNode	200.43153455612463
		ArgOfPericen	149.92668088131433
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 196"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5266716585639283
		Eccentricity	0.055606168073607194
		Inclination		-1.2712361607482845
		AscendingNode	25.200549436145565
		ArgOfPericen	262.6437593742504
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 196 A"
{
	ParentBody	"Acheron 196"
	Class		"Asteroid"
	Mass		3.9742861926300013e-07
	Radius		56.641507720803965

	Orbit
	{
		Epoch			2457395.5
		Period			0.002290504476857233
		Eccentricity	0.004828297427318237
		Inclination		169.78253734954194
		AscendingNode	134.59614982394024
		ArgOfPericen	130.45412897521535
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 196 B"
{
	ParentBody	"Acheron 196"
	Class		"Asteroid"
	Mass		3.2969639097255745e-08
	Radius		24.70319672542447

	Orbit
	{
		Epoch			2457395.5
		Period			0.002290504476857233
		Eccentricity	0.004828297427318237
		Inclination		169.78253734954194
		AscendingNode	134.59614982394024
		ArgOfPericen	310.4541289752153
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 197"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.7372154108388545e-07
	Radius		55.854057211755375

	RotationPeriod	4.608872085660652

	Obliquity		93.40682904149534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5451202737140651
		Eccentricity	0.06865049749779811
		Inclination		0.7358866292611842
		AscendingNode	29.843961836256664
		ArgOfPericen	218.7273136017426
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 198"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.343212979667509e-08
	Radius		34.57794041486572

	RotationPeriod	6.220676846146379

	Obliquity		98.0193921092955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5354179975368363
		Eccentricity	0.05373079891987546
		Inclination		-1.1748445872640063
		AscendingNode	105.42578758608332
		ArgOfPericen	0.9519944327927865
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 199"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.7780927049705277e-07
	Radius		60.010692294308335

	RotationPeriod	8.201851394716474

	Obliquity		299.20062243700704

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5216043227488099
		Eccentricity	0.018231754041392878
		Inclination		-0.27965535320537965
		AscendingNode	205.7088448447795
		ArgOfPericen	148.36875029639498
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 200"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3547320280812561e-06
	Radius		83.58164361519343

	RotationPeriod	3.997453380690541

	Obliquity		290.61003648609386

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5512552634234523
		Eccentricity	0.07530541986279575
		Inclination		-0.5423083512708382
		AscendingNode	147.1798379528675
		ArgOfPericen	192.9650786383779
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 201"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1775665943252626e-07
	Radius		36.58615857309306

	RotationPeriod	1.9874172534615768

	Obliquity		18.673079770981648

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5635508799911236
		Eccentricity	0.060883341526008
		Inclination		-0.14095776483789665
		AscendingNode	235.52605622427217
		ArgOfPericen	161.83433494033991
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 202"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2636673513637763e-07
	Radius		37.85592035850763

	RotationPeriod	6.100038189440234

	Obliquity		131.11122725460734

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.551171929591979
		Eccentricity	0.04287159657166733
		Inclination		-1.9967354204489227
		AscendingNode	286.92135924745213
		ArgOfPericen	25.035102146269985
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 203"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.545772515817158
		Eccentricity	0.02731648332681613
		Inclination		-1.9482525827792785
		AscendingNode	245.6674260630527
		ArgOfPericen	191.47358229187458
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 203 A"
{
	ParentBody	"Acheron 203"
	Class		"Asteroid"
	Mass		3.61212134277912e-07
	Radius		56.64735625748766

	Orbit
	{
		Epoch			2457395.5
		Period			0.004738796085323589
		Eccentricity	0.005362689700263436
		Inclination		347.08944571082424
		AscendingNode	292.7077156461693
		ArgOfPericen	340.0896170241472
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 203 B"
{
	ParentBody	"Acheron 203"
	Class		"Asteroid"
	Mass		3.5661120742312434e-08
	Radius		26.181259278385962

	Orbit
	{
		Epoch			2457395.5
		Period			0.004738796085323589
		Eccentricity	0.005362689700263436
		Inclination		347.08944571082424
		AscendingNode	292.7077156461693
		ArgOfPericen	160.08961702414717
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 204"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.79295287006269e-08
	Radius		33.5607787334703

	RotationPeriod	7.40016305172719

	Obliquity		351.7479171731715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5361882823726134
		Eccentricity	0.053404684009296
		Inclination		0.9215719712102121
		AscendingNode	218.39182547904366
		ArgOfPericen	191.94720665133462
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 204.1"
{
	ParentBody	"Acheron 204"
	Class		"Asteroid"
	Mass		1.1382065173070344e-10
	Radius		3.807778718334789

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.642963000018362e-06
		Eccentricity	0.003764097047316425
		Inclination		42.72096193728764
		AscendingNode	160.2519081707387
		ArgOfPericen	27.052370280117813
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 205"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.024366764395435e-07
	Radius		66.77295101204476

	RotationPeriod	4.725640730170998

	Obliquity		229.59143139835783

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5249663450800969
		Eccentricity	0.03439935171722043
		Inclination		0.42341293839300614
		AscendingNode	189.1997645358093
		ArgOfPericen	138.24077725305756
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 206"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5319307999193562
		Eccentricity	0.041991278725002565
		Inclination		1.1187910842106839
		AscendingNode	239.16015669471636
		ArgOfPericen	287.1888320078438
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 206 A"
{
	ParentBody	"Acheron 206"
	Class		"Asteroid"
	Mass		1.9174962790235622e-07
	Radius		47.245546617585205

	Orbit
	{
		Epoch			2457395.5
		Period			0.00221932537841522
		Eccentricity	0.004613361707302333
		Inclination		111.8844584555693
		AscendingNode	190.1821131159048
		ArgOfPericen	52.452402978839835
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 206 B"
{
	ParentBody	"Acheron 206"
	Class		"Asteroid"
	Mass		8.835623965879896e-09
	Radius		16.937986260155643

	Orbit
	{
		Epoch			2457395.5
		Period			0.00221932537841522
		Eccentricity	0.004613361707302333
		Inclination		111.8844584555693
		AscendingNode	190.1821131159048
		ArgOfPericen	232.45240297883984
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 207"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.137329414838726e-07
	Radius		45.17391832896011

	RotationPeriod	6.746124384126599

	Obliquity		232.63229910118685

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5354980334336144
		Eccentricity	0.05413294575199541
		Inclination		0.6098381748582805
		AscendingNode	319.72802452194173
		ArgOfPericen	72.46923412447191
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 208"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5419105087493898
		Eccentricity	0.01936207924155407
		Inclination		-0.05285557442647002
		AscendingNode	212.77080445003307
		ArgOfPericen	331.44985751685624
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 208 A"
{
	ParentBody	"Acheron 208"
	Class		"Asteroid"
	Mass		4.359706338760467e-08
	Radius		26.825142019854404

	Orbit
	{
		Epoch			2457395.5
		Period			0.005111479254934804
		Eccentricity	0.0035201255595560706
		Inclination		11.868714282885012
		AscendingNode	340.87795463646296
		ArgOfPericen	293.88765899932326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 208 B"
{
	ParentBody	"Acheron 208"
	Class		"Asteroid"
	Mass		7.614396128306253e-09
	Radius		14.994596140891705

	Orbit
	{
		Epoch			2457395.5
		Period			0.005111479254934804
		Eccentricity	0.0035201255595560706
		Inclination		11.868714282885012
		AscendingNode	340.87795463646296
		ArgOfPericen	113.88765899932326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 209"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3267697117454676e-07
	Radius		55.68817837456258

	RotationPeriod	6.406421476487119

	Obliquity		63.539343084152875

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5244313994548211
		Eccentricity	0.026646985363248554
		Inclination		-0.16968896777868306
		AscendingNode	1.8104359852401775
		ArgOfPericen	79.72576779892587
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 210"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5153964262747043
		Eccentricity	0.05327497660208534
		Inclination		3.6136677153693997
		AscendingNode	346.97736078283197
		ArgOfPericen	243.136849443044
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 210 A"
{
	ParentBody	"Acheron 210"
	Class		"Asteroid"
	Mass		5.061131723432317e-07
	Radius		60.083359477313564

	Orbit
	{
		Epoch			2457395.5
		Period			0.003952251304030265
		Eccentricity	0.005306056806499721
		Inclination		106.90768047784437
		AscendingNode	113.25625185583499
		ArgOfPericen	347.66164099752217
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 210 B"
{
	ParentBody	"Acheron 210"
	Class		"Asteroid"
	Mass		9.09709158741557e-08
	Radius		33.90828695619872

	Orbit
	{
		Epoch			2457395.5
		Period			0.003952251304030265
		Eccentricity	0.005306056806499721
		Inclination		106.90768047784437
		AscendingNode	113.25625185583499
		ArgOfPericen	167.66164099752223
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 211"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5526017202513596
		Eccentricity	0.05494913942999356
		Inclination		0.14908304208706769
		AscendingNode	152.17013701968025
		ArgOfPericen	208.2358219929517
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 211 A"
{
	ParentBody	"Acheron 211"
	Class		"Asteroid"
	Mass		1.1447697717325128e-07
	Radius		39.81880349990877

	Orbit
	{
		Epoch			2457395.5
		Period			0.004358497359266503
		Eccentricity	0.0047658758713669
		Inclination		143.70830770313762
		AscendingNode	354.09870169029386
		ArgOfPericen	261.8091686094546
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 211 B"
{
	ParentBody	"Acheron 211"
	Class		"Asteroid"
	Mass		5.48940256378873e-08
	Radius		31.166678078222315

	Orbit
	{
		Epoch			2457395.5
		Period			0.004358497359266503
		Eccentricity	0.0047658758713669
		Inclination		143.70830770313762
		AscendingNode	354.09870169029386
		ArgOfPericen	81.80916860945462
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 212"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.445376049911532e-07
	Radius		48.73398176848083

	RotationPeriod	9.571213487332699

	Obliquity		354.4592651091012

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5134013686637449
		Eccentricity	0.03954903500553962
		Inclination		2.702647776883636
		AscendingNode	34.07973293655876
		ArgOfPericen	235.54131523864385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 212.1"
{
	ParentBody	"Acheron 212"
	Class		"Asteroid"
	Mass		3.1191510842951537e-09
	Radius		11.386637167522778

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.096010910532049e-07
		Eccentricity	0.004246166962415211
		Inclination		2.8678790802980005
		AscendingNode	95.9214811703752
		ArgOfPericen	139.24641909326394
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 213"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.7269843717620247e-07
	Radius		44.37975067080656

	RotationPeriod	7.087094735260255

	Obliquity		180.9842036651836

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5478454031503952
		Eccentricity	0.08103602111980739
		Inclination		2.593802695336707
		AscendingNode	35.37571433407966
		ArgOfPericen	203.8875617693983
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 214"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.773229636211991e-07
	Radius		70.02481860762035

	RotationPeriod	4.5791670239058195

	Obliquity		226.58647861621054

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5510741138852187
		Eccentricity	0.030324652836059406
		Inclination		-0.4554170317718571
		AscendingNode	158.62824789849992
		ArgOfPericen	113.9682023926069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 215"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2921971823195555e-07
	Radius		45.6312722210307

	RotationPeriod	4.26940524664618

	Obliquity		332.397842761584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5548301965172772
		Eccentricity	0.02883617938731669
		Inclination		-0.28593577834359796
		AscendingNode	221.2162640730963
		ArgOfPericen	183.48383098448974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 216"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5161790441100606e-07
	Radius		41.02313900508413

	RotationPeriod	7.313023008033342

	Obliquity		334.1411427553958

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5460740747533286
		Eccentricity	0.028272155998383345
		Inclination		-0.6969465637491625
		AscendingNode	238.9711784772021
		ArgOfPericen	214.43434844384703
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 216.1"
{
	ParentBody	"Acheron 216"
	Class		"Asteroid"
	Mass		2.6820746293776685e-10
	Radius		4.961378321748754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.321809588407114e-06
		Eccentricity	0.005684741937023206
		Inclination		18.985693974788116
		AscendingNode	153.24002402456458
		ArgOfPericen	111.27419832240338
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 217"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.728541714459806e-07
	Radius		79.26340043631774

	RotationPeriod	8.450930197939808

	Obliquity		132.21808717207776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5472105523908588
		Eccentricity	0.03695350904747021
		Inclination		-0.9394553919429046
		AscendingNode	286.55905177854345
		ArgOfPericen	141.80752425783976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 218"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5338231447562654
		Eccentricity	0.04191794633759295
		Inclination		-1.1259195435887435
		AscendingNode	116.87655909301782
		ArgOfPericen	170.97872270147806
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 218 A"
{
	ParentBody	"Acheron 218"
	Class		"Asteroid"
	Mass		5.736315681276788e-07
	Radius		63.36242803057801

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008914393520886484
		Eccentricity	0.002032647048533563
		Inclination		265.89228418725804
		AscendingNode	15.586992166784999
		ArgOfPericen	137.112934835024
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 218 B"
{
	ParentBody	"Acheron 218"
	Class		"Asteroid"
	Mass		3.20408995294392e-07
	Radius		52.18219737909666

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008914393520886484
		Eccentricity	0.002032647048533563
		Inclination		265.89228418725804
		AscendingNode	15.586992166784999
		ArgOfPericen	317.112934835024
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 219"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.1089990385686644e-07
	Radius		57.37413645592253

	RotationPeriod	4.893471400337865

	Obliquity		354.68662086244717

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5453361395298649
		Eccentricity	0.052190950027442846
		Inclination		-1.919558055280585
		AscendingNode	329.26609521459716
		ArgOfPericen	270.2591470081001
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 220"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0773714448085782e-07
	Radius		37.84806714179563

	RotationPeriod	5.92865759103635

	Obliquity		178.47572715010776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5306125283221935
		Eccentricity	0.03742618061246341
		Inclination		-2.991647882028705
		AscendingNode	296.3865446281869
		ArgOfPericen	110.16960557983583
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 221"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5276244997209579
		Eccentricity	0.061897856295535354
		Inclination		0.7560987212255252
		AscendingNode	119.5115687610392
		ArgOfPericen	140.46606136514572
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 221 A"
{
	ParentBody	"Acheron 221"
	Class		"Asteroid"
	Mass		2.063342807894052e-07
	Radius		45.26763736751617

	Orbit
	{
		Epoch			2457395.5
		Period			0.003985370441885013
		Eccentricity	0.0034136615818469392
		Inclination		158.4604894882515
		AscendingNode	313.6989513952372
		ArgOfPericen	219.52450149561537
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 221 B"
{
	ParentBody	"Acheron 221"
	Class		"Asteroid"
	Mass		4.6248996781167974e-09
	Radius		12.763353686666429

	Orbit
	{
		Epoch			2457395.5
		Period			0.003985370441885013
		Eccentricity	0.0034136615818469392
		Inclination		158.4604894882515
		AscendingNode	313.6989513952372
		ArgOfPericen	39.52450149561537
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 222"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5188911306727249
		Eccentricity	0.04216228367722829
		Inclination		2.523106149116197
		AscendingNode	85.53343876999861
		ArgOfPericen	144.75142460257166
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 222 A"
{
	ParentBody	"Acheron 222"
	Class		"Asteroid"
	Mass		1.9509373046982e-07
	Radius		44.61438209454417

	Orbit
	{
		Epoch			2457395.5
		Period			0.003971045530851769
		Eccentricity	0.0038238067569257806
		Inclination		155.82327494392135
		AscendingNode	326.5772779312981
		ArgOfPericen	223.32513594311203
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 222 B"
{
	ParentBody	"Acheron 222"
	Class		"Asteroid"
	Mass		5.271265820955042e-09
	Radius		13.387477395490027

	Orbit
	{
		Epoch			2457395.5
		Period			0.003971045530851769
		Eccentricity	0.0038238067569257806
		Inclination		155.82327494392135
		AscendingNode	326.5772779312981
		ArgOfPericen	43.32513594311206
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 223"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3235291447253126e-08
	Radius		25.345876501974537

	RotationPeriod	6.123098088416711

	Obliquity		80.26003151101158

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5434979738735349
		Eccentricity	0.030659123309761237
		Inclination		1.418990977985429
		AscendingNode	228.38683598666114
		ArgOfPericen	161.91447705298762
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 224"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.328475866960064e-07
	Radius		63.7038480406445

	RotationPeriod	3.7774921690557823

	Obliquity		0.23009441130480202

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5418500260954725
		Eccentricity	0.04758890488560108
		Inclination		-4.652186557905601
		AscendingNode	36.54384511630737
		ArgOfPericen	336.0876545643429
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 225"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.434357854320892e-08
	Radius		24.909585320128024

	RotationPeriod	7.563258954617074

	Obliquity		146.039892000903

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5077805140754628
		Eccentricity	0.04394615927551075
		Inclination		-1.0526390435258146
		AscendingNode	90.31476759643124
		ArgOfPericen	327.33400029224083
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 226"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4393177588856154e-07
	Radius		38.71211201998245

	RotationPeriod	10.013727410838417

	Obliquity		106.32765567058532

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5737063280773684
		Eccentricity	0.047758035896544065
		Inclination		0.013846378189759614
		AscendingNode	320.1803727582577
		ArgOfPericen	137.0718731436895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 227"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5433457039690561
		Eccentricity	0.07474528875357034
		Inclination		1.7622948700500352
		AscendingNode	111.66060738551118
		ArgOfPericen	62.51819803617024
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 227 A"
{
	ParentBody	"Acheron 227"
	Class		"Asteroid"
	Mass		5.736763332666197e-07
	Radius		66.00964375135673

	Orbit
	{
		Epoch			2457395.5
		Period			0.007017730056141934
		Eccentricity	0.005485023658623833
		Inclination		151.66132238780244
		AscendingNode	106.2630069611329
		ArgOfPericen	289.8447483779116
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 227 B"
{
	ParentBody	"Acheron 227"
	Class		"Asteroid"
	Mass		3.5388074753456233e-07
	Radius		56.19151261908908

	Orbit
	{
		Epoch			2457395.5
		Period			0.007017730056141934
		Eccentricity	0.005485023658623833
		Inclination		151.66132238780244
		AscendingNode	106.2630069611329
		ArgOfPericen	109.84474837791163
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 228"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.66311508060608e-07
	Radius		72.98273888335505

	RotationPeriod	4.566885659611047

	Obliquity		10.919916567318634

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5348135397219335
		Eccentricity	0.04551589048080366
		Inclination		1.449475177210753
		AscendingNode	340.0833936183823
		ArgOfPericen	306.6785815740991
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 229"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.6655601903448875e-08
	Radius		29.482251061090228

	RotationPeriod	8.236849304701114

	Obliquity		66.84845447156027

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5034570511021176
		Eccentricity	0.0437507141608059
		Inclination		-1.1499534228936545
		AscendingNode	207.19813465070462
		ArgOfPericen	107.85946696741019
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 230"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2700237559321917e-07
	Radius		47.265795824486986

	RotationPeriod	2.0025298841236046

	Obliquity		239.19400877562637

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5556056985437072
		Eccentricity	0.07752996462155391
		Inclination		2.9154361782711464
		AscendingNode	82.14182021000894
		ArgOfPericen	334.79033629768054
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 231"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.046729072664056e-07
	Radius		36.97696554849129

	RotationPeriod	4.599393864545538

	Obliquity		215.41409859810267

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5411023914009198
		Eccentricity	0.07150119887913017
		Inclination		-0.33131768146949114
		AscendingNode	182.8468854598411
		ArgOfPericen	311.23561573300367
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 232"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.567262686860868e-08
	Radius		35.171731330805684

	RotationPeriod	6.8097775291894

	Obliquity		167.5619261388433

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5354676523484773
		Eccentricity	0.05504404864881034
		Inclination		1.3784388731716515
		AscendingNode	330.32275023592297
		ArgOfPericen	40.42050277461919
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 232.1"
{
	ParentBody	"Acheron 232"
	Class		"Asteroid"
	Mass		4.2996977810099165e-10
	Radius		5.804219453507833

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2985998586967655e-06
		Eccentricity	0.0041063727765806935
		Inclination		-29.264648023974306
		AscendingNode	254.6777942244826
		ArgOfPericen	351.83729338175266
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 232.2"
{
	ParentBody	"Acheron 232"
	Class		"Asteroid"
	Mass		2.1572332214076305e-10
	Radius		4.6120805197206245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.7537505428703185e-06
		Eccentricity	0.004297584028204155
		Inclination		-9.098149248742336
		AscendingNode	230.6802049245652
		ArgOfPericen	152.3711148371847
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 233"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.560654996748548e-07
	Radius		51.9217014828814

	RotationPeriod	2.6484792134905772

	Obliquity		335.7085067296703

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5621298434286227
		Eccentricity	0.05589680801018873
		Inclination		-0.45936198156657876
		AscendingNode	19.805512039381306
		ArgOfPericen	242.61810545834604
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 233.1"
{
	ParentBody	"Acheron 233"
	Class		"Asteroid"
	Mass		6.070532413738077e-10
	Radius		6.923209712153705

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.0288925239268733e-06
		Eccentricity	0.006701630049010556
		Inclination		-26.28256415767176
		AscendingNode	118.67099850012656
		ArgOfPericen	100.87809536588651
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 233.2"
{
	ParentBody	"Acheron 233"
	Class		"Asteroid"
	Mass		2.2551494408029296e-10
	Radius		4.976878079004669

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.521103448099813e-06
		Eccentricity	0.002358468543830844
		Inclination		0.21322865271770647
		AscendingNode	9.662120702699543
		ArgOfPericen	280.2005543147118
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 233.3"
{
	ParentBody	"Acheron 233"
	Class		"Asteroid"
	Mass		3.839366043705184e-09
	Radius		12.803196161545461

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.4917339558924346e-06
		Eccentricity	0.005533666761380337
		Inclination		35.61498458246211
		AscendingNode	138.60849364799077
		ArgOfPericen	325.77658119459244
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 233.4"
{
	ParentBody	"Acheron 233"
	Class		"Asteroid"
	Mass		9.602431796046293e-11
	Radius		3.744199405875048

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.444330664999064e-06
		Eccentricity	0.005373759015923298
		Inclination		-8.977607691452066
		AscendingNode	329.22047268524824
		ArgOfPericen	233.96108588572773
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 234"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3490349095616014e-07
	Radius		53.75993048768707

	RotationPeriod	7.791308076446393

	Obliquity		113.11915776198721

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5298072929534924
		Eccentricity	0.07296944199907673
		Inclination		0.3884152959295889
		AscendingNode	253.80047082136207
		ArgOfPericen	171.58159705243878
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 234.1"
{
	ParentBody	"Acheron 234"
	Class		"Asteroid"
	Mass		3.6904664148094567e-09
	Radius		11.963159492419159

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.668087185099805e-06
		Eccentricity	0.002528955499294888
		Inclination		32.21017836928489
		AscendingNode	14.7161394600645
		ArgOfPericen	106.09161391811573
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 235"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.000449134045312e-07
	Radius		64.72472998754056

	RotationPeriod	5.871254968034648

	Obliquity		355.482032546622

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5671894231014355
		Eccentricity	0.06289767191406459
		Inclination		1.0244639404220008
		AscendingNode	59.55623615793001
		ArgOfPericen	312.24458719257063
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 236"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5474341334078584
		Eccentricity	0.05364462529673523
		Inclination		-0.6148278216576145
		AscendingNode	72.0779800891594
		ArgOfPericen	350.0734631178974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 236 A"
{
	ParentBody	"Acheron 236"
	Class		"Asteroid"
	Mass		1.7301801437676866e-07
	Radius		44.08756405197045

	Orbit
	{
		Epoch			2457395.5
		Period			0.005116068588654675
		Eccentricity	0.004534284977839883
		Inclination		257.2738029665069
		AscendingNode	309.19727074353193
		ArgOfPericen	194.42353028778751
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 236 B"
{
	ParentBody	"Acheron 236"
	Class		"Asteroid"
	Mass		1.3694275846999827e-08
	Radius		18.9291895309481

	Orbit
	{
		Epoch			2457395.5
		Period			0.005116068588654675
		Eccentricity	0.004534284977839883
		Inclination		257.2738029665069
		AscendingNode	309.19727074353193
		ArgOfPericen	14.423530287787514
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 237"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.662089663528104e-07
	Radius		45.490503653583694

	RotationPeriod	8.613492022706478

	Obliquity		342.5523849781456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5301513955755031
		Eccentricity	0.09183612597146493
		Inclination		-1.1976713204841651
		AscendingNode	73.29315557757157
		ArgOfPericen	303.44565008935865
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 238"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.907652959165056e-08
	Radius		36.47863758913034

	RotationPeriod	4.199964420070444

	Obliquity		320.5217222477297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.545926019496294
		Eccentricity	0.05319717566257772
		Inclination		1.5848425823734422
		AscendingNode	89.67609029755647
		ArgOfPericen	219.0612653364422
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 238.1"
{
	ParentBody	"Acheron 238"
	Class		"Asteroid"
	Mass		1.146207273185089e-09
	Radius		8.250293548550985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.1225199629839508e-06
		Eccentricity	0.006531939646442589
		Inclination		15.873559891130718
		AscendingNode	309.6317768455035
		ArgOfPericen	82.37432695999216
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 239"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.11879524641543e-07
	Radius		53.46615778625805

	RotationPeriod	5.154826830029506

	Obliquity		247.45014351957965

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.528435617301502
		Eccentricity	0.022799659147673165
		Inclination		1.0339774052506943
		AscendingNode	283.6159856203361
		ArgOfPericen	185.12433030868888
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 240"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5281672599064912
		Eccentricity	0.06404901524401341
		Inclination		0.04501618425909085
		AscendingNode	62.677733749987226
		ArgOfPericen	66.9219603879512
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 240 A"
{
	ParentBody	"Acheron 240"
	Class		"Asteroid"
	Mass		9.798409114714358e-08
	Radius		36.9635719382826

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006801683858007832
		Eccentricity	0.0030419177020313687
		Inclination		96.6664966954986
		AscendingNode	235.9607763835902
		ArgOfPericen	153.68475287266494
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 240 B"
{
	ParentBody	"Acheron 240"
	Class		"Asteroid"
	Mass		3.915503322240261e-09
	Radius		12.637212107382117

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006801683858007832
		Eccentricity	0.0030419177020313687
		Inclination		96.6664966954986
		AscendingNode	235.9607763835902
		ArgOfPericen	333.68475287266494
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 241"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.3402080770478273e-07
	Radius		52.70837546719931

	RotationPeriod	7.4787895498761126

	Obliquity		295.0980982396742

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5321003476877126
		Eccentricity	0.050039654328253934
		Inclination		-2.4216298392297197
		AscendingNode	267.03315200413397
		ArgOfPericen	190.8507262789444
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 242"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5447565136244016
		Eccentricity	0.046320603231784996
		Inclination		-1.4251650634467081
		AscendingNode	326.8307427870761
		ArgOfPericen	10.794953055525669
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 242 A"
{
	ParentBody	"Acheron 242"
	Class		"Asteroid"
	Mass		3.296698376713728e-07
	Radius		61.40898635274112

	Orbit
	{
		Epoch			2457395.5
		Period			0.001996109168040263
		Eccentricity	0.004078173144778394
		Inclination		106.82413342176262
		AscendingNode	312.1535773081222
		ArgOfPericen	251.2877318641719
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 242 B"
{
	ParentBody	"Acheron 242"
	Class		"Asteroid"
	Mass		1.5558286125344737e-08
	Radius		22.191812552304707

	Orbit
	{
		Epoch			2457395.5
		Period			0.001996109168040263
		Eccentricity	0.004078173144778394
		Inclination		106.82413342176262
		AscendingNode	312.1535773081222
		ArgOfPericen	71.28773186417186
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 243"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2211247368093806e-07
	Radius		49.66984522976202

	RotationPeriod	5.385614014723906

	Obliquity		319.95161633527385

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5368017851928211
		Eccentricity	0.057944658914821506
		Inclination		-3.6085263112414765
		AscendingNode	346.2753626944994
		ArgOfPericen	1.9540467688065588
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 244"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.425536869671918e-07
	Radius		46.623956414258416

	RotationPeriod	4.894079839436241

	Obliquity		320.36790653419365

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5591509430455225
		Eccentricity	0.0245591762751944
		Inclination		1.3510549621129897
		AscendingNode	114.66705537622437
		ArgOfPericen	104.08155081427843
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 245"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8760077703408344e-07
	Radius		44.42878658675613

	RotationPeriod	5.7829603779009595

	Obliquity		243.0909765482229

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5395119040264624
		Eccentricity	0.03951922134226103
		Inclination		1.0317968812730873
		AscendingNode	33.61208253171468
		ArgOfPericen	68.80191666079831
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 246"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.906269175249691e-07
	Radius		70.8573481936368

	RotationPeriod	8.809421153234773

	Obliquity		275.6158476570956

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5317450911427323
		Eccentricity	0.04479499276253582
		Inclination		-2.16770856260668
		AscendingNode	250.40452238237455
		ArgOfPericen	323.7989181186987
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 247"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3174106558728205e-07
	Radius		41.36078591986957

	RotationPeriod	5.608055338122586

	Obliquity		205.8775376496383

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5541148369659596
		Eccentricity	0.08018283734106614
		Inclination		-2.1776663989336256
		AscendingNode	26.22958848513635
		ArgOfPericen	54.60866464011766
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 248"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.29108314256542e-08
	Radius		35.59713941847459

	RotationPeriod	6.125174690024822

	Obliquity		355.5341613456595

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.534395563916374
		Eccentricity	0.051367367887679906
		Inclination		-0.7101691069789233
		AscendingNode	83.80753558639942
		ArgOfPericen	207.37424008252762
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 249"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5139094402797237
		Eccentricity	0.09351788747901069
		Inclination		0.27067967457296715
		AscendingNode	249.5073951106176
		ArgOfPericen	332.451440967858
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 249 A"
{
	ParentBody	"Acheron 249"
	Class		"Asteroid"
	Mass		8.968717173641455e-07
	Radius		72.56438332224538

	Orbit
	{
		Epoch			2457395.5
		Period			0.007640232943641015
		Eccentricity	0.004104366368686337
		Inclination		288.3489026241298
		AscendingNode	42.679624460845574
		ArgOfPericen	132.9486087238185
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 249 B"
{
	ParentBody	"Acheron 249"
	Class		"Asteroid"
	Mass		6.130885899738846e-07
	Radius		63.922606748983114

	Orbit
	{
		Epoch			2457395.5
		Period			0.007640232943641015
		Eccentricity	0.004104366368686337
		Inclination		288.3489026241298
		AscendingNode	42.679624460845574
		ArgOfPericen	312.9486087238185
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 250"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.54988685595367e-07
	Radius		66.03401095830263

	RotationPeriod	5.87939372061491

	Obliquity		327.66466082155057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5384033675507117
		Eccentricity	0.03017205836631831
		Inclination		1.9083796406121845
		AscendingNode	143.0516879589159
		ArgOfPericen	102.21996127067065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 250.1"
{
	ParentBody	"Acheron 250"
	Class		"Asteroid"
	Mass		1.169237471335925e-09
	Radius		8.465264701857102

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.817559323233917e-06
		Eccentricity	0.00694723796768175
		Inclination		-31.06287987777766
		AscendingNode	109.00558539986842
		ArgOfPericen	176.11702124412588
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 250.2"
{
	ParentBody	"Acheron 250"
	Class		"Asteroid"
	Mass		1.4808357238131587e-09
	Radius		9.158870714632386

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4270346755101676e-06
		Eccentricity	0.003277970943814196
		Inclination		-20.02211572930143
		AscendingNode	62.01503120458423
		ArgOfPericen	101.91340733045836
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 251"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.540284886083682
		Eccentricity	0.027572833287421227
		Inclination		-1.8264080047774272
		AscendingNode	90.26051364854057
		ArgOfPericen	12.761973547238451
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 251 A"
{
	ParentBody	"Acheron 251"
	Class		"Asteroid"
	Mass		7.272653953429389e-08
	Radius		33.36108219864976

	Orbit
	{
		Epoch			2457395.5
		Period			0.006199350289425853
		Eccentricity	0.007338183392741698
		Inclination		14.60704905886562
		AscendingNode	169.21657904663397
		ArgOfPericen	256.56743037731934
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 251 B"
{
	ParentBody	"Acheron 251"
	Class		"Asteroid"
	Mass		3.3701074558141513e-09
	Radius		11.982765819531338

	Orbit
	{
		Epoch			2457395.5
		Period			0.006199350289425853
		Eccentricity	0.007338183392741698
		Inclination		14.60704905886562
		AscendingNode	169.21657904663397
		ArgOfPericen	76.56743037731934
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 252"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5454365856092972
		Eccentricity	0.03162483965406024
		Inclination		-0.10060275806514021
		AscendingNode	121.59802441674935
		ArgOfPericen	332.79109739248923
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 252 A"
{
	ParentBody	"Acheron 252"
	Class		"Asteroid"
	Mass		4.42614212540795e-07
	Radius		58.83750636102971

	Orbit
	{
		Epoch			2457395.5
		Period			0.005346745477666312
		Eccentricity	0.007360375593649055
		Inclination		155.86299978868186
		AscendingNode	30.088980276058557
		ArgOfPericen	344.5118954621403
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 252 B"
{
	ParentBody	"Acheron 252"
	Class		"Asteroid"
	Mass		6.916232599108401e-08
	Radius		31.690980050649525

	Orbit
	{
		Epoch			2457395.5
		Period			0.005346745477666312
		Eccentricity	0.007360375593649055
		Inclination		155.86299978868186
		AscendingNode	30.088980276058557
		ArgOfPericen	164.51189546214027
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 253"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.168542756513827e-07
	Radius		67.98328618647801

	RotationPeriod	7.589837370762714

	Obliquity		91.6686935136909

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5275318319389237
		Eccentricity	0.05100236906248495
		Inclination		-1.4761470876495113
		AscendingNode	355.11779242623265
		ArgOfPericen	279.87214639141854
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 254"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.828277227487661e-08
	Radius		34.055921451676106

	RotationPeriod	4.762327082569371

	Obliquity		203.36593436773134

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5427775791158911
		Eccentricity	0.06649451081261804
		Inclination		-0.6597948621708216
		AscendingNode	16.002749206986287
		ArgOfPericen	151.4696964023416
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 255"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.042968922663784e-07
	Radius		36.17791056000177

	RotationPeriod	6.220345558972675

	Obliquity		228.59133760956456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5454385388852069
		Eccentricity	0.012408504044762896
		Inclination		1.3325024783079875
		AscendingNode	205.66026909122803
		ArgOfPericen	36.495112498915304
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 256"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.711336367635043e-07
	Radius		56.79984056618405

	RotationPeriod	6.642181970084289

	Obliquity		53.63242145560533

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5350350815962499
		Eccentricity	0.0586404773352203
		Inclination		-1.0897523756393956
		AscendingNode	181.28488445950714
		ArgOfPericen	275.47702710962017
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 256.1"
{
	ParentBody	"Acheron 256"
	Class		"Asteroid"
	Mass		3.626399296833221e-10
	Radius		5.63631882504463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.251700027226882e-07
		Eccentricity	0.0024702079532102875
		Inclination		11.270182475905457
		AscendingNode	253.5004457357151
		ArgOfPericen	144.73761475256282
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 257"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.025754995710202e-07
	Radius		74.37790118045723

	RotationPeriod	6.153904948877712

	Obliquity		146.59799935055267

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5265984691188952
		Eccentricity	0.04950063370939781
		Inclination		-1.2950827587777147
		AscendingNode	91.51982001853543
		ArgOfPericen	321.30102575486364
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 258"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.53752041609442
		Eccentricity	0.04534065225466097
		Inclination		-0.10782948708945947
		AscendingNode	296.72894177933495
		ArgOfPericen	1.4069184215663366
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 258 A"
{
	ParentBody	"Acheron 258"
	Class		"Asteroid"
	Mass		2.6199892596420975e-07
	Radius		53.57709332784704

	Orbit
	{
		Epoch			2457395.5
		Period			0.005371145199945145
		Eccentricity	0.002971280386908508
		Inclination		353.7546933156391
		AscendingNode	206.90430054561102
		ArgOfPericen	262.85761825422065
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 258 B"
{
	ParentBody	"Acheron 258"
	Class		"Asteroid"
	Mass		1.636597320074194e-07
	Radius		45.79941422473727

	Orbit
	{
		Epoch			2457395.5
		Period			0.005371145199945145
		Eccentricity	0.002971280386908508
		Inclination		353.7546933156391
		AscendingNode	206.90430054561102
		ArgOfPericen	82.85761825422065
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 259"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.737481412773818e-08
	Radius		35.71149452458416

	RotationPeriod	4.536973010415652

	Obliquity		344.64616583792133

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.529212922896807
		Eccentricity	0.056959210917677805
		Inclination		1.822245387443817
		AscendingNode	152.88327717183245
		ArgOfPericen	194.34273686777988
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 260"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.974312204893267e-07
	Radius		77.31292352059072

	RotationPeriod	6.5255837197297675

	Obliquity		116.3988350188971

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5324995380149947
		Eccentricity	0.020061025665447676
		Inclination		-1.79204906410783
		AscendingNode	237.9859835954535
		ArgOfPericen	55.86189213820476
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 261"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.329032455159709e-07
	Radius		50.31846030300229

	RotationPeriod	8.900314548128765

	Obliquity		224.99606899402715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5590151262184894
		Eccentricity	0.009852582132869596
		Inclination		3.473889903988418
		AscendingNode	148.51642325752968
		ArgOfPericen	295.6976889468385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 262"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.838344095709413e-07
	Radius		67.02269844015194

	RotationPeriod	6.286169239840325

	Obliquity		2.6555152377459956

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5254931725124821
		Eccentricity	0.06236743914185157
		Inclination		-0.8608425049615569
		AscendingNode	199.84500323744624
		ArgOfPericen	201.04577858552292
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 263"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.936681286541687e-07
	Radius		67.57592560387437

	RotationPeriod	5.7690117380584915

	Obliquity		236.5944019358529

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5380887240540788
		Eccentricity	0.06773508773940282
		Inclination		0.5591684233033011
		AscendingNode	28.437789810805842
		ArgOfPericen	143.70475794841337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 264"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.576540820478134e-07
	Radius		53.46760085527416

	RotationPeriod	2.838697166620047

	Obliquity		243.67551802175117

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5431186266455509
		Eccentricity	0.04655547856972353
		Inclination		-0.1024286825418284
		AscendingNode	167.99105000806117
		ArgOfPericen	148.5941024656103
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 265"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.8799515790434636e-07
	Radius		56.520485483322744

	RotationPeriod	9.248840498511129

	Obliquity		47.63094992568224

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.560682358713766
		Eccentricity	0.04734515851050201
		Inclination		-2.4471388860745997
		AscendingNode	266.7445638068537
		ArgOfPericen	301.1446532999995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 266"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.518127128578684e-07
	Radius		65.94507801757312

	RotationPeriod	6.766429179472945

	Obliquity		236.36410202630324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5358987551763946
		Eccentricity	0.015338773925533476
		Inclination		1.7568716441709802
		AscendingNode	68.11156604833653
		ArgOfPericen	167.64173049955258
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 267"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5172626591211531
		Eccentricity	0.05831251334131325
		Inclination		0.2088624523016112
		AscendingNode	254.10659715231543
		ArgOfPericen	325.1541184489386
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 267 A"
{
	ParentBody	"Acheron 267"
	Class		"Asteroid"
	Mass		2.7354175949956614e-07
	Radius		48.390782931205095

	Orbit
	{
		Epoch			2457395.5
		Period			0.0036847731692561704
		Eccentricity	0.002227720511961503
		Inclination		291.6155914685104
		AscendingNode	308.26922570954275
		ArgOfPericen	123.88152374767093
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 267 B"
{
	ParentBody	"Acheron 267"
	Class		"Asteroid"
	Mass		1.8561331617344992e-07
	Radius		42.523057142897876

	Orbit
	{
		Epoch			2457395.5
		Period			0.0036847731692561704
		Eccentricity	0.002227720511961503
		Inclination		291.6155914685104
		AscendingNode	308.26922570954275
		ArgOfPericen	303.88152374767094
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 268"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.656511785843586e-07
	Radius		41.43150570572298

	RotationPeriod	6.491147020171909

	Obliquity		350.73768917888015

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5526652445365832
		Eccentricity	0.08931535122742784
		Inclination		0.48738971694462574
		AscendingNode	292.1012851294381
		ArgOfPericen	19.02532822897246
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 269"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.257509784157802e-07
	Radius		45.45835913398602

	RotationPeriod	3.611006559231924

	Obliquity		117.05951563913077

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5381009333438621
		Eccentricity	0.07321584125084157
		Inclination		1.7832219432234229
		AscendingNode	249.93652924199287
		ArgOfPericen	68.11035045105294
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 270"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5642618580639025e-08
	Radius		19.98936403117882

	RotationPeriod	4.884193882440144

	Obliquity		203.58112272626272

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5172187113501506
		Eccentricity	0.05430749723709759
		Inclination		-1.3228209809232307
		AscendingNode	229.06964397516188
		ArgOfPericen	28.045527835682996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 271"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6204354445778375e-07
	Radius		43.3949411431302

	RotationPeriod	6.58932584582522

	Obliquity		191.49147923979194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5733455608362915
		Eccentricity	0.07443601760065625
		Inclination		-3.074177729549483
		AscendingNode	351.8050626698599
		ArgOfPericen	40.64078620973385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 272"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5300304176281055
		Eccentricity	0.024077060937558868
		Inclination		2.5115340649915843
		AscendingNode	350.29025073512406
		ArgOfPericen	345.15510644283853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 272 A"
{
	ParentBody	"Acheron 272"
	Class		"Asteroid"
	Mass		4.1028368457594446e-07
	Radius		56.61679068175609

	Orbit
	{
		Epoch			2457395.5
		Period			0.004839124648094594
		Eccentricity	0.006424352991465604
		Inclination		28.809636598011508
		AscendingNode	356.33718840470857
		ArgOfPericen	309.8020040375716
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 272 B"
{
	ParentBody	"Acheron 272"
	Class		"Asteroid"
	Mass		6.597680032982649e-08
	Radius		30.787960120706334

	Orbit
	{
		Epoch			2457395.5
		Period			0.004839124648094594
		Eccentricity	0.006424352991465604
		Inclination		28.809636598011508
		AscendingNode	356.33718840470857
		ArgOfPericen	129.80200403757158
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 273"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2206423625326263e-06
	Radius		86.87479071495048

	RotationPeriod	6.755890334491816

	Obliquity		200.83410073984095

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5547218603977416
		Eccentricity	0.04437305868707985
		Inclination		0.5393590806384256
		AscendingNode	352.89803295418386
		ArgOfPericen	256.0151625655026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 273.1"
{
	ParentBody	"Acheron 273"
	Class		"Asteroid"
	Mass		3.013657769981895e-09
	Radius		11.741644742371058

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.00830603901572e-06
		Eccentricity	0.008812247249763022
		Inclination		18.15400806360706
		AscendingNode	103.63638595841311
		ArgOfPericen	213.94047080157992
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 274"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9002314077603918e-07
	Radius		47.71715863099246

	RotationPeriod	6.590358801329627

	Obliquity		167.8812082739936

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5410433368013666
		Eccentricity	0.06284884750509472
		Inclination		2.4944791256169525
		AscendingNode	34.275122465952464
		ArgOfPericen	231.0473424417552
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 275"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.312830944613622e-07
	Radius		55.519271588114904

	RotationPeriod	5.6392989153541775

	Obliquity		41.148125048652496

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.533110978191913
		Eccentricity	0.05957454376186046
		Inclination		2.0691754973101415
		AscendingNode	101.47194146060929
		ArgOfPericen	217.70740688826328
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 276"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.229793453438257e-08
	Radius		32.90500764476754

	RotationPeriod	5.753604266153847

	Obliquity		357.77151553040903

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5164968583767273
		Eccentricity	0.036408764495927726
		Inclination		2.540387609711023
		AscendingNode	57.9695301534901
		ArgOfPericen	83.83459290582908
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 277"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.215337759850718e-08
	Radius		33.43230858767802

	RotationPeriod	5.927498023035526

	Obliquity		17.823321092848726

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5285576588347397
		Eccentricity	0.04017287690371826
		Inclination		0.056779105774457245
		AscendingNode	358.07450086959375
		ArgOfPericen	234.72940237448717
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 278"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.7711532495111457e-07
	Radius		57.12393763135887

	RotationPeriod	8.060882734155253

	Obliquity		344.4361908616589

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5517928051303835
		Eccentricity	0.037113690907369115
		Inclination		-0.4255416289602019
		AscendingNode	57.26016942103826
		ArgOfPericen	63.76749379108966
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 278.1"
{
	ParentBody	"Acheron 278"
	Class		"Asteroid"
	Mass		6.467129099726287e-10
	Radius		6.837498636630102

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.2322867178732414e-06
		Eccentricity	0.00477187065590479
		Inclination		62.1146007519084
		AscendingNode	293.88839536396785
		ArgOfPericen	42.601442191703285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 279"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.1902104045890935e-07
	Radius		46.69241763740368

	RotationPeriod	5.741897630445942

	Obliquity		289.6529385837219

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5252066359100538
		Eccentricity	0.04166717136810986
		Inclination		-1.3747042973628456
		AscendingNode	151.6744902466274
		ArgOfPericen	262.5420728950211
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 280"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.74562797326464e-07
	Radius		66.16438980565822

	RotationPeriod	6.030593139809491

	Obliquity		159.93023142347647

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.530434165414508
		Eccentricity	0.09139549592788142
		Inclination		-3.479049531822213
		AscendingNode	127.42510742577197
		ArgOfPericen	127.69258093395774
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 281"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.2513292743242935e-07
	Radius		57.05205493941134

	RotationPeriod	5.907659210664638

	Obliquity		258.4991064603524

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5329564684613673
		Eccentricity	0.028629657263209804
		Inclination		-0.9237263135125939
		AscendingNode	183.19472983855766
		ArgOfPericen	276.0765765748092
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 282"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.368188306835948e-09
	Radius		10.551031495933152

	RotationPeriod	8.498206168434548

	Obliquity		132.11100956350114

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5349283361555729
		Eccentricity	0.059545845686137716
		Inclination		0.39424683769285307
		AscendingNode	146.4272646503422
		ArgOfPericen	345.6143312681902
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 283"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5202404711550709
		Eccentricity	0.06696616363451363
		Inclination		-0.294082327531534
		AscendingNode	98.29447467130252
		ArgOfPericen	258.59401982635404
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 283 A"
{
	ParentBody	"Acheron 283"
	Class		"Asteroid"
	Mass		1.2071539956083523e-07
	Radius		41.41595351646478

	Orbit
	{
		Epoch			2457395.5
		Period			0.0032086221350015446
		Eccentricity	0.008539791861201592
		Inclination		337.33967554104754
		AscendingNode	37.834959534760785
		ArgOfPericen	134.79725430273345
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 283 B"
{
	ParentBody	"Acheron 283"
	Class		"Asteroid"
	Mass		5.9757642460028765e-09
	Radius		15.207036592037781

	Orbit
	{
		Epoch			2457395.5
		Period			0.0032086221350015446
		Eccentricity	0.008539791861201592
		Inclination		337.33967554104754
		AscendingNode	37.834959534760785
		ArgOfPericen	314.79725430273345
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 284"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.0201295803227545e-10
	Radius		5.52157773472787

	RotationPeriod	5.89628023764153

	Obliquity		223.7566891923387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.531770498549576
		Eccentricity	0.0466372160471294
		Inclination		-1.9820816355085755
		AscendingNode	212.2983304762591
		ArgOfPericen	100.1234487354449
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 285"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.924122072651088e-07
	Radius		54.7747439703553

	RotationPeriod	9.72093282486446

	Obliquity		16.237334360309816

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5093554924167356
		Eccentricity	0.03010803690254875
		Inclination		0.19210012211552574
		AscendingNode	114.7785222673921
		ArgOfPericen	182.91038388978177
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 285.1"
{
	ParentBody	"Acheron 285"
	Class		"Asteroid"
	Mass		2.464516922642757e-09
	Radius		10.105941690031933

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5047754616007774e-06
		Eccentricity	0.005860389211021699
		Inclination		12.781479174558017
		AscendingNode	332.27060177866247
		ArgOfPericen	79.54940985707807
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 286"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.693875888459252e-07
	Radius		61.953540508456584

	RotationPeriod	8.853040847796748

	Obliquity		231.0018415262455

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.558731651076949
		Eccentricity	0.0467386680746843
		Inclination		-4.106290732706924
		AscendingNode	250.13694767712917
		ArgOfPericen	339.1110443946592
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 286.1"
{
	ParentBody	"Acheron 286"
	Class		"Asteroid"
	Mass		2.4858494631501074e-09
	Radius		10.798925327258232

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.257764726375876e-06
		Eccentricity	0.004371982623373944
		Inclination		-14.104656469234222
		AscendingNode	87.44089007206043
		ArgOfPericen	188.34397786197718
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 286.2"
{
	ParentBody	"Acheron 286"
	Class		"Asteroid"
	Mass		8.283733010984295e-11
	Radius		3.4750758953068264

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.030816614767662e-06
		Eccentricity	0.0048221132886408806
		Inclination		-18.351044149910766
		AscendingNode	185.7742492368258
		ArgOfPericen	102.53491205936945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 286.3"
{
	ParentBody	"Acheron 286"
	Class		"Asteroid"
	Mass		4.551832120258447e-09
	Radius		13.211465907065952

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.785377734231744e-06
		Eccentricity	0.009245540005695125
		Inclination		10.788086728023114
		AscendingNode	199.65487542213972
		ArgOfPericen	282.52629145316666
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 286.4"
{
	ParentBody	"Acheron 286"
	Class		"Asteroid"
	Mass		2.1217638805568628e-09
	Radius		10.243647225880004

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.495220229534041e-06
		Eccentricity	0.004270200108570981
		Inclination		11.152404478216683
		AscendingNode	116.47985788702199
		ArgOfPericen	203.0122208345947
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 287"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.675922837815424e-08
	Radius		32.70791991537783

	RotationPeriod	8.109402811675299

	Obliquity		38.92481449085268

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5199258375777731
		Eccentricity	0.03673822842026219
		Inclination		1.7158100219187293
		AscendingNode	22.14100185277418
		ArgOfPericen	155.64109027132662
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 288"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.7614252461943375e-07
	Radius		44.11602038389446

	RotationPeriod	5.705985152335592

	Obliquity		65.92976328751597

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5353772726309795
		Eccentricity	0.05837616100528399
		Inclination		-1.4285185429788658
		AscendingNode	136.1992930228962
		ArgOfPericen	17.033449118323446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 288.1"
{
	ParentBody	"Acheron 288"
	Class		"Asteroid"
	Mass		4.975868017441269e-11
	Radius		2.8946620934955742

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.432425498235271e-06
		Eccentricity	0.006413288405729793
		Inclination		10.540922292301772
		AscendingNode	260.7589304279359
		ArgOfPericen	335.66384743127946
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 288.2"
{
	ParentBody	"Acheron 288"
	Class		"Asteroid"
	Mass		3.168066180005116e-10
	Radius		5.365040502024184

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.453015387689517e-06
		Eccentricity	0.004931009793083602
		Inclination		30.813405959711805
		AscendingNode	133.25279731712118
		ArgOfPericen	321.7892506805505
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 289"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9063534217584585e-07
	Radius		45.812567483142146

	RotationPeriod	7.3668247138504634

	Obliquity		0.9771329803877071

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5109830888281589
		Eccentricity	0.0517351279767227
		Inclination		-1.9039434600409866
		AscendingNode	254.56304553939725
		ArgOfPericen	308.1710886233737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 290"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5323654511002569
		Eccentricity	0.05796909666015883
		Inclination		-2.8650778006212834
		AscendingNode	53.64008092336002
		ArgOfPericen	0.48544993555315497
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 290 A"
{
	ParentBody	"Acheron 290"
	Class		"Asteroid"
	Mass		1.9348849543311835e-07
	Radius		42.94993374270548

	Orbit
	{
		Epoch			2457395.5
		Period			0.006714561279821375
		Eccentricity	0.003665161300717472
		Inclination		12.150047025154631
		AscendingNode	193.2453294978184
		ArgOfPericen	199.42348624732404
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 290 B"
{
	ParentBody	"Acheron 290"
	Class		"Asteroid"
	Mass		5.4262338022444866e-08
	Radius		28.11320006074663

	Orbit
	{
		Epoch			2457395.5
		Period			0.006714561279821375
		Eccentricity	0.003665161300717472
		Inclination		12.150047025154631
		AscendingNode	193.2453294978184
		ArgOfPericen	19.423486247324036
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 291"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.965174544513228e-08
	Radius		29.28026268434767

	RotationPeriod	7.393567956362996

	Obliquity		180.75317007719707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5343575636541574
		Eccentricity	0.07451324988877747
		Inclination		-0.19044078790265204
		AscendingNode	106.24096995973684
		ArgOfPericen	347.2372341514924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 292"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.341069615130491e-07
	Radius		62.88086937657505

	RotationPeriod	6.924422103852367

	Obliquity		314.2347131924741

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5357048480543957
		Eccentricity	0.035289924463511965
		Inclination		-3.2110514611335406
		AscendingNode	170.4882705053365
		ArgOfPericen	293.6700634459437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 292.1"
{
	ParentBody	"Acheron 292"
	Class		"Asteroid"
	Mass		4.193226745233978e-10
	Radius		5.800853627098171

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.70853379076022e-07
		Eccentricity	0.005046750349062504
		Inclination		-11.867149958573915
		AscendingNode	178.95543259706855
		ArgOfPericen	49.948516563805974
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 293"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.407825217328291e-07
	Radius		41.05198767820969

	RotationPeriod	6.686958522655212

	Obliquity		300.91110588724985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5532563496679931
		Eccentricity	0.037267194784605544
		Inclination		1.4725308470282847
		AscendingNode	125.66586661274488
		ArgOfPericen	347.16359426646693
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 294"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.091723613504943e-07
	Radius		69.97263243782206

	RotationPeriod	6.337139851950001

	Obliquity		201.82589152014168

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5508589613244264
		Eccentricity	0.052313795673446614
		Inclination		-0.11370701528591622
		AscendingNode	164.586088529581
		ArgOfPericen	31.849392440484287
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 295"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.500703330133624e-08
	Radius		31.11053421270767

	RotationPeriod	4.381493209293155

	Obliquity		306.5770633042071

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5501007033266687
		Eccentricity	0.018673439300406595
		Inclination		-2.301139561644933
		AscendingNode	319.3695918573755
		ArgOfPericen	136.90291970072326
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 296"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.450464952783945e-08
	Radius		25.719372402563064

	RotationPeriod	4.703941657360058

	Obliquity		12.881832840084071

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.533832378273199
		Eccentricity	0.051586015110915866
		Inclination		-2.4182234918320806
		AscendingNode	324.5730906466487
		ArgOfPericen	334.23026166007475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 297"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.870159829510198e-07
	Radius		60.22461468433621

	RotationPeriod	4.1504503017970436

	Obliquity		334.6970447462213

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4975662871194177
		Eccentricity	0.08112781617360956
		Inclination		0.8734250950827107
		AscendingNode	124.08847615360676
		ArgOfPericen	59.96151120544343
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 297.1"
{
	ParentBody	"Acheron 297"
	Class		"Asteroid"
	Mass		7.105844852112289e-11
	Radius		3.1705275574967824

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.738435085704887e-06
		Eccentricity	0.005160636647617673
		Inclination		24.21665641934343
		AscendingNode	259.40314598199484
		ArgOfPericen	235.91774589445157
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 297.2"
{
	ParentBody	"Acheron 297"
	Class		"Asteroid"
	Mass		5.804115120501698e-09
	Radius		13.75640535717957

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.780325488139936e-06
		Eccentricity	0.006797917945374975
		Inclination		-40.46632283716445
		AscendingNode	255.49081963958946
		ArgOfPericen	76.13320043208601
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 297.3"
{
	ParentBody	"Acheron 297"
	Class		"Asteroid"
	Mass		7.032685698216575e-09
	Radius		14.665606504896964

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.175282945172258e-06
		Eccentricity	0.008307557724872431
		Inclination		7.935521810448354
		AscendingNode	52.4198467766542
		ArgOfPericen	25.3670873596119
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Acheron 298"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5502680314011891
		Eccentricity	0.04381687577656919
		Inclination		-1.0586497839034026
		AscendingNode	19.320106366551116
		ArgOfPericen	225.55517641696312
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 298 A"
{
	ParentBody	"Acheron 298"
	Class		"Asteroid"
	Mass		2.386660824553067e-07
	Radius		49.30109356477435

	Orbit
	{
		Epoch			2457395.5
		Period			0.006068866677744886
		Eccentricity	0.0020507393881871354
		Inclination		341.92305506720777
		AscendingNode	348.9012065017336
		ArgOfPericen	264.6011049708827
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 298 B"
{
	ParentBody	"Acheron 298"
	Class		"Asteroid"
	Mass		3.001330132329546e-08
	Radius		24.700035299584933

	Orbit
	{
		Epoch			2457395.5
		Period			0.006068866677744886
		Eccentricity	0.0020507393881871354
		Inclination		341.92305506720777
		AscendingNode	348.9012065017336
		ArgOfPericen	84.60110497088272
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 299"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.9044371455513036e-08
	Radius		30.727532250006973

	RotationPeriod	3.7453633919768965

	Obliquity		222.6332869639262

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5187148760502852
		Eccentricity	0.06644294904126513
		Inclination		0.14396108010198572
		AscendingNode	1.0812379152702523
		ArgOfPericen	76.05641149110697
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 299.1"
{
	ParentBody	"Acheron 299"
	Class		"Asteroid"
	Mass		1.0979511361152297e-11
	Radius		1.7538637532726276

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0113012777276545e-06
		Eccentricity	0.0057549315340323015
		Inclination		-23.13303591685048
		AscendingNode	182.0167724329406
		ArgOfPericen	211.02100581603912
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 299.2"
{
	ParentBody	"Acheron 299"
	Class		"Asteroid"
	Mass		2.4842815419518526e-10
	Radius		4.960610399880303

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.0760341668204547e-06
		Eccentricity	0.007987447052611148
		Inclination		49.12749161808841
		AscendingNode	338.1542547765442
		ArgOfPericen	113.25245225777336
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Acheron 300"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.092478338270399e-08
	Radius		33.45706734301554

	RotationPeriod	5.506477323676634

	Obliquity		20.14830514329581

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4938896582438184
		Eccentricity	0.03317844498041754
		Inclination		1.417414633015518
		AscendingNode	251.28625685965454
		ArgOfPericen	95.02072563613997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Acheron 300.1"
{
	ParentBody	"Acheron 300"
	Class		"Asteroid"
	Mass		4.2345232838041754e-10
	Radius		6.069552973974536

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.733673769035071e-06
		Eccentricity	0.006385322158478824
		Inclination		10.454335085663734
		AscendingNode	216.55789287725386
		ArgOfPericen	344.298219406174
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Erebos asteroid belt --------------------------------------------------------
//------------------------------------------------------------------------------
Asteroid "Erebos 1"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.616057070863449e-08
	Radius		33.39804660274578

	RotationPeriod	4.196778592344575

	Obliquity		35.960721802722404

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.311410984852571
		Eccentricity	0.04684175453759814
		Inclination		-0.15984975763350742
		AscendingNode	319.91147843707864
		ArgOfPericen	306.09499681413814
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 2"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.0056788464775494e-07
	Radius		61.82055300152516

	RotationPeriod	6.591424386440602

	Obliquity		15.953777078757376

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.417147507701413
		Eccentricity	0.07260281745133662
		Inclination		-0.5161291378997679
		AscendingNode	314.2453727166828
		ArgOfPericen	326.38086533193785
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 3"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8586475191236362e-10
	Radius		4.484583898872195

	RotationPeriod	3.2259904944383346

	Obliquity		30.584083841740632

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.268193472878133
		Eccentricity	0.08448535132208826
		Inclination		0.2225245149089541
		AscendingNode	77.95266813880261
		ArgOfPericen	137.99917312396394
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 4"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.439992074126654e-07
	Radius		62.49403043448598

	RotationPeriod	5.732680795568545

	Obliquity		235.33350953811754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3018958978328774
		Eccentricity	0.043947135629166335
		Inclination		-0.7920729510725365
		AscendingNode	355.86584069081755
		ArgOfPericen	354.0657757076749
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 5"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.280291993964923e-07
	Radius		61.42325841566026

	RotationPeriod	8.061956227760295

	Obliquity		61.483372653058325

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3363148440783
		Eccentricity	0.03953552053324551
		Inclination		4.0137462694344865
		AscendingNode	243.18998277695604
		ArgOfPericen	128.2412109812197
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 6"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.40944889886224e-08
	Radius		32.725626130356574

	RotationPeriod	8.019603512242073

	Obliquity		122.30180925329955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3460120829230755
		Eccentricity	0.029398406844824684
		Inclination		-0.17942689392193104
		AscendingNode	180.70668054129644
		ArgOfPericen	82.91794238264389
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 7"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2868330221878495
		Eccentricity	0.06266754404095978
		Inclination		-3.339080037329802
		AscendingNode	54.087723870212386
		ArgOfPericen	96.84246407074565
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 7 A"
{
	ParentBody	"Erebos 7"
	Class		"Asteroid"
	Mass		3.518434454571881e-07
	Radius		56.61037718439332

	Orbit
	{
		Epoch			2457395.5
		Period			0.00757164288815279
		Eccentricity	0.004021021333506642
		Inclination		192.928090061504
		AscendingNode	208.8170098274197
		ArgOfPericen	334.64606536165707
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 7 B"
{
	ParentBody	"Erebos 7"
	Class		"Asteroid"
	Mass		9.73000813452394e-09
	Radius		17.119219535792116

	Orbit
	{
		Epoch			2457395.5
		Period			0.00757164288815279
		Eccentricity	0.004021021333506642
		Inclination		192.928090061504
		AscendingNode	208.8170098274197
		ArgOfPericen	154.64606536165707
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 8"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2453670468221447
		Eccentricity	0.03500182907033727
		Inclination		-0.02616387402334742
		AscendingNode	172.96747470123694
		ArgOfPericen	348.1619065261769
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 8 A"
{
	ParentBody	"Erebos 8"
	Class		"Asteroid"
	Mass		2.175393243215716e-06
	Radius		100.0

	Orbit
	{
		Epoch			2457395.5
		Period			0.0070946505945023225
		Eccentricity	0.0034063125362847222
		Inclination		54.191907141348295
		AscendingNode	259.9751649065154
		ArgOfPericen	82.62405802792594
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 8 B"
{
	ParentBody	"Erebos 8"
	Class		"Asteroid"
	Mass		1.0175042178574345e-06
	Radius		77.62461889238888

	Orbit
	{
		Epoch			2457395.5
		Period			0.0070946505945023225
		Eccentricity	0.0034063125362847222
		Inclination		54.191907141348295
		AscendingNode	259.9751649065154
		ArgOfPericen	262.6240580279259
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 9"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1180668515065606e-07
	Radius		35.19268689435193

	RotationPeriod	5.184910732352555

	Obliquity		55.71930030904351

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2606803850464634
		Eccentricity	0.05597556047245562
		Inclination		2.1824819742811092
		AscendingNode	50.06305807154209
		ArgOfPericen	195.3946047659801
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 9.1"
{
	ParentBody	"Erebos 9"
	Class		"Asteroid"
	Mass		5.757480408872196e-10
	Radius		6.0772531123020865

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.219983972093827e-06
		Eccentricity	0.005226421075723886
		Inclination		53.00510154507868
		AscendingNode	1.7569132265589271
		ArgOfPericen	349.3783709753929
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 10"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0794077637514735e-07
	Radius		35.05631198606687

	RotationPeriod	7.727364820468833

	Obliquity		218.85602224811194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.269810198231556
		Eccentricity	0.03820909391240845
		Inclination		0.23668580282778093
		AscendingNode	53.9879554047237
		ArgOfPericen	86.05468604481105
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 11"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4256044146998074e-07
	Radius		42.41527879271532

	RotationPeriod	9.21860713820665

	Obliquity		160.8110196031627

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4145057839527446
		Eccentricity	0.03723494826366533
		Inclination		1.0337834920471534
		AscendingNode	195.49668938095076
		ArgOfPericen	212.8712365914284
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 11.1"
{
	ParentBody	"Erebos 11"
	Class		"Asteroid"
	Mass		2.926951818560408e-10
	Radius		5.390898726216732

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.720880063037505e-06
		Eccentricity	0.007209080725841255
		Inclination		-2.7581914842123805
		AscendingNode	314.99902322147256
		ArgOfPericen	177.0192718565736
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 12"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.280452644491326
		Eccentricity	0.03841601463272593
		Inclination		-2.7527973666817003
		AscendingNode	153.5680671896592
		ArgOfPericen	151.56405618355976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 12 A"
{
	ParentBody	"Erebos 12"
	Class		"Asteroid"
	Mass		1.353761468974757e-06
	Radius		86.06777915941146

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017228623948035652
		Eccentricity	0.006352491170919896
		Inclination		89.7073188469528
		AscendingNode	185.14993326555944
		ArgOfPericen	13.405609948502315
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 12 B"
{
	ParentBody	"Erebos 12"
	Class		"Asteroid"
	Mass		4.720177971158463e-07
	Radius		60.57768488578688

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017228623948035652
		Eccentricity	0.006352491170919896
		Inclination		89.7073188469528
		AscendingNode	185.14993326555944
		ArgOfPericen	193.4056099485023
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 13"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.485869682969443e-09
	Radius		13.830043147507567

	RotationPeriod	6.614182280751411

	Obliquity		4.613711245856016

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2833831767797967
		Eccentricity	0.02170957066183732
		Inclination		-0.9914980499345609
		AscendingNode	319.00541685746686
		ArgOfPericen	178.31014638355248
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 13.1"
{
	ParentBody	"Erebos 13"
	Class		"Asteroid"
	Mass		3.9454331164388565e-11
	Radius		2.6695615263779624

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3074528905376318e-07
		Eccentricity	0.007311672497271576
		Inclination		-6.760197893018725
		AscendingNode	121.52113977051339
		ArgOfPericen	39.07154995985474
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 14"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8439885312964817e-07
	Radius		43.66428481572267

	RotationPeriod	4.8674391066220055

	Obliquity		259.6956271156547

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.270824809936021
		Eccentricity	0.05853736579295389
		Inclination		-1.8418135157909503
		AscendingNode	16.05786123326398
		ArgOfPericen	261.177912088417
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 14.1"
{
	ParentBody	"Erebos 14"
	Class		"Asteroid"
	Mass		2.2627321230526807e-09
	Radius		10.071279762987356

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.978833131777578e-06
		Eccentricity	0.004263406238930697
		Inclination		9.408008678552207
		AscendingNode	137.26373241654682
		ArgOfPericen	342.4804343467988
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 15"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.570832894427979e-07
	Radius		65.53888148757939

	RotationPeriod	7.8757270751260595

	Obliquity		290.9317165993124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.257860151803661
		Eccentricity	0.06723479832856978
		Inclination		-4.239554375486954
		AscendingNode	290.1291796157529
		ArgOfPericen	247.69926196968805
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 15.1"
{
	ParentBody	"Erebos 15"
	Class		"Asteroid"
	Mass		3.7229013417350587e-09
	Radius		13.186445768898663

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5970156539295293e-06
		Eccentricity	0.004347697845362728
		Inclination		-4.963720668926478
		AscendingNode	91.01135863921563
		ArgOfPericen	288.97038147858717
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 16"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2993567315775203
		Eccentricity	0.0402342221717827
		Inclination		-0.9424866275571842
		AscendingNode	70.09883220282576
		ArgOfPericen	27.23591294001579
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 16 A"
{
	ParentBody	"Erebos 16"
	Class		"Asteroid"
	Mass		1.2161681827825586e-06
	Radius		80.81787860282569

	Orbit
	{
		Epoch			2457395.5
		Period			0.006074315088822476
		Eccentricity	0.0069457158805820325
		Inclination		198.64966037838326
		AscendingNode	335.1999485267515
		ArgOfPericen	345.8023128895996
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 16 B"
{
	ParentBody	"Erebos 16"
	Class		"Asteroid"
	Mass		8.164525871140655e-07
	Radius		70.76522477858417

	Orbit
	{
		Epoch			2457395.5
		Period			0.006074315088822476
		Eccentricity	0.0069457158805820325
		Inclination		198.64966037838326
		AscendingNode	335.1999485267515
		ArgOfPericen	165.80231288959953
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 17"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.808680590031501e-08
	Radius		31.284064012481938

	RotationPeriod	7.194356705204562

	Obliquity		103.45971215561393

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2911294377038725
		Eccentricity	0.09233233686558961
		Inclination		-0.3940668303671576
		AscendingNode	155.5243520251363
		ArgOfPericen	266.4745852026187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 18"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.320351014202946
		Eccentricity	0.04728884087035969
		Inclination		-4.330863020516434
		AscendingNode	292.202597963244
		ArgOfPericen	121.75850029324732
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 18 A"
{
	ParentBody	"Erebos 18"
	Class		"Asteroid"
	Mass		2.504294767505964e-07
	Radius		49.06693201033697

	Orbit
	{
		Epoch			2457395.5
		Period			0.0060184881196992095
		Eccentricity	0.0030508922070079172
		Inclination		258.41115614115455
		AscendingNode	217.39060166240375
		ArgOfPericen	283.49204759313864
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 18 B"
{
	ParentBody	"Erebos 18"
	Class		"Asteroid"
	Mass		3.0028935608235645e-08
	Radius		24.19582314156454

	Orbit
	{
		Epoch			2457395.5
		Period			0.0060184881196992095
		Eccentricity	0.0030508922070079172
		Inclination		258.41115614115455
		AscendingNode	217.39060166240375
		ArgOfPericen	103.49204759313864
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 19"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9351836338038578e-08
	Radius		23.828237325278472

	RotationPeriod	7.608085328938353

	Obliquity		322.48137111460056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.336355552750987
		Eccentricity	0.061840135128148635
		Inclination		-0.3409784417221873
		AscendingNode	66.60020677345258
		ArgOfPericen	218.54007014022415
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 20"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1150027671001658e-07
	Radius		48.9309762727792

	RotationPeriod	3.2512134252219727

	Obliquity		254.1356932943389

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3307014438389597
		Eccentricity	0.059284065698919884
		Inclination		0.9581943928730363
		AscendingNode	208.03544641892864
		ArgOfPericen	309.15551201147036
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 21"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2257696141200856
		Eccentricity	0.03943635192443583
		Inclination		-0.28305881625530105
		AscendingNode	299.7749428954407
		ArgOfPericen	306.7620826839627
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 21 A"
{
	ParentBody	"Erebos 21"
	Class		"Asteroid"
	Mass		3.0606073965451047e-07
	Radius		50.60822601856445

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010393531131386222
		Eccentricity	0.006906203667790656
		Inclination		315.08538638121206
		AscendingNode	60.06830282349939
		ArgOfPericen	333.79416560670467
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 21 B"
{
	ParentBody	"Erebos 21"
	Class		"Asteroid"
	Mass		1.44472641176457e-08
	Radius		18.290003017845468

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010393531131386222
		Eccentricity	0.006906203667790656
		Inclination		315.08538638121206
		AscendingNode	60.06830282349939
		ArgOfPericen	153.7941656067046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 22"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.57888534973914e-07
	Radius		48.941683935523365

	RotationPeriod	5.197752496680486

	Obliquity		336.4043368170321

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3139766257969128
		Eccentricity	0.047675911043291455
		Inclination		0.8598006136901226
		AscendingNode	118.54078541616127
		ArgOfPericen	39.40531139713635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 23"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.258570485563873
		Eccentricity	0.049770668237683606
		Inclination		-2.267161582497639
		AscendingNode	319.75640155059386
		ArgOfPericen	145.39725092189872
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 23 A"
{
	ParentBody	"Erebos 23"
	Class		"Asteroid"
	Mass		4.7668954291459245e-07
	Radius		63.13180190957517

	Orbit
	{
		Epoch			2457395.5
		Period			0.005388105504652414
		Eccentricity	0.00522874943946385
		Inclination		304.9813405148016
		AscendingNode	270.2543820914279
		ArgOfPericen	217.7014142039081
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 23 B"
{
	ParentBody	"Erebos 23"
	Class		"Asteroid"
	Mass		3.0714266446564843e-07
	Radius		54.52759703961255

	Orbit
	{
		Epoch			2457395.5
		Period			0.005388105504652414
		Eccentricity	0.00522874943946385
		Inclination		304.9813405148016
		AscendingNode	270.2543820914279
		ArgOfPericen	37.70141420390809
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 24"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4563544386708302e-07
	Radius		41.50461902072411

	RotationPeriod	4.435449027232746

	Obliquity		207.50516823464196

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3468273612374038
		Eccentricity	0.06050421486669279
		Inclination		0.1839815154436858
		AscendingNode	344.67481916669976
		ArgOfPericen	23.450036616412532
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 25"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.37969051896476e-08
	Radius		38.41667630356937

	RotationPeriod	8.921450250642545

	Obliquity		173.3495536678755

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2867546919232096
		Eccentricity	0.03704980371838233
		Inclination		0.7144023867478099
		AscendingNode	17.75194939976563
		ArgOfPericen	269.3178674251998
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 26"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.738597009732659e-08
	Radius		31.42666734110744

	RotationPeriod	6.293997568544679

	Obliquity		77.54604049235553

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3344975251664275
		Eccentricity	0.039009554085725415
		Inclination		-0.002790344354736272
		AscendingNode	19.11254651076579
		ArgOfPericen	93.86935657850944
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 27"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.373473013592508
		Eccentricity	0.037710618189068165
		Inclination		-0.36130001247970145
		AscendingNode	291.37501814053695
		ArgOfPericen	62.770705009076266
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 27 A"
{
	ParentBody	"Erebos 27"
	Class		"Asteroid"
	Mass		2.3312526828917494e-07
	Radius		48.98098869179381

	Orbit
	{
		Epoch			2457395.5
		Period			0.005892348390571889
		Eccentricity	0.008503323726997893
		Inclination		239.43185791075118
		AscendingNode	49.29118438746008
		ArgOfPericen	89.44212548693898
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 27 B"
{
	ParentBody	"Erebos 27"
	Class		"Asteroid"
	Mass		9.62216041289808e-08
	Radius		36.468841035062965

	Orbit
	{
		Epoch			2457395.5
		Period			0.005892348390571889
		Eccentricity	0.008503323726997893
		Inclination		239.43185791075118
		AscendingNode	49.29118438746008
		ArgOfPericen	269.44212548693895
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 28"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9689782730856285e-07
	Radius		55.198841816973435

	RotationPeriod	7.414852839583969

	Obliquity		268.8664534552241

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.334642880827456
		Eccentricity	0.05465139273419719
		Inclination		-2.7828091362276384
		AscendingNode	37.2383251393153
		ArgOfPericen	209.57721093081997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 29"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3472147577282283
		Eccentricity	0.04375565598155756
		Inclination		-0.36277776439961007
		AscendingNode	32.226745575658896
		ArgOfPericen	87.89799540556955
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 29 A"
{
	ParentBody	"Erebos 29"
	Class		"Asteroid"
	Mass		1.3674118081928204e-07
	Radius		41.88321420553484

	Orbit
	{
		Epoch			2457395.5
		Period			0.005831359535248583
		Eccentricity	0.0034501934120971843
		Inclination		231.12338340177982
		AscendingNode	297.9872953914977
		ArgOfPericen	205.29795342746868
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 29 B"
{
	ParentBody	"Erebos 29"
	Class		"Asteroid"
	Mass		1.3490108699307947e-07
	Radius		41.69449429135422

	Orbit
	{
		Epoch			2457395.5
		Period			0.005831359535248583
		Eccentricity	0.0034501934120971843
		Inclination		231.12338340177982
		AscendingNode	297.9872953914977
		ArgOfPericen	25.297953427468656
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 30"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2824069785164967e-07
	Radius		49.00426585919074

	RotationPeriod	1.4604432217454626

	Obliquity		182.91063382858397

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.31751588573421
		Eccentricity	0.03487376875361112
		Inclination		3.158081817141459
		AscendingNode	265.834756974121
		ArgOfPericen	332.3765926565574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 31"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.117270617753569e-07
	Radius		69.99061629161926

	RotationPeriod	9.387766049592944

	Obliquity		249.37873612671444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3489611488490376
		Eccentricity	0.02613953098980512
		Inclination		-0.9491497229451666
		AscendingNode	235.55430970992165
		ArgOfPericen	287.345678936099
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 32"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.483432640706502e-07
	Radius		54.149971416260485

	RotationPeriod	8.758480248685567

	Obliquity		256.4892700464036

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3844985617210175
		Eccentricity	0.06345727112930505
		Inclination		-3.016517727633889
		AscendingNode	338.4912502413575
		ArgOfPericen	101.39737393773198
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 33"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.373916454655015e-07
	Radius		72.6735311613962

	RotationPeriod	4.867350873329747

	Obliquity		84.33261205378237

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3095727080249095
		Eccentricity	0.042736095395833805
		Inclination		0.924296836253404
		AscendingNode	289.51327405680814
		ArgOfPericen	178.8122037695708
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 34"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3335371607677917
		Eccentricity	0.07399727303915213
		Inclination		-0.30920601444466017
		AscendingNode	244.34539548256612
		ArgOfPericen	350.83706495392266
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 34 A"
{
	ParentBody	"Erebos 34"
	Class		"Asteroid"
	Mass		1.2874711335623217e-07
	Radius		41.155205544824284

	Orbit
	{
		Epoch			2457395.5
		Period			0.004437739102568812
		Eccentricity	0.0030248474502809247
		Inclination		359.6464020259608
		AscendingNode	190.57230042132497
		ArgOfPericen	356.24831584493484
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 34 B"
{
	ParentBody	"Erebos 34"
	Class		"Asteroid"
	Mass		1.0590695923654781e-07
	Radius		38.56148716051269

	Orbit
	{
		Epoch			2457395.5
		Period			0.004437739102568812
		Eccentricity	0.0030248474502809247
		Inclination		359.6464020259608
		AscendingNode	190.57230042132497
		ArgOfPericen	176.24831584493484
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 35"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.751028355323545e-08
	Radius		35.91331331826137

	RotationPeriod	6.953300363387147

	Obliquity		357.01872973391585

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.318661371275179
		Eccentricity	0.043827303150757765
		Inclination		1.8332103370733508
		AscendingNode	195.0349460633865
		ArgOfPericen	233.14054249326986
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 36"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.20288578682166e-07
	Radius		50.67898295268907

	RotationPeriod	3.944714434930023

	Obliquity		165.62930832284087

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2973296094769444
		Eccentricity	0.041255103527131035
		Inclination		2.786198281947278
		AscendingNode	211.29671386429462
		ArgOfPericen	128.43668602365952
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 37"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.69316820699638e-07
	Radius		51.54568223291419

	RotationPeriod	6.337995119403519

	Obliquity		228.33730217224107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2563552019535646
		Eccentricity	0.05079506573648133
		Inclination		0.7860723971189558
		AscendingNode	165.88349120668713
		ArgOfPericen	239.45326609230955
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 38"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3106063891236324
		Eccentricity	0.05569886927284175
		Inclination		-1.8203738363729642
		AscendingNode	347.24957552485574
		ArgOfPericen	15.312204971223426
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 38 A"
{
	ParentBody	"Erebos 38"
	Class		"Asteroid"
	Mass		1.2151595718432914e-06
	Radius		79.50478710033013

	Orbit
	{
		Epoch			2457395.5
		Period			0.007533054294977523
		Eccentricity	0.005809363523658057
		Inclination		268.8496845916808
		AscendingNode	251.93250864230626
		ArgOfPericen	270.06963772148816
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 38 B"
{
	ParentBody	"Erebos 38"
	Class		"Asteroid"
	Mass		1.4329563691870656e-07
	Radius		38.98759960308401

	Orbit
	{
		Epoch			2457395.5
		Period			0.007533054294977523
		Eccentricity	0.005809363523658057
		Inclination		268.8496845916808
		AscendingNode	251.93250864230626
		ArgOfPericen	90.06963772148816
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 39"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4541006957102023e-07
	Radius		46.94398070796077

	RotationPeriod	5.585885041620091

	Obliquity		270.8325635123056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3369489479926346
		Eccentricity	0.0708430895668912
		Inclination		-1.1414430730789562
		AscendingNode	333.9205160405551
		ArgOfPericen	213.19766898063173
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 40"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.398635235308914e-07
	Radius		53.61423268874563

	RotationPeriod	2.8878078335193904

	Obliquity		67.17124454212932

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4463029133632563
		Eccentricity	0.06021411854599828
		Inclination		2.4272208931514134
		AscendingNode	183.4825966975024
		ArgOfPericen	9.874233974171815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 41"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.677656984226052e-07
	Radius		57.4610936690763

	RotationPeriod	3.7863194790294985

	Obliquity		39.444107377799746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3506353888940765
		Eccentricity	0.052577003140360054
		Inclination		0.04811847438724301
		AscendingNode	339.4810853490062
		ArgOfPericen	80.90392084878226
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 42"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3588141274843197
		Eccentricity	0.049225470268340496
		Inclination		3.6730249082754094
		AscendingNode	159.0901177437377
		ArgOfPericen	232.83290398913593
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 42 A"
{
	ParentBody	"Erebos 42"
	Class		"Asteroid"
	Mass		4.744355996851581e-08
	Radius		27.949933886389605

	Orbit
	{
		Epoch			2457395.5
		Period			0.003310875913532615
		Eccentricity	0.003909112891684448
		Inclination		174.17238654063536
		AscendingNode	70.59418665864894
		ArgOfPericen	42.583150097617086
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 42 B"
{
	ParentBody	"Erebos 42"
	Class		"Asteroid"
	Mass		3.467790030785691e-08
	Radius		25.177114777594774

	Orbit
	{
		Epoch			2457395.5
		Period			0.003310875913532615
		Eccentricity	0.003909112891684448
		Inclination		174.17238654063536
		AscendingNode	70.59418665864894
		ArgOfPericen	222.58315009761708
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 43"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.376734269414108
		Eccentricity	0.05622935872847079
		Inclination		3.6544128813355865
		AscendingNode	348.5623233295102
		ArgOfPericen	162.96173820403112
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 43 A"
{
	ParentBody	"Erebos 43"
	Class		"Asteroid"
	Mass		1.7136096024074133e-07
	Radius		43.16569153624978

	Orbit
	{
		Epoch			2457395.5
		Period			0.0038294264961567966
		Eccentricity	0.00541819347931208
		Inclination		283.2532206305342
		AscendingNode	281.9496066913331
		ArgOfPericen	165.5421711915256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 43 B"
{
	ParentBody	"Erebos 43"
	Class		"Asteroid"
	Mass		1.4330651303002162e-08
	Radius		18.876583064527644

	Orbit
	{
		Epoch			2457395.5
		Period			0.0038294264961567966
		Eccentricity	0.00541819347931208
		Inclination		283.2532206305342
		AscendingNode	281.9496066913331
		ArgOfPericen	345.5421711915256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 44"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.179940104766971e-08
	Radius		31.65018125374033

	RotationPeriod	7.24162667890069

	Obliquity		201.0431163103386

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.265739373070314
		Eccentricity	0.07127807151589438
		Inclination		-0.44219215953444996
		AscendingNode	142.7692788304
		ArgOfPericen	315.0093246516555
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 44.1"
{
	ParentBody	"Erebos 44"
	Class		"Asteroid"
	Mass		5.578632153267837e-11
	Radius		3.0588441831632833

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.8356855110468494e-06
		Eccentricity	0.005328420984120334
		Inclination		-22.056973157606862
		AscendingNode	296.0899085205855
		ArgOfPericen	56.34823985972665
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 45"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.718794798550761e-07
	Radius		43.87573460791835

	RotationPeriod	6.099796506768781

	Obliquity		277.8434628077914

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.355067284731081
		Eccentricity	0.040738771042011186
		Inclination		-3.0413496409101586
		AscendingNode	138.20530253861625
		ArgOfPericen	227.78786387526333
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 46"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2251133101446645
		Eccentricity	0.028489360067237075
		Inclination		-2.113156632530095
		AscendingNode	330.21674273114445
		ArgOfPericen	204.4777032998526
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 46 A"
{
	ParentBody	"Erebos 46"
	Class		"Asteroid"
	Mass		9.415737281653909e-07
	Radius		76.2207683019738

	Orbit
	{
		Epoch			2457395.5
		Period			0.005997110388118899
		Eccentricity	0.005608006178477599
		Inclination		213.90745839427254
		AscendingNode	326.53061352279434
		ArgOfPericen	298.2471781769631
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 46 B"
{
	ParentBody	"Erebos 46"
	Class		"Asteroid"
	Mass		3.9171935888024687e-07
	Radius		56.900169009269

	Orbit
	{
		Epoch			2457395.5
		Period			0.005997110388118899
		Eccentricity	0.005608006178477599
		Inclination		213.90745839427254
		AscendingNode	326.53061352279434
		ArgOfPericen	118.24717817696308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 47"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.4673799344305257e-07
	Radius		55.86812043494621

	RotationPeriod	6.9415088879286575

	Obliquity		32.70188893831648

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2694207150618118
		Eccentricity	0.055501031172901845
		Inclination		0.4675065699169151
		AscendingNode	5.904720803724177
		ArgOfPericen	217.26607022032434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 48"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9519117015022775e-07
	Radius		50.82685948250073

	RotationPeriod	7.363112820451477

	Obliquity		48.88726721816244

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2793553174077035
		Eccentricity	0.02491873188731186
		Inclination		-2.5497313106125423
		AscendingNode	41.6789471124303
		ArgOfPericen	196.48224354353871
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 49"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.560003554895163e-07
	Radius		43.71831722721878

	RotationPeriod	10.145622702398171

	Obliquity		278.9675664438383

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.206268148921998
		Eccentricity	0.05294824823166171
		Inclination		2.4955270290919316
		AscendingNode	334.0430928776523
		ArgOfPericen	71.99795562896784
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 50"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0355879238955433e-07
	Radius		44.784449372112306

	RotationPeriod	9.928339694097883

	Obliquity		244.58138051521715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.273084692076024
		Eccentricity	0.07050125932477228
		Inclination		-0.6136757173554277
		AscendingNode	275.98944435872914
		ArgOfPericen	354.5899636711654
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 51"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.5497681577193957e-07
	Radius		54.92361549048144

	RotationPeriod	7.386938384078025

	Obliquity		105.47142806498242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2090060832889007
		Eccentricity	0.05777096259628706
		Inclination		-0.019102385448583958
		AscendingNode	358.5650916428988
		ArgOfPericen	319.0459971010779
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 52"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272371585778778
		Eccentricity	0.034031443134926384
		Inclination		-0.43825985788841737
		AscendingNode	164.5105480140331
		ArgOfPericen	142.09812595504974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 52 A"
{
	ParentBody	"Erebos 52"
	Class		"Asteroid"
	Mass		3.0029846727777234e-07
	Radius		50.97913084913167

	Orbit
	{
		Epoch			2457395.5
		Period			0.005723711043227317
		Eccentricity	0.006262129935810792
		Inclination		7.644536880362485
		AscendingNode	226.07168510384875
		ArgOfPericen	321.8019878274319
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 52 B"
{
	ParentBody	"Erebos 52"
	Class		"Asteroid"
	Mass		2.2831747487627003e-07
	Radius		46.52872006010404

	Orbit
	{
		Epoch			2457395.5
		Period			0.005723711043227317
		Eccentricity	0.006262129935810792
		Inclination		7.644536880362485
		AscendingNode	226.07168510384875
		ArgOfPericen	141.8019878274319
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 53"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7027920879076757e-07
	Radius		42.18485939022238

	RotationPeriod	3.854104829758078

	Obliquity		96.77093781703829

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3869423405919834
		Eccentricity	0.03564579090737539
		Inclination		-1.953119403823768
		AscendingNode	260.4048322001212
		ArgOfPericen	253.05417472689956
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 54"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2123500869956563e-07
	Radius		48.95078279309784

	RotationPeriod	4.384261334948243

	Obliquity		136.87587975692185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2929677484087683
		Eccentricity	0.042341983482011236
		Inclination		-1.9370545628205005
		AscendingNode	242.78059635985602
		ArgOfPericen	260.3665906164183
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 55"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.48821291215877e-08
	Radius		31.570344365529095

	RotationPeriod	4.281817507257002

	Obliquity		127.61919200678767

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.345213988256921
		Eccentricity	0.025437640058607443
		Inclination		-1.5529860198120562
		AscendingNode	337.05119423633505
		ArgOfPericen	68.43468358464482
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 55.1"
{
	ParentBody	"Erebos 55"
	Class		"Asteroid"
	Mass		1.0353568259024744e-11
	Radius		1.6324877890084726

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.27594348677485e-07
		Eccentricity	0.0035811549202266653
		Inclination		39.258125738715655
		AscendingNode	134.46287220429898
		ArgOfPericen	30.213323106244488
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 56"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0980574863023233e-07
	Radius		46.5508424494469

	RotationPeriod	5.687331990497703

	Obliquity		67.7256797673492

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3023441035161487
		Eccentricity	0.049415024565166804
		Inclination		1.175370623203621
		AscendingNode	163.32999334268723
		ArgOfPericen	50.557156354993744
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 57"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.767840819413275e-07
	Radius		62.24176465519119

	RotationPeriod	5.621418615824946

	Obliquity		91.59430635961692

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2660073367119393
		Eccentricity	0.028728556006677092
		Inclination		-3.5135989095791476
		AscendingNode	190.12007353266426
		ArgOfPericen	129.3353919504505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 58"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.091012395285257e-08
	Radius		29.357752767955155

	RotationPeriod	5.325495880638219

	Obliquity		112.93544016239974

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3190912079782664
		Eccentricity	0.06187671775222398
		Inclination		-1.1649924423812004
		AscendingNode	256.95134732525094
		ArgOfPericen	242.548300989579
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 59"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0682777973305235e-06
	Radius		85.39329064751396

	RotationPeriod	8.751866671108997

	Obliquity		146.5281318128247

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2725490778287685
		Eccentricity	0.01678415350863592
		Inclination		2.6297013540711514
		AscendingNode	260.54585058244817
		ArgOfPericen	234.31287530643885
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 60"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.265167327594659
		Eccentricity	0.05063475839937188
		Inclination		-3.6738181875349705
		AscendingNode	123.07366630039654
		ArgOfPericen	83.62649154704616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 60 A"
{
	ParentBody	"Erebos 60"
	Class		"Asteroid"
	Mass		2.6897559337035067e-07
	Radius		49.165468586285634

	Orbit
	{
		Epoch			2457395.5
		Period			0.004107941980791194
		Eccentricity	0.0008569725863855036
		Inclination		7.447742277780707
		AscendingNode	6.651045488241301
		ArgOfPericen	132.06244125165
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 60 B"
{
	ParentBody	"Erebos 60"
	Class		"Asteroid"
	Mass		1.1667079158571567e-08
	Radius		17.27467714707936

	Orbit
	{
		Epoch			2457395.5
		Period			0.004107941980791194
		Eccentricity	0.0008569725863855036
		Inclination		7.447742277780707
		AscendingNode	6.651045488241301
		ArgOfPericen	312.06244125165
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 61"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.358344271026929
		Eccentricity	0.07181817532335104
		Inclination		1.5088500376461484
		AscendingNode	320.49432922337735
		ArgOfPericen	146.165705237181
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 61 A"
{
	ParentBody	"Erebos 61"
	Class		"Asteroid"
	Mass		2.5598244695151025e-07
	Radius		48.80840431241865

	Orbit
	{
		Epoch			2457395.5
		Period			0.0072939549768489135
		Eccentricity	0.006276589751920353
		Inclination		256.6960213057284
		AscendingNode	3.728848178050317
		ArgOfPericen	301.71454815304185
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 61 B"
{
	ParentBody	"Erebos 61"
	Class		"Asteroid"
	Mass		2.1179579705150796e-08
	Radius		21.268179972072893

	Orbit
	{
		Epoch			2457395.5
		Period			0.0072939549768489135
		Eccentricity	0.006276589751920353
		Inclination		256.6960213057284
		AscendingNode	3.728848178050317
		ArgOfPericen	121.71454815304185
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 62"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.23372323250636
		Eccentricity	0.04671873592376392
		Inclination		-0.017847750161347622
		AscendingNode	87.1852140421906
		ArgOfPericen	38.10802839534921
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 62 A"
{
	ParentBody	"Erebos 62"
	Class		"Asteroid"
	Mass		1.4830974326378414e-07
	Radius		40.24133792021243

	Orbit
	{
		Epoch			2457395.5
		Period			0.007188596692668241
		Eccentricity	0.00695762611562124
		Inclination		96.3962981948406
		AscendingNode	102.23610084758367
		ArgOfPericen	126.28635880806229
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 62 B"
{
	ParentBody	"Erebos 62"
	Class		"Asteroid"
	Mass		5.368725755210434e-08
	Radius		28.679589030162667

	Orbit
	{
		Epoch			2457395.5
		Period			0.007188596692668241
		Eccentricity	0.00695762611562124
		Inclination		96.3962981948406
		AscendingNode	102.23610084758367
		ArgOfPericen	306.2863588080623
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 63"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2538436170527256
		Eccentricity	0.04321866746065226
		Inclination		-0.33266077035429015
		AscendingNode	248.58536153288298
		ArgOfPericen	112.65826159171209
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 63 A"
{
	ParentBody	"Erebos 63"
	Class		"Asteroid"
	Mass		1.9036888395508907e-07
	Radius		46.64168870577028

	Orbit
	{
		Epoch			2457395.5
		Period			0.008004312716379363
		Eccentricity	0.005803374670149115
		Inclination		59.849475363842686
		AscendingNode	205.60563876824222
		ArgOfPericen	108.77695834632368
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 63 B"
{
	ParentBody	"Erebos 63"
	Class		"Asteroid"
	Mass		1.8139074188680306e-08
	Radius		21.30332128193286

	Orbit
	{
		Epoch			2457395.5
		Period			0.008004312716379363
		Eccentricity	0.005803374670149115
		Inclination		59.849475363842686
		AscendingNode	205.60563876824222
		ArgOfPericen	288.7769583463237
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 64"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1070291699057146e-07
	Radius		47.425441595384285

	RotationPeriod	6.64134026482179

	Obliquity		292.4288383210408

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.317984743009677
		Eccentricity	0.0490006969709629
		Inclination		0.9763381279864333
		AscendingNode	64.70706590352017
		ArgOfPericen	150.2554696015143
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 65"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3096573970277445
		Eccentricity	0.03947483098478039
		Inclination		0.40007101316250615
		AscendingNode	231.2314063550007
		ArgOfPericen	47.14645370328793
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 65 A"
{
	ParentBody	"Erebos 65"
	Class		"Asteroid"
	Mass		1.7307137234205234e-07
	Radius		44.22763709825247

	Orbit
	{
		Epoch			2457395.5
		Period			0.004088108202353424
		Eccentricity	0.005324705123900466
		Inclination		309.67421395851346
		AscendingNode	177.2065232053809
		ArgOfPericen	88.16108877925832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 65 B"
{
	ParentBody	"Erebos 65"
	Class		"Asteroid"
	Mass		1.7181907672775697e-07
	Radius		44.120705873247395

	Orbit
	{
		Epoch			2457395.5
		Period			0.004088108202353424
		Eccentricity	0.005324705123900466
		Inclination		309.67421395851346
		AscendingNode	177.2065232053809
		ArgOfPericen	268.1610887792583
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 66"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.07365301627735e-07
	Radius		56.90235141495798

	RotationPeriod	5.661940818772564

	Obliquity		63.43842247586031

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.212508085367149
		Eccentricity	0.08493475284230624
		Inclination		0.12548049774917247
		AscendingNode	25.620828667388686
		ArgOfPericen	306.37150450839965
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 67"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.485735264411208e-07
	Radius		43.14936922876619

	RotationPeriod	6.010174990352211

	Obliquity		233.13520404523985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.379130674283252
		Eccentricity	0.04684839102695219
		Inclination		2.891301345975716
		AscendingNode	110.06550061081896
		ArgOfPericen	109.23141532783046
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 68"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.363842441136948e-08
	Radius		32.28551941723397

	RotationPeriod	4.970863345565668

	Obliquity		97.91802476776942

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1850928178467344
		Eccentricity	0.06339911916408446
		Inclination		1.6784622455150764
		AscendingNode	160.0743183084874
		ArgOfPericen	277.86411576722276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 69"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.123324728204085e-07
	Radius		69.94734854220022

	RotationPeriod	8.747103930358493

	Obliquity		270.68970859142826

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.349865034113268
		Eccentricity	0.04524183789451368
		Inclination		0.1434133494066544
		AscendingNode	337.45151526858814
		ArgOfPericen	114.36776409024156
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 69.1"
{
	ParentBody	"Erebos 69"
	Class		"Asteroid"
	Mass		4.841918846340504e-09
	Radius		13.250009134277558

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.450934985593242e-06
		Eccentricity	0.00698819767282226
		Inclination		-3.2730036298578526
		AscendingNode	53.760841863415976
		ArgOfPericen	187.71146794020873
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 70"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.101110407229197e-08
	Radius		30.953534280814207

	RotationPeriod	5.737815734939627

	Obliquity		301.1610552942163

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1848899594797824
		Eccentricity	0.05849607175817574
		Inclination		-1.3465570144530064
		AscendingNode	148.09143523669206
		ArgOfPericen	354.28259980625916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 71"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.080328242152335e-07
	Radius		67.68743048317143

	RotationPeriod	5.824945275621877

	Obliquity		20.518158917512274

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3278083109679892
		Eccentricity	0.04888947283416972
		Inclination		1.2029407228002933
		AscendingNode	142.43800750146298
		ArgOfPericen	340.29721565504127
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 72"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.665601694399869e-08
	Radius		29.19272737970609

	RotationPeriod	6.990276198168229

	Obliquity		301.70845262713

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.27087613285178
		Eccentricity	0.06988228938966612
		Inclination		1.3241737148656119
		AscendingNode	291.2043298899405
		ArgOfPericen	248.31291522203676
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 72.1"
{
	ParentBody	"Erebos 72"
	Class		"Asteroid"
	Mass		2.113912173551071e-10
	Radius		4.830600235044787

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.309912033237787e-06
		Eccentricity	0.006859709570982526
		Inclination		11.206603704299955
		AscendingNode	197.4568994535121
		ArgOfPericen	355.8759259238076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 73"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272234695821718
		Eccentricity	0.07153658673702475
		Inclination		3.223714714357779
		AscendingNode	329.29874570859477
		ArgOfPericen	159.72523645938418
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 73 A"
{
	ParentBody	"Erebos 73"
	Class		"Asteroid"
	Mass		2.867705474938683e-08
	Radius		24.995720246110167

	Orbit
	{
		Epoch			2457395.5
		Period			0.007111101545044471
		Eccentricity	0.003350841605025871
		Inclination		181.8229441348286
		AscendingNode	202.67534817354579
		ArgOfPericen	305.8164789393083
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 73 B"
{
	ParentBody	"Erebos 73"
	Class		"Asteroid"
	Mass		4.087784244762825e-09
	Radius		13.057202175207285

	Orbit
	{
		Epoch			2457395.5
		Period			0.007111101545044471
		Eccentricity	0.003350841605025871
		Inclination		181.8229441348286
		AscendingNode	202.67534817354579
		ArgOfPericen	125.8164789393083
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 74"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.407874001545202e-07
	Radius		68.65862436663446

	RotationPeriod	7.367248049337682

	Obliquity		298.75415583294944

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2821697610578413
		Eccentricity	0.08356825541796262
		Inclination		1.7576571711431042
		AscendingNode	2.6177428889109455
		ArgOfPericen	85.55678788330178
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 75"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.463306222318716e-07
	Radius		55.24258392896185

	RotationPeriod	5.407008111737102

	Obliquity		87.79820559822384

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3325599386121625
		Eccentricity	0.07377294102198562
		Inclination		3.3160344039021923
		AscendingNode	181.57966548109118
		ArgOfPericen	314.39729260257144
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 76"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.002252814575556e-08
	Radius		23.995203140930723

	RotationPeriod	2.8358236196645854

	Obliquity		80.60969070128463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.36061602821779
		Eccentricity	0.055745896794680776
		Inclination		0.2118007430858294
		AscendingNode	113.072157828888
		ArgOfPericen	170.98986223012406
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 77"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.357992780325939e-07
	Radius		70.33300021462824

	RotationPeriod	4.783258826260238

	Obliquity		215.45905008406748

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2257667980228653
		Eccentricity	0.03778398918148566
		Inclination		-1.5890215510589518
		AscendingNode	182.26743424867456
		ArgOfPericen	14.19009619846431
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 78"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.645691980789772e-07
	Radius		63.4754611911828

	RotationPeriod	4.182688812157395

	Obliquity		101.62332608587319

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2531554018408775
		Eccentricity	0.05027235324786169
		Inclination		-0.5846568117500045
		AscendingNode	188.77451632649317
		ArgOfPericen	191.71934188540183
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 78.1"
{
	ParentBody	"Erebos 78"
	Class		"Asteroid"
	Mass		4.015579205709274e-09
	Radius		13.026821430213083

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.382537333820376e-06
		Eccentricity	0.005883515782002512
		Inclination		5.188156390738504
		AscendingNode	247.58849829732526
		ArgOfPericen	110.34288314720023
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 78.2"
{
	ParentBody	"Erebos 78"
	Class		"Asteroid"
	Mass		1.886285588348632e-09
	Radius		10.126473019947694

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4531964223130082e-06
		Eccentricity	0.005307326435055821
		Inclination		-35.35601675895267
		AscendingNode	44.18170242555311
		ArgOfPericen	118.81290891016292
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 78.3"
{
	ParentBody	"Erebos 78"
	Class		"Asteroid"
	Mass		3.163681306191613e-10
	Radius		5.584530114101958

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.348467299262382e-07
		Eccentricity	0.008970922164533308
		Inclination		14.008593533339242
		AscendingNode	320.8766205404168
		ArgOfPericen	141.20181074932114
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 78.4"
{
	ParentBody	"Erebos 78"
	Class		"Asteroid"
	Mass		6.645242691525316e-11
	Radius		3.3196528994945127

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.144854472905757e-06
		Eccentricity	0.007054195921336598
		Inclination		-40.33176771259306
		AscendingNode	313.49403688603877
		ArgOfPericen	102.90333160625713
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 78.5"
{
	ParentBody	"Erebos 78"
	Class		"Asteroid"
	Mass		1.5377994868981951e-09
	Radius		9.459952700690392

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.0344747855363296e-06
		Eccentricity	0.004109875503334522
		Inclination		39.1983632589954
		AscendingNode	35.4035022102049
		ArgOfPericen	266.7400885122862
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 79"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.506777976157261e-07
	Radius		60.47324035209594

	RotationPeriod	9.658463197589422

	Obliquity		24.056011980836686

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2962387002355023
		Eccentricity	0.0419761456266386
		Inclination		0.782838549282771
		AscendingNode	272.61117943625754
		ArgOfPericen	180.46914810007405
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 80"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.632967401027572e-07
	Radius		75.68095961871231

	RotationPeriod	5.353783181090592

	Obliquity		243.12141212834143

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2582782341885497
		Eccentricity	0.046751156692161816
		Inclination		3.0633904147646565
		AscendingNode	341.6750608129926
		ArgOfPericen	110.02552877914545
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 81"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3541014204216112e-07
	Radius		42.19353726533896

	RotationPeriod	4.96902290688808

	Obliquity		115.20100033878718

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3844834205999756
		Eccentricity	0.030231908184969954
		Inclination		2.3758531895233954
		AscendingNode	328.95537133989
		ArgOfPericen	333.052467725668
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 82"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.7468278797206175e-07
	Radius		54.7716331285502

	RotationPeriod	9.020252494358044

	Obliquity		107.77106492587987

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2508182385692335
		Eccentricity	0.023632536574028206
		Inclination		-0.6708558143721617
		AscendingNode	275.74169424148903
		ArgOfPericen	8.778974958349487
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 82.1"
{
	ParentBody	"Erebos 82"
	Class		"Asteroid"
	Mass		1.1569532918807657e-09
	Radius		7.975777895446313

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.707738210325981e-06
		Eccentricity	0.004395356051431086
		Inclination		-15.59121982988063
		AscendingNode	26.31180288737181
		ArgOfPericen	324.24041747870984
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 83"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.32583658626573
		Eccentricity	0.02767882789010614
		Inclination		-1.0876989631550797
		AscendingNode	277.918972484312
		ArgOfPericen	263.9402118957554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 83 A"
{
	ParentBody	"Erebos 83"
	Class		"Asteroid"
	Mass		7.426535021935654e-07
	Radius		69.01214159641587

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029720639691744625
		Eccentricity	0.0041356725830561354
		Inclination		119.22352523514206
		AscendingNode	248.58380774525705
		ArgOfPericen	64.90926731037581
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 83 B"
{
	ParentBody	"Erebos 83"
	Class		"Asteroid"
	Mass		6.927387456876848e-08
	Radius		31.298240245640176

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029720639691744625
		Eccentricity	0.0041356725830561354
		Inclination		119.22352523514206
		AscendingNode	248.58380774525705
		ArgOfPericen	244.9092673103758
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 84"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.253146379060167e-07
	Radius		42.953138620714356

	RotationPeriod	4.987323882829015

	Obliquity		35.67875278705253

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3195762102656685
		Eccentricity	0.04799460045379137
		Inclination		-2.0298391560066813
		AscendingNode	11.465626598341423
		ArgOfPericen	69.14423411138621
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 85"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.55534282982323e-08
	Radius		33.835241388406004

	RotationPeriod	4.409812381787597

	Obliquity		87.01449907949467

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4001997853766346
		Eccentricity	0.07940689165994866
		Inclination		1.139301368870175
		AscendingNode	323.17249260612584
		ArgOfPericen	35.18301435714303
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 86"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0135183040029805e-06
	Radius		76.75241695642386

	RotationPeriod	7.044304558410348

	Obliquity		204.01806182808457

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2679841414236717
		Eccentricity	0.06870121471817342
		Inclination		-2.5481521191887944
		AscendingNode	172.32724287822458
		ArgOfPericen	28.32823091438175
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 87"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6619200612808947e-07
	Radius		42.929224445383454

	RotationPeriod	4.738408059766835

	Obliquity		143.67920826968628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.277642081486879
		Eccentricity	0.04891739115524832
		Inclination		0.521607297335372
		AscendingNode	168.5823213113965
		ArgOfPericen	231.71208094686656
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 88"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4151061923320425
		Eccentricity	0.07430356855057123
		Inclination		-2.315535521185575
		AscendingNode	214.85095382857077
		ArgOfPericen	303.6025107026297
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 88 A"
{
	ParentBody	"Erebos 88"
	Class		"Asteroid"
	Mass		1.767189697935354e-07
	Radius		45.30820622475666

	Orbit
	{
		Epoch			2457395.5
		Period			0.005900325889634248
		Eccentricity	0.0051119322168376394
		Inclination		299.8244775848661
		AscendingNode	185.84495939314652
		ArgOfPericen	310.51366788116655
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 88 B"
{
	ParentBody	"Erebos 88"
	Class		"Asteroid"
	Mass		5.325037764515064e-08
	Radius		30.375495813694165

	Orbit
	{
		Epoch			2457395.5
		Period			0.005900325889634248
		Eccentricity	0.0051119322168376394
		Inclination		299.8244775848661
		AscendingNode	185.84495939314652
		ArgOfPericen	130.51366788116655
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 89"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.256980482891039e-07
	Radius		80.03445193124347

	RotationPeriod	2.661800045011037

	Obliquity		74.70115992377943

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2378489680615523
		Eccentricity	0.07636189019673575
		Inclination		-2.594460992419029
		AscendingNode	226.46865532793527
		ArgOfPericen	192.9767134548371
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 90"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.125760566971746e-08
	Radius		33.72838994277019

	RotationPeriod	4.417353019236353

	Obliquity		271.33780192080036

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.334893605629797
		Eccentricity	0.0892753253909277
		Inclination		-1.7593627601861639
		AscendingNode	154.33350175794507
		ArgOfPericen	80.30183280899585
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 91"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3402702236434914e-07
	Radius		38.33214652729735

	RotationPeriod	5.691932112922319

	Obliquity		29.46877955104492

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.326033117843562
		Eccentricity	0.0582424324046281
		Inclination		1.794095655853483
		AscendingNode	289.88694053010664
		ArgOfPericen	316.17493160697325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 92"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.84092646228218e-07
	Radius		53.215810372355946

	RotationPeriod	5.911252988139091

	Obliquity		59.58529490040468

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3918627162847614
		Eccentricity	0.05257296312707301
		Inclination		-2.380834900170986
		AscendingNode	255.13098171483978
		ArgOfPericen	210.37241187772685
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 93"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0926532165151952e-07
	Radius		45.22512002268314

	RotationPeriod	6.0018432135536015

	Obliquity		68.4642689213089

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2324227367900096
		Eccentricity	0.07497088554639314
		Inclination		0.35296867478485644
		AscendingNode	241.15123892733348
		ArgOfPericen	236.8863640064213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 93.1"
{
	ParentBody	"Erebos 93"
	Class		"Asteroid"
	Mass		2.236099084626753e-09
	Radius		9.961184579896475

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.297637656294511e-06
		Eccentricity	0.004973469621310667
		Inclination		19.949419150009266
		AscendingNode	7.872621522562868
		ArgOfPericen	307.3063131359764
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 94"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3759059693026273e-06
	Radius		86.03572809108803

	RotationPeriod	3.438989140636973

	Obliquity		248.84886261821353

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.313919704621109
		Eccentricity	0.026912153604132218
		Inclination		1.634173390806005
		AscendingNode	172.4727109475337
		ArgOfPericen	355.6225183546432
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 95"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.169946745663325e-07
	Radius		70.03921475124002

	RotationPeriod	3.2026851389977087

	Obliquity		112.09914096324681

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3542386322419557
		Eccentricity	0.041351724062359756
		Inclination		-2.265969588640428
		AscendingNode	346.35889850999905
		ArgOfPericen	145.19733237716025
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 96"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3668021708502214
		Eccentricity	0.05623208303716481
		Inclination		0.024151910798191883
		AscendingNode	350.8697466952506
		ArgOfPericen	285.34575211593767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 96 A"
{
	ParentBody	"Erebos 96"
	Class		"Asteroid"
	Mass		1.751650978023618e-07
	Radius		44.33271990088856

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028754937695888885
		Eccentricity	0.0036392164917488793
		Inclination		16.236845079742316
		AscendingNode	284.88448776998916
		ArgOfPericen	124.32417752161601
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 96 B"
{
	ParentBody	"Erebos 96"
	Class		"Asteroid"
	Mass		5.136441957150437e-08
	Radius		29.452984800189522

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028754937695888885
		Eccentricity	0.0036392164917488793
		Inclination		16.236845079742316
		AscendingNode	284.88448776998916
		ArgOfPericen	304.324177521616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 97"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.03518105733393e-07
	Radius		56.01585205876986

	RotationPeriod	4.540359275719476

	Obliquity		18.634941546005336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.339044582908208
		Eccentricity	0.06341043101297979
		Inclination		-0.2146859003974773
		AscendingNode	330.38229369461067
		ArgOfPericen	247.78091345760623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 98"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2175304122761468e-07
	Radius		42.07468611189986

	RotationPeriod	5.6575830323122815

	Obliquity		136.66760520739388

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.354648866908469
		Eccentricity	0.05297144797649451
		Inclination		-2.3214395361067592
		AscendingNode	286.47438706986503
		ArgOfPericen	34.956891638726916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 99"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.136384705478707e-07
	Radius		38.12149557769723

	RotationPeriod	4.492187110249415

	Obliquity		17.459589917367424

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3213011773456365
		Eccentricity	0.05727559021068136
		Inclination		2.502484906320103
		AscendingNode	94.95670348968727
		ArgOfPericen	181.57774617869293
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 100"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4950476217202193e-07
	Radius		43.14173404175439

	RotationPeriod	6.705891218172573

	Obliquity		154.96787450677638

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2114332072341965
		Eccentricity	0.06745850714071362
		Inclination		-0.8714094295271612
		AscendingNode	352.5141239054666
		ArgOfPericen	237.81914891982507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 101"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.190250711545741e-08
	Radius		31.323711667278403

	RotationPeriod	4.984661996972782

	Obliquity		180.68038635481847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2847637182912823
		Eccentricity	0.04845700350245354
		Inclination		1.108017008810641
		AscendingNode	142.68522165040213
		ArgOfPericen	26.782941931068777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 102"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1934470870539857e-07
	Radius		38.943883325952854

	RotationPeriod	8.073282330297644

	Obliquity		71.53366086441036

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.364650732224703
		Eccentricity	0.055375894132351715
		Inclination		1.9112362858636183
		AscendingNode	270.4455429726385
		ArgOfPericen	293.4390700473127
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 103"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.520016880746121e-07
	Radius		42.541048226156235

	RotationPeriod	5.9877536761713115

	Obliquity		127.59524809727685

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.330157357360188
		Eccentricity	0.05607954004189256
		Inclination		0.0997274640155321
		AscendingNode	106.03309236379393
		ArgOfPericen	234.0756369156098
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 104"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.856043753634585e-07
	Radius		78.32508639862326

	RotationPeriod	3.868746955931892

	Obliquity		18.89780093172636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3328194482280473
		Eccentricity	0.04622130938042421
		Inclination		1.1593299946669158
		AscendingNode	45.80778384425587
		ArgOfPericen	220.3758319521757
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 105"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.009691320106934e-07
	Radius		55.85861893616072

	RotationPeriod	2.442860849283504

	Obliquity		270.2438853879893

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.280917603625681
		Eccentricity	0.043799157910659275
		Inclination		0.3790862110362953
		AscendingNode	43.29253040794964
		ArgOfPericen	314.8574008864144
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 105.1"
{
	ParentBody	"Erebos 105"
	Class		"Asteroid"
	Mass		3.542587676606524e-09
	Radius		12.706416235390527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.917546333941545e-06
		Eccentricity	0.002020514188240252
		Inclination		-29.765248541723256
		AscendingNode	112.87424130935007
		ArgOfPericen	77.45605754367618
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 106"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1991306014497138e-07
	Radius		48.32576874302686

	RotationPeriod	9.919718116811925

	Obliquity		328.63904553033336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.305207663893437
		Eccentricity	0.06408051523494185
		Inclination		0.8718487988012601
		AscendingNode	339.48612719059395
		ArgOfPericen	250.40598375488537
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 107"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.965126728565422e-07
	Radius		74.29607841256012

	RotationPeriod	8.748676794587935

	Obliquity		345.7069834129143

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4348644910626485
		Eccentricity	0.048827822501606034
		Inclination		-3.4721089346349596
		AscendingNode	13.673952283081157
		ArgOfPericen	188.9359322476072
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 108"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1101100988119666e-07
	Radius		47.50301537894495

	RotationPeriod	3.9011138548860496

	Obliquity		345.09917880054866

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.35485197234146
		Eccentricity	0.061936842134582976
		Inclination		-0.8256407130281489
		AscendingNode	194.14571114803672
		ArgOfPericen	108.52913819209544
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 109"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1051875317846553e-07
	Radius		52.19646743132013

	RotationPeriod	9.897070313031882

	Obliquity		316.2196940580741

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.295795144840087
		Eccentricity	0.057030861944079934
		Inclination		-1.128530793692457
		AscendingNode	210.75784687458523
		ArgOfPericen	220.06271366473158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 110"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.433522131559014
		Eccentricity	0.04735441569002915
		Inclination		1.9943836212279253
		AscendingNode	280.91614161234224
		ArgOfPericen	123.18615606763224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 110 A"
{
	ParentBody	"Erebos 110"
	Class		"Asteroid"
	Mass		4.062349871244274e-08
	Radius		27.212945028494598

	Orbit
	{
		Epoch			2457395.5
		Period			0.005987703139487954
		Eccentricity	0.003008850654809251
		Inclination		169.2805921573539
		AscendingNode	226.76273797879287
		ArgOfPericen	103.13572415694976
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 110 B"
{
	ParentBody	"Erebos 110"
	Class		"Asteroid"
	Mass		1.7480812302563275e-08
	Radius		20.544881442699616

	Orbit
	{
		Epoch			2457395.5
		Period			0.005987703139487954
		Eccentricity	0.003008850654809251
		Inclination		169.2805921573539
		AscendingNode	226.76273797879287
		ArgOfPericen	283.1357241569498
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 111"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.433020795994474e-07
	Radius		57.337887049181475

	RotationPeriod	4.621359012369586

	Obliquity		125.91713965376456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.359150984355212
		Eccentricity	0.05141755427303706
		Inclination		1.8615882835559165
		AscendingNode	238.02625565851233
		ArgOfPericen	330.6961704769876
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 112"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.036083213666034e-08
	Radius		29.133840985805353

	RotationPeriod	7.399318296892851

	Obliquity		38.429407673170616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.368170114749803
		Eccentricity	0.048276876181578866
		Inclination		1.0255770319962205
		AscendingNode	67.18205779430082
		ArgOfPericen	311.38391698720767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 113"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.178395288870108e-08
	Radius		21.382979368325337

	RotationPeriod	8.47872473746305

	Obliquity		329.61993424511957

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2841100530788077
		Eccentricity	0.07936430517949475
		Inclination		-2.4410980923364995
		AscendingNode	239.95071271478332
		ArgOfPericen	201.20380530410608
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 114"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.079596921670485e-07
	Radius		73.63718731022117

	RotationPeriod	6.552616666058058

	Obliquity		206.67456141069422

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2411111722656987
		Eccentricity	0.07244134951109815
		Inclination		-0.6174826178794215
		AscendingNode	107.93719530038123
		ArgOfPericen	120.94717039283586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 114.1"
{
	ParentBody	"Erebos 114"
	Class		"Asteroid"
	Mass		4.5933348987464295e-09
	Radius		12.641085600711186

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.379903092790289e-06
		Eccentricity	0.0035787677367417475
		Inclination		-8.865997675972672
		AscendingNode	162.3826903109926
		ArgOfPericen	177.1672524705326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 115"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3070623938761687
		Eccentricity	0.034339181527575924
		Inclination		0.3034970745001804
		AscendingNode	38.45572484154479
		ArgOfPericen	202.45627599449574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 115 A"
{
	ParentBody	"Erebos 115"
	Class		"Asteroid"
	Mass		1.2981828364325037e-07
	Radius		38.265051918352285

	Orbit
	{
		Epoch			2457395.5
		Period			0.004408474659373436
		Eccentricity	0.007895170613601869
		Inclination		251.52449217364654
		AscendingNode	342.917821279015
		ArgOfPericen	222.24994121098203
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 115 B"
{
	ParentBody	"Erebos 115"
	Class		"Asteroid"
	Mass		4.7495302835867657e-08
	Radius		27.367843201930864

	Orbit
	{
		Epoch			2457395.5
		Period			0.004408474659373436
		Eccentricity	0.007895170613601869
		Inclination		251.52449217364654
		AscendingNode	342.917821279015
		ArgOfPericen	42.249941210982
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 116"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.996501819156733e-08
	Radius		24.854217371084964

	RotationPeriod	4.655574200185169

	Obliquity		165.90266682483744

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2967234559655694
		Eccentricity	0.0362423753028693
		Inclination		-2.0620003574564056
		AscendingNode	337.14046418771096
		ArgOfPericen	181.90070288529685
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 117"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1602963019123536e-07
	Radius		54.21664909207432

	RotationPeriod	5.881935356806423

	Obliquity		228.23470001798506

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.274513264845036
		Eccentricity	0.041212612107416
		Inclination		-0.2115888563190153
		AscendingNode	5.231272021484994
		ArgOfPericen	268.54954885175624
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 118"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.544028178257666e-08
	Radius		31.01594892376447

	RotationPeriod	8.909882077454895

	Obliquity		336.0768608545175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.421092760339923
		Eccentricity	0.03184844804497641
		Inclination		1.0603186444158867
		AscendingNode	224.3310018742324
		ArgOfPericen	247.604076330653
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 119"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2254353004200085
		Eccentricity	0.029703159168213568
		Inclination		0.20561380397696627
		AscendingNode	29.7449448640204
		ArgOfPericen	268.63967282227907
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 119 A"
{
	ParentBody	"Erebos 119"
	Class		"Asteroid"
	Mass		4.141670537008463e-07
	Radius		57.96121901203332

	Orbit
	{
		Epoch			2457395.5
		Period			0.007801348266507222
		Eccentricity	0.0033707241602554533
		Inclination		219.9412977962519
		AscendingNode	280.7654177566056
		ArgOfPericen	356.7258360274386
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 119 B"
{
	ParentBody	"Erebos 119"
	Class		"Asteroid"
	Mass		8.436175805098862e-08
	Radius		34.10312695597205

	Orbit
	{
		Epoch			2457395.5
		Period			0.007801348266507222
		Eccentricity	0.0033707241602554533
		Inclination		219.9412977962519
		AscendingNode	280.7654177566056
		ArgOfPericen	176.72583602743862
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 120"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.6979154776259967e-07
	Radius		62.140690953995126

	RotationPeriod	7.236872896717618

	Obliquity		351.66040309554455

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3322857514049313
		Eccentricity	0.032461866091261476
		Inclination		0.6362554349231644
		AscendingNode	93.58794037982568
		ArgOfPericen	114.90813717674895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 121"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3860713317019064e-07
	Radius		49.20953881528943

	RotationPeriod	5.039051023910453

	Obliquity		147.75201125208636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.268995269065733
		Eccentricity	0.03888945995244835
		Inclination		0.8810100048652583
		AscendingNode	308.27322633525745
		ArgOfPericen	169.83283261182473
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 122"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.377568348613367e-07
	Radius		40.215681931665486

	RotationPeriod	4.504126744787257

	Obliquity		12.055761147632001

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.256101102081939
		Eccentricity	0.054708589819428124
		Inclination		1.347624459636121
		AscendingNode	15.033177209653994
		ArgOfPericen	288.8607010037645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 123"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.1842112577213635e-07
	Radius		59.792470774114484

	RotationPeriod	4.8050642704005435

	Obliquity		259.1283552998424

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3242088437478454
		Eccentricity	0.049823068137601643
		Inclination		-0.8759146288520624
		AscendingNode	280.4922437364935
		ArgOfPericen	205.17372592872584
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 123.1"
{
	ParentBody	"Erebos 123"
	Class		"Asteroid"
	Mass		7.407190048484265e-10
	Radius		7.23313317403254

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.047010729601334e-06
		Eccentricity	0.006108885082016498
		Inclination		39.14367415527904
		AscendingNode	47.253444118953226
		ArgOfPericen	272.1630261708786
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 124"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9808834050716805e-07
	Radius		43.513413568920335

	RotationPeriod	7.528657488240992

	Obliquity		309.5879046577105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.335762020716933
		Eccentricity	0.059818111720493616
		Inclination		0.25684435230714947
		AscendingNode	229.83229379156248
		ArgOfPericen	206.1601512224254
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 125"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.5334694625616696e-07
	Radius		56.692660264582905

	RotationPeriod	3.1119854248050958

	Obliquity		173.58575664075488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3027025935875307
		Eccentricity	0.07000849143193255
		Inclination		-1.187048131813602
		AscendingNode	312.98010020998646
		ArgOfPericen	263.00846775869076
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 126"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.264266105028921e-07
	Radius		53.962423062434

	RotationPeriod	9.185122021771729

	Obliquity		94.83702743379155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.183728417645113
		Eccentricity	0.06739290956489212
		Inclination		0.10298299653848969
		AscendingNode	284.7523894987266
		ArgOfPericen	307.8950669071206
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 127"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.358597718558039e-07
	Radius		69.53316493084111

	RotationPeriod	5.752667162137406

	Obliquity		270.9273291294457

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286486792537575
		Eccentricity	0.044012440794260574
		Inclination		-2.694483745704672
		AscendingNode	235.12764610371264
		ArgOfPericen	139.88898898693404
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 127.1"
{
	ParentBody	"Erebos 127"
	Class		"Asteroid"
	Mass		3.711616137049838e-09
	Radius		11.924714640911876

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.7858367455046256e-06
		Eccentricity	0.005645478442206789
		Inclination		7.579250735928077
		AscendingNode	36.977182095317545
		ArgOfPericen	328.4063815085833
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 128"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.807215361325868e-07
	Radius		76.84353770884294

	RotationPeriod	7.093107271104886

	Obliquity		204.84527451021737

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.389212408229081
		Eccentricity	0.05092226889352134
		Inclination		2.3538707491288364
		AscendingNode	89.69254792212378
		ArgOfPericen	216.37648979262457
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 129"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.634851888570235e-08
	Radius		32.59047329555955

	RotationPeriod	3.2632709040381327

	Obliquity		254.1026624163459

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3605898256138107
		Eccentricity	0.03814497745318586
		Inclination		-1.6202402465571313
		AscendingNode	239.52267449407498
		ArgOfPericen	22.228124381461747
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 130"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7191316965702595e-07
	Radius		48.599430119974976

	RotationPeriod	4.482213051451257

	Obliquity		155.43816259221128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.263584840223004
		Eccentricity	0.058650041148784
		Inclination		-0.4539167160843517
		AscendingNode	315.2309320461642
		ArgOfPericen	305.5705524625159
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 131"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.110613258647346e-08
	Radius		27.00105229094554

	RotationPeriod	2.3232574256106315

	Obliquity		286.41607800081397

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.353849231676036
		Eccentricity	0.0780120479813933
		Inclination		0.8421768355343268
		AscendingNode	30.51974290674266
		ArgOfPericen	214.28664323032743
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 132"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9271938648443666e-07
	Radius		52.35805841944408

	RotationPeriod	10.057120940793066

	Obliquity		145.68427612501358

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.257956683024542
		Eccentricity	0.030101654717871875
		Inclination		2.672576385099492
		AscendingNode	180.60640818614638
		ArgOfPericen	265.7614842429738
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 133"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.081350431865623e-07
	Radius		44.742795954644016

	RotationPeriod	6.88408579542538

	Obliquity		97.56296373906724

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.275068890295832
		Eccentricity	0.049504383330580715
		Inclination		-2.261521038499916
		AscendingNode	96.77147481549336
		ArgOfPericen	127.84611848948136
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 133.1"
{
	ParentBody	"Erebos 133"
	Class		"Asteroid"
	Mass		4.0679206247737804e-11
	Radius		2.5965630562506186

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.636226743500553e-07
		Eccentricity	0.007145231190485745
		Inclination		19.37204397263773
		AscendingNode	67.4675345646166
		ArgOfPericen	234.7392426195206
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 133.2"
{
	ParentBody	"Erebos 133"
	Class		"Asteroid"
	Mass		1.1965013193062063e-10
	Radius		3.720309839992148

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.990418438297434e-06
		Eccentricity	0.0056267440289831045
		Inclination		25.541611437499313
		AscendingNode	152.89543137938887
		ArgOfPericen	129.64835764449035
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 134"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3813481318838603
		Eccentricity	0.06830241084203259
		Inclination		-0.18672157071943296
		AscendingNode	344.65204108828664
		ArgOfPericen	44.14863626105869
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 134 A"
{
	ParentBody	"Erebos 134"
	Class		"Asteroid"
	Mass		9.24513382949529e-08
	Radius		33.56242318524125

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013820857103030158
		Eccentricity	0.008556331056682983
		Inclination		327.35430995751017
		AscendingNode	358.1043945869456
		ArgOfPericen	164.0856038095756
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 134 B"
{
	ParentBody	"Erebos 134"
	Class		"Asteroid"
	Mass		5.469451027680374e-08
	Radius		28.17497164763051

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013820857103030158
		Eccentricity	0.008556331056682983
		Inclination		327.35430995751017
		AscendingNode	358.1043945869456
		ArgOfPericen	344.08560380957556
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 135"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3355348048682956
		Eccentricity	0.057597225231174054
		Inclination		-0.4035285030002355
		AscendingNode	126.52692305034552
		ArgOfPericen	119.36622158484624
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 135 A"
{
	ParentBody	"Erebos 135"
	Class		"Asteroid"
	Mass		3.914336839100421e-07
	Radius		57.38868514180939

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021414679295928213
		Eccentricity	0.004923830479362371
		Inclination		299.91896726869055
		AscendingNode	79.68746334449963
		ArgOfPericen	345.59851780579083
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 135 B"
{
	ParentBody	"Erebos 135"
	Class		"Asteroid"
	Mass		1.0142120518085664e-07
	Radius		36.586129321007974

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021414679295928213
		Eccentricity	0.004923830479362371
		Inclination		299.91896726869055
		AscendingNode	79.68746334449963
		ArgOfPericen	165.59851780579083
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 136"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5114544813036897e-06
	Radius		85.95780576293268

	RotationPeriod	10.165585799185884

	Obliquity		293.77646336337665

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2362690924083672
		Eccentricity	0.05633288071696543
		Inclination		0.2919513494309521
		AscendingNode	324.56236345288244
		ArgOfPericen	122.42993569278332
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 137"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3163017874628656e-07
	Radius		38.78598464177132

	RotationPeriod	6.592189197608127

	Obliquity		119.47329458601462

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.265176524524119
		Eccentricity	0.02109782159634515
		Inclination		-0.41494468540564183
		AscendingNode	302.81449265638605
		ArgOfPericen	208.68630900600175
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 137.1"
{
	ParentBody	"Erebos 137"
	Class		"Asteroid"
	Mass		6.868835890428343e-10
	Radius		6.727453597860802

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.651549585379766e-06
		Eccentricity	0.005243344191431309
		Inclination		-20.085431411739865
		AscendingNode	215.18150955926967
		ArgOfPericen	249.75599850154524
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 138"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.194924611279667e-07
	Radius		58.62484632357071

	RotationPeriod	3.434557735391989

	Obliquity		345.1480693950909

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.422888210072442
		Eccentricity	0.046866179638253354
		Inclination		0.28099229698501943
		AscendingNode	31.455894133824614
		ArgOfPericen	297.7127100164971
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 139"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.480619879285432e-07
	Radius		64.74026212608582

	RotationPeriod	6.9558309057548176

	Obliquity		253.00688135389376

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2449374340886528
		Eccentricity	0.03624653806589994
		Inclination		1.0237882080902543
		AscendingNode	285.4003631064884
		ArgOfPericen	349.1413907312073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 140"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7777878294984742e-07
	Radius		43.440876276929586

	RotationPeriod	5.32368727435701

	Obliquity		183.49817726497335

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.21975897767818
		Eccentricity	0.055326349513981146
		Inclination		0.5760412784304122
		AscendingNode	42.01958386025008
		ArgOfPericen	329.54529571979907
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 141"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2015027454499021e-06
	Radius		78.41335901427493

	RotationPeriod	6.4776291359005915

	Obliquity		208.01516272403495

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.240613623943395
		Eccentricity	0.025763422415207304
		Inclination		-0.11497345645275601
		AscendingNode	253.92993865315276
		ArgOfPericen	101.20605276732306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 141.1"
{
	ParentBody	"Erebos 141"
	Class		"Asteroid"
	Mass		1.7490399039525112e-10
	Radius		4.124915361118541

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5304596838053163e-06
		Eccentricity	0.006607475794668662
		Inclination		20.60779127554529
		AscendingNode	222.78632900609094
		ArgOfPericen	105.9491366653357
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 142"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.052207485048227e-08
	Radius		28.686414108310807

	RotationPeriod	7.474257722066078

	Obliquity		243.58612024484066

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3491571610970965
		Eccentricity	0.05357919902752109
		Inclination		-1.9768729569281096
		AscendingNode	31.93206548861965
		ArgOfPericen	356.00188908745713
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 142.1"
{
	ParentBody	"Erebos 142"
	Class		"Asteroid"
	Mass		1.970885311310542e-10
	Radius		4.86033446379344

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7142797002578693e-06
		Eccentricity	0.005823266876519442
		Inclination		19.79777163234378
		AscendingNode	94.19876730549387
		ArgOfPericen	173.046011899598
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 142.2"
{
	ParentBody	"Erebos 142"
	Class		"Asteroid"
	Mass		5.911481720923316e-10
	Radius		7.009351227452017

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.634818060088461e-07
		Eccentricity	0.008080228456717289
		Inclination		-28.566983714481417
		AscendingNode	267.061568232784
		ArgOfPericen	356.5910214179673
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 143"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7506416598457315e-07
	Radius		51.09012641284559

	RotationPeriod	6.804157687400979

	Obliquity		115.32089846502731

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.325743452253954
		Eccentricity	0.061023040843018975
		Inclination		0.5839484872035182
		AscendingNode	308.68140456054743
		ArgOfPericen	145.56602413462699
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 144"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.295701266444915
		Eccentricity	0.06407003246945893
		Inclination		0.34309130699877
		AscendingNode	331.83809293757633
		ArgOfPericen	229.3232777504817
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 144 A"
{
	ParentBody	"Erebos 144"
	Class		"Asteroid"
	Mass		2.2355316386322456e-07
	Radius		47.30717962609467

	Orbit
	{
		Epoch			2457395.5
		Period			0.0057455799793533595
		Eccentricity	0.002908400157267037
		Inclination		29.56849723442002
		AscendingNode	118.62230275296976
		ArgOfPericen	1.564000567310333
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 144 B"
{
	ParentBody	"Erebos 144"
	Class		"Asteroid"
	Mass		2.208478924753118e-08
	Radius		21.86911473555878

	Orbit
	{
		Epoch			2457395.5
		Period			0.0057455799793533595
		Eccentricity	0.002908400157267037
		Inclination		29.56849723442002
		AscendingNode	118.62230275296976
		ArgOfPericen	181.56400056731033
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 145"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.377820836442637e-07
	Radius		53.28241882915321

	RotationPeriod	7.522889589425

	Obliquity		176.86988235247532

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3401805403073457
		Eccentricity	0.04267936716132546
		Inclination		-1.7659823628441773
		AscendingNode	116.43333931290591
		ArgOfPericen	203.47501788137788
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 146"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2156109985151663e-07
	Radius		47.117383139668604

	RotationPeriod	7.973342622510861

	Obliquity		247.9841736528199

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2890924234824284
		Eccentricity	0.059444508687819
		Inclination		0.7067697034977711
		AscendingNode	329.36364909691986
		ArgOfPericen	225.23068883791615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 147"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4459761608773974e-07
	Radius		42.084748640085145

	RotationPeriod	6.367418067692102

	Obliquity		290.6110195644367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3292522188029006
		Eccentricity	0.06130554485450731
		Inclination		1.3994764751432522
		AscendingNode	34.5578686824037
		ArgOfPericen	195.73213507758163
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 147.1"
{
	ParentBody	"Erebos 147"
	Class		"Asteroid"
	Mass		3.39320373065201e-10
	Radius		5.592521622221524

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9640275437742595e-06
		Eccentricity	0.005266757373523317
		Inclination		27.393054983934203
		AscendingNode	95.34121377146846
		ArgOfPericen	35.13584778121207
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 148"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.604047513510552e-07
	Radius		49.61483286530174

	RotationPeriod	3.631804104598239

	Obliquity		230.85610259253139

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2860746252959023
		Eccentricity	0.04782853779939217
		Inclination		0.4877170589780352
		AscendingNode	354.01298465322566
		ArgOfPericen	211.8241072119304
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 148.1"
{
	ParentBody	"Erebos 148"
	Class		"Asteroid"
	Mass		1.0319430316240266e-10
	Radius		3.6442973529286804

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7591902727335558e-06
		Eccentricity	0.005056022665264089
		Inclination		-13.127216518361514
		AscendingNode	291.84430113572176
		ArgOfPericen	338.8255875289971
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 149"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.999671684440586e-07
	Radius		63.37660585551429

	RotationPeriod	3.0816040798666773

	Obliquity		150.09952312954343

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3404321236633474
		Eccentricity	0.08531218495690318
		Inclination		-2.46407951458843
		AscendingNode	122.98910910167922
		ArgOfPericen	103.0040487388298
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 149.1"
{
	ParentBody	"Erebos 149"
	Class		"Asteroid"
	Mass		8.539543009187415e-09
	Radius		15.359061934802924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.036659963934248e-07
		Eccentricity	0.007490606714792906
		Inclination		-50.17472817339918
		AscendingNode	88.28137054758419
		ArgOfPericen	130.1398476807721
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 150"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.5258087613769256e-07
	Radius		61.26164479655818

	RotationPeriod	6.224904104092768

	Obliquity		272.8961260793234

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4078478123728337
		Eccentricity	0.026241717553812268
		Inclination		-0.025368440171263117
		AscendingNode	322.554495589471
		ArgOfPericen	227.94802128325472
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 151"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7594679040503907e-07
	Radius		50.17075616710814

	RotationPeriod	3.074069949012876

	Obliquity		35.24544857712273

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2607508793206113
		Eccentricity	0.042285472585363755
		Inclination		3.127016999118269
		AscendingNode	76.27052077864059
		ArgOfPericen	251.2494141056261
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 152"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.3999887838489e-08
	Radius		32.78341815043912

	RotationPeriod	4.553638748779221

	Obliquity		184.31977000374715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4149440063200887
		Eccentricity	0.05442827982205696
		Inclination		2.004156623259275
		AscendingNode	35.08270217937362
		ArgOfPericen	50.92791369950372
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 152.1"
{
	ParentBody	"Erebos 152"
	Class		"Asteroid"
	Mass		3.7749358561900155e-11
	Radius		2.619471864819608

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2088521171879474e-06
		Eccentricity	0.006667665064470821
		Inclination		-20.605082992266183
		AscendingNode	40.294686400783036
		ArgOfPericen	267.4336729420117
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 153"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.330610594122209e-07
	Radius		38.1634487712647

	RotationPeriod	7.118029424177295

	Obliquity		163.14863804512598

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2407497478098986
		Eccentricity	0.04580929376627835
		Inclination		0.9568491331973067
		AscendingNode	182.45846388044527
		ArgOfPericen	178.76625907721288
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 153.1"
{
	ParentBody	"Erebos 153"
	Class		"Asteroid"
	Mass		3.8425377168346447e-10
	Radius		5.434630248658779

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.162733703511873e-06
		Eccentricity	0.006513183434343029
		Inclination		51.131579505863535
		AscendingNode	288.8569160085242
		ArgOfPericen	317.8158000488402
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 153.2"
{
	ParentBody	"Erebos 153"
	Class		"Asteroid"
	Mass		5.72276597036255e-10
	Radius		6.2062978947420975

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9198132568314624e-06
		Eccentricity	0.006098171949470285
		Inclination		22.997235109703272
		AscendingNode	311.6850491348189
		ArgOfPericen	161.93864268714685
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 154"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.225688904388231e-07
	Radius		48.44055859738615

	RotationPeriod	2.8120781578246157

	Obliquity		140.6719100554716

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2379334255480403
		Eccentricity	0.05558564312543153
		Inclination		0.107318163199785
		AscendingNode	271.90487288782816
		ArgOfPericen	83.11550471615041
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 155"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.0262851926986483e-07
	Radius		53.52428351249418

	RotationPeriod	3.8075135072295647

	Obliquity		330.0185868492177

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3528319294509554
		Eccentricity	0.05034386079421983
		Inclination		0.33213170024293664
		AscendingNode	357.0816412228087
		ArgOfPericen	268.99445708482693
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 156"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.135437837320657e-07
	Radius		45.03147929262242

	RotationPeriod	6.612338213495938

	Obliquity		93.50321507465537

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.275373821781403
		Eccentricity	0.03254924765626784
		Inclination		-0.7500535626428166
		AscendingNode	144.73065428578983
		ArgOfPericen	36.2574718888384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 157"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5110395540495321e-07
	Radius		39.14713750602233

	RotationPeriod	6.339920493000378

	Obliquity		145.39212311387072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2387667004336165
		Eccentricity	0.041911481417535375
		Inclination		-0.6632384648041719
		AscendingNode	43.265239094920524
		ArgOfPericen	110.28100995991022
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 158"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.82519184585684e-07
	Radius		68.81777779250055

	RotationPeriod	7.160283525798363

	Obliquity		114.10262271088659

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2187692155268066
		Eccentricity	0.02959379331297397
		Inclination		-0.35390213517652636
		AscendingNode	286.3428906422902
		ArgOfPericen	284.1774620257603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 159"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1235155340937778e-07
	Radius		37.714578582592125

	RotationPeriod	6.53069361848273

	Obliquity		105.68340954311128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3123859810251193
		Eccentricity	0.060520362178600545
		Inclination		0.8192108205248659
		AscendingNode	83.99867397771325
		ArgOfPericen	126.84857979326999
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 160"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.934357759203052e-07
	Radius		68.39849552705898

	RotationPeriod	3.956793418009279

	Obliquity		99.76269283406089

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3967393609363055
		Eccentricity	0.04124954505340626
		Inclination		1.155910056506529
		AscendingNode	307.9126499348413
		ArgOfPericen	235.26359435445414
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 161"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.05154400974937e-08
	Radius		34.3560282515494

	RotationPeriod	4.2218576470976

	Obliquity		62.34298516913689

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.351568678478837
		Eccentricity	0.047920688297948655
		Inclination		0.5515035130645403
		AscendingNode	74.52822682843967
		ArgOfPericen	138.2428657692248
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 161.1"
{
	ParentBody	"Erebos 161"
	Class		"Asteroid"
	Mass		7.174570185057167e-11
	Radius		3.17951363358101

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2412884194219229e-06
		Eccentricity	0.0055040266353761184
		Inclination		14.615557622287596
		AscendingNode	53.84544565229526
		ArgOfPericen	173.66402199500672
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 161.2"
{
	ParentBody	"Erebos 161"
	Class		"Asteroid"
	Mass		8.248130664795779e-11
	Radius		3.3307899034260497

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9690947091196826e-06
		Eccentricity	0.005315342422038099
		Inclination		-13.619380172202048
		AscendingNode	71.51612983573916
		ArgOfPericen	288.01081417649357
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 161.3"
{
	ParentBody	"Erebos 161"
	Class		"Asteroid"
	Mass		1.5386289308901764e-10
	Radius		4.10021559846354

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.272956878314017e-07
		Eccentricity	0.0035424497242335156
		Inclination		-9.195667732851975
		AscendingNode	66.20040305659538
		ArgOfPericen	307.84069136371085
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 162"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.307955887230793
		Eccentricity	0.05799581833500961
		Inclination		1.9582072972909947
		AscendingNode	72.36909957993586
		ArgOfPericen	314.9305321740383
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 162 A"
{
	ParentBody	"Erebos 162"
	Class		"Asteroid"
	Mass		1.435865516487673e-07
	Radius		39.24874080692764

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010171836453453501
		Eccentricity	0.0057490108639695215
		Inclination		254.73303937420613
		AscendingNode	167.6656110749663
		ArgOfPericen	87.16164497658545
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 162 B"
{
	ParentBody	"Erebos 162"
	Class		"Asteroid"
	Mass		1.6836279145967172e-08
	Radius		19.210404612062025

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010171836453453501
		Eccentricity	0.0057490108639695215
		Inclination		254.73303937420613
		AscendingNode	167.6656110749663
		ArgOfPericen	267.1616449765854
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 163"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8207458259763517e-07
	Radius		42.8495486129913

	RotationPeriod	6.152292043454636

	Obliquity		43.9970306087203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310448018948786
		Eccentricity	0.07844040389030102
		Inclination		-0.6417892706939836
		AscendingNode	140.59478309567646
		ArgOfPericen	31.84867140708118
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 164"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.425134689975172
		Eccentricity	0.055815635732907584
		Inclination		-0.001225477458579246
		AscendingNode	119.58979122276638
		ArgOfPericen	183.16695598683876
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 164 A"
{
	ParentBody	"Erebos 164"
	Class		"Asteroid"
	Mass		6.059780625782846e-07
	Radius		67.07560432884614

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028661756826296545
		Eccentricity	0.0035223164474597218
		Inclination		323.1462091615957
		AscendingNode	177.93505922135193
		ArgOfPericen	35.254723336678495
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 164 B"
{
	ParentBody	"Erebos 164"
	Class		"Asteroid"
	Mass		4.0222807720952255e-08
	Radius		27.158331666032414

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028661756826296545
		Eccentricity	0.0035223164474597218
		Inclination		323.1462091615957
		AscendingNode	177.93505922135193
		ArgOfPericen	215.2547233366785
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 165"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.16579360967499e-07
	Radius		64.77107852365343

	RotationPeriod	6.239912781445163

	Obliquity		278.9096735330722

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.303620627316184
		Eccentricity	0.059926528672554776
		Inclination		-2.0657827070569303
		AscendingNode	0.29949222559152666
		ArgOfPericen	9.814463869164785
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 165.1"
{
	ParentBody	"Erebos 165"
	Class		"Asteroid"
	Mass		5.801253835569049e-09
	Radius		13.673890269485911

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9467798745241975e-06
		Eccentricity	0.006049422543233773
		Inclination		-33.23412828375175
		AscendingNode	162.2759815778258
		ArgOfPericen	256.37476687980285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 166"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.223295194478994e-08
	Radius		34.19845582514882

	RotationPeriod	6.4438380067446035

	Obliquity		4.061212325798489

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272218427093586
		Eccentricity	0.0505157626234279
		Inclination		1.7019762852249924
		AscendingNode	88.22633620543294
		ArgOfPericen	45.10324965242445
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 167"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.8234697366573625e-07
	Radius		60.31432077240101

	RotationPeriod	4.014873924376407

	Obliquity		223.18962260003988

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3733319190229842
		Eccentricity	0.059502741724230306
		Inclination		-1.358545900691291
		AscendingNode	268.43116187168056
		ArgOfPericen	339.7226302363833
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 168"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.006659425019754e-07
	Radius		76.27132341006238

	RotationPeriod	7.353850175119909

	Obliquity		326.51255890402416

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3415288141043322
		Eccentricity	0.041730103381006925
		Inclination		0.5816352851681119
		AscendingNode	302.28896322815245
		ArgOfPericen	162.8383937171253
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 168.1"
{
	ParentBody	"Erebos 168"
	Class		"Asteroid"
	Mass		2.9234635010358882e-09
	Radius		11.29291156428417

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7268927855512032e-06
		Eccentricity	0.0035966272803960517
		Inclination		44.12495246133494
		AscendingNode	161.79755360815184
		ArgOfPericen	334.8955240418912
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 169"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.7875948367909e-07
	Radius		62.38336703382656

	RotationPeriod	4.527410955520166

	Obliquity		133.76213615704128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3167121876972243
		Eccentricity	0.036400223098458445
		Inclination		-0.7215971221421651
		AscendingNode	174.4331851055746
		ArgOfPericen	90.6000100559546
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 169.1"
{
	ParentBody	"Erebos 169"
	Class		"Asteroid"
	Mass		5.8690325149250075e-09
	Radius		14.384182565915761

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.728237487025131e-06
		Eccentricity	0.0056070500697189656
		Inclination		-19.66524618965253
		AscendingNode	275.8903234088927
		ArgOfPericen	121.08436250775394
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 170"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.35288748334547e-07
	Radius		58.76340454248228

	RotationPeriod	4.737009559200727

	Obliquity		49.635702951847676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286948359746152
		Eccentricity	0.05201220883790361
		Inclination		-0.45790175810990164
		AscendingNode	129.36385962316461
		ArgOfPericen	12.377280181628048
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 171"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2078443046657892e-07
	Radius		37.76563027720901

	RotationPeriod	7.59560907918627

	Obliquity		220.00503586429818

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4030153666258705
		Eccentricity	0.0433357427112762
		Inclination		-0.758239988177482
		AscendingNode	93.87797468860529
		ArgOfPericen	71.32810965733071
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 172"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.9679485686561235e-08
	Radius		29.27215021836043

	RotationPeriod	5.9416228233269095

	Obliquity		94.75432759903383

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3305355537497654
		Eccentricity	0.03572294289226759
		Inclination		-0.4698978553873814
		AscendingNode	332.57306042093245
		ArgOfPericen	7.316969579217361
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 173"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.145235717759793e-09
	Radius		11.311133600192662

	RotationPeriod	7.37029937285827

	Obliquity		297.8456300519693

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.383516512214413
		Eccentricity	0.049095854303318046
		Inclination		0.47687897597962325
		AscendingNode	357.4209102251484
		ArgOfPericen	20.322210791149015
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 174"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1003960705413641e-07
	Radius		47.28420441458652

	RotationPeriod	7.39310099819841

	Obliquity		29.968026326897863

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3429682166368537
		Eccentricity	0.057801256863834104
		Inclination		-1.980810979715472
		AscendingNode	239.98155554796026
		ArgOfPericen	312.8108388487947
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 174.1"
{
	ParentBody	"Erebos 174"
	Class		"Asteroid"
	Mass		3.1658281944577293e-09
	Radius		11.68005267315904

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.782476248464984e-06
		Eccentricity	0.007736385842388404
		Inclination		-14.73691793786289
		AscendingNode	144.27315363262082
		ArgOfPericen	29.796351765257796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 175"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.685876933893186e-09
	Radius		9.437603163861958

	RotationPeriod	5.719068750710082

	Obliquity		272.559239830129

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.308338070622891
		Eccentricity	0.06511952496314215
		Inclination		-0.7992775303270981
		AscendingNode	174.4324664281941
		ArgOfPericen	43.02809476330216
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 175.1"
{
	ParentBody	"Erebos 175"
	Class		"Asteroid"
	Mass		1.7288867040451233e-12
	Radius		0.9517186953157633

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.191018306203737e-07
		Eccentricity	0.00537828475090563
		Inclination		27.788277278270357
		AscendingNode	11.271200693039765
		ArgOfPericen	321.40631273464584
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 175.2"
{
	ParentBody	"Erebos 175"
	Class		"Asteroid"
	Mass		8.632592490191655e-12
	Radius		1.626672666487222

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3193554743961682e-06
		Eccentricity	0.005793154531007222
		Inclination		-7.387438577956152
		AscendingNode	336.016041814505
		ArgOfPericen	356.42542402953114
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 175.3"
{
	ParentBody	"Erebos 175"
	Class		"Asteroid"
	Mass		1.177166952839929e-11
	Radius		1.8038445540811128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2636862236900997e-06
		Eccentricity	0.005600780345340098
		Inclination		-62.817909958117525
		AscendingNode	118.66181392824232
		ArgOfPericen	112.29614844017605
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 176"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3298148336139834
		Eccentricity	0.03359162469724661
		Inclination		1.8149548857662305
		AscendingNode	120.51335482852498
		ArgOfPericen	211.81011145186562
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 176 A"
{
	ParentBody	"Erebos 176"
	Class		"Asteroid"
	Mass		4.741430374266396e-08
	Radius		27.790984663100083

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024221387993423223
		Eccentricity	0.003797358084006762
		Inclination		120.96233332277946
		AscendingNode	359.0885235522996
		ArgOfPericen	18.68759672720493
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 176 B"
{
	ParentBody	"Erebos 176"
	Class		"Asteroid"
	Mass		1.0458514473603028e-09
	Radius		7.793947498229426

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024221387993423223
		Eccentricity	0.003797358084006762
		Inclination		120.96233332277946
		AscendingNode	359.0885235522996
		ArgOfPericen	198.68759672720492
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 177"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2583776027235034
		Eccentricity	0.02387226550801197
		Inclination		0.8622892164115252
		AscendingNode	79.81589258601224
		ArgOfPericen	95.13959830318788
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 177 A"
{
	ParentBody	"Erebos 177"
	Class		"Asteroid"
	Mass		6.156647674704137e-08
	Radius		31.477272067880303

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019764651407705447
		Eccentricity	0.004463964642771442
		Inclination		153.19777215459098
		AscendingNode	300.4859554157243
		ArgOfPericen	53.714023034802
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 177 B"
{
	ParentBody	"Erebos 177"
	Class		"Asteroid"
	Mass		4.7901081767773364e-08
	Radius		28.951035014736252

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019764651407705447
		Eccentricity	0.004463964642771442
		Inclination		153.19777215459098
		AscendingNode	300.4859554157243
		ArgOfPericen	233.71402303480198
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 178"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.502204177031594e-07
	Radius		64.48788593968355

	RotationPeriod	7.3316028615577205

	Obliquity		143.98372965964805

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4139742417171166
		Eccentricity	0.011895511823688677
		Inclination		-0.4410225745952162
		AscendingNode	75.37104326052632
		ArgOfPericen	113.47313344281086
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 178.1"
{
	ParentBody	"Erebos 178"
	Class		"Asteroid"
	Mass		6.522311152436038e-09
	Radius		13.90780021848356

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.073543587060262e-06
		Eccentricity	0.004988362523956968
		Inclination		-50.90600953174428
		AscendingNode	202.4525386213339
		ArgOfPericen	293.410661842477
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 179"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.4441440758096814e-07
	Radius		59.43588522537564

	RotationPeriod	4.69308488934781

	Obliquity		340.9161211745355

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.372292677304935
		Eccentricity	0.037621255655840194
		Inclination		1.406395342253561
		AscendingNode	31.318726626826525
		ArgOfPericen	35.8724934316451
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 180"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.971687712469369e-09
	Radius		15.532122253154057

	RotationPeriod	7.845938776083283

	Obliquity		200.73883510310208

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3570087574655205
		Eccentricity	0.036929862296994936
		Inclination		-1.981484605351284
		AscendingNode	174.58682336697362
		ArgOfPericen	1.8513292792690672
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 181"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.895911784660535e-08
	Radius		26.050857954701897

	RotationPeriod	6.97263516148604

	Obliquity		226.74661444831503

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2722187528419893
		Eccentricity	0.05922215037402977
		Inclination		0.4444046305184618
		AscendingNode	84.53451167513482
		ArgOfPericen	250.95952701372107
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 182"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2958770054732525
		Eccentricity	0.029404617149637928
		Inclination		2.8586804519372864
		AscendingNode	92.59748381039478
		ArgOfPericen	354.9040286752258
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 182 A"
{
	ParentBody	"Erebos 182"
	Class		"Asteroid"
	Mass		2.0662793185698124e-15
	Radius		0.1

	Orbit
	{
		Epoch			2457395.5
		Period			0.001071023461743475
		Eccentricity	0.008193939161185503
		Inclination		145.28639080079085
		AscendingNode	192.90081431294178
		ArgOfPericen	248.46107503010248
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 182 B"
{
	ParentBody	"Erebos 182"
	Class		"Asteroid"
	Mass		2.2057005489948442e-16
	Radius		0.047437213919837795

	Orbit
	{
		Epoch			2457395.5
		Period			0.001071023461743475
		Eccentricity	0.008193939161185503
		Inclination		145.28639080079085
		AscendingNode	192.90081431294178
		ArgOfPericen	68.4610750301025
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 183"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1769149828781673e-07
	Radius		47.99195727938843

	RotationPeriod	4.955634512646551

	Obliquity		190.23489024960776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3465849383468362
		Eccentricity	0.03882362692049481
		Inclination		-0.07555014579147827
		AscendingNode	114.56283912236539
		ArgOfPericen	132.08272008012193
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 184"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.554864793634901e-08
	Radius		31.19661254180787

	RotationPeriod	4.452014015338488

	Obliquity		306.9902759337207

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2559180242319665
		Eccentricity	0.03729514922280676
		Inclination		0.9857932838905248
		AscendingNode	150.76026317493958
		ArgOfPericen	198.12583990584002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 185"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.380985669232492e-07
	Radius		70.9138402655701

	RotationPeriod	6.430129328813678

	Obliquity		252.52187481848347

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3118912568822014
		Eccentricity	0.029361682659098696
		Inclination		1.7791715268573376
		AscendingNode	2.1776155582114765
		ArgOfPericen	247.0803457993553
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 186"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.409663485603356e-08
	Radius		31.663132406784136

	RotationPeriod	6.491166863988244

	Obliquity		197.4614389288372

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3124967288722904
		Eccentricity	0.0447873883030836
		Inclination		2.219276824965914
		AscendingNode	266.2391408466752
		ArgOfPericen	182.93933346401423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 187"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.978031949235642e-07
	Radius		75.58177911689192

	RotationPeriod	5.086283413856146

	Obliquity		81.61413559246856

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.279080424478006
		Eccentricity	0.04776440310940144
		Inclination		1.0772920899266103
		AscendingNode	336.1474478297469
		ArgOfPericen	309.45267000621556
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 188"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.830251928777796e-07
	Radius		73.05158367262892

	RotationPeriod	8.294493933477813

	Obliquity		133.3101151642841

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3169917209690993
		Eccentricity	0.04661423161783919
		Inclination		-0.84159497022631
		AscendingNode	304.60347309345815
		ArgOfPericen	322.77492012382345
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 189"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.064849140988944e-07
	Radius		63.66393533314142

	RotationPeriod	6.516962859700531

	Obliquity		94.7117062241689

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3321492349891684
		Eccentricity	0.04701601726517312
		Inclination		-0.5888599809884565
		AscendingNode	244.12804936929413
		ArgOfPericen	40.007329063220254
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 190"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.1882137544569e-08
	Radius		36.293136376661025

	RotationPeriod	5.917661414685312

	Obliquity		137.99416216879393

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2995107478942707
		Eccentricity	0.031798114596358854
		Inclination		0.15401261864998583
		AscendingNode	330.63251612998556
		ArgOfPericen	198.7822993839173
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 191"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.018495786380787e-07
	Radius		53.18850427638182

	RotationPeriod	5.47601172461901

	Obliquity		355.76224306380243

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2512688167975994
		Eccentricity	0.061641284510975156
		Inclination		-0.3518161962379332
		AscendingNode	182.3837204297273
		ArgOfPericen	208.755028601879
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 192"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.6554204604603877e-07
	Radius		53.06175948284496

	RotationPeriod	3.411291420411481

	Obliquity		233.4424038803667

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2683486095815693
		Eccentricity	0.08194914441125309
		Inclination		1.0201370694209018
		AscendingNode	167.04347575535607
		ArgOfPericen	184.45303345596656
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 192.1"
{
	ParentBody	"Erebos 192"
	Class		"Asteroid"
	Mass		5.255896957734771e-09
	Radius		12.902825227817605

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.939731293078727e-06
		Eccentricity	0.002585687535597004
		Inclination		32.84062829746461
		AscendingNode	302.68638064338137
		ArgOfPericen	142.23071441121616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 193"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2628132347850487
		Eccentricity	0.1
		Inclination		-0.4158802316255791
		AscendingNode	346.90894111940673
		ArgOfPericen	317.20684078407356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 193 A"
{
	ParentBody	"Erebos 193"
	Class		"Asteroid"
	Mass		3.720140108532905e-08
	Radius		25.882918207098395

	Orbit
	{
		Epoch			2457395.5
		Period			0.002113908037005031
		Eccentricity	0.004727299480214033
		Inclination		42.21978055411994
		AscendingNode	78.09396430076194
		ArgOfPericen	99.13513436615254
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 193 B"
{
	ParentBody	"Erebos 193"
	Class		"Asteroid"
	Mass		1.019957350377754e-09
	Radius		7.804662816512926

	Orbit
	{
		Epoch			2457395.5
		Period			0.002113908037005031
		Eccentricity	0.004727299480214033
		Inclination		42.21978055411994
		AscendingNode	78.09396430076194
		ArgOfPericen	279.13513436615256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 194"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.366000554485671e-08
	Radius		21.491925865767534

	RotationPeriod	7.370061822965764

	Obliquity		229.55821620672543

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310081851047111
		Eccentricity	0.05605915758046126
		Inclination		-0.08259035374791332
		AscendingNode	144.90483389718915
		ArgOfPericen	206.31010768620234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 195"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.288334027620817e-08
	Radius		33.20224391397616

	RotationPeriod	6.127812000351353

	Obliquity		175.49545003171707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.381712607380316
		Eccentricity	0.05040855046333172
		Inclination		-0.18087477324890203
		AscendingNode	89.73268090836305
		ArgOfPericen	225.6794141463006
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 196"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0973036489391195e-07
	Radius		36.35523852119607

	RotationPeriod	5.163586359221532

	Obliquity		284.12121229317785

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2997203086055804
		Eccentricity	0.04136498320385597
		Inclination		-1.1172058220886196
		AscendingNode	197.55832978382693
		ArgOfPericen	317.2785530929532
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 197"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.107703848310473e-07
	Radius		39.30202273881949

	RotationPeriod	7.188880018551299

	Obliquity		229.86545639613445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2802986258622506
		Eccentricity	0.03441557900557053
		Inclination		-0.40717055309739425
		AscendingNode	356.5875734586765
		ArgOfPericen	188.00922631949658
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 198"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7580086047506782e-07
	Radius		46.73456686461185

	RotationPeriod	5.3142452137281335

	Obliquity		277.2783959224005

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2479840262489943
		Eccentricity	0.05836998115861676
		Inclination		-1.3293962481812691
		AscendingNode	315.73534226488783
		ArgOfPericen	184.02906671284455
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 198.1"
{
	ParentBody	"Erebos 198"
	Class		"Asteroid"
	Mass		2.1413021535839865e-09
	Radius		10.752857104140915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5854555191161227e-06
		Eccentricity	0.006820516137596757
		Inclination		-47.24198284792817
		AscendingNode	319.96928312466264
		ArgOfPericen	154.97638669680882
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 199"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.260378080481274
		Eccentricity	0.059975680173946055
		Inclination		-2.157536466606325
		AscendingNode	276.80796368627125
		ArgOfPericen	47.12162198111955
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 199 A"
{
	ParentBody	"Erebos 199"
	Class		"Asteroid"
	Mass		3.3409015208945125e-07
	Radius		56.09857040869399

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025812707713459824
		Eccentricity	0.004765173283858622
		Inclination		57.84767613755641
		AscendingNode	165.5088290139434
		ArgOfPericen	334.0850806054653
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 199 B"
{
	ParentBody	"Erebos 199"
	Class		"Asteroid"
	Mass		7.58986744883757e-08
	Radius		34.230136664565215

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025812707713459824
		Eccentricity	0.004765173283858622
		Inclination		57.84767613755641
		AscendingNode	165.5088290139434
		ArgOfPericen	154.08508060546524
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 200"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3303211536740314
		Eccentricity	0.022858428116262097
		Inclination		4.30763554113276
		AscendingNode	61.33264741008442
		ArgOfPericen	215.41270294910373
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 200 A"
{
	ParentBody	"Erebos 200"
	Class		"Asteroid"
	Mass		5.796788512101761e-07
	Radius		63.081777637631006

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007834971427643273
		Eccentricity	0.0044012518745408374
		Inclination		135.19898174977928
		AscendingNode	154.2796115680797
		ArgOfPericen	234.56271462997088
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 200 B"
{
	ParentBody	"Erebos 200"
	Class		"Asteroid"
	Mass		4.523059324108224e-08
	Radius		26.955798370046317

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007834971427643273
		Eccentricity	0.0044012518745408374
		Inclination		135.19898174977928
		AscendingNode	154.2796115680797
		ArgOfPericen	54.562714629970856
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 201"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.050940488532711e-07
	Radius		75.771168246706

	RotationPeriod	3.4749270009404247

	Obliquity		316.96867758209356

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3482473932578354
		Eccentricity	0.03117671205832468
		Inclination		-0.98419277318178
		AscendingNode	356.00046642729626
		ArgOfPericen	345.49887238461935
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 202"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9223266059856595e-07
	Radius		44.9607168311118

	RotationPeriod	6.074211738541805

	Obliquity		33.49603410796383

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3139995185995987
		Eccentricity	0.053264202792033415
		Inclination		-3.370532011777121
		AscendingNode	170.88423600161676
		ArgOfPericen	128.5916590894423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 203"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.9562489201857533e-07
	Radius		56.4685373854604

	RotationPeriod	9.82815211397365

	Obliquity		24.72856044701057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3507750212231002
		Eccentricity	0.07976179111313125
		Inclination		-0.6926444637646315
		AscendingNode	297.2789122652304
		ArgOfPericen	137.18935901437757
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 204"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.5728094526878745e-07
	Radius		53.9964914821843

	RotationPeriod	6.267634526561726

	Obliquity		327.1788881392132

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2363807277676275
		Eccentricity	0.06973225029555818
		Inclination		-2.7743133581424435
		AscendingNode	78.0771798983809
		ArgOfPericen	249.26083735656488
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 205"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1916549403259528e-07
	Radius		39.18687874632249

	RotationPeriod	4.813240167438851

	Obliquity		96.63146110972784

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2513609583331875
		Eccentricity	0.04763357414218464
		Inclination		-1.4520451822073077
		AscendingNode	313.40002699978487
		ArgOfPericen	322.1564155679919
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 206"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4023283551638897
		Eccentricity	0.03987056802696927
		Inclination		-1.9539963822624893
		AscendingNode	297.9746608438109
		ArgOfPericen	342.88336631533315
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 206 A"
{
	ParentBody	"Erebos 206"
	Class		"Asteroid"
	Mass		5.156608624642814e-08
	Radius		29.209634303569093

	Orbit
	{
		Epoch			2457395.5
		Period			0.00789917463197401
		Eccentricity	0.003184878569156023
		Inclination		301.43323446035294
		AscendingNode	104.67500660872294
		ArgOfPericen	236.83603706288773
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 206 B"
{
	ParentBody	"Erebos 206"
	Class		"Asteroid"
	Mass		3.331233602527534e-09
	Radius		11.720327818095315

	Orbit
	{
		Epoch			2457395.5
		Period			0.00789917463197401
		Eccentricity	0.003184878569156023
		Inclination		301.43323446035294
		AscendingNode	104.67500660872294
		ArgOfPericen	56.836037062887726
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 207"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2820250774585355e-07
	Radius		39.09330095112256

	RotationPeriod	5.949456230279761

	Obliquity		292.0055387324787

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272219683730585
		Eccentricity	0.02945297263768908
		Inclination		-4.982316453350746
		AscendingNode	57.516960954376856
		ArgOfPericen	299.2566705650088
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 207.1"
{
	ParentBody	"Erebos 207"
	Class		"Asteroid"
	Mass		1.4776182722859406e-09
	Radius		8.83061438361433

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.2755075328994706e-06
		Eccentricity	0.005816496872895139
		Inclination		15.348367192342424
		AscendingNode	135.41998119156256
		ArgOfPericen	324.6210603359258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 208"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.568121418267577e-07
	Radius		50.794886988855815

	RotationPeriod	6.0560700930436075

	Obliquity		95.66464406391337

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.28087049015947
		Eccentricity	0.04865953116891269
		Inclination		-1.0951758787814918
		AscendingNode	91.60417055073725
		ArgOfPericen	333.3229320147554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 209"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5361418814782497e-07
	Radius		44.83173725555827

	RotationPeriod	4.223275737370431

	Obliquity		64.54433858313443

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.369855424611375
		Eccentricity	0.06121330051517815
		Inclination		1.851120142398409
		AscendingNode	155.31334508784175
		ArgOfPericen	175.5100706936897
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 209.1"
{
	ParentBody	"Erebos 209"
	Class		"Asteroid"
	Mass		1.0200583008151207e-09
	Radius		8.426556229654768

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.854769329032109e-06
		Eccentricity	0.001976359537371149
		Inclination		36.72838950581951
		AscendingNode	220.58324717170441
		ArgOfPericen	199.6592539482503
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 209.2"
{
	ParentBody	"Erebos 209"
	Class		"Asteroid"
	Mass		7.872155034818516e-10
	Radius		7.729291228865126

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.7620564563831712e-06
		Eccentricity	0.003903440179356362
		Inclination		-19.36883169566451
		AscendingNode	220.8200449247173
		ArgOfPericen	121.24262615982202
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 209.3"
{
	ParentBody	"Erebos 209"
	Class		"Asteroid"
	Mass		9.054870109962115e-10
	Radius		8.098461712853915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.422593739833816e-06
		Eccentricity	0.007006459416088628
		Inclination		-21.011979191121895
		AscendingNode	339.64341008265706
		ArgOfPericen	192.4507643995
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 210"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7038009031039353e-07
	Radius		43.148688498279135

	RotationPeriod	5.045019722319289

	Obliquity		126.33595561236127

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2932187115551605
		Eccentricity	0.0436243555041704
		Inclination		0.014572344251869814
		AscendingNode	186.42280008872905
		ArgOfPericen	155.81149784556627
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 211"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.8111454974292597e-07
	Radius		52.306963036179766

	RotationPeriod	4.40808100930913

	Obliquity		86.51948155537072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.311072968981973
		Eccentricity	0.02562533004548542
		Inclination		-2.7088089966835844
		AscendingNode	151.4279096479623
		ArgOfPericen	163.8471171780765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 212"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.333508044270932e-07
	Radius		68.34766899321237

	RotationPeriod	2.6562749546858098

	Obliquity		291.11893008460845

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.31160520464848
		Eccentricity	0.07459404577552473
		Inclination		0.9140121225161817
		AscendingNode	70.24512906473653
		ArgOfPericen	223.82460928091638
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 213"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.724172853977002e-07
	Radius		65.60804998390402

	RotationPeriod	6.37792303286121

	Obliquity		349.6681576400476

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2816046054185732
		Eccentricity	0.027106637818214863
		Inclination		1.3664356717615447
		AscendingNode	279.0186022870325
		ArgOfPericen	230.7705987544392
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 213.1"
{
	ParentBody	"Erebos 213"
	Class		"Asteroid"
	Mass		2.45292619296819e-09
	Radius		10.65649478515992

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.67937760376489e-06
		Eccentricity	0.0037352706128725593
		Inclination		-59.58526752845201
		AscendingNode	24.766722599192178
		ArgOfPericen	158.22969640200859
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 214"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.059294058050968e-07
	Radius		53.91395738160145

	RotationPeriod	4.53305446162953

	Obliquity		263.89837877768275

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3016102197141204
		Eccentricity	0.050724020920324395
		Inclination		-0.3818912272932523
		AscendingNode	139.59306220442673
		ArgOfPericen	346.30660356661514
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 215"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.0243077154120263e-07
	Radius		52.38521848338378

	RotationPeriod	5.697378077240424

	Obliquity		200.0897115082077

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3115300472983873
		Eccentricity	0.011360898458025424
		Inclination		1.0790100895560637
		AscendingNode	168.09726134824314
		ArgOfPericen	200.08631486089513
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 216"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.506443061522647e-07
	Radius		53.933001901380486

	RotationPeriod	6.709099685319307

	Obliquity		344.164256260251

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.396525253648445
		Eccentricity	0.0670583076779567
		Inclination		-2.951803218981919
		AscendingNode	350.7907720430835
		ArgOfPericen	22.00563265375238
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 217"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3924964751039206
		Eccentricity	0.02746490501147947
		Inclination		2.1771677988836995
		AscendingNode	170.20860167155809
		ArgOfPericen	5.782841921374446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 217 A"
{
	ParentBody	"Erebos 217"
	Class		"Asteroid"
	Mass		7.58493276532254e-09
	Radius		15.358618762302747

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029193511456003752
		Eccentricity	0.004743550229439078
		Inclination		311.4195044630057
		AscendingNode	91.17017016340948
		ArgOfPericen	55.00839448181203
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 217 B"
{
	ParentBody	"Erebos 217"
	Class		"Asteroid"
	Mass		2.367708381612459e-09
	Radius		10.41863889043349

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029193511456003752
		Eccentricity	0.004743550229439078
		Inclination		311.4195044630057
		AscendingNode	91.17017016340948
		ArgOfPericen	235.00839448181205
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 218"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.118287724357591e-08
	Radius		31.809729990686208

	RotationPeriod	4.990359097344311

	Obliquity		54.20882182294091

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.182522360021571
		Eccentricity	0.050964843097745606
		Inclination		0.15555509342505813
		AscendingNode	222.00175100321974
		ArgOfPericen	53.62276397764775
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 219"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2785735531990518e-07
	Radius		39.217670315180776

	RotationPeriod	6.116574852204533

	Obliquity		264.6447858565871

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.32451530299401
		Eccentricity	0.06736673822539628
		Inclination		3.7395379148590844
		AscendingNode	300.73774918802343
		ArgOfPericen	325.37294778945727
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 220"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.277409337456256
		Eccentricity	0.04337712673379687
		Inclination		0.7759251208067217
		AscendingNode	32.953571710126774
		ArgOfPericen	205.87044515631766
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 220 A"
{
	ParentBody	"Erebos 220"
	Class		"Asteroid"
	Mass		5.414637757369356e-07
	Radius		69.1366288277691

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014038424938561278
		Eccentricity	0.005180764799446682
		Inclination		17.34293939082643
		AscendingNode	81.00376112507846
		ArgOfPericen	303.19379834030786
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 220 B"
{
	ParentBody	"Erebos 220"
	Class		"Asteroid"
	Mass		9.56051432916348e-09
	Radius		18.00302490209222

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014038424938561278
		Eccentricity	0.005180764799446682
		Inclination		17.34293939082643
		AscendingNode	81.00376112507846
		ArgOfPericen	123.19379834030786
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 221"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3199474908080644
		Eccentricity	0.04652542118919144
		Inclination		-1.2873795218212705
		AscendingNode	23.323121540905497
		ArgOfPericen	54.737915449934256
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 221 A"
{
	ParentBody	"Erebos 221"
	Class		"Asteroid"
	Mass		9.859190917956679e-07
	Radius		80.86127290749404

	Orbit
	{
		Epoch			2457395.5
		Period			0.006892432384533019
		Eccentricity	0.00460695109033988
		Inclination		14.18752983435089
		AscendingNode	318.6850363123102
		ArgOfPericen	218.0064808226036
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 221 B"
{
	ParentBody	"Erebos 221"
	Class		"Asteroid"
	Mass		4.189897423991931e-08
	Radius		28.218111492252362

	Orbit
	{
		Epoch			2457395.5
		Period			0.006892432384533019
		Eccentricity	0.00460695109033988
		Inclination		14.18752983435089
		AscendingNode	318.6850363123102
		ArgOfPericen	38.006480822603635
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 222"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.236371009032037e-07
	Radius		71.88876971270209

	RotationPeriod	5.9472037190572715

	Obliquity		184.98937618251855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3775506552203534
		Eccentricity	0.027666520485915037
		Inclination		2.040791060200305
		AscendingNode	16.8453583232193
		ArgOfPericen	93.0347794213673
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 223"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8239981762271013e-07
	Radius		43.2900674041542

	RotationPeriod	2.8490238751968224

	Obliquity		45.079882290019604

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3776233671047065
		Eccentricity	0.046069236771499246
		Inclination		0.8410373531183184
		AscendingNode	349.6422532228946
		ArgOfPericen	229.24021662232707
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 224"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.169335117458111e-07
	Radius		60.27107641523829

	RotationPeriod	9.407342903362007

	Obliquity		224.87976259818456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.440035334438092
		Eccentricity	0.04945558462667685
		Inclination		-1.1182768458230505
		AscendingNode	226.76166704353403
		ArgOfPericen	308.58412050220574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 225"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.461104676737265e-07
	Radius		74.5243920326991

	RotationPeriod	2.899721487642125

	Obliquity		293.3604108603555

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.355275943307867
		Eccentricity	0.04719667584112164
		Inclination		-0.8703339290658278
		AscendingNode	154.47980154339032
		ArgOfPericen	1.6110693467145332
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 226"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2558542724245187
		Eccentricity	0.04892349265533199
		Inclination		-1.6542114707705589
		AscendingNode	276.36022240192824
		ArgOfPericen	102.34199130002797
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 226 A"
{
	ParentBody	"Erebos 226"
	Class		"Asteroid"
	Mass		4.832548466602161e-07
	Radius		62.60217422202534

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018542615776630678
		Eccentricity	0.006510771336803966
		Inclination		134.1418298445407
		AscendingNode	103.0087831051735
		ArgOfPericen	122.90578274723893
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 226 B"
{
	ParentBody	"Erebos 226"
	Class		"Asteroid"
	Mass		6.95914740938641e-08
	Radius		32.81325820984587

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018542615776630678
		Eccentricity	0.006510771336803966
		Inclination		134.1418298445407
		AscendingNode	103.0087831051735
		ArgOfPericen	302.90578274723896
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 227"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.26795823329447e-07
	Radius		38.64087335719023

	RotationPeriod	6.710573965751522

	Obliquity		71.51826196168354

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.349709048911861
		Eccentricity	0.04828310315515089
		Inclination		-2.918796639346762
		AscendingNode	59.381535259866276
		ArgOfPericen	115.79744709913933
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 228"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1798283631830393e-07
	Radius		48.5038184521805

	RotationPeriod	5.506269605370647

	Obliquity		249.02575214481894

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2963052245029574
		Eccentricity	0.0714866542616492
		Inclination		-1.1150734706761685
		AscendingNode	100.49358064212514
		ArgOfPericen	348.7406396757387
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 228.1"
{
	ParentBody	"Erebos 228"
	Class		"Asteroid"
	Mass		2.7243813358371636e-10
	Radius		5.224657135113921

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.953583381934745e-06
		Eccentricity	0.004368065684322798
		Inclination		-6.2736392003543875
		AscendingNode	106.9875445040734
		ArgOfPericen	169.33347810369037
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 229"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.3203467308035685e-07
	Radius		52.97119741853747

	RotationPeriod	5.311231659959606

	Obliquity		292.76671799378147

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3868998971558426
		Eccentricity	0.05320591622686123
		Inclination		2.711841594956749
		AscendingNode	17.682265482436208
		ArgOfPericen	24.97181123113623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 230"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.3594528630918085e-08
	Radius		28.733991571721468

	RotationPeriod	6.828797316546027

	Obliquity		257.3636531782977

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2906791942291993
		Eccentricity	0.07480992468844207
		Inclination		0.30640757891009807
		AscendingNode	11.247356771827342
		ArgOfPericen	285.4029988228773
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 231"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.055927839518715e-08
	Radius		24.358553238913697

	RotationPeriod	3.7146481378608702

	Obliquity		299.72294453327413

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3644265941738736
		Eccentricity	0.04166226382785756
		Inclination		0.20548148970401728
		AscendingNode	168.19796661121146
		ArgOfPericen	315.5636715844258
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 232"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3519942257553235e-06
	Radius		85.44403981182839

	RotationPeriod	8.977401217923079

	Obliquity		303.4992570381845

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.341340199012529
		Eccentricity	0.0469804619030047
		Inclination		-3.1097467250881174
		AscendingNode	145.28339277413585
		ArgOfPericen	206.63469032839504
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 233"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3308522809379266e-08
	Radius		22.699441557071196

	RotationPeriod	6.789050491516309

	Obliquity		26.701350973899928

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.429125658831983
		Eccentricity	0.0319449263577287
		Inclination		-0.011474799693632066
		AscendingNode	110.03648969376358
		ArgOfPericen	166.04349274860826
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 234"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3465368594160094
		Eccentricity	0.07467623660980274
		Inclination		2.343616980926946
		AscendingNode	107.85704998466788
		ArgOfPericen	23.34179520808973
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 234 A"
{
	ParentBody	"Erebos 234"
	Class		"Asteroid"
	Mass		1.5978855600910675e-07
	Radius		40.1202170247789

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055378988645949055
		Eccentricity	0.006361296681790935
		Inclination		97.85512905871313
		AscendingNode	1.2024888592065963
		ArgOfPericen	239.63475784689666
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 234 B"
{
	ParentBody	"Erebos 234"
	Class		"Asteroid"
	Mass		1.255258045102321e-08
	Radius		17.182738764714973

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055378988645949055
		Eccentricity	0.006361296681790935
		Inclination		97.85512905871313
		AscendingNode	1.2024888592065963
		ArgOfPericen	59.63475784689666
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 235"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1376111623605707e-07
	Radius		55.26194760691627

	RotationPeriod	4.55809386026123

	Obliquity		324.3111882667089

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3288898334931987
		Eccentricity	0.07152629176430869
		Inclination		0.4887725573019971
		AscendingNode	116.33998046652614
		ArgOfPericen	110.3657017125993
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 235.1"
{
	ParentBody	"Erebos 235"
	Class		"Asteroid"
	Mass		4.3998716987917285e-10
	Radius		6.18547634673768

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.041669631128584e-06
		Eccentricity	0.005946277468030508
		Inclination		44.00457631080451
		AscendingNode	280.7703888394682
		ArgOfPericen	196.56104929686038
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 235.2"
{
	ParentBody	"Erebos 235"
	Class		"Asteroid"
	Mass		1.0879700590171868e-10
	Radius		3.8823867329469914

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.295054100847855e-06
		Eccentricity	0.00800391976807136
		Inclination		21.73161774476278
		AscendingNode	249.96114348206152
		ArgOfPericen	353.1639189499592
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 236"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2754936811804325
		Eccentricity	0.05083503804469043
		Inclination		-0.08533927142983806
		AscendingNode	70.49196093295146
		ArgOfPericen	103.76592528970326
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 236 A"
{
	ParentBody	"Erebos 236"
	Class		"Asteroid"
	Mass		8.451143825530727e-07
	Radius		73.36081063333263

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019299796957805164
		Eccentricity	0.007731235765353256
		Inclination		169.92092392622428
		AscendingNode	264.774607539558
		ArgOfPericen	3.4518800866574573
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 236 B"
{
	ParentBody	"Erebos 236"
	Class		"Asteroid"
	Mass		7.717295751784527e-07
	Radius		71.1727924149593

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019299796957805164
		Eccentricity	0.007731235765353256
		Inclination		169.92092392622428
		AscendingNode	264.774607539558
		ArgOfPericen	183.45188008665747
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 237"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.164072399352035e-07
	Radius		55.2609931290988

	RotationPeriod	7.910778911614873

	Obliquity		0.37872950614449064

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.32527952834168
		Eccentricity	0.05204920150960614
		Inclination		-5.0
		AscendingNode	58.95511583783949
		ArgOfPericen	31.154418515987526
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 237.1"
{
	ParentBody	"Erebos 237"
	Class		"Asteroid"
	Mass		1.1115437908304893e-09
	Radius		8.400634195958883

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5928365320482823e-06
		Eccentricity	0.0036086017421697487
		Inclination		6.725305470425596
		AscendingNode	188.50781761368
		ArgOfPericen	102.03531282265077
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 238"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3761959210851652e-07
	Radius		47.2923190077552

	RotationPeriod	6.6336200003196835

	Obliquity		49.24557268896976

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.31021799244493
		Eccentricity	0.05957088182705905
		Inclination		2.0407494035755898
		AscendingNode	319.0586354748274
		ArgOfPericen	113.98215631594327
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 239"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.30221207364204
		Eccentricity	0.05693135446951876
		Inclination		0.9954670052552366
		AscendingNode	284.89234376454783
		ArgOfPericen	237.25576595047193
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 239 A"
{
	ParentBody	"Erebos 239"
	Class		"Asteroid"
	Mass		3.0210219719890225e-07
	Radius		55.714688637451864

	Orbit
	{
		Epoch			2457395.5
		Period			0.002155177655611276
		Eccentricity	0.005802122034766604
		Inclination		101.51694272299684
		AscendingNode	240.08357506003537
		ArgOfPericen	9.501989416600104
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 239 B"
{
	ParentBody	"Erebos 239"
	Class		"Asteroid"
	Mass		1.9322459890739083e-08
	Radius		22.281232887349145

	Orbit
	{
		Epoch			2457395.5
		Period			0.002155177655611276
		Eccentricity	0.005802122034766604
		Inclination		101.51694272299684
		AscendingNode	240.08357506003537
		ArgOfPericen	189.5019894166001
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 240"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5396691753611482e-07
	Radius		45.24253036115377

	RotationPeriod	7.558956453462607

	Obliquity		203.95230664292143

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.252353949388254
		Eccentricity	0.03591615050433006
		Inclination		-0.2697066661247509
		AscendingNode	45.76680816303935
		ArgOfPericen	110.69538971191862
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 241"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0205251453965173e-08
	Radius		21.473773262655264

	RotationPeriod	6.284018378772174

	Obliquity		319.89573768754474

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2628550472536837
		Eccentricity	0.020095208645235972
		Inclination		-0.7089126846199226
		AscendingNode	216.45953976488002
		ArgOfPericen	138.3781498745665
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 242"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.37522382468703e-07
	Radius		71.06370570786609

	RotationPeriod	8.421683643350889

	Obliquity		292.42533417369

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.34762808318844
		Eccentricity	0.04592827838797241
		Inclination		-0.12723579162265747
		AscendingNode	39.17250255369645
		ArgOfPericen	116.65556550212233
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 243"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3212133431469915
		Eccentricity	0.060150141753043174
		Inclination		1.3671061253443924
		AscendingNode	67.95573101839108
		ArgOfPericen	4.413081279603661
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 243 A"
{
	ParentBody	"Erebos 243"
	Class		"Asteroid"
	Mass		2.7575655496982967e-07
	Radius		49.60737902965693

	Orbit
	{
		Epoch			2457395.5
		Period			0.0075962946093000895
		Eccentricity	0.008430518772722509
		Inclination		236.95002701893216
		AscendingNode	195.2420658788234
		ArgOfPericen	309.02827891895566
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 243 B"
{
	ParentBody	"Erebos 243"
	Class		"Asteroid"
	Mass		2.598312355002011e-08
	Radius		22.57363264454061

	Orbit
	{
		Epoch			2457395.5
		Period			0.0075962946093000895
		Eccentricity	0.008430518772722509
		Inclination		236.95002701893216
		AscendingNode	195.2420658788234
		ArgOfPericen	129.02827891895566
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 244"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.159393908763856e-07
	Radius		67.93214624173419

	RotationPeriod	2.3838370055298146

	Obliquity		200.79703845301285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.274765905278946
		Eccentricity	0.057627572600707624
		Inclination		1.6971607093620176
		AscendingNode	170.60305490782875
		ArgOfPericen	53.103417096338994
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 245"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.528755124070453e-07
	Radius		52.90917807529361

	RotationPeriod	3.556269386155182

	Obliquity		166.30041495210517

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272415109542808
		Eccentricity	0.030130176222954625
		Inclination		0.852379354673402
		AscendingNode	224.63899558060234
		ArgOfPericen	213.23984980402227
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 246"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2645636576432744
		Eccentricity	0.07685973955052505
		Inclination		-1.6601320292881874
		AscendingNode	247.3396711767049
		ArgOfPericen	315.8800457488935
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 246 A"
{
	ParentBody	"Erebos 246"
	Class		"Asteroid"
	Mass		1.5599630165812403e-07
	Radius		42.42540329902113

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018434047129261767
		Eccentricity	0.007625466652301128
		Inclination		220.33157361726973
		AscendingNode	160.02721254914064
		ArgOfPericen	340.1803812453442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 246 B"
{
	ParentBody	"Erebos 246"
	Class		"Asteroid"
	Mass		1.519859909737709e-07
	Radius		42.058689055072364

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018434047129261767
		Eccentricity	0.007625466652301128
		Inclination		220.33157361726973
		AscendingNode	160.02721254914064
		ArgOfPericen	160.18038124534428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 247"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.888214253198528e-08
	Radius		27.086381039206547

	RotationPeriod	5.062793587359426

	Obliquity		56.94859897954534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3454694163495167
		Eccentricity	0.026121503502014608
		Inclination		-0.23040290368768282
		AscendingNode	134.01634325686055
		ArgOfPericen	246.71000239768824
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 247.1"
{
	ParentBody	"Erebos 247"
	Class		"Asteroid"
	Mass		6.448788717326872e-10
	Radius		6.4002011286954374

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.21408422608239e-06
		Eccentricity	0.003365930110299852
		Inclination		33.31609875715293
		AscendingNode	266.9670125769893
		ArgOfPericen	177.1062773027993
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 248"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3504574579361712e-07
	Radius		42.07102997585649

	RotationPeriod	2.9437863003405753

	Obliquity		296.68918817417233

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2719366492829516
		Eccentricity	0.04781306587153161
		Inclination		2.1188405803978942
		AscendingNode	9.08671057159026
		ArgOfPericen	245.90755797457695
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 249"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.819331768675712e-07
	Radius		64.28754737859175

	RotationPeriod	4.686187012778621

	Obliquity		283.7038697142079

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3113526282451735
		Eccentricity	0.052032065497137694
		Inclination		2.646472049470471
		AscendingNode	88.28282420808308
		ArgOfPericen	311.30250591576606
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 250"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.390306538560018e-07
	Radius		49.950733100981175

	RotationPeriod	4.510833777559741

	Obliquity		274.8545066873419

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4279052486701356
		Eccentricity	0.06028184842028927
		Inclination		-1.2791452759958768
		AscendingNode	139.56671490244574
		ArgOfPericen	244.21468880038478
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 251"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2056712457913227e-07
	Radius		48.73739273223805

	RotationPeriod	3.15314280227796

	Obliquity		170.37080231625973

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.233068573126439
		Eccentricity	0.0610270350603708
		Inclination		-1.594280236733433
		AscendingNode	75.65399517301776
		ArgOfPericen	357.6964987096162
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 252"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2210324773660597
		Eccentricity	0.03394405010664356
		Inclination		-1.1994795826022029
		AscendingNode	147.86281823224192
		ArgOfPericen	196.42458778230431
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 252 A"
{
	ParentBody	"Erebos 252"
	Class		"Asteroid"
	Mass		4.811778440161354e-07
	Radius		62.71545978338267

	Orbit
	{
		Epoch			2457395.5
		Period			0.001734366995178615
		Eccentricity	0.005425849077295323
		Inclination		148.47544153799592
		AscendingNode	303.9096004747855
		ArgOfPericen	140.89941946969932
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 252 B"
{
	ParentBody	"Erebos 252"
	Class		"Asteroid"
	Mass		1.2260261541289638e-07
	Radius		39.75935357720742

	Orbit
	{
		Epoch			2457395.5
		Period			0.001734366995178615
		Eccentricity	0.005425849077295323
		Inclination		148.47544153799592
		AscendingNode	303.9096004747855
		ArgOfPericen	320.8994194696993
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 253"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.567378838116534e-07
	Radius		60.054889503767654

	RotationPeriod	6.834834659224735

	Obliquity		33.62814385351426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2723672554082195
		Eccentricity	0.06022380922586536
		Inclination		-0.3115574873956813
		AscendingNode	324.1090532882464
		ArgOfPericen	18.599039574583554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 254"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.273195821138091e-09
	Radius		15.017292621655812

	RotationPeriod	5.4966912266266625

	Obliquity		220.2214727600688

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.312469487361858
		Eccentricity	0.017345941895150298
		Inclination		-0.7996643398656942
		AscendingNode	229.40768540310964
		ArgOfPericen	22.727340442821063
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 254.1"
{
	ParentBody	"Erebos 254"
	Class		"Asteroid"
	Mass		1.2084676694165065e-12
	Radius		0.8673087087511766

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8833195812546257e-06
		Eccentricity	0.006323128637957578
		Inclination		51.840320801609586
		AscendingNode	195.8616361211239
		ArgOfPericen	17.57251773793549
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 254.2"
{
	ParentBody	"Erebos 254"
	Class		"Asteroid"
	Mass		1.4210509192022479e-12
	Radius		0.9154442654226843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.360489320085897e-06
		Eccentricity	0.005025123225365055
		Inclination		3.7601916519023204
		AscendingNode	300.6062746988574
		ArgOfPericen	51.129496336898285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 255"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.1655976026073333e-08
	Radius		26.000349336469746

	RotationPeriod	5.460009902420476

	Obliquity		17.54378141379445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2947399764183527
		Eccentricity	0.007833434634423528
		Inclination		1.0705507380789607
		AscendingNode	221.06724344404034
		ArgOfPericen	277.17429452444105
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 256"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4065091135946515e-08
	Radius		22.711149974211203

	RotationPeriod	6.07250931343808

	Obliquity		242.31768791433208

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.361115030748707
		Eccentricity	0.02493323912794347
		Inclination		0.5766098945743027
		AscendingNode	273.2742144027811
		ArgOfPericen	154.31222362861013
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 256.1"
{
	ParentBody	"Erebos 256"
	Class		"Asteroid"
	Mass		3.1537427697671435e-11
	Radius		2.4853375277404295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.554880849245959e-06
		Eccentricity	0.0035739396311765086
		Inclination		35.891950748344236
		AscendingNode	90.6833398061192
		ArgOfPericen	271.19959681090097
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 257"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.878643492853557e-07
	Radius		47.31661835452812

	RotationPeriod	0.7589496469743295

	Obliquity		155.38269782349826

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3170057774536637
		Eccentricity	0.03366676223326574
		Inclination		2.1117623641140804
		AscendingNode	219.08500525294738
		ArgOfPericen	135.15430344698194
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 258"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.857212669045772e-07
	Radius		72.12175377214922

	RotationPeriod	3.011203744128039

	Obliquity		224.44318944474267

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.285249523775158
		Eccentricity	0.02338298374536767
		Inclination		2.457441664812764
		AscendingNode	294.7600576525455
		ArgOfPericen	83.09661545471957
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 259"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8953128810035596e-06
	Radius		92.67981502500969

	RotationPeriod	6.013332463676558

	Obliquity		169.3309379015254

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.369208600790377
		Eccentricity	0.043067247444124254
		Inclination		2.8532703807769297
		AscendingNode	27.014231233640153
		ArgOfPericen	91.15616025385812
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 259.1"
{
	ParentBody	"Erebos 259"
	Class		"Asteroid"
	Mass		3.057386812152224e-10
	Radius		5.045160454232798

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.018634431707473e-05
		Eccentricity	0.006631084324595011
		Inclination		-11.673268679923295
		AscendingNode	298.4962783571055
		ArgOfPericen	172.3013656124226
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 259.2"
{
	ParentBody	"Erebos 259"
	Class		"Asteroid"
	Mass		2.9588946734596444e-08
	Radius		23.163349262304664

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.152991871265313e-06
		Eccentricity	0.008150197924841328
		Inclination		-26.43346841645318
		AscendingNode	170.51582042012976
		ArgOfPericen	325.0925454164953
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 259.3"
{
	ParentBody	"Erebos 259"
	Class		"Asteroid"
	Mass		6.046050993883879e-09
	Radius		13.643175179289047

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.5811591240220554e-06
		Eccentricity	0.006147807587210771
		Inclination		-0.17823602779696615
		AscendingNode	297.1946342182413
		ArgOfPericen	138.70157586657484
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 260"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.296660730136343
		Eccentricity	0.05258707264657342
		Inclination		-1.1545207717960144
		AscendingNode	69.37025062906173
		ArgOfPericen	203.1018298943528
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 260 A"
{
	ParentBody	"Erebos 260"
	Class		"Asteroid"
	Mass		1.2981476567767961e-08
	Radius		17.787819387181038

	Orbit
	{
		Epoch			2457395.5
		Period			0.005142055999567399
		Eccentricity	0.004766206793907214
		Inclination		226.99125992844998
		AscendingNode	355.49721374729415
		ArgOfPericen	295.2873907165715
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 260 B"
{
	ParentBody	"Erebos 260"
	Class		"Asteroid"
	Mass		9.120040575695253e-09
	Radius		15.812975692705377

	Orbit
	{
		Epoch			2457395.5
		Period			0.005142055999567399
		Eccentricity	0.004766206793907214
		Inclination		226.99125992844998
		AscendingNode	355.49721374729415
		ArgOfPericen	115.28739071657151
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 261"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.343623542689528e-07
	Radius		54.32995901379749

	RotationPeriod	9.38388873440363

	Obliquity		32.72067996694012

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4156959812045113
		Eccentricity	0.03647493409622774
		Inclination		0.30289782658109693
		AscendingNode	126.92072975786787
		ArgOfPericen	117.98625863247193
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 262"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.886789921529026e-07
	Radius		76.99257905056885

	RotationPeriod	7.267934890548037

	Obliquity		58.00421575517295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.27361285543065
		Eccentricity	0.046822294258292776
		Inclination		-1.4979794491264256
		AscendingNode	355.89507585901697
		ArgOfPericen	252.04025144807625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 263"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.300191589799875
		Eccentricity	0.0663604747648368
		Inclination		-0.5866630402432933
		AscendingNode	132.39572807867518
		ArgOfPericen	323.16422069265263
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 263 A"
{
	ParentBody	"Erebos 263"
	Class		"Asteroid"
	Mass		1.3829893376741543e-07
	Radius		42.89019686106906

	Orbit
	{
		Epoch			2457395.5
		Period			0.005424094663986171
		Eccentricity	0.005962784041490749
		Inclination		199.01838833030192
		AscendingNode	66.55398695230855
		ArgOfPericen	209.48179489269776
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 263 B"
{
	ParentBody	"Erebos 263"
	Class		"Asteroid"
	Mass		4.6298389804889455e-08
	Radius		29.781076442198643

	Orbit
	{
		Epoch			2457395.5
		Period			0.005424094663986171
		Eccentricity	0.005962784041490749
		Inclination		199.01838833030192
		AscendingNode	66.55398695230855
		ArgOfPericen	29.481794892697735
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 264"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7258236715676987e-07
	Radius		44.161607468020875

	RotationPeriod	4.1608647015028035

	Obliquity		217.48217546290175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.304023674373409
		Eccentricity	0.06536618095194928
		Inclination		-1.165276222050297
		AscendingNode	162.30298272580578
		ArgOfPericen	243.38703426511145
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 265"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2675515038330483
		Eccentricity	0.1
		Inclination		-1.1428669880331792
		AscendingNode	185.82473168472464
		ArgOfPericen	109.769719163967
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 265 A"
{
	ParentBody	"Erebos 265"
	Class		"Asteroid"
	Mass		2.795874148516328e-07
	Radius		49.304090887179164

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011486763308059254
		Eccentricity	0.003904412823388489
		Inclination		145.52413048803572
		AscendingNode	249.21783897035513
		ArgOfPericen	17.861017639220947
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 265 B"
{
	ParentBody	"Erebos 265"
	Class		"Asteroid"
	Mass		2.232533389695612e-07
	Radius		45.741429902794714

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011486763308059254
		Eccentricity	0.003904412823388489
		Inclination		145.52413048803572
		AscendingNode	249.21783897035513
		ArgOfPericen	197.86101763922096
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 266"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.195926020193068e-07
	Radius		60.752976769987306

	RotationPeriod	6.248302071702734

	Obliquity		171.81706440265728

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.325470056505415
		Eccentricity	0.08327920656360116
		Inclination		-0.8838020724220906
		AscendingNode	164.64226987780654
		ArgOfPericen	96.5877424341077
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 266.1"
{
	ParentBody	"Erebos 266"
	Class		"Asteroid"
	Mass		1.8786227761549136e-09
	Radius		9.324518976408221

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.824751618187775e-06
		Eccentricity	0.0031327454467648826
		Inclination		9.361518586007152
		AscendingNode	234.16113961987745
		ArgOfPericen	42.08533935826234
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 266.2"
{
	ParentBody	"Erebos 266"
	Class		"Asteroid"
	Mass		5.139432320535923e-09
	Radius		13.041222155581789

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.538350718452016e-06
		Eccentricity	0.0025000523918630594
		Inclination		-17.10234621096207
		AscendingNode	334.40713875013665
		ArgOfPericen	93.69874125225542
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 266.3"
{
	ParentBody	"Erebos 266"
	Class		"Asteroid"
	Mass		8.367148571556584e-11
	Radius		3.3052608246930193

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.895559442686389e-06
		Eccentricity	0.00439066240984512
		Inclination		-13.379590951594032
		AscendingNode	250.98929232913062
		ArgOfPericen	268.16289104369037
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 266.4"
{
	ParentBody	"Erebos 266"
	Class		"Asteroid"
	Mass		6.5974679014066675e-09
	Radius		14.173344326605207

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.670009814309083e-06
		Eccentricity	0.0020051273842235915
		Inclination		-36.188719840374176
		AscendingNode	89.28168558972428
		ArgOfPericen	91.93846720997449
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 267"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.673719777525771e-07
	Radius		46.02185373118639

	RotationPeriod	9.29239212289993

	Obliquity		278.24019506207077

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2811142059418854
		Eccentricity	0.06785575951055817
		Inclination		1.2836242348201459
		AscendingNode	31.598957072111293
		ArgOfPericen	72.8693028420958
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 268"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.3323825399898e-08
	Radius		32.092698791134225

	RotationPeriod	6.2031811817785

	Obliquity		269.3320627962934

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.300082947435279
		Eccentricity	0.06819011074776068
		Inclination		1.820738076007628
		AscendingNode	345.4573716323159
		ArgOfPericen	316.0296020879089
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 269"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.32545390331756e-08
	Radius		36.35198304347297

	RotationPeriod	7.000444427283616

	Obliquity		223.67142091189862

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3882571011766647
		Eccentricity	0.028492705024876268
		Inclination		-1.0657260407016809
		AscendingNode	354.0172256985383
		ArgOfPericen	163.62388254010423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 270"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.404613811392086e-08
	Radius		31.150578240895538

	RotationPeriod	7.680641255637637

	Obliquity		337.21199580048994

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3323477385281177
		Eccentricity	0.04446496043218047
		Inclination		-1.3911782281845908
		AscendingNode	90.49214488676925
		ArgOfPericen	70.45024991031542
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 271"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3429482303736643e-07
	Radius		38.21797126714809

	RotationPeriod	2.1574037415135403

	Obliquity		212.85090723949128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.277280745975612
		Eccentricity	0.04566263989213265
		Inclination		-2.4323362574045304
		AscendingNode	70.66709183241939
		ArgOfPericen	179.63807407298
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 272"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.138094553495567e-08
	Radius		29.457886186074905

	RotationPeriod	5.736244543587478

	Obliquity		154.44285571667444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2435588600592693
		Eccentricity	0.07778378024278045
		Inclination		1.6625326827701143
		AscendingNode	18.381489915033015
		ArgOfPericen	55.12362416910697
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 273"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.207793173920357e-07
	Radius		52.68524500821579

	RotationPeriod	4.864016738491397

	Obliquity		110.36116365758183

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2842235224318683
		Eccentricity	0.07493875696238878
		Inclination		-1.4617858377128032
		AscendingNode	86.38347261409467
		ArgOfPericen	116.57963785251191
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 274"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.61565938303813e-08
	Radius		27.5536710752358

	RotationPeriod	5.741912643695037

	Obliquity		129.67294796199977

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.300514090377251
		Eccentricity	0.03695528391866486
		Inclination		-0.9208214539080872
		AscendingNode	103.24144055698827
		ArgOfPericen	267.659750498347
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 275"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.5558546072150914e-07
	Radius		63.565167413325526

	RotationPeriod	1.0824102787361598

	Obliquity		316.5270887624053

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2826918777171885
		Eccentricity	0.03576785346011595
		Inclination		2.2218101914934922
		AscendingNode	85.59676435687496
		ArgOfPericen	358.023916890852
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 276"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0528924723701877e-07
	Radius		44.633685556301046

	RotationPeriod	9.166310626156292

	Obliquity		6.309932419684547

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2927264132325087
		Eccentricity	0.07746319955714681
		Inclination		0.4366616256120661
		AscendingNode	202.47788930015028
		ArgOfPericen	86.53355746006329
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 277"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3525601452039335e-07
	Radius		49.424215827559216

	RotationPeriod	6.108026119312102

	Obliquity		89.34299255061855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2630498178268845
		Eccentricity	0.03566933568427337
		Inclination		0.6114557641225286
		AscendingNode	80.6511914422502
		ArgOfPericen	357.1956271911431
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 278"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.73989303284484e-08
	Radius		36.20774349398896

	RotationPeriod	3.8901994274857374

	Obliquity		52.04532516702134

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2513027931683207
		Eccentricity	0.07089220031878876
		Inclination		0.3789588061137575
		AscendingNode	268.35488858079253
		ArgOfPericen	87.65401976609446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 279"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.80771805559333e-07
	Radius		51.196991610267496

	RotationPeriod	4.425138005317859

	Obliquity		177.5901383400943

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286510836881248
		Eccentricity	0.04887989673611318
		Inclination		0.011685973679657336
		AscendingNode	195.32105459666917
		ArgOfPericen	203.84670922660092
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 280"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.007575802215414e-08
	Radius		18.081336512220542

	RotationPeriod	6.315498789889903

	Obliquity		309.18380460805787

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.394420859939799
		Eccentricity	0.03939848037484412
		Inclination		-1.3489750006701409
		AscendingNode	192.18830886818012
		ArgOfPericen	121.95574554588465
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 280.1"
{
	ParentBody	"Erebos 280"
	Class		"Asteroid"
	Mass		4.61496206461783e-11
	Radius		3.0028063878988718

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.307301588167459e-07
		Eccentricity	0.004858014491966592
		Inclination		-3.756554727182863
		AscendingNode	307.74103704962323
		ArgOfPericen	251.03990302378864
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 280.2"
{
	ParentBody	"Erebos 280"
	Class		"Asteroid"
	Mass		6.958140454958936e-11
	Radius		3.443253647980012

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.99249696832874e-07
		Eccentricity	0.004502769956317269
		Inclination		-4.308931457632097
		AscendingNode	123.07096070831476
		ArgOfPericen	143.58311573787086
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 281"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5814808115609525e-07
	Radius		43.19587122285432

	RotationPeriod	3.718865436799849

	Obliquity		96.95866869458449

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.341854762681644
		Eccentricity	0.05006567571090198
		Inclination		-3.1361174700688657
		AscendingNode	244.79733670649412
		ArgOfPericen	33.30788244632447
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 282"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0362253269203543e-07
	Radius		36.88166693022525

	RotationPeriod	8.414518665164582

	Obliquity		79.02844724259798

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2942021032018243
		Eccentricity	0.0669997429885612
		Inclination		4.1756700671935665
		AscendingNode	253.91260457026294
		ArgOfPericen	238.33980489688815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 282.1"
{
	ParentBody	"Erebos 282"
	Class		"Asteroid"
	Mass		1.2457617981937932e-09
	Radius		8.448977304472132

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.0486610250322204e-06
		Eccentricity	0.005469463319783047
		Inclination		-34.40476850515277
		AscendingNode	67.13602670915466
		ArgOfPericen	168.4627446369517
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 282.2"
{
	ParentBody	"Erebos 282"
	Class		"Asteroid"
	Mass		1.1195478028860713e-10
	Radius		3.7844841254866513

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8470497781573866e-06
		Eccentricity	0.004971364598180797
		Inclination		29.769891870638553
		AscendingNode	223.0606556418288
		ArgOfPericen	355.3671188475048
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 283"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.9095336120470034e-08
	Radius		29.272335841904564

	RotationPeriod	8.970025213651748

	Obliquity		163.89438048089679

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2203667775850757
		Eccentricity	0.07778971704261735
		Inclination		-0.3345181129054313
		AscendingNode	257.1290273931079
		ArgOfPericen	18.56421631024451
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 284"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.964793245540821e-08
	Radius		29.297990365208655

	RotationPeriod	6.603032950888834

	Obliquity		51.45361976363412

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2842635713356954
		Eccentricity	0.052500648389518484
		Inclination		-1.9300809893123587
		AscendingNode	122.32917128950622
		ArgOfPericen	275.64321684723166
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 285"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.93326898980038e-08
	Radius		34.97808212828579

	RotationPeriod	6.16808630332269

	Obliquity		34.07196045894516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3637008844107816
		Eccentricity	0.013730946345033024
		Inclination		-0.5036731820072703
		AscendingNode	196.38929360951548
		ArgOfPericen	210.63380642183358
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 286"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.957628957540611e-07
	Radius		49.98662333414325

	RotationPeriod	5.7076936267192115

	Obliquity		45.34021568639853

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4214383975154012
		Eccentricity	0.0337671604274116
		Inclination		-0.7791150248452605
		AscendingNode	91.34421719679112
		ArgOfPericen	158.93631026868331
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 287"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.387843218003268
		Eccentricity	0.04070821107855728
		Inclination		-0.1905112998156315
		AscendingNode	31.885486120275644
		ArgOfPericen	84.02123271163468
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 287 A"
{
	ParentBody	"Erebos 287"
	Class		"Asteroid"
	Mass		3.45283839917362e-07
	Radius		55.44303935152804

	Orbit
	{
		Epoch			2457395.5
		Period			0.005173259748871423
		Eccentricity	0.007891189314524441
		Inclination		147.1774240967821
		AscendingNode	353.5976237166748
		ArgOfPericen	18.23697885879694
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 287 B"
{
	ParentBody	"Erebos 287"
	Class		"Asteroid"
	Mass		1.4390759703901436e-08
	Radius		19.222779584610468

	Orbit
	{
		Epoch			2457395.5
		Period			0.005173259748871423
		Eccentricity	0.007891189314524441
		Inclination		147.1774240967821
		AscendingNode	353.5976237166748
		ArgOfPericen	198.23697885879693
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 288"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.81146325852122e-07
	Radius		54.963869424813836

	RotationPeriod	0.2991203288237063

	Obliquity		195.87443002694476

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.408091109839141
		Eccentricity	0.01012558398517581
		Inclination		3.897214175974871
		AscendingNode	180.36897571193953
		ArgOfPericen	271.7325782819437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 289"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.273997193605872
		Eccentricity	0.0513711355079456
		Inclination		0.2513057808701965
		AscendingNode	9.071284468644553
		ArgOfPericen	269.1108210843315
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 289 A"
{
	ParentBody	"Erebos 289"
	Class		"Asteroid"
	Mass		1.3872934000341737e-07
	Radius		41.98820182067952

	Orbit
	{
		Epoch			2457395.5
		Period			0.007009086524773431
		Eccentricity	0.00484996542528269
		Inclination		62.60885192074288
		AscendingNode	15.321183712821128
		ArgOfPericen	81.26081051718906
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 289 B"
{
	ParentBody	"Erebos 289"
	Class		"Asteroid"
	Mass		1.627872956012007e-08
	Radius		20.556286977447332

	Orbit
	{
		Epoch			2457395.5
		Period			0.007009086524773431
		Eccentricity	0.00484996542528269
		Inclination		62.60885192074288
		AscendingNode	15.321183712821128
		ArgOfPericen	261.26081051718904
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 290"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.7446094433945085e-07
	Radius		62.59878558242728

	RotationPeriod	2.5159262225071513

	Obliquity		231.53742694448886

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.309215582232405
		Eccentricity	0.04961655254564355
		Inclination		-2.3504273895116685
		AscendingNode	6.296997146829946
		ArgOfPericen	23.69529275054616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 290.1"
{
	ParentBody	"Erebos 290"
	Class		"Asteroid"
	Mass		3.6125051101597227e-09
	Radius		12.315023408979954

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.960428565508834e-06
		Eccentricity	0.005942996057740209
		Inclination		-22.81621041597545
		AscendingNode	169.2786762277328
		ArgOfPericen	324.8273272325058
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 290.2"
{
	ParentBody	"Erebos 290"
	Class		"Asteroid"
	Mass		5.0076223786190195e-09
	Radius		13.731235285245589

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.714228286229981e-06
		Eccentricity	0.004330987290948061
		Inclination		67.65310096618045
		AscendingNode	144.60406283075022
		ArgOfPericen	242.80169695628115
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 290.3"
{
	ParentBody	"Erebos 290"
	Class		"Asteroid"
	Mass		5.005211362159399e-09
	Radius		13.72903120871228

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.125240604630429e-06
		Eccentricity	0.00488707768748008
		Inclination		30.204142932964974
		AscendingNode	105.77468323366742
		ArgOfPericen	68.44659111729507
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 290.4"
{
	ParentBody	"Erebos 290"
	Class		"Asteroid"
	Mass		1.0862456273089976e-09
	Radius		8.250401785629657

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3137805584793262e-06
		Eccentricity	0.005164293426167355
		Inclination		19.430800248612982
		AscendingNode	236.45247990314925
		ArgOfPericen	24.504744559391682
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 291"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.079173361176767e-07
	Radius		60.18983503221219

	RotationPeriod	5.117804935782105

	Obliquity		109.87658789663185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2568555181142065
		Eccentricity	0.07190301116311718
		Inclination		0.060265188884624385
		AscendingNode	125.3212285704655
		ArgOfPericen	267.8164088310893
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 292"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.346908745179562
		Eccentricity	0.013633642009739322
		Inclination		-0.7079480700096082
		AscendingNode	197.70397143192082
		ArgOfPericen	238.56965255834442
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 292 A"
{
	ParentBody	"Erebos 292"
	Class		"Asteroid"
	Mass		7.228772311682262e-08
	Radius		35.49223444105848

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026044404061528782
		Eccentricity	0.005569109546890756
		Inclination		139.71983107741707
		AscendingNode	52.43288056160544
		ArgOfPericen	350.3413782604582
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 292 B"
{
	ParentBody	"Erebos 292"
	Class		"Asteroid"
	Mass		7.004088211303654e-09
	Radius		16.301554814683303

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026044404061528782
		Eccentricity	0.005569109546890756
		Inclination		139.71983107741707
		AscendingNode	52.43288056160544
		ArgOfPericen	170.3413782604582
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 293"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.079345977712564e-08
	Radius		28.18810063407074

	RotationPeriod	8.612270998971573

	Obliquity		337.3230311833722

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4101191024426947
		Eccentricity	0.04724135422900225
		Inclination		0.6062856937102145
		AscendingNode	234.31518794853923
		ArgOfPericen	135.20390549835224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 294"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.246529397609346e-07
	Radius		76.4291736893928

	RotationPeriod	6.684502234966992

	Obliquity		256.6057484351277

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3075973188564354
		Eccentricity	0.04780677421284433
		Inclination		-0.41309630710399287
		AscendingNode	240.54743091732936
		ArgOfPericen	291.5930959985763
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 295"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1447452091177345e-07
	Radius		41.43250517418902

	RotationPeriod	4.3293398548639335

	Obliquity		17.47956814680636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1756377796726976
		Eccentricity	0.08374952765003085
		Inclination		-2.0254557867950975
		AscendingNode	92.28765348001114
		ArgOfPericen	309.16795422693457
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 296"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.713108631380084e-07
	Radius		77.18311799150794

	RotationPeriod	3.0623911585727464

	Obliquity		252.99606979211543

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2774305558476304
		Eccentricity	0.058401829183407805
		Inclination		1.85410325970907
		AscendingNode	98.09750043086868
		ArgOfPericen	231.2878413909252
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 297"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.413019059143626
		Eccentricity	0.057110343208761745
		Inclination		-1.3465726504145856
		AscendingNode	34.455402175324664
		ArgOfPericen	302.23817093290074
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 297 A"
{
	ParentBody	"Erebos 297"
	Class		"Asteroid"
	Mass		1.3575254858569336e-07
	Radius		40.09970769759494

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066130434010691855
		Eccentricity	0.004304045854149255
		Inclination		67.5554219918278
		AscendingNode	7.569883639011747
		ArgOfPericen	25.43161855951063
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 297 B"
{
	ParentBody	"Erebos 297"
	Class		"Asteroid"
	Mass		7.591527963545384e-08
	Radius		33.03707645279744

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066130434010691855
		Eccentricity	0.004304045854149255
		Inclination		67.5554219918278
		AscendingNode	7.569883639011747
		ArgOfPericen	205.43161855951064
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 298"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.279381666849029
		Eccentricity	0.04880691162125225
		Inclination		-0.519608671171297
		AscendingNode	191.41472568735716
		ArgOfPericen	345.07618925850994
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 298 A"
{
	ParentBody	"Erebos 298"
	Class		"Asteroid"
	Mass		3.9412059313696535e-07
	Radius		58.692418891927886

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026250308056263924
		Eccentricity	0.007318337837938886
		Inclination		288.22301637045643
		AscendingNode	98.45376595381208
		ArgOfPericen	76.3755764648016
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 298 B"
{
	ParentBody	"Erebos 298"
	Class		"Asteroid"
	Mass		9.397615740469062e-08
	Radius		36.39526285364597

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026250308056263924
		Eccentricity	0.007318337837938886
		Inclination		288.22301637045643
		AscendingNode	98.45376595381208
		ArgOfPericen	256.3755764648016
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 299"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.274464708592738
		Eccentricity	0.07110536592837369
		Inclination		-1.2921317086157527
		AscendingNode	206.03196647516745
		ArgOfPericen	1.5424997075655167
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 299 A"
{
	ParentBody	"Erebos 299"
	Class		"Asteroid"
	Mass		6.233382828727562e-07
	Radius		67.85015934291576

	Orbit
	{
		Epoch			2457395.5
		Period			0.005592055546444904
		Eccentricity	0.005310074861683412
		Inclination		336.9166185927065
		AscendingNode	195.0581912652496
		ArgOfPericen	338.60451845230904
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 299 B"
{
	ParentBody	"Erebos 299"
	Class		"Asteroid"
	Mass		3.474030836663394e-08
	Radius		25.917165071746453

	Orbit
	{
		Epoch			2457395.5
		Period			0.005592055546444904
		Eccentricity	0.005310074861683412
		Inclination		336.9166185927065
		AscendingNode	195.0581912652496
		ArgOfPericen	158.6045184523091
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 300"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.504941049417742e-07
	Radius		63.477553748595625

	RotationPeriod	4.964476336646563

	Obliquity		212.46955620623132

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.292719862879585
		Eccentricity	0.05730623563583838
		Inclination		-0.21541307893194228
		AscendingNode	346.9848326885922
		ArgOfPericen	63.73161952074327
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 301"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.23965395137338
		Eccentricity	0.04079953149705144
		Inclination		0.9450534912768548
		AscendingNode	19.606918942119343
		ArgOfPericen	342.39511139241057
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 301 A"
{
	ParentBody	"Erebos 301"
	Class		"Asteroid"
	Mass		1.0367631358749881e-07
	Radius		36.352175526668624

	Orbit
	{
		Epoch			2457395.5
		Period			0.005354618262871904
		Eccentricity	0.00447204386995366
		Inclination		304.20578457360295
		AscendingNode	127.15878968229677
		ArgOfPericen	177.93116098007758
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 301 B"
{
	ParentBody	"Erebos 301"
	Class		"Asteroid"
	Mass		6.874121365464414e-09
	Radius		14.713284171596998

	Orbit
	{
		Epoch			2457395.5
		Period			0.005354618262871904
		Eccentricity	0.00447204386995366
		Inclination		304.20578457360295
		AscendingNode	127.15878968229677
		ArgOfPericen	357.9311609800776
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 302"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.6472945694710353e-07
	Radius		63.78229523893969

	RotationPeriod	4.070831307900191

	Obliquity		95.86047070158813

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1848004240252674
		Eccentricity	0.05121414167875459
		Inclination		-3.3534539890911716
		AscendingNode	180.0849535997631
		ArgOfPericen	60.04048738136871
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 303"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.198534796789019e-07
	Radius		65.33969621546318

	RotationPeriod	7.269333321957142

	Obliquity		277.2278066382668

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.295719986410132
		Eccentricity	0.017966915254311246
		Inclination		-1.104798951281595
		AscendingNode	281.1815911354652
		ArgOfPericen	304.93381905957574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 304"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.811606897286086e-07
	Radius		75.12714743859961

	RotationPeriod	9.438535365707539

	Obliquity		253.92848944166943

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.301031865025546
		Eccentricity	0.035679725026613575
		Inclination		0.400313245163043
		AscendingNode	333.50725821376255
		ArgOfPericen	10.974845915736289
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 305"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.5170630961049695e-07
	Radius		55.87691647862657

	RotationPeriod	4.95119202861948

	Obliquity		189.91705519715782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.422253013181096
		Eccentricity	0.04013001286199045
		Inclination		0.962108565480143
		AscendingNode	209.6916288837616
		ArgOfPericen	162.39863106603434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 306"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.192640462751418e-07
	Radius		67.12749393456357

	RotationPeriod	2.771796001369138

	Obliquity		319.8929288728057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2705860818695203
		Eccentricity	0.07186992133051631
		Inclination		-1.2960635176660251
		AscendingNode	21.34560920655671
		ArgOfPericen	165.4492126346475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 307"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.073412989489931e-07
	Radius		72.83753062813565

	RotationPeriod	8.475916813445759

	Obliquity		170.87885978158843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.336278977655039
		Eccentricity	0.04946610955622518
		Inclination		0.17059687638569004
		AscendingNode	32.48989476820314
		ArgOfPericen	39.46524433638999
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 308"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7949836175738745e-07
	Radius		49.48266431939602

	RotationPeriod	7.461655601990639

	Obliquity		351.34818950003216

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3738382863738385
		Eccentricity	0.06253861007442144
		Inclination		1.7317530921786695
		AscendingNode	309.75311268643253
		ArgOfPericen	85.61647045302516
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 308.1"
{
	ParentBody	"Erebos 308"
	Class		"Asteroid"
	Mass		2.4838156929656347e-09
	Radius		10.249431458642984

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0381905425381576e-06
		Eccentricity	0.004113618149358466
		Inclination		-17.76503972801884
		AscendingNode	230.5641013037559
		ArgOfPericen	124.64823977563788
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 309"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.861805503673356e-07
	Radius		59.260599979568156

	RotationPeriod	7.634041652328707

	Obliquity		176.92783078336572

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.280968626829477
		Eccentricity	0.05072289454590915
		Inclination		-2.848697868356242
		AscendingNode	80.9189145638752
		ArgOfPericen	337.5643937860821
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 310"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8250560356770967e-07
	Radius		47.94124591437173

	RotationPeriod	6.1726997210977075

	Obliquity		78.24012144296154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.263293017933038
		Eccentricity	0.01909250072219781
		Inclination		0.4339818543003135
		AscendingNode	55.38523788123504
		ArgOfPericen	199.0677148614937
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 311"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.603023382351399e-07
	Radius		76.70137456531867

	RotationPeriod	5.3316142304339476

	Obliquity		286.3480050152428

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3265428978417946
		Eccentricity	0.03930259878983822
		Inclination		0.2819203344481728
		AscendingNode	169.90965377308052
		ArgOfPericen	117.66048703203505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 312"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2317840307566023e-08
	Radius		18.22829598515063

	RotationPeriod	3.0591806530803614

	Obliquity		27.127021678708005

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.323014754300621
		Eccentricity	0.0641839712156773
		Inclination		2.089849443429829
		AscendingNode	321.6132182124083
		ArgOfPericen	289.49874711136096
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 313"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.282202083110958
		Eccentricity	0.04202849840335354
		Inclination		-0.772104036384068
		AscendingNode	116.90303720119603
		ArgOfPericen	148.2141402832634
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 313 A"
{
	ParentBody	"Erebos 313"
	Class		"Asteroid"
	Mass		3.064332361235442e-08
	Radius		23.67650407315388

	Orbit
	{
		Epoch			2457395.5
		Period			0.00429995074024303
		Eccentricity	0.003922497352263157
		Inclination		104.1520190350725
		AscendingNode	259.87563581943084
		ArgOfPericen	53.84631596999844
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 313 B"
{
	ParentBody	"Erebos 313"
	Class		"Asteroid"
	Mass		2.063564020364301e-09
	Radius		9.6326312968303

	Orbit
	{
		Epoch			2457395.5
		Period			0.00429995074024303
		Eccentricity	0.003922497352263157
		Inclination		104.1520190350725
		AscendingNode	259.87563581943084
		ArgOfPericen	233.84631596999844
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 314"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2897063398850905
		Eccentricity	0.020819589564434943
		Inclination		1.1654072256932595
		AscendingNode	124.81482637123545
		ArgOfPericen	156.16398994411244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 314 A"
{
	ParentBody	"Erebos 314"
	Class		"Asteroid"
	Mass		9.799184167669813e-08
	Radius		37.52979016962178

	Orbit
	{
		Epoch			2457395.5
		Period			0.004028637770755235
		Eccentricity	0.004855822402333481
		Inclination		285.6939788382459
		AscendingNode	275.0126962548733
		ArgOfPericen	27.88712192176828
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 314 B"
{
	ParentBody	"Erebos 314"
	Class		"Asteroid"
	Mass		8.93813343581997e-09
	Radius		16.893842497434026

	Orbit
	{
		Epoch			2457395.5
		Period			0.004028637770755235
		Eccentricity	0.004855822402333481
		Inclination		285.6939788382459
		AscendingNode	275.0126962548733
		ArgOfPericen	207.88712192176828
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 315"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3342320847238818
		Eccentricity	0.04179533371897139
		Inclination		0.8698855732813895
		AscendingNode	265.8883906910164
		ArgOfPericen	85.44430241251736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 315 A"
{
	ParentBody	"Erebos 315"
	Class		"Asteroid"
	Mass		3.5060656145461614e-07
	Radius		53.697975150490834

	Orbit
	{
		Epoch			2457395.5
		Period			0.004573904151487153
		Eccentricity	0.004650989938875509
		Inclination		7.768622491984849
		AscendingNode	306.4569002529196
		ArgOfPericen	260.4306362576076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 315 B"
{
	ParentBody	"Erebos 315"
	Class		"Asteroid"
	Mass		3.872114216512686e-08
	Radius		25.763248123589733

	Orbit
	{
		Epoch			2457395.5
		Period			0.004573904151487153
		Eccentricity	0.004650989938875509
		Inclination		7.768622491984849
		AscendingNode	306.4569002529196
		ArgOfPericen	80.4306362576076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 316"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3405001398141354
		Eccentricity	0.06189854328433653
		Inclination		-4.760213322259678
		AscendingNode	59.609289218662965
		ArgOfPericen	348.9949969520594
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 316 A"
{
	ParentBody	"Erebos 316"
	Class		"Asteroid"
	Mass		1.5130273936657542e-07
	Radius		43.18506171596782

	Orbit
	{
		Epoch			2457395.5
		Period			0.004901344738880667
		Eccentricity	0.004800611863849093
		Inclination		313.87292140310115
		AscendingNode	186.59404561503223
		ArgOfPericen	102.43737836509268
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 316 B"
{
	ParentBody	"Erebos 316"
	Class		"Asteroid"
	Mass		3.599763432690828e-09
	Radius		12.420600728524207

	Orbit
	{
		Epoch			2457395.5
		Period			0.004901344738880667
		Eccentricity	0.004800611863849093
		Inclination		313.87292140310115
		AscendingNode	186.59404561503223
		ArgOfPericen	282.4373783650927
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 317"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.366942973832448e-07
	Radius		56.36461959454142

	RotationPeriod	5.63345524649782

	Obliquity		308.4818172825494

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.377349395429353
		Eccentricity	0.0121508577852045
		Inclination		0.5725990417178677
		AscendingNode	281.52457839211866
		ArgOfPericen	90.65108670719862
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 317.1"
{
	ParentBody	"Erebos 317"
	Class		"Asteroid"
	Mass		1.5980302570333778e-10
	Radius		4.0315842452597455

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.329048357885145e-06
		Eccentricity	0.0033686872369328206
		Inclination		25.117981537932092
		AscendingNode	47.34105136624669
		ArgOfPericen	30.022027838795307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 318"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1602843597095798e-07
	Radius		37.313023384057786

	RotationPeriod	3.4215126727990057

	Obliquity		86.72724505939364

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2349827322867855
		Eccentricity	0.019773750623747508
		Inclination		-1.2488856253675373
		AscendingNode	242.3908964971497
		ArgOfPericen	264.1064293526648
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 318.1"
{
	ParentBody	"Erebos 318"
	Class		"Asteroid"
	Mass		3.0195601572878504e-10
	Radius		5.132396376416139

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.221830158732986e-07
		Eccentricity	0.0031206236682067272
		Inclination		-27.106684518897033
		AscendingNode	92.73169337246695
		ArgOfPericen	328.5029451603694
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 319"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3800028005587928
		Eccentricity	0.03185854101380066
		Inclination		-3.0219769566765415
		AscendingNode	273.2028502754236
		ArgOfPericen	231.81210858125934
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 319 A"
{
	ParentBody	"Erebos 319"
	Class		"Asteroid"
	Mass		3.9369776928581186e-08
	Radius		27.159557337729208

	Orbit
	{
		Epoch			2457395.5
		Period			0.004559770504429898
		Eccentricity	0.005934491278083216
		Inclination		96.78451906568691
		AscendingNode	242.2383276132864
		ArgOfPericen	83.50404093808964
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 319 B"
{
	ParentBody	"Erebos 319"
	Class		"Asteroid"
	Mass		2.2140802569514453e-08
	Radius		22.418135460344065

	Orbit
	{
		Epoch			2457395.5
		Period			0.004559770504429898
		Eccentricity	0.005934491278083216
		Inclination		96.78451906568691
		AscendingNode	242.2383276132864
		ArgOfPericen	263.50404093808964
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 320"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.1901771153926163e-07
	Radius		59.61145783686962

	RotationPeriod	1.590665809125431

	Obliquity		66.47144675905217

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3992691191208686
		Eccentricity	0.05939389031683422
		Inclination		1.462415373382558
		AscendingNode	115.06473464351974
		ArgOfPericen	113.53778879979708
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 321"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.296494260344556e-07
	Radius		37.7831782994998

	RotationPeriod	6.43296818161663

	Obliquity		27.497684804764297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310013494384201
		Eccentricity	0.02320902646216265
		Inclination		-2.42845465157536
		AscendingNode	263.3100385736369
		ArgOfPericen	160.70824540314524
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 322"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7111232888376412e-08
	Radius		20.15624185659771

	RotationPeriod	6.885572083678458

	Obliquity		174.41757184800207

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.307887962890434
		Eccentricity	0.06318153055570776
		Inclination		2.576555180559649
		AscendingNode	168.08723248159723
		ArgOfPericen	316.9170028879583
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 322.1"
{
	ParentBody	"Erebos 322"
	Class		"Asteroid"
	Mass		1.3902384702756806e-11
	Radius		1.880812752556331

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.182710616474391e-06
		Eccentricity	0.005880832559168447
		Inclination		24.69006420592455
		AscendingNode	171.19939976478534
		ArgOfPericen	175.374654193869
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 323"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2375588537070445
		Eccentricity	0.04053406572348496
		Inclination		0.3360849547187151
		AscendingNode	127.08728927790315
		ArgOfPericen	52.60532943289762
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 323 A"
{
	ParentBody	"Erebos 323"
	Class		"Asteroid"
	Mass		6.846106347169974e-07
	Radius		68.07999681744533

	Orbit
	{
		Epoch			2457395.5
		Period			0.004836608815378566
		Eccentricity	0.0042264018459937
		Inclination		81.2406195796553
		AscendingNode	73.34172850415325
		ArgOfPericen	52.13069177836526
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 323 B"
{
	ParentBody	"Erebos 323"
	Class		"Asteroid"
	Mass		8.698935907421793e-08
	Radius		34.226331840811135

	Orbit
	{
		Epoch			2457395.5
		Period			0.004836608815378566
		Eccentricity	0.0042264018459937
		Inclination		81.2406195796553
		AscendingNode	73.34172850415325
		ArgOfPericen	232.13069177836525
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 324"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3489042412654785e-07
	Radius		41.66590234188662

	RotationPeriod	5.486378185459571

	Obliquity		302.28951894662316

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.413563318617878
		Eccentricity	0.057979478195056125
		Inclination		2.9348960234872954
		AscendingNode	83.23594504866178
		ArgOfPericen	167.7198279785752
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 324.1"
{
	ParentBody	"Erebos 324"
	Class		"Asteroid"
	Mass		4.934085530308297e-10
	Radius		6.419816914988285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.528260124344309e-06
		Eccentricity	0.005786599647433947
		Inclination		-11.793436209535479
		AscendingNode	308.10181551261934
		ArgOfPericen	288.83777682305487
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 325"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.871996695532656e-08
	Radius		35.17466643635483

	RotationPeriod	4.9906998642620355

	Obliquity		342.47974201658525

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1857362224932775
		Eccentricity	0.06208081315869519
		Inclination		1.2779246369014068
		AscendingNode	55.318896595008326
		ArgOfPericen	349.3999557475418
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 326"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3106050556353307e-07
	Radius		40.329434353427985

	RotationPeriod	6.1460524895415825

	Obliquity		143.1160130980099

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3561284190527028
		Eccentricity	0.026470008782645063
		Inclination		3.8578666314456775
		AscendingNode	246.50666328232631
		ArgOfPericen	9.01777733817147
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 326.1"
{
	ParentBody	"Erebos 326"
	Class		"Asteroid"
	Mass		1.211243478007964e-09
	Radius		8.463344159203167

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.620276114642035e-06
		Eccentricity	0.004931324139406737
		Inclination		-66.6774172079979
		AscendingNode	201.16516061049603
		ArgOfPericen	237.0013118733329
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 326.2"
{
	ParentBody	"Erebos 326"
	Class		"Asteroid"
	Mass		3.306343414049065e-10
	Radius		5.490107365943425

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.941055714331355e-06
		Eccentricity	0.0046092955219051825
		Inclination		33.95100745692087
		AscendingNode	280.7327051437777
		ArgOfPericen	22.328585818482594
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 326.3"
{
	ParentBody	"Erebos 326"
	Class		"Asteroid"
	Mass		1.4177841884862197e-09
	Radius		8.919384664175777

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.4058518336362803e-06
		Eccentricity	0.0049792126521122065
		Inclination		-40.19262429138635
		AscendingNode	178.90403894174094
		ArgOfPericen	353.8091544527519
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 327"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.026227656433334e-08
	Radius		24.062665204705866

	RotationPeriod	8.2432733880604

	Obliquity		60.0168830155367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3341674391223637
		Eccentricity	0.03489939268692534
		Inclination		1.712492486917203
		AscendingNode	131.57764370244354
		ArgOfPericen	2.9712720991703545
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 328"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.842934460654205e-07
	Radius		63.04734731282455

	RotationPeriod	5.228779133758396

	Obliquity		313.9605511508303

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2836429861524783
		Eccentricity	0.06583049117890397
		Inclination		-2.5226060512170823
		AscendingNode	197.91228685414694
		ArgOfPericen	170.4172611445637
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 329"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7967203507153504e-07
	Radius		52.049558346677856

	RotationPeriod	9.131679645903477

	Obliquity		265.0155920648539

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.316219228880049
		Eccentricity	0.04198963785828221
		Inclination		1.8810110005451968
		AscendingNode	75.60637211110104
		ArgOfPericen	143.11877347753767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 330"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.476200128913e-07
	Radius		40.82900225440538

	RotationPeriod	7.832659587143768

	Obliquity		97.16365601982167

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1928092241180326
		Eccentricity	0.046080429917414956
		Inclination		-1.9439874277780487
		AscendingNode	223.87343372860636
		ArgOfPericen	108.1446455420674
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 330.1"
{
	ParentBody	"Erebos 330"
	Class		"Asteroid"
	Mass		5.085215829226474e-10
	Radius		6.16628344765472

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.911144944001186e-07
		Eccentricity	0.004852591588186144
		Inclination		24.547235958886834
		AscendingNode	89.85701530937035
		ArgOfPericen	10.072817132311052
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 330.2"
{
	ParentBody	"Erebos 330"
	Class		"Asteroid"
	Mass		8.008301483227906e-11
	Radius		3.329920197263843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.352927949521143e-07
		Eccentricity	0.0019148462692770776
		Inclination		-7.25134706584871
		AscendingNode	33.04287995419059
		ArgOfPericen	355.91186601526283
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 331"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.52362742610362e-08
	Radius		22.09552692049468

	RotationPeriod	4.002015432982585

	Obliquity		11.262265756575584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3363076908163656
		Eccentricity	0.03866721147412577
		Inclination		3.0126255455304665
		AscendingNode	155.63433196553765
		ArgOfPericen	351.7091203055477
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 332"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2253590954359257e-07
	Radius		38.81430573325541

	RotationPeriod	9.269614369121935

	Obliquity		236.74884694441482

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2057189436289772
		Eccentricity	0.054575152545997895
		Inclination		-1.1878186190992328
		AscendingNode	350.59621943254325
		ArgOfPericen	270.5457595608924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 333"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.961353161036658e-07
	Radius		65.12375650773079

	RotationPeriod	5.364735437672222

	Obliquity		339.1521593244624

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3283887752911476
		Eccentricity	0.03596028035711303
		Inclination		-0.5893781333936363
		AscendingNode	97.90307515269696
		ArgOfPericen	237.001532214162
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 334"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8532933727176309e-06
	Radius		90.7177322663373

	RotationPeriod	5.889500126954469

	Obliquity		183.01400169968886

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3308960898698428
		Eccentricity	0.06955184571445494
		Inclination		-0.9237153766669489
		AscendingNode	168.86697711479835
		ArgOfPericen	245.09289401448626
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 334.1"
{
	ParentBody	"Erebos 334"
	Class		"Asteroid"
	Mass		1.5713741038050677e-08
	Radius		18.498534547345525

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.76694410040307e-06
		Eccentricity	0.0030686182201366432
		Inclination		-35.346075667472135
		AscendingNode	342.0583070292362
		ArgOfPericen	165.50793091408232
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 334.2"
{
	ParentBody	"Erebos 334"
	Class		"Asteroid"
	Mass		4.531024645749041e-09
	Radius		12.22108043730729

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.78108209114042e-06
		Eccentricity	0.004970115085773402
		Inclination		55.89034969786099
		AscendingNode	197.40648076392543
		ArgOfPericen	342.3444713767051
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 335"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.243050493058963e-07
	Radius		51.01438092464278

	RotationPeriod	6.20896835530766

	Obliquity		327.0427488812939

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.415021470493489
		Eccentricity	0.03025624646517854
		Inclination		2.2303004261442254
		AscendingNode	358.69048831001686
		ArgOfPericen	261.4998089616343
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 336"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.537865884403231e-08
	Radius		33.31638207268993

	RotationPeriod	5.001671955392448

	Obliquity		246.34234778534136

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2739983103592594
		Eccentricity	0.05505335781102721
		Inclination		-0.6099420355182923
		AscendingNode	308.41407906774606
		ArgOfPericen	40.578090552536395
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 337"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2969466930315215e-07
	Radius		45.61332492924407

	RotationPeriod	5.0579474590322935

	Obliquity		8.504976024214645

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2583124782745516
		Eccentricity	0.029531162717023104
		Inclination		1.1911259105458343
		AscendingNode	2.3963474418087527
		ArgOfPericen	322.14016481010424
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 337.1"
{
	ParentBody	"Erebos 337"
	Class		"Asteroid"
	Mass		3.4612410361732805e-09
	Radius		11.266405371824524

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6837917636694963e-06
		Eccentricity	0.006875932207409097
		Inclination		32.557044373544784
		AscendingNode	64.95941059665513
		ArgOfPericen	84.52669961890408
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 338"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.084830055590383e-07
	Radius		67.16162629550436

	RotationPeriod	6.166833282176557

	Obliquity		175.61722287058038

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.299292098037829
		Eccentricity	0.042848147863874274
		Inclination		1.2139963618687892
		AscendingNode	151.28209665639872
		ArgOfPericen	345.42529735468753
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 339"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3256943669690147
		Eccentricity	0.059925370380527546
		Inclination		-0.8105856112164949
		AscendingNode	164.06833056157518
		ArgOfPericen	19.17682037432032
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 339 A"
{
	ParentBody	"Erebos 339"
	Class		"Asteroid"
	Mass		4.271888062477926e-07
	Radius		56.621252036167334

	Orbit
	{
		Epoch			2457395.5
		Period			0.00212471234884551
		Eccentricity	0.007038949187550811
		Inclination		262.12847011395485
		AscendingNode	144.63449114476555
		ArgOfPericen	282.0483984633831
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 339 B"
{
	ParentBody	"Erebos 339"
	Class		"Asteroid"
	Mass		2.420182302552171e-07
	Radius		46.85136056589291

	Orbit
	{
		Epoch			2457395.5
		Period			0.00212471234884551
		Eccentricity	0.007038949187550811
		Inclination		262.12847011395485
		AscendingNode	144.63449114476555
		ArgOfPericen	102.04839846338308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 340"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3310346648487146
		Eccentricity	0.08225510067144066
		Inclination		-0.02422224643642925
		AscendingNode	290.51181197129813
		ArgOfPericen	233.50134900329175
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 340 A"
{
	ParentBody	"Erebos 340"
	Class		"Asteroid"
	Mass		5.552531008036773e-07
	Radius		61.47739528835257

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019401337864764685
		Eccentricity	0.00476431707970923
		Inclination		289.1737797794256
		AscendingNode	109.77193289171586
		ArgOfPericen	22.674611681635604
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 340 B"
{
	ParentBody	"Erebos 340"
	Class		"Asteroid"
	Mass		4.709179072380088e-07
	Radius		58.19247960266104

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019401337864764685
		Eccentricity	0.00476431707970923
		Inclination		289.1737797794256
		AscendingNode	109.77193289171586
		ArgOfPericen	202.6746116816356
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 341"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.276749687497331
		Eccentricity	0.05303622701788387
		Inclination		1.6877424029162489
		AscendingNode	45.26178507497606
		ArgOfPericen	75.79831935916528
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 341 A"
{
	ParentBody	"Erebos 341"
	Class		"Asteroid"
	Mass		7.062101871759381e-08
	Radius		31.23295257018956

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021225810724592596
		Eccentricity	0.005102360400639301
		Inclination		62.99933146091089
		AscendingNode	287.4061417728927
		ArgOfPericen	335.8501400062308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 341 B"
{
	ParentBody	"Erebos 341"
	Class		"Asteroid"
	Mass		3.029199974234729e-08
	Radius		23.554706500962872

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021225810724592596
		Eccentricity	0.005102360400639301
		Inclination		62.99933146091089
		AscendingNode	287.4061417728927
		ArgOfPericen	155.85014000623073
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 342"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.017506216764649e-07
	Radius		56.852359436524885

	RotationPeriod	10.050260808159141

	Obliquity		236.35338932360847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.187329231202817
		Eccentricity	0.03703770480450146
		Inclination		2.629190474574718
		AscendingNode	134.70227735025895
		ArgOfPericen	26.05847774497059
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 343"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.826209515584542e-07
	Radius		56.62718080090979

	RotationPeriod	4.871676477252453

	Obliquity		302.1722914152959

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2829934738071436
		Eccentricity	0.03972546487299706
		Inclination		0.7423456136016824
		AscendingNode	8.17895530828034
		ArgOfPericen	181.38681841311814
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 344"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2450769246864998e-07
	Radius		41.50683870565834

	RotationPeriod	6.6167549186726635

	Obliquity		103.89039540772391

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2629194894688127
		Eccentricity	0.03350701090663729
		Inclination		0.9929053270831671
		AscendingNode	110.20039230829285
		ArgOfPericen	327.9972487378623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 345"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.361711753672084e-07
	Radius		41.86301328335602

	RotationPeriod	2.0040940917326227

	Obliquity		294.53115788719975

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.262662618368758
		Eccentricity	0.05290491025249885
		Inclination		1.473872369348835
		AscendingNode	314.07606805467776
		ArgOfPericen	277.2121386989011
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 346"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.359249085691336e-08
	Radius		30.18955242303525

	RotationPeriod	6.548389547693792

	Obliquity		224.80273262285587

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.312524447849977
		Eccentricity	0.04462500948923932
		Inclination		0.3601164076125751
		AscendingNode	44.99511135177337
		ArgOfPericen	140.5560502911102
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 347"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.172233006134344e-08
	Radius		27.000049141160062

	RotationPeriod	4.181893307674013

	Obliquity		334.2785629812757

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3088158002550365
		Eccentricity	0.055015939877703694
		Inclination		-1.6761051097681472
		AscendingNode	275.045566632037
		ArgOfPericen	260.37664078838947
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 347.1"
{
	ParentBody	"Erebos 347"
	Class		"Asteroid"
	Mass		6.384827377117558e-12
	Radius		1.4441914065163357

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.135803616964319e-06
		Eccentricity	0.005174258902021942
		Inclination		0.488073169549105
		AscendingNode	234.7508327578762
		ArgOfPericen	123.64674567351241
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 348"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.041182478067719e-07
	Radius		57.688029771953936

	RotationPeriod	2.9992893948330708

	Obliquity		130.94522010517773

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2864523662263427
		Eccentricity	0.07415096394510376
		Inclination		1.4162740863008292
		AscendingNode	49.78459742188497
		ArgOfPericen	17.588620081253538
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 348.1"
{
	ParentBody	"Erebos 348"
	Class		"Asteroid"
	Mass		2.171756958283247e-09
	Radius		10.104619402202577

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2227012445187335e-06
		Eccentricity	0.004106184056251585
		Inclination		-13.755947417547329
		AscendingNode	144.6955783245066
		ArgOfPericen	63.06866776582913
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 349"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.258234864764439e-07
	Radius		38.49008803572847

	RotationPeriod	9.92816360349828

	Obliquity		103.99950242302018

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.328328663694293
		Eccentricity	0.06379642333446155
		Inclination		-0.6724323220620101
		AscendingNode	207.3867493730461
		ArgOfPericen	346.6116262795623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 350"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.950740739996335e-06
	Radius		90.88440822016611

	RotationPeriod	8.011002639185907

	Obliquity		323.01507209256124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2961254280344336
		Eccentricity	0.07094588791122645
		Inclination		1.4546417104928018
		AscendingNode	194.01045294243482
		ArgOfPericen	197.3392059778425
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 350.1"
{
	ParentBody	"Erebos 350"
	Class		"Asteroid"
	Mass		1.738292066792288e-08
	Radius		18.842149634996673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.2426700673072245e-06
		Eccentricity	0.004545692838089024
		Inclination		0.012622949971523594
		AscendingNode	323.9278098132543
		ArgOfPericen	216.33981722558326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 350.2"
{
	ParentBody	"Erebos 350"
	Class		"Asteroid"
	Mass		1.2656234974269061e-08
	Radius		16.950832879829363

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.6436301987227776e-06
		Eccentricity	0.0033647434454074096
		Inclination		-18.84503753141575
		AscendingNode	201.30057849771381
		ArgOfPericen	280.1702047908953
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 351"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3514205323205477
		Eccentricity	0.04778356971471556
		Inclination		-1.1563212898144613
		AscendingNode	33.30220897713066
		ArgOfPericen	276.24958950754825
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 351 A"
{
	ParentBody	"Erebos 351"
	Class		"Asteroid"
	Mass		5.7440304064122394e-08
	Radius		29.978596933700047

	Orbit
	{
		Epoch			2457395.5
		Period			0.005275135887893192
		Eccentricity	0.004388459030310789
		Inclination		340.28330646787293
		AscendingNode	20.84502900482625
		ArgOfPericen	35.158276285285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 351 B"
{
	ParentBody	"Erebos 351"
	Class		"Asteroid"
	Mass		1.1359530236283139e-08
	Radius		17.465962239770338

	Orbit
	{
		Epoch			2457395.5
		Period			0.005275135887893192
		Eccentricity	0.004388459030310789
		Inclination		340.28330646787293
		AscendingNode	20.84502900482625
		ArgOfPericen	215.158276285285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 352"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0442088280366517e-07
	Radius		37.867385172241825

	RotationPeriod	8.552079553322777

	Obliquity		194.35813942658913

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2056394543858446
		Eccentricity	0.04356334117875828
		Inclination		-2.195668449459708
		AscendingNode	92.8011271066096
		ArgOfPericen	142.18386988754625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 353"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.403743760901448e-07
	Radius		52.33907765464513

	RotationPeriod	9.9878794917901

	Obliquity		283.53548449028233

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2702991982541816
		Eccentricity	0.05077117842466671
		Inclination		0.838641154716635
		AscendingNode	278.7681891875663
		ArgOfPericen	145.92791280153412
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 354"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.2822891820925043e-08
	Radius		27.2584820296166

	RotationPeriod	3.1581829723658443

	Obliquity		0.3988202801652019

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.316055621864893
		Eccentricity	0.05052901232230199
		Inclination		-0.7628626206373806
		AscendingNode	229.926251074105
		ArgOfPericen	68.2460124366725
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 355"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7352336366605878e-07
	Radius		41.86875560809599

	RotationPeriod	8.480953335171844

	Obliquity		162.7112144017438

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3268642548052143
		Eccentricity	0.06554885146220692
		Inclination		2.864437518037271
		AscendingNode	246.93570861989
		ArgOfPericen	81.48486365891311
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 356"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.236871278233882e-07
	Radius		37.43268723588773

	RotationPeriod	5.279772405817003

	Obliquity		12.931054409424426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.269799750926653
		Eccentricity	0.048006770394806234
		Inclination		0.07477738897558668
		AscendingNode	12.48631815150041
		ArgOfPericen	34.22508534930478
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 357"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.577394416641844e-08
	Radius		28.839901076658755

	RotationPeriod	9.309174399468187

	Obliquity		99.60102884363319

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.246705199469914
		Eccentricity	0.0581464046466499
		Inclination		1.5077209033053207
		AscendingNode	105.89493925832036
		ArgOfPericen	209.30327020907217
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 358"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.616910373794323e-07
	Radius		61.77681776302234

	RotationPeriod	4.728955318303598

	Obliquity		45.682175286212136

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.353980765184455
		Eccentricity	0.08557665092004149
		Inclination		-1.9066164194722965
		AscendingNode	319.33170969595665
		ArgOfPericen	70.72840096400492
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 359"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2771150960595654
		Eccentricity	0.04185850134855627
		Inclination		-1.5608190917449525
		AscendingNode	255.1361663626828
		ArgOfPericen	150.556850058331
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 359 A"
{
	ParentBody	"Erebos 359"
	Class		"Asteroid"
	Mass		2.5640719878534365e-07
	Radius		49.14392953856134

	Orbit
	{
		Epoch			2457395.5
		Period			0.002795394776102452
		Eccentricity	0.004887415188201917
		Inclination		202.83406400488695
		AscendingNode	27.676784847988536
		ArgOfPericen	120.36503188046531
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 359 B"
{
	ParentBody	"Erebos 359"
	Class		"Asteroid"
	Mass		4.4578590156477737e-08
	Radius		27.428491179416326

	Orbit
	{
		Epoch			2457395.5
		Period			0.002795394776102452
		Eccentricity	0.004887415188201917
		Inclination		202.83406400488695
		AscendingNode	27.676784847988536
		ArgOfPericen	300.3650318804653
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 360"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.362743937658138e-08
	Radius		29.213819390404215

	RotationPeriod	10.39955202188241

	Obliquity		341.25689631533

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.369364835166502
		Eccentricity	0.03852749070053908
		Inclination		-0.9781223165874768
		AscendingNode	98.59034527864759
		ArgOfPericen	87.56435187208997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 360.1"
{
	ParentBody	"Erebos 360"
	Class		"Asteroid"
	Mass		2.7809459127216404e-11
	Radius		2.347056263111198

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.5213877993304818e-06
		Eccentricity	0.003398732059011837
		Inclination		0.6202545023703228
		AscendingNode	1.8770213737033536
		ArgOfPericen	190.2696984741549
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 361"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.386340335757771e-07
	Radius		61.75990365452987

	RotationPeriod	5.899553914545003

	Obliquity		242.1857694329443

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.341010588109401
		Eccentricity	0.07839574841237743
		Inclination		1.8058099259278582
		AscendingNode	2.3289789073971656
		ArgOfPericen	291.03495723346606
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 362"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2634872697698794
		Eccentricity	0.04704076202800633
		Inclination		0.554082880455598
		AscendingNode	132.91533153433434
		ArgOfPericen	163.64071163547612
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 362 A"
{
	ParentBody	"Erebos 362"
	Class		"Asteroid"
	Mass		9.683869749516263e-08
	Radius		36.89665672277931

	Orbit
	{
		Epoch			2457395.5
		Period			0.005308140264808565
		Eccentricity	0.008482343545652525
		Inclination		275.86280700903154
		AscendingNode	299.98992969011056
		ArgOfPericen	260.9922324174553
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 362 B"
{
	ParentBody	"Erebos 362"
	Class		"Asteroid"
	Mass		3.6250198090710085e-09
	Radius		12.342623948823306

	Orbit
	{
		Epoch			2457395.5
		Period			0.005308140264808565
		Eccentricity	0.008482343545652525
		Inclination		275.86280700903154
		AscendingNode	299.98992969011056
		ArgOfPericen	80.99223241745528
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 363"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7682888896053932e-07
	Radius		44.574982879475385

	RotationPeriod	5.189003459935532

	Obliquity		244.10567547289847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3473992778477153
		Eccentricity	0.050411117529222706
		Inclination		-0.2729892998491571
		AscendingNode	310.999113028815
		ArgOfPericen	249.9188396814378
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 364"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.284226912304522e-07
	Radius		59.97466517914101

	RotationPeriod	4.437043100363378

	Obliquity		83.1081047164289

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3693054740758765
		Eccentricity	0.031682812800192785
		Inclination		0.8023199095056964
		AscendingNode	123.06820024260175
		ArgOfPericen	69.33015513428765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 365"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.55934653726377e-07
	Radius		78.82988638321672

	RotationPeriod	5.814821190822103

	Obliquity		232.3882276174697

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.353798380728679
		Eccentricity	0.040978824748328646
		Inclination		-2.0482150293233334
		AscendingNode	106.1346473312826
		ArgOfPericen	175.76961364397198
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 366"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.384273475588344e-07
	Radius		52.66461896795337

	RotationPeriod	8.751616333250267

	Obliquity		222.37988884076512

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.249325222334182
		Eccentricity	0.07805204985151425
		Inclination		-2.8139794655533557
		AscendingNode	289.1257953138533
		ArgOfPericen	205.83090512096825
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 367"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.268282907354401
		Eccentricity	0.045172766445646
		Inclination		1.2550041251738386
		AscendingNode	259.4034452476178
		ArgOfPericen	210.9346408734279
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 367 A"
{
	ParentBody	"Erebos 367"
	Class		"Asteroid"
	Mass		8.046817116859054e-08
	Radius		33.78331412384219

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009484935262166757
		Eccentricity	0.0043076171011200756
		Inclination		358.0679774137013
		AscendingNode	288.41691566014083
		ArgOfPericen	127.90965920500933
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 367 B"
{
	ParentBody	"Erebos 367"
	Class		"Asteroid"
	Mass		6.9101908360665785e-09
	Radius		14.904733715710083

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009484935262166757
		Eccentricity	0.0043076171011200756
		Inclination		358.0679774137013
		AscendingNode	288.41691566014083
		ArgOfPericen	307.90965920500935
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 368"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9773909753720134e-07
	Radius		51.723074155914475

	RotationPeriod	6.989306040732523

	Obliquity		126.79766296260631

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3081843238264907
		Eccentricity	0.05396236625508392
		Inclination		0.7742101382007213
		AscendingNode	74.60084841383613
		ArgOfPericen	206.94421393335972
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 369"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.8158897483146057e-07
	Radius		56.53760749476626

	RotationPeriod	4.740353860806124

	Obliquity		56.96828581608387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3295262888486885
		Eccentricity	0.05656385577151631
		Inclination		-0.23385086942870723
		AscendingNode	289.4488748370941
		ArgOfPericen	189.64634275963041
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 370"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.6542769258415926e-08
	Radius		25.67947403977862

	RotationPeriod	5.813908748818038

	Obliquity		304.2656970460622

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.332647470200924
		Eccentricity	0.06873696007314915
		Inclination		-2.9484305584005552
		AscendingNode	50.8183561427217
		ArgOfPericen	44.73768956610749
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 371"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.162891805307783e-08
	Radius		31.227593355166896

	RotationPeriod	2.7071992409593957

	Obliquity		4.701397328005519

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.259447992511013
		Eccentricity	0.05179316306997701
		Inclination		-1.063845277325932
		AscendingNode	228.60642539649731
		ArgOfPericen	259.2341809563097
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 372"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.350186501134579e-07
	Radius		53.441167178529966

	RotationPeriod	8.663246577407568

	Obliquity		35.06415518468256

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3137667126816845
		Eccentricity	0.07494130228852486
		Inclination		1.1842395773091094
		AscendingNode	78.02215352647217
		ArgOfPericen	34.85640296471233
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 372.1"
{
	ParentBody	"Erebos 372"
	Class		"Asteroid"
	Mass		4.996468033964604e-09
	Radius		13.154488866255551

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.771612356495622e-06
		Eccentricity	0.005168309952476915
		Inclination		-78.74212194967599
		AscendingNode	116.76154260842608
		ArgOfPericen	222.61388562613445
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 373"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.411053219967974
		Eccentricity	0.04151997014100928
		Inclination		2.918243433290344
		AscendingNode	301.7973129839158
		ArgOfPericen	206.00395740023765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 373 A"
{
	ParentBody	"Erebos 373"
	Class		"Asteroid"
	Mass		2.1563395377239288e-07
	Radius		44.76871218014776

	Orbit
	{
		Epoch			2457395.5
		Period			0.00034252403026204165
		Eccentricity	0.005868654720739835
		Inclination		219.45975167287529
		AscendingNode	274.6130570027363
		ArgOfPericen	212.34091546094112
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 373 B"
{
	ParentBody	"Erebos 373"
	Class		"Asteroid"
	Mass		2.0959141822179502e-07
	Radius		44.34657172778707

	Orbit
	{
		Epoch			2457395.5
		Period			0.00034252403026204165
		Eccentricity	0.005868654720739835
		Inclination		219.45975167287529
		AscendingNode	274.6130570027363
		ArgOfPericen	32.34091546094112
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 374"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.670206612822789e-07
	Radius		62.13677784045157

	RotationPeriod	7.271650736510284

	Obliquity		344.76494795166826

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.367965223392393
		Eccentricity	0.0854959428944172
		Inclination		0.3565594932444241
		AscendingNode	16.94709644654634
		ArgOfPericen	63.057108656632124
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 375"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3094612125767275
		Eccentricity	0.05397838063864415
		Inclination		1.9714681479328926
		AscendingNode	357.4908949619862
		ArgOfPericen	86.34368947850994
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 375 A"
{
	ParentBody	"Erebos 375"
	Class		"Asteroid"
	Mass		5.184761920196617e-07
	Radius		60.490472285293116

	Orbit
	{
		Epoch			2457395.5
		Period			0.005414485180346671
		Eccentricity	0.006096456509793508
		Inclination		22.630248160596366
		AscendingNode	145.93647855925153
		ArgOfPericen	117.17044873841976
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 375 B"
{
	ParentBody	"Erebos 375"
	Class		"Asteroid"
	Mass		2.805505398120112e-08
	Radius		22.879563708826296

	Orbit
	{
		Epoch			2457395.5
		Period			0.005414485180346671
		Eccentricity	0.006096456509793508
		Inclination		22.630248160596366
		AscendingNode	145.93647855925153
		ArgOfPericen	297.17044873841974
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 376"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.012612340808237e-07
	Radius		53.32064579926888

	RotationPeriod	5.258359780620362

	Obliquity		231.85263878346194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.331288222771962
		Eccentricity	0.07548965485469064
		Inclination		0.289589324310858
		AscendingNode	337.1694812875448
		ArgOfPericen	312.25930753554917
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 377"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.693532043591728e-08
	Radius		34.565192956677635

	RotationPeriod	9.25524546896171

	Obliquity		122.23367422030384

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2548188845470385
		Eccentricity	0.05289665789975457
		Inclination		1.8682497399709752
		AscendingNode	39.051231365993516
		ArgOfPericen	10.357726247395247
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 378"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2610585440319017e-07
	Radius		49.742190765311754

	RotationPeriod	3.0492655195373493

	Obliquity		33.4880579815825

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.294419640223101
		Eccentricity	0.039105342159398135
		Inclination		-2.223922984670665
		AscendingNode	110.05184669595309
		ArgOfPericen	88.52561228900191
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 379"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2591808728136145
		Eccentricity	0.05229995533452555
		Inclination		0.4270781641320413
		AscendingNode	159.24331026298748
		ArgOfPericen	159.64152476989045
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 379 A"
{
	ParentBody	"Erebos 379"
	Class		"Asteroid"
	Mass		5.849203518721135e-07
	Radius		65.11668981219353

	Orbit
	{
		Epoch			2457395.5
		Period			0.006898007548255652
		Eccentricity	0.005808468547964497
		Inclination		201.63303805398832
		AscendingNode	171.43700149266044
		ArgOfPericen	227.021197988033
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 379 B"
{
	ParentBody	"Erebos 379"
	Class		"Asteroid"
	Mass		7.695388153742188e-08
	Radius		33.11846868049604

	Orbit
	{
		Epoch			2457395.5
		Period			0.006898007548255652
		Eccentricity	0.005808468547964497
		Inclination		201.63303805398832
		AscendingNode	171.43700149266044
		ArgOfPericen	47.02119798803301
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 380"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.235815151822467e-06
	Radius		81.83412735298724

	RotationPeriod	7.4282235548607325

	Obliquity		358.0802651378413

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.266065402814446
		Eccentricity	0.03163609445292191
		Inclination		-0.832043038721194
		AscendingNode	281.50093640328595
		ArgOfPericen	311.3565342374797
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 381"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1655089951656487e-06
	Radius		84.88740814269386

	RotationPeriod	5.067423385367984

	Obliquity		116.85559436371744

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2280130320567704
		Eccentricity	0.05215774882500937
		Inclination		1.8176072967321375
		AscendingNode	190.22447403508286
		ArgOfPericen	47.72546136230375
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 382"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.310866341899026e-08
	Radius		26.934126498489892

	RotationPeriod	8.340168028905284

	Obliquity		58.393420272709925

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2184987955239097
		Eccentricity	0.06916414641354371
		Inclination		-1.1887239627322779
		AscendingNode	332.54587702652935
		ArgOfPericen	207.59946182272765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 383"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.417835170489316e-07
	Radius		47.68447731514655

	RotationPeriod	6.564347094498602

	Obliquity		348.20237970732796

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2545882035748925
		Eccentricity	0.0497203327020988
		Inclination		3.3585331135422445
		AscendingNode	270.37713699514507
		ArgOfPericen	311.44427176055234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 383.1"
{
	ParentBody	"Erebos 383"
	Class		"Asteroid"
	Mass		2.1448229321579836e-10
	Radius		4.581755865222245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.837909037218674e-07
		Eccentricity	0.0018905153721922576
		Inclination		19.7291944116045
		AscendingNode	146.3926128649727
		ArgOfPericen	145.5957949864744
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 384"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.963713014690259e-07
	Radius		52.75304180491972

	RotationPeriod	7.54639852433791

	Obliquity		237.98164036176865

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.307847844568396
		Eccentricity	0.06131441311726329
		Inclination		-1.1410654626661354
		AscendingNode	356.19980945462436
		ArgOfPericen	235.38625266791337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 384.1"
{
	ParentBody	"Erebos 384"
	Class		"Asteroid"
	Mass		3.196577602363692e-10
	Radius		5.4099992918271935

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8677081551109316e-06
		Eccentricity	0.0077478851580905644
		Inclination		54.60569584561729
		AscendingNode	280.81499479149227
		ArgOfPericen	49.26711357248831
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 385"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.204784850251376e-07
	Radius		60.01207251235634

	RotationPeriod	4.74312859239158

	Obliquity		75.03310495709468

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2864831286191727
		Eccentricity	0.06505475795683018
		Inclination		1.2078860658764528
		AscendingNode	294.52395382784
		ArgOfPericen	35.67142394991333
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 386"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.347453731155363e-07
	Radius		65.48133667497441

	RotationPeriod	5.576736210523907

	Obliquity		348.3114782006248

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272504452964472
		Eccentricity	0.048368680972039405
		Inclination		-0.4498934203343087
		AscendingNode	173.10035143522452
		ArgOfPericen	284.6302452382216
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 386.1"
{
	ParentBody	"Erebos 386"
	Class		"Asteroid"
	Mass		7.777947713016385e-09
	Radius		15.096375669507745

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.84841574996394e-07
		Eccentricity	0.0027588541650651354
		Inclination		23.954704260055514
		AscendingNode	334.7220126127519
		ArgOfPericen	179.49870972034986
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 387"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.102819073285671e-08
	Radius		26.942057790406334

	RotationPeriod	4.568808353121442

	Obliquity		147.00445782233183

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3264725242967264
		Eccentricity	0.019327967054488138
		Inclination		2.9819337998264275
		AscendingNode	148.70036508243112
		ArgOfPericen	260.25008721448967
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 387.1"
{
	ParentBody	"Erebos 387"
	Class		"Asteroid"
	Mass		8.735624003815691e-11
	Radius		3.8043160561111478

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2130645292200798e-06
		Eccentricity	0.006726203579585283
		Inclination		-31.06340342806583
		AscendingNode	4.416321417600169
		ArgOfPericen	209.03063862396328
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 387.2"
{
	ParentBody	"Erebos 387"
	Class		"Asteroid"
	Mass		3.460348164549081e-10
	Radius		6.019381628695707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.421970083583987e-06
		Eccentricity	0.004397592375495272
		Inclination		67.41255963926545
		AscendingNode	174.3749789777673
		ArgOfPericen	335.68872175821315
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 388"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3552325043816866
		Eccentricity	0.0804198166436417
		Inclination		-1.7691699659752866
		AscendingNode	130.1015918226348
		ArgOfPericen	173.73025587248273
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 388 A"
{
	ParentBody	"Erebos 388"
	Class		"Asteroid"
	Mass		1.4170144232806615e-08
	Radius		18.863793189827703

	Orbit
	{
		Epoch			2457395.5
		Period			0.005988679115568964
		Eccentricity	0.002612278855402917
		Inclination		61.5060229240992
		AscendingNode	54.88641623671268
		ArgOfPericen	267.76658312272724
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 388 B"
{
	ParentBody	"Erebos 388"
	Class		"Asteroid"
	Mass		6.890331106479869e-09
	Radius		14.83375039123214

	Orbit
	{
		Epoch			2457395.5
		Period			0.005988679115568964
		Eccentricity	0.002612278855402917
		Inclination		61.5060229240992
		AscendingNode	54.88641623671268
		ArgOfPericen	87.76658312272724
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 389"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0358545058393983e-09
	Radius		7.690028854974344

	RotationPeriod	9.018813036337743

	Obliquity		199.89972554955295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.282220122765837
		Eccentricity	0.03365161858392418
		Inclination		-0.7783816160674505
		AscendingNode	15.222334262173781
		ArgOfPericen	67.06658187796808
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 390"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.1530074670496474e-08
	Radius		29.852760436933107

	RotationPeriod	9.05051153029777

	Obliquity		283.2360862705263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3333912464860243
		Eccentricity	0.04579383254032167
		Inclination		-2.0169076446806113
		AscendingNode	263.2959531619237
		ArgOfPericen	107.63621634027824
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 391"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.055829837672956e-07
	Radius		49.723288744344664

	RotationPeriod	8.115704311754666

	Obliquity		151.73107108089616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.268383760113375
		Eccentricity	0.04036090128989562
		Inclination		1.854150433527813
		AscendingNode	183.44781849696784
		ArgOfPericen	94.18753026790117
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 392"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.042513754201113e-07
	Radius		62.891645154634446

	RotationPeriod	7.573243889557485

	Obliquity		205.49187035742875

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3665972840115637
		Eccentricity	0.05898102595464869
		Inclination		0.015737238078864863
		AscendingNode	291.41975701363447
		ArgOfPericen	43.51678875698979
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 393"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.977436522167048e-07
	Radius		75.0118182015014

	RotationPeriod	4.1242266041089435

	Obliquity		105.36530518287375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.303444746300893
		Eccentricity	0.05976224685358829
		Inclination		2.514306125512586
		AscendingNode	79.95686490978439
		ArgOfPericen	0.9014834617976231
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 394"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.627862068099868e-07
	Radius		71.83985693876333

	RotationPeriod	5.959365193926133

	Obliquity		62.99069429725839

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2982747809433013
		Eccentricity	0.06318406387320791
		Inclination		-3.8063760446277692
		AscendingNode	324.2727069356045
		ArgOfPericen	297.2417499032995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 395"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1945281642471783e-08
	Radius		23.701704810463916

	RotationPeriod	3.8093933467066092

	Obliquity		66.66718589188187

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.361150268103082
		Eccentricity	0.03595962402794581
		Inclination		0.12493281472100354
		AscendingNode	357.3015916760555
		ArgOfPericen	99.06414351372577
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 396"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.703433929015406e-07
	Radius		53.56032590642399

	RotationPeriod	7.245701427136453

	Obliquity		196.5439105634699

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2712538442238497
		Eccentricity	0.07677297985184192
		Inclination		0.6764415987928142
		AscendingNode	57.159930396296524
		ArgOfPericen	16.158881674163098
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 397"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.672129262601323e-07
	Radius		71.01475835887194

	RotationPeriod	7.217064422019554

	Obliquity		98.92068303675967

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.251500703937683
		Eccentricity	0.04169801621924694
		Inclination		0.39616068019398815
		AscendingNode	141.67275872838127
		ArgOfPericen	312.47763712977667
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 398"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.28654719623707
		Eccentricity	0.044215380804786576
		Inclination		-0.3531420600284652
		AscendingNode	15.238499544196674
		ArgOfPericen	20.619947170365165
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 398 A"
{
	ParentBody	"Erebos 398"
	Class		"Asteroid"
	Mass		2.1925055822215874e-07
	Radius		45.432828583769954

	Orbit
	{
		Epoch			2457395.5
		Period			0.007640992079973843
		Eccentricity	0.004855985770492155
		Inclination		235.27756204695987
		AscendingNode	3.7617782555798396
		ArgOfPericen	264.2936714655001
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 398 B"
{
	ParentBody	"Erebos 398"
	Class		"Asteroid"
	Mass		3.099610268253611e-08
	Radius		23.66783705278107

	Orbit
	{
		Epoch			2457395.5
		Period			0.007640992079973843
		Eccentricity	0.004855985770492155
		Inclination		235.27756204695987
		AscendingNode	3.7617782555798396
		ArgOfPericen	84.2936714655001
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 399"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.327836123852642
		Eccentricity	0.06396226484812366
		Inclination		-0.034613908073609034
		AscendingNode	279.0212871525023
		ArgOfPericen	277.73906509866254
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 399 A"
{
	ParentBody	"Erebos 399"
	Class		"Asteroid"
	Mass		5.642114216889243e-07
	Radius		64.31220778906393

	Orbit
	{
		Epoch			2457395.5
		Period			0.00434826236148132
		Eccentricity	0.006399498339256333
		Inclination		252.3630714655764
		AscendingNode	243.40062216190455
		ArgOfPericen	249.57024982814204
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 399 B"
{
	ParentBody	"Erebos 399"
	Class		"Asteroid"
	Mass		1.5009287938863733e-07
	Radius		41.36180575239342

	Orbit
	{
		Epoch			2457395.5
		Period			0.00434826236148132
		Eccentricity	0.006399498339256333
		Inclination		252.3630714655764
		AscendingNode	243.40062216190455
		ArgOfPericen	69.57024982814204
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 400"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.930399314748231e-07
	Radius		52.48779275239442

	RotationPeriod	4.312582233415773

	Obliquity		73.2984911037303

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2237180020896066
		Eccentricity	0.024429279557710997
		Inclination		1.6134860741389194
		AscendingNode	27.109250304907178
		ArgOfPericen	158.2673935005267
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 401"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.013516171672465e-08
	Radius		38.57972552390802

	RotationPeriod	9.629810293033934

	Obliquity		197.4028108145944

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3542605461469517
		Eccentricity	0.06616448863514922
		Inclination		-1.7988444609744423
		AscendingNode	101.52724706256902
		ArgOfPericen	278.42951145354084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 402"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.726282629346563e-08
	Radius		29.615918216228543

	RotationPeriod	4.981137589446

	Obliquity		109.68879403947422

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.320872979825015
		Eccentricity	0.055336226380064565
		Inclination		-0.7574111031177069
		AscendingNode	322.1275685218872
		ArgOfPericen	251.05432051731012
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 403"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6091981491848645e-07
	Radius		42.64255281792237

	RotationPeriod	5.75894302401573

	Obliquity		81.28048810105832

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.209117195856153
		Eccentricity	0.03663232559926623
		Inclination		0.14738505465624385
		AscendingNode	10.975343146912042
		ArgOfPericen	165.2404099854835
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 403.1"
{
	ParentBody	"Erebos 403"
	Class		"Asteroid"
	Mass		2.0644443927156834e-09
	Radius		9.982540581118466

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.644440002076576e-06
		Eccentricity	0.005514274643004568
		Inclination		-13.096686008786978
		AscendingNode	117.44601707961075
		ArgOfPericen	350.81562687626933
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 404"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3454364347042236
		Eccentricity	0.061553571310171015
		Inclination		-0.7759621972543712
		AscendingNode	78.27739746801092
		ArgOfPericen	241.88650437429473
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 404 A"
{
	ParentBody	"Erebos 404"
	Class		"Asteroid"
	Mass		2.1960195838494725e-08
	Radius		21.2421819735535

	Orbit
	{
		Epoch			2457395.5
		Period			0.005684578795469567
		Eccentricity	0.0017092052389068935
		Inclination		111.10534091219264
		AscendingNode	76.02941580528923
		ArgOfPericen	180.63162476611714
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 404 B"
{
	ParentBody	"Erebos 404"
	Class		"Asteroid"
	Mass		7.658438736918494e-09
	Radius		14.952040666277703

	Orbit
	{
		Epoch			2457395.5
		Period			0.005684578795469567
		Eccentricity	0.0017092052389068935
		Inclination		111.10534091219264
		AscendingNode	76.02941580528923
		ArgOfPericen	0.6316247661171701
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 405"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.650309055741035e-07
	Radius		70.28536393237967

	RotationPeriod	6.468005955212215

	Obliquity		194.49839810386044

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3613386503062386
		Eccentricity	0.022963180704704305
		Inclination		-1.1812237214262917
		AscendingNode	228.77360553185875
		ArgOfPericen	319.9937611064867
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 406"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.289697101161796e-07
	Radius		64.09438791769193

	RotationPeriod	4.774547932083078

	Obliquity		128.70807846138877

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2412410656418973
		Eccentricity	0.07505572117260174
		Inclination		0.5521102399151974
		AscendingNode	291.3162712056675
		ArgOfPericen	103.1681560762931
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 407"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6926441972436218e-07
	Radius		42.37537906207503

	RotationPeriod	7.239641969866412

	Obliquity		213.6824397232881

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.259169328276406
		Eccentricity	0.06342667366226319
		Inclination		-0.16898087228456754
		AscendingNode	100.78022101540853
		ArgOfPericen	110.20175167143306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 408"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.089713135720204e-08
	Radius		35.41284491550456

	RotationPeriod	6.962267168963207

	Obliquity		28.931318528574003

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3235248832219764
		Eccentricity	0.04413302066106538
		Inclination		-1.7526212254476459
		AscendingNode	81.84608267101221
		ArgOfPericen	335.7935835357017
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 409"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.945497584637631e-07
	Radius		63.45254668569575

	RotationPeriod	8.20377966077202

	Obliquity		124.43621016254282

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2852586220988766
		Eccentricity	0.061781367731849134
		Inclination		2.18981525332861
		AscendingNode	159.66088146373517
		ArgOfPericen	18.138541819547388
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 410"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4009591843156253
		Eccentricity	0.03951625906246403
		Inclination		3.4840239390420167
		AscendingNode	249.24866708071517
		ArgOfPericen	205.34797296718125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 410 A"
{
	ParentBody	"Erebos 410"
	Class		"Asteroid"
	Mass		9.021805933083582e-07
	Radius		73.78298212705346

	Orbit
	{
		Epoch			2457395.5
		Period			0.004234471887172938
		Eccentricity	0.005341097533640984
		Inclination		231.09863822468327
		AscendingNode	230.92893931249964
		ArgOfPericen	345.74604353815346
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 410 B"
{
	ParentBody	"Erebos 410"
	Class		"Asteroid"
	Mass		1.4678165462932503e-07
	Radius		40.279336105341706

	Orbit
	{
		Epoch			2457395.5
		Period			0.004234471887172938
		Eccentricity	0.005341097533640984
		Inclination		231.09863822468327
		AscendingNode	230.92893931249964
		ArgOfPericen	165.74604353815346
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 411"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.259628035880994e-08
	Radius		33.92199303600431

	RotationPeriod	7.155770682638949

	Obliquity		148.12730331635555

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.282978425341637
		Eccentricity	0.0927712418397697
		Inclination		-0.3852105065448682
		AscendingNode	240.11737969322553
		ArgOfPericen	79.11281392795901
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 411.1"
{
	ParentBody	"Erebos 411"
	Class		"Asteroid"
	Mass		1.1447316998753738e-09
	Radius		8.14821413803908

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.661380976848213e-07
		Eccentricity	0.004736124157092005
		Inclination		8.536799561495789
		AscendingNode	1.2729573380005332
		ArgOfPericen	253.9534764480746
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 412"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.838705632804998e-08
	Radius		30.025057934065458

	RotationPeriod	5.521886575425567

	Obliquity		148.23685857815536

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.382741593786284
		Eccentricity	0.07488202232667872
		Inclination		1.9442843009012576
		AscendingNode	11.315578313570818
		ArgOfPericen	310.4115529764236
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 413"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.514267943376955e-07
	Radius		45.40350450217629

	RotationPeriod	4.394675392635475

	Obliquity		252.33928376011286

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2136047649332222
		Eccentricity	0.0700460002233519
		Inclination		-1.7617460910909493
		AscendingNode	41.14787072518417
		ArgOfPericen	22.271804297903095
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 414"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.157783253013284e-08
	Radius		31.163334533083646

	RotationPeriod	6.5589445041113725

	Obliquity		236.29645433198482

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2600565350284096
		Eccentricity	0.022677297673306226
		Inclination		1.533384716675755
		AscendingNode	324.35147592168937
		ArgOfPericen	4.057724054515104
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 415"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.976863240785733e-07
	Radius		75.54774656712026

	RotationPeriod	3.8665178144061967

	Obliquity		217.32865025341565

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3967901130924414
		Eccentricity	0.09088084953517231
		Inclination		1.5018209417928188
		AscendingNode	214.38785851876625
		ArgOfPericen	337.0973227129381
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 416"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.815559937354202e-08
	Radius		33.071622036331526

	RotationPeriod	5.339942416926884

	Obliquity		219.57584918284584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.393322014022626
		Eccentricity	0.05558767384169565
		Inclination		1.7129589193351757
		AscendingNode	279.5037416661969
		ArgOfPericen	151.3968964254498
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 417"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.384857218906343e-07
	Radius		71.55698719519793

	RotationPeriod	7.4718658087522005

	Obliquity		122.71883087074241

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3321977831505993
		Eccentricity	0.03507987334656368
		Inclination		0.2965675069658814
		AscendingNode	68.91429939947812
		ArgOfPericen	344.00903743906156
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 418"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.47315871610003e-07
	Radius		64.99272497729613

	RotationPeriod	6.947765704358129

	Obliquity		244.51502955620626

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3423049866926737
		Eccentricity	0.03957961838017565
		Inclination		-1.8266498020299948
		AscendingNode	327.87271963345717
		ArgOfPericen	125.14604641280263
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 419"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3697293734666576
		Eccentricity	0.05541362208652249
		Inclination		-0.019796273001217314
		AscendingNode	105.13697584519137
		ArgOfPericen	49.66770992054151
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 419 A"
{
	ParentBody	"Erebos 419"
	Class		"Asteroid"
	Mass		2.533533678657176e-07
	Radius		48.94968300557571

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008682983627537844
		Eccentricity	0.005196894384964371
		Inclination		257.7461275031491
		AscendingNode	304.8699785364929
		ArgOfPericen	189.73398004895984
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 419 B"
{
	ParentBody	"Erebos 419"
	Class		"Asteroid"
	Mass		9.705834035796265e-08
	Radius		35.55100998988279

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008682983627537844
		Eccentricity	0.005196894384964371
		Inclination		257.7461275031491
		AscendingNode	304.8699785364929
		ArgOfPericen	9.733980048959836
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 420"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.026819128627475e-08
	Radius		32.07435760434363

	RotationPeriod	8.95924651311827

	Obliquity		49.96753521492491

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2476126653103283
		Eccentricity	0.04169800521067065
		Inclination		0.5734466617997138
		AscendingNode	167.23483919210474
		ArgOfPericen	212.39016183129561
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 421"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2866554866957607
		Eccentricity	0.03841963996600603
		Inclination		1.0403497447629413
		AscendingNode	244.73993839743818
		ArgOfPericen	288.06052216857745
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 421 A"
{
	ParentBody	"Erebos 421"
	Class		"Asteroid"
	Mass		1.5539972036275313e-07
	Radius		40.95677585368929

	Orbit
	{
		Epoch			2457395.5
		Period			0.00116229087276115
		Eccentricity	0.0043784529114
		Inclination		79.24328840138584
		AscendingNode	289.0447762684273
		ArgOfPericen	296.8361665658897
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 421 B"
{
	ParentBody	"Erebos 421"
	Class		"Asteroid"
	Mass		3.907256661910653e-09
	Radius		11.99866690722724

	Orbit
	{
		Epoch			2457395.5
		Period			0.00116229087276115
		Eccentricity	0.0043784529114
		Inclination		79.24328840138584
		AscendingNode	289.0447762684273
		ArgOfPericen	116.8361665658897
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 422"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3541735902435729e-07
	Radius		39.61291569839566

	RotationPeriod	4.655305396265035

	Obliquity		310.118459741108

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310044454439793
		Eccentricity	0.04236858041501292
		Inclination		-1.902881055747848
		AscendingNode	314.9795395527077
		ArgOfPericen	188.84711243085118
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 423"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.241675592763612
		Eccentricity	0.04370987479405801
		Inclination		-1.3087964300879837
		AscendingNode	6.501876395728972
		ArgOfPericen	39.04761396338171
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 423 A"
{
	ParentBody	"Erebos 423"
	Class		"Asteroid"
	Mass		1.8084193691102772e-07
	Radius		44.634454990142075

	Orbit
	{
		Epoch			2457395.5
		Period			0.004193481766732858
		Eccentricity	0.0038531029185287988
		Inclination		133.60090036211577
		AscendingNode	161.84505767197612
		ArgOfPericen	148.33032848064613
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 423 B"
{
	ParentBody	"Erebos 423"
	Class		"Asteroid"
	Mass		1.5920632238029152e-07
	Radius		42.778342801363095

	Orbit
	{
		Epoch			2457395.5
		Period			0.004193481766732858
		Eccentricity	0.0038531029185287988
		Inclination		133.60090036211577
		AscendingNode	161.84505767197612
		ArgOfPericen	328.33032848064613
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 424"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.987613434758068e-09
	Radius		9.988148806778355

	RotationPeriod	5.6850093372169574

	Obliquity		110.26163014442324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.386172277123603
		Eccentricity	0.037986869023937345
		Inclination		1.6403971373311073
		AscendingNode	285.9890033589932
		ArgOfPericen	261.0519818650451
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 425"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5077563770133884e-07
	Radius		43.486434800786284

	RotationPeriod	5.814765210284029

	Obliquity		84.82078633474791

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.400309048084867
		Eccentricity	0.054359726043243115
		Inclination		-2.256874188909229
		AscendingNode	27.190127227860877
		ArgOfPericen	114.26645556920546
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 426"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.277335551911713e-07
	Radius		70.60903028880304

	RotationPeriod	7.461558212486088

	Obliquity		198.60331417192657

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2438593310846486
		Eccentricity	0.02762748831755344
		Inclination		4.098491709360908
		AscendingNode	66.7281675131596
		ArgOfPericen	138.06596486300646
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 427"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3808704403444683
		Eccentricity	0.04957115588470787
		Inclination		-2.4377333800191887
		AscendingNode	274.3806859028387
		ArgOfPericen	287.79611961297655
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 427 A"
{
	ParentBody	"Erebos 427"
	Class		"Asteroid"
	Mass		7.273978596514468e-08
	Radius		33.68139582361087

	Orbit
	{
		Epoch			2457395.5
		Period			0.007588927870204081
		Eccentricity	0.0020535100507715694
		Inclination		191.05076045301038
		AscendingNode	203.19872180886725
		ArgOfPericen	236.6888035327726
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 427 B"
{
	ParentBody	"Erebos 427"
	Class		"Asteroid"
	Mass		4.490931114047052e-09
	Radius		13.312047934921656

	Orbit
	{
		Epoch			2457395.5
		Period			0.007588927870204081
		Eccentricity	0.0020535100507715694
		Inclination		191.05076045301038
		AscendingNode	203.19872180886725
		ArgOfPericen	56.68880353277257
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 428"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3903079452541162e-06
	Radius		83.83191795290747

	RotationPeriod	8.263338854462397

	Obliquity		205.47890240080605

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.321643033691185
		Eccentricity	0.0625891240017439
		Inclination		1.0214665315839775
		AscendingNode	144.95678221194237
		ArgOfPericen	218.57136874803663
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 429"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3174253173165984
		Eccentricity	0.07274217074577677
		Inclination		2.521083623489517
		AscendingNode	6.099844889086921
		ArgOfPericen	296.5767744277739
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 429 A"
{
	ParentBody	"Erebos 429"
	Class		"Asteroid"
	Mass		8.978613893436483e-07
	Radius		75.6902831145592

	Orbit
	{
		Epoch			2457395.5
		Period			0.0076135592461047934
		Eccentricity	0.003036916065941508
		Inclination		23.817392029629076
		AscendingNode	144.78050010971157
		ArgOfPericen	202.42052022874668
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 429 B"
{
	ParentBody	"Erebos 429"
	Class		"Asteroid"
	Mass		5.185440921463132e-07
	Radius		63.03265414666883

	Orbit
	{
		Epoch			2457395.5
		Period			0.0076135592461047934
		Eccentricity	0.003036916065941508
		Inclination		23.817392029629076
		AscendingNode	144.78050010971157
		ArgOfPericen	22.420520228746682
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 430"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.367824306461019e-07
	Radius		64.7724679997239

	RotationPeriod	9.218126005738752

	Obliquity		263.23223692589676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2754671580270864
		Eccentricity	0.04407512274152513
		Inclination		1.8975432677377988
		AscendingNode	273.64254274556197
		ArgOfPericen	270.7779342469507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 431"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.269128810585258
		Eccentricity	0.06015924259102458
		Inclination		1.4785940271118216
		AscendingNode	302.8579454090397
		ArgOfPericen	297.024906527727
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 431 A"
{
	ParentBody	"Erebos 431"
	Class		"Asteroid"
	Mass		7.150694445380705e-08
	Radius		32.445407065622604

	Orbit
	{
		Epoch			2457395.5
		Period			0.003997122450404808
		Eccentricity	0.005230111912900507
		Inclination		59.80534269905824
		AscendingNode	131.03987949372743
		ArgOfPericen	301.83251533111263
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 431 B"
{
	ParentBody	"Erebos 431"
	Class		"Asteroid"
	Mass		2.8983695840091716e-08
	Radius		24.01163546909512

	Orbit
	{
		Epoch			2457395.5
		Period			0.003997122450404808
		Eccentricity	0.005230111912900507
		Inclination		59.80534269905824
		AscendingNode	131.03987949372743
		ArgOfPericen	121.83251533111263
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 432"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.501533875990894e-07
	Radius		64.24812317596648

	RotationPeriod	5.8491217278476455

	Obliquity		182.19834438744772

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.307204319982861
		Eccentricity	0.02017804252548106
		Inclination		0.5067857581121249
		AscendingNode	327.87932358306216
		ArgOfPericen	141.26365184167378
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 433"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3147551752326736e-07
	Radius		38.708501618825146

	RotationPeriod	3.6639350001880504

	Obliquity		65.86779867038916

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.275971835314145
		Eccentricity	0.03054845278541343
		Inclination		-0.9521936166323552
		AscendingNode	322.7621339839613
		ArgOfPericen	306.02357597755974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 434"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.324976129876419
		Eccentricity	0.020198847688130045
		Inclination		1.1220912577992934
		AscendingNode	13.278324089416639
		ArgOfPericen	146.4743226234334
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 434 A"
{
	ParentBody	"Erebos 434"
	Class		"Asteroid"
	Mass		4.217375731177492e-09
	Radius		12.563619400249827

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022984095974477336
		Eccentricity	0.004450702162381066
		Inclination		184.32608741117167
		AscendingNode	269.0174012196172
		ArgOfPericen	22.333085719202643
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 434 B"
{
	ParentBody	"Erebos 434"
	Class		"Asteroid"
	Mass		2.93133498651562e-10
	Radius		5.165620423318911

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022984095974477336
		Eccentricity	0.004450702162381066
		Inclination		184.32608741117167
		AscendingNode	269.0174012196172
		ArgOfPericen	202.33308571920264
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 435"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.299284558780371
		Eccentricity	0.07739545430653823
		Inclination		-1.3052118285458985
		AscendingNode	83.40354924212318
		ArgOfPericen	178.80051146025005
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 435 A"
{
	ParentBody	"Erebos 435"
	Class		"Asteroid"
	Mass		1.2054305404709638e-06
	Radius		87.51275167713331

	Orbit
	{
		Epoch			2457395.5
		Period			0.00721043597832119
		Eccentricity	0.006639407086794082
		Inclination		6.741392539753579
		AscendingNode	249.26746868191162
		ArgOfPericen	233.82640498857043
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 435 B"
{
	ParentBody	"Erebos 435"
	Class		"Asteroid"
	Mass		5.501828387315321e-07
	Radius		67.37926813573839

	Orbit
	{
		Epoch			2457395.5
		Period			0.00721043597832119
		Eccentricity	0.006639407086794082
		Inclination		6.741392539753579
		AscendingNode	249.26746868191162
		ArgOfPericen	53.8264049885704
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 436"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.215197463864737e-07
	Radius		45.64892743821619

	RotationPeriod	4.277071349061435

	Obliquity		164.53156671713876

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3265031509617757
		Eccentricity	0.07139017201507568
		Inclination		-0.3312180760341499
		AscendingNode	83.7311111309364
		ArgOfPericen	0.005686968211069399
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 437"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.37758461672242
		Eccentricity	0.025312648457801998
		Inclination		2.3078145989672345
		AscendingNode	58.70693750467296
		ArgOfPericen	159.38898936722472
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 437 A"
{
	ParentBody	"Erebos 437"
	Class		"Asteroid"
	Mass		2.805067740527956e-07
	Radius		47.77710455714253

	Orbit
	{
		Epoch			2457395.5
		Period			0.004367517648784878
		Eccentricity	0.0057042460896349345
		Inclination		47.65790014270535
		AscendingNode	339.67457302079225
		ArgOfPericen	208.00583026008954
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 437 B"
{
	ParentBody	"Erebos 437"
	Class		"Asteroid"
	Mass		9.334521820586695e-08
	Radius		33.10823789746048

	Orbit
	{
		Epoch			2457395.5
		Period			0.004367517648784878
		Eccentricity	0.0057042460896349345
		Inclination		47.65790014270535
		AscendingNode	339.67457302079225
		ArgOfPericen	28.00583026008951
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 438"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.3559732553113476e-07
	Radius		60.70162099486963

	RotationPeriod	7.613873657773616

	Obliquity		148.33620360621896

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2911870812828146
		Eccentricity	0.08960461009197006
		Inclination		1.8996303009565694
		AscendingNode	95.48084189813262
		ArgOfPericen	78.67706136622586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 439"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.8254694134158543e-07
	Radius		59.98555209928155

	RotationPeriod	6.502027638635308

	Obliquity		48.98290460251516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.31855151459219
		Eccentricity	0.030626944983597765
		Inclination		2.0509543360849376
		AscendingNode	96.43200522782614
		ArgOfPericen	136.9003722195976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 439.1"
{
	ParentBody	"Erebos 439"
	Class		"Asteroid"
	Mass		1.5682685043802145e-09
	Radius		9.600456613506907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.376903268189314e-06
		Eccentricity	0.005400937648993824
		Inclination		-24.388117645177307
		AscendingNode	184.57200140446417
		ArgOfPericen	336.4858047759826
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 440"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.062896800731336e-08
	Radius		30.34987365560743

	RotationPeriod	7.097009378067103

	Obliquity		176.98693028042257

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3037134808862763
		Eccentricity	0.07616110180623882
		Inclination		-3.371139430329304
		AscendingNode	216.74999419281042
		ArgOfPericen	214.94255829412978
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 440.1"
{
	ParentBody	"Erebos 440"
	Class		"Asteroid"
	Mass		8.45635199764561e-12
	Radius		1.5739508975655163

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7956172156170289e-06
		Eccentricity	0.0063841399642437305
		Inclination		-13.542510889864367
		AscendingNode	125.5836252929697
		ArgOfPericen	7.778428149016996
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 441"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.0151947219749357e-07
	Radius		50.238576533386066

	RotationPeriod	7.374750648213427

	Obliquity		268.789168185865

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.293825360436521
		Eccentricity	0.011177602668251095
		Inclination		2.844014712669477
		AscendingNode	182.79776769857992
		ArgOfPericen	81.60033323356615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 441.1"
{
	ParentBody	"Erebos 441"
	Class		"Asteroid"
	Mass		2.454027978667553e-09
	Radius		10.105520965591868

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3262657085240904e-06
		Eccentricity	0.004617296829595837
		Inclination		-46.008430189200915
		AscendingNode	138.06493540107104
		ArgOfPericen	19.72702222898979
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 442"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.170862375750619e-07
	Radius		60.38505182321988

	RotationPeriod	5.99336997739915

	Obliquity		263.2640759372702

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.290078806134266
		Eccentricity	0.030853807210194158
		Inclination		-0.006324430506140844
		AscendingNode	109.35268252216147
		ArgOfPericen	349.2018058433139
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 443"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3611560079109503e-07
	Radius		43.19002459639394

	RotationPeriod	6.9037168333636

	Obliquity		103.0336938477575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.277404226469136
		Eccentricity	0.0486668180260583
		Inclination		1.1416305859098481
		AscendingNode	340.9290899534978
		ArgOfPericen	19.1913038350298
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 444"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0692604642198535e-07
	Radius		45.82010524265477

	RotationPeriod	7.409564422620451

	Obliquity		174.99325859263485

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.354731015425151
		Eccentricity	0.05231769533109592
		Inclination		-1.5418863797945799
		AscendingNode	265.85724664527334
		ArgOfPericen	7.700122099349995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 445"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3107717852137177e-07
	Radius		40.874969149260245

	RotationPeriod	7.6963726750615296

	Obliquity		58.8706162913365

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3229099374049618
		Eccentricity	0.04434560550162134
		Inclination		0.6065009374377632
		AscendingNode	238.75478953150974
		ArgOfPericen	23.782984611937987
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 446"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1780094177123038e-06
	Radius		83.34810123727149

	RotationPeriod	5.4568618106112

	Obliquity		330.33247507029324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.306399885112756
		Eccentricity	0.05023439731106177
		Inclination		-4.3038984532715965
		AscendingNode	218.51785339766826
		ArgOfPericen	154.87404505096134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 446.1"
{
	ParentBody	"Erebos 446"
	Class		"Asteroid"
	Mass		4.878149960108203e-09
	Radius		13.384367068270612

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0181411361022571e-05
		Eccentricity	0.005448021234708871
		Inclination		39.334979620163054
		AscendingNode	145.66375240560754
		ArgOfPericen	322.0438298301006
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 447"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5684054029691344e-07
	Radius		51.280464420595344

	RotationPeriod	6.370366929577581

	Obliquity		137.02680914141578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.374013906843027
		Eccentricity	0.027520889013801023
		Inclination		1.1525690329546885
		AscendingNode	83.0455872427372
		ArgOfPericen	246.23548403244746
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 448"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.680490005191454e-07
	Radius		63.87819382024199

	RotationPeriod	5.271362426900286

	Obliquity		32.13339894418441

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3570237563672873
		Eccentricity	0.02948909709103394
		Inclination		0.3984737619444239
		AscendingNode	324.0897783392946
		ArgOfPericen	25.694606813380325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 449"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.457164539311287e-09
	Radius		14.363174416332178

	RotationPeriod	5.5449868327198

	Obliquity		98.85228327209998

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2911900556737916
		Eccentricity	0.027559146071004213
		Inclination		-0.055695705653091426
		AscendingNode	23.198472564807663
		ArgOfPericen	266.46556912305084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 449.1"
{
	ParentBody	"Erebos 449"
	Class		"Asteroid"
	Mass		2.5594900224501237e-12
	Radius		1.0550854407827746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9257140740410494e-06
		Eccentricity	0.0036225760702676578
		Inclination		20.378368424272935
		AscendingNode	195.69680650906398
		ArgOfPericen	152.16352584506063
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 450"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.654105364262771e-07
	Radius		59.97785146852021

	RotationPeriod	5.218590632633933

	Obliquity		152.4222087139513

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.390552194336346
		Eccentricity	0.033743349031807715
		Inclination		3.5097817366206607
		AscendingNode	328.1344297807078
		ArgOfPericen	29.524610137364963
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 450.1"
{
	ParentBody	"Erebos 450"
	Class		"Asteroid"
	Mass		2.1444923335111442e-10
	Radius		5.021560680608701

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.596527998577355e-06
		Eccentricity	0.002671807480134762
		Inclination		48.88168285382996
		AscendingNode	34.30682062546482
		ArgOfPericen	46.83378544291029
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 450.2"
{
	ParentBody	"Erebos 450"
	Class		"Asteroid"
	Mass		2.823247555636688e-09
	Radius		11.857146961270885

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.835862184630324e-06
		Eccentricity	0.006925445617963633
		Inclination		-14.429546491926027
		AscendingNode	120.80098668204964
		ArgOfPericen	162.36490980333343
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 450.3"
{
	ParentBody	"Erebos 450"
	Class		"Asteroid"
	Mass		4.098972043373414e-09
	Radius		13.426274884009247

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.755919095296125e-06
		Eccentricity	0.005369276589731055
		Inclination		1.77973732336434
		AscendingNode	246.4138316284814
		ArgOfPericen	227.06170064187148
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 451"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.29988915401507e-08
	Radius		35.250326963399786

	RotationPeriod	7.637490094196442

	Obliquity		215.20280163861977

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3415148637112932
		Eccentricity	0.06057731384540689
		Inclination		1.0290628904781298
		AscendingNode	10.93591069668384
		ArgOfPericen	347.7057974992559
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 451.1"
{
	ParentBody	"Erebos 451"
	Class		"Asteroid"
	Mass		9.86132145245117e-10
	Radius		7.744301708047283

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.07314988063243e-06
		Eccentricity	0.0070811371245785345
		Inclination		76.47358987442841
		AscendingNode	309.9268865030711
		ArgOfPericen	159.89257377590747
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 452"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3741422430544614
		Eccentricity	0.07280475236859159
		Inclination		0.02780935457178667
		AscendingNode	219.06057582487776
		ArgOfPericen	276.2897365130144
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 452 A"
{
	ParentBody	"Erebos 452"
	Class		"Asteroid"
	Mass		7.722442418054481e-07
	Radius		72.38180928791512

	Orbit
	{
		Epoch			2457395.5
		Period			0.006624831633396475
		Eccentricity	0.005164359881931447
		Inclination		330.6010047319782
		AscendingNode	25.983348685469654
		ArgOfPericen	35.6813631634138
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 452 B"
{
	ParentBody	"Erebos 452"
	Class		"Asteroid"
	Mass		6.824634227468994e-07
	Radius		69.46046214033636

	Orbit
	{
		Epoch			2457395.5
		Period			0.006624831633396475
		Eccentricity	0.005164359881931447
		Inclination		330.6010047319782
		AscendingNode	25.983348685469654
		ArgOfPericen	215.6813631634138
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 453"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.613587350134641e-08
	Radius		36.44193209786283

	RotationPeriod	9.389697096698848

	Obliquity		342.59342863703205

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3520647998136672
		Eccentricity	0.03288657213215796
		Inclination		-1.8859987585166216
		AscendingNode	78.59516487452834
		ArgOfPericen	174.80547689675228
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 453.1"
{
	ParentBody	"Erebos 453"
	Class		"Asteroid"
	Mass		3.273586526644219e-11
	Radius		2.5447639895354897

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.156318097508418e-06
		Eccentricity	0.006004216086554531
		Inclination		16.750200895285637
		AscendingNode	327.40878377121857
		ArgOfPericen	29.32801140408828
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 453.2"
{
	ParentBody	"Erebos 453"
	Class		"Asteroid"
	Mass		5.570894260429986e-10
	Radius		6.545576065289591

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3468139530478657e-06
		Eccentricity	0.005013176907437999
		Inclination		52.24343982501326
		AscendingNode	38.46919356891024
		ArgOfPericen	17.78805246877547
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 453.3"
{
	ParentBody	"Erebos 453"
	Class		"Asteroid"
	Mass		5.161005085733718e-10
	Radius		6.380935156925618

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8554462467440108e-06
		Eccentricity	0.004863244457845981
		Inclination		-22.906418846703325
		AscendingNode	348.62290437727194
		ArgOfPericen	72.54638985510492
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 454"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2915740818330326
		Eccentricity	0.06720227287698588
		Inclination		0.14859291569347405
		AscendingNode	268.2171730308564
		ArgOfPericen	30.962904413118757
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 454 A"
{
	ParentBody	"Erebos 454"
	Class		"Asteroid"
	Mass		8.655170570070501e-07
	Radius		72.54621690426607

	Orbit
	{
		Epoch			2457395.5
		Period			0.005264023120551463
		Eccentricity	0.0037687040135967165
		Inclination		338.26757095689817
		AscendingNode	23.685920987473615
		ArgOfPericen	240.32957977489886
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 454 B"
{
	ParentBody	"Erebos 454"
	Class		"Asteroid"
	Mass		1.5639170530310354e-07
	Radius		41.01355970133719

	Orbit
	{
		Epoch			2457395.5
		Period			0.005264023120551463
		Eccentricity	0.0037687040135967165
		Inclination		338.26757095689817
		AscendingNode	23.685920987473615
		ArgOfPericen	60.32957977489889
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 455"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2099583987969096
		Eccentricity	0.037822027106995226
		Inclination		-0.11026678393143349
		AscendingNode	37.823142961308335
		ArgOfPericen	250.16895347434044
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 455 A"
{
	ParentBody	"Erebos 455"
	Class		"Asteroid"
	Mass		5.25255006379908e-07
	Radius		64.81325436082982

	Orbit
	{
		Epoch			2457395.5
		Period			0.0036146789927058317
		Eccentricity	0.006207485035341612
		Inclination		169.08708120803172
		AscendingNode	47.030464793900435
		ArgOfPericen	14.737808255461742
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 455 B"
{
	ParentBody	"Erebos 455"
	Class		"Asteroid"
	Mass		3.80599612063142e-07
	Radius		58.21432624595576

	Orbit
	{
		Epoch			2457395.5
		Period			0.0036146789927058317
		Eccentricity	0.006207485035341612
		Inclination		169.08708120803172
		AscendingNode	47.030464793900435
		ArgOfPericen	194.73780825546174
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 456"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.49663399632113e-08
	Radius		34.399610819872606

	RotationPeriod	6.397181372150896

	Obliquity		93.08720908670439

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.305022124430254
		Eccentricity	0.07379509623307247
		Inclination		0.17224369072506449
		AscendingNode	52.90533113867631
		ArgOfPericen	20.33116020254049
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 457"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.805669060337014e-07
	Radius		62.969151272536166

	RotationPeriod	7.4852341593807745

	Obliquity		248.5550398978146

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.396960255832888
		Eccentricity	0.08705157926350984
		Inclination		2.451758154408536
		AscendingNode	104.90719097749607
		ArgOfPericen	153.36329411395528
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 458"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.332842409194215
		Eccentricity	0.039576002997613116
		Inclination		0.834226182586501
		AscendingNode	237.14616878570425
		ArgOfPericen	305.3461070701777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 458 A"
{
	ParentBody	"Erebos 458"
	Class		"Asteroid"
	Mass		2.2875687826103287e-07
	Radius		48.41946448724019

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007502108385945194
		Eccentricity	0.0050618607644032
		Inclination		350.9466038564024
		AscendingNode	224.2527292767243
		ArgOfPericen	115.70926008278883
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 458 B"
{
	ParentBody	"Erebos 458"
	Class		"Asteroid"
	Mass		1.1939266084098238e-07
	Radius		38.98412628192081

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007502108385945194
		Eccentricity	0.0050618607644032
		Inclination		350.9466038564024
		AscendingNode	224.2527292767243
		ArgOfPericen	295.70926008278883
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 459"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3836224279918782e-07
	Radius		41.57560334203615

	RotationPeriod	5.741092598255423

	Obliquity		95.21715453124816

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.275956949994178
		Eccentricity	0.05213395108423527
		Inclination		-0.7489701372376971
		AscendingNode	356.8491522189278
		ArgOfPericen	325.3553104325128
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 460"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7067816281873614e-08
	Radius		19.66640514503314

	RotationPeriod	7.5340449762351795

	Obliquity		200.38418278789027

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.233438977465667
		Eccentricity	0.03330286252383337
		Inclination		0.6488890968308924
		AscendingNode	13.23753981093418
		ArgOfPericen	236.49403157269487
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 460.1"
{
	ParentBody	"Erebos 460"
	Class		"Asteroid"
	Mass		2.203359634620672e-12
	Radius		0.9939414256720985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3321374247305383e-06
		Eccentricity	0.005223691918995908
		Inclination		-30.564740442131374
		AscendingNode	307.56425997369917
		ArgOfPericen	223.07717221953726
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 461"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.8875817610461265e-07
	Radius		53.155849572250474

	RotationPeriod	7.376779943022303

	Obliquity		224.73463047928655

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.235393186675253
		Eccentricity	0.05541869294031207
		Inclination		-2.408035031218811
		AscendingNode	266.261303146581
		ArgOfPericen	37.60801446009054
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 462"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0015339310796729e-07
	Radius		38.39710823873803

	RotationPeriod	5.402001647214826

	Obliquity		219.50546474061204

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3204650530562554
		Eccentricity	0.01927508414199322
		Inclination		-1.554139738982295
		AscendingNode	76.6694197065406
		ArgOfPericen	215.3963092290857
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 463"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2746429842355917
		Eccentricity	0.03382846007146781
		Inclination		0.8946098652188982
		AscendingNode	171.46553943592258
		ArgOfPericen	94.86102217125398
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 463 A"
{
	ParentBody	"Erebos 463"
	Class		"Asteroid"
	Mass		4.598896759091512e-09
	Radius		13.678612248644868

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006185852025732743
		Eccentricity	0.008417656980878622
		Inclination		194.2350995151441
		AscendingNode	143.58686621311608
		ArgOfPericen	153.35603225930063
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 463 B"
{
	ParentBody	"Erebos 463"
	Class		"Asteroid"
	Mass		2.8672696147269057e-09
	Radius		11.685491828804965

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006185852025732743
		Eccentricity	0.008417656980878622
		Inclination		194.2350995151441
		AscendingNode	143.58686621311608
		ArgOfPericen	333.3560322593006
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 464"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.30596225338654
		Eccentricity	0.05212383022112558
		Inclination		0.7130361121804192
		AscendingNode	124.87913616407174
		ArgOfPericen	75.8427063395449
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 464 A"
{
	ParentBody	"Erebos 464"
	Class		"Asteroid"
	Mass		1.593851642053857e-07
	Radius		42.643311152713316

	Orbit
	{
		Epoch			2457395.5
		Period			0.00154765434137976
		Eccentricity	0.0006789192798394581
		Inclination		200.36527786369479
		AscendingNode	2.245384355499347
		ArgOfPericen	311.28663549808607
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 464 B"
{
	ParentBody	"Erebos 464"
	Class		"Asteroid"
	Mass		7.384207982886158e-08
	Radius		32.99663059002199

	Orbit
	{
		Epoch			2457395.5
		Period			0.00154765434137976
		Eccentricity	0.0006789192798394581
		Inclination		200.36527786369479
		AscendingNode	2.245384355499347
		ArgOfPericen	131.28663549808607
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 465"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.3234053947310556e-07
	Radius		54.51264806848479

	RotationPeriod	3.6430725492987373

	Obliquity		111.26489786402706

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2529474475546065
		Eccentricity	0.046125751817755974
		Inclination		0.22056232223697067
		AscendingNode	88.77791733011094
		ArgOfPericen	109.77859620735863
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 465.1"
{
	ParentBody	"Erebos 465"
	Class		"Asteroid"
	Mass		3.3576458935373006e-09
	Radius		11.784589794822757

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.94738267766148e-06
		Eccentricity	0.003354289777950439
		Inclination		-3.263362586902519
		AscendingNode	1.6673981412517769
		ArgOfPericen	288.2390112722971
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 466"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.331354560922829
		Eccentricity	0.02978488469160198
		Inclination		2.483648616343776
		AscendingNode	34.93481283389711
		ArgOfPericen	235.7690473669396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 466 A"
{
	ParentBody	"Erebos 466"
	Class		"Asteroid"
	Mass		9.146604666937735e-07
	Radius		75.52403421970315

	Orbit
	{
		Epoch			2457395.5
		Period			0.006313950642892357
		Eccentricity	0.0042933286670296875
		Inclination		132.04285391529035
		AscendingNode	220.37892666985925
		ArgOfPericen	356.3244207395805
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 466 B"
{
	ParentBody	"Erebos 466"
	Class		"Asteroid"
	Mass		1.1630463160243586e-07
	Radius		37.97789424883105

	Orbit
	{
		Epoch			2457395.5
		Period			0.006313950642892357
		Eccentricity	0.0042933286670296875
		Inclination		132.04285391529035
		AscendingNode	220.37892666985925
		ArgOfPericen	176.32442073958055
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 467"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.201138370847443e-07
	Radius		66.96294622760217

	RotationPeriod	4.599599476105682

	Obliquity		220.92835771973725

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.331597906272457
		Eccentricity	0.04630900609312284
		Inclination		-0.1968606345660198
		AscendingNode	320.16455817690564
		ArgOfPericen	128.51527939530936
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 468"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.567404324557623e-09
	Radius		12.339311178020978

	RotationPeriod	4.354093310853678

	Obliquity		166.88260545430944

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2537661142727754
		Eccentricity	0.05886746570572747
		Inclination		-0.1766003566337517
		AscendingNode	108.65322748220186
		ArgOfPericen	228.83611959508784
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 469"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.5370178886443833e-07
	Radius		59.4015654926708

	RotationPeriod	2.991103489592021

	Obliquity		319.517595244462

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3453343109539055
		Eccentricity	0.05800638830525382
		Inclination		-1.7740583524611198
		AscendingNode	305.0644698251766
		ArgOfPericen	309.71498776315894
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 470"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1071399540903423e-08
	Radius		20.43007572182831

	RotationPeriod	6.057403173262049

	Obliquity		31.782047054884444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.264187236176135
		Eccentricity	0.08204763209161256
		Inclination		1.7917730524333997
		AscendingNode	49.77634890148873
		ArgOfPericen	256.56218285891316
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 471"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1044041250301e-07
	Radius		40.44784192888079

	RotationPeriod	4.1312279211789615

	Obliquity		130.88879470014285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2916852872438067
		Eccentricity	0.06412923307380164
		Inclination		0.9680462200161633
		AscendingNode	273.41831323396457
		ArgOfPericen	8.10515535576795
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 471.1"
{
	ParentBody	"Erebos 471"
	Class		"Asteroid"
	Mass		6.517401608684793e-10
	Radius		7.309328985798621

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5879419443071525e-06
		Eccentricity	0.003911580764813807
		Inclination		-35.038294197398756
		AscendingNode	327.53721873457965
		ArgOfPericen	327.5070239540133
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 472"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.979496207255862e-07
	Radius		59.874449180134405

	RotationPeriod	8.590548626637307

	Obliquity		93.89081334195426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.245690064991678
		Eccentricity	0.036421778523458806
		Inclination		-0.9098250713863598
		AscendingNode	174.39920963445942
		ArgOfPericen	287.95019162604603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 473"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.530772396546043e-07
	Radius		60.280145837031334

	RotationPeriod	8.530562753350921

	Obliquity		308.1569918055331

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.239742462701118
		Eccentricity	0.05485709699998814
		Inclination		-0.1627055862297788
		AscendingNode	291.18353176245466
		ArgOfPericen	302.0655001736207
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 474"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3332799847438579e-07
	Radius		39.64405716229306

	RotationPeriod	1.703216994283296

	Obliquity		30.147338971703004

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2476382740451757
		Eccentricity	0.07384107461211813
		Inclination		1.1121930787451064
		AscendingNode	118.11364073806433
		ArgOfPericen	211.65241278266157
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 475"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.1034356362029766e-08
	Radius		26.81919749304971

	RotationPeriod	5.894861747877406

	Obliquity		359.24666661299733

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3080955565454944
		Eccentricity	0.0440209660641502
		Inclination		1.4248875560715941
		AscendingNode	86.61362580622284
		ArgOfPericen	351.908204283058
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 476"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.330296589320771e-06
	Radius		83.27286166193811

	RotationPeriod	5.157274012392863

	Obliquity		121.80670366725371

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310472572069299
		Eccentricity	0.024120006334244628
		Inclination		0.31714256528158274
		AscendingNode	117.58688548452916
		ArgOfPericen	72.31385189086677
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 477"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2730947312592604e-07
	Radius		52.561659611589604

	RotationPeriod	7.483627691447765

	Obliquity		351.16230490390575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.295166693626283
		Eccentricity	0.03809187329825485
		Inclination		0.9519012030242587
		AscendingNode	192.77928214146257
		ArgOfPericen	260.70558964575616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 477.1"
{
	ParentBody	"Erebos 477"
	Class		"Asteroid"
	Mass		1.2905593315085783e-09
	Radius		9.376826553310647

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.3218176121718905e-06
		Eccentricity	0.0030450341816219933
		Inclination		-2.870592638757892
		AscendingNode	153.84979082039033
		ArgOfPericen	121.18289789601434
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 478"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.3149938394145537e-07
	Radius		57.056548444897366

	RotationPeriod	6.114810027486266

	Obliquity		113.59360719319153

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.263423727820974
		Eccentricity	0.044692006546796226
		Inclination		0.6778738822287954
		AscendingNode	228.96010492103244
		ArgOfPericen	229.22630413785544
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 478.1"
{
	ParentBody	"Erebos 478"
	Class		"Asteroid"
	Mass		1.3208928364196463e-09
	Radius		8.284531705888378

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.277802641099082e-06
		Eccentricity	0.004088498140274419
		Inclination		-16.950469834232887
		AscendingNode	353.7361622486757
		ArgOfPericen	281.3082555445491
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 479"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5593072558795524e-07
	Radius		55.138711342309094

	RotationPeriod	8.100980793018888

	Obliquity		68.35665647364213

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3216206491818445
		Eccentricity	0.08189848319100163
		Inclination		2.902690130074545
		AscendingNode	144.683214294086
		ArgOfPericen	111.24462855476332
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 479.1"
{
	ParentBody	"Erebos 479"
	Class		"Asteroid"
	Mass		2.1340772267529765e-09
	Radius		11.181133847760623

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.633433846154561e-06
		Eccentricity	0.004818808221297812
		Inclination		-51.19696690713443
		AscendingNode	338.6772600696403
		ArgOfPericen	147.22159105857205
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 480"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.538069241031038e-07
	Radius		51.56009289913942

	RotationPeriod	3.8795639884812823

	Obliquity		341.0978922724985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.313454203512757
		Eccentricity	0.052344752637349244
		Inclination		-0.07867837644479186
		AscendingNode	245.44919879598598
		ArgOfPericen	273.8158672537202
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 481"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4627644937930674e-07
	Radius		49.84363220003463

	RotationPeriod	6.03047303219065

	Obliquity		326.50011825227557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.412330737205408
		Eccentricity	0.056323833364030504
		Inclination		-0.90791050695185
		AscendingNode	347.43942061481675
		ArgOfPericen	53.60272253630111
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 482"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2924047167522903
		Eccentricity	0.04277199142054977
		Inclination		0.7482983402047959
		AscendingNode	80.57956774462946
		ArgOfPericen	56.93689063543386
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 482 A"
{
	ParentBody	"Erebos 482"
	Class		"Asteroid"
	Mass		1.4983444010033518e-07
	Radius		44.26524964103277

	Orbit
	{
		Epoch			2457395.5
		Period			0.004117268790423194
		Eccentricity	0.0072684793200321045
		Inclination		329.41051461700033
		AscendingNode	111.44280325628232
		ArgOfPericen	101.15260222009435
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 482 B"
{
	ParentBody	"Erebos 482"
	Class		"Asteroid"
	Mass		1.0630128249867647e-07
	Radius		39.479520516060404

	Orbit
	{
		Epoch			2457395.5
		Period			0.004117268790423194
		Eccentricity	0.0072684793200321045
		Inclination		329.41051461700033
		AscendingNode	111.44280325628232
		ArgOfPericen	281.15260222009437
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 483"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3800698746735022e-07
	Radius		39.87186610651936

	RotationPeriod	3.8096454997151286

	Obliquity		18.163740945953

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310185744519565
		Eccentricity	0.03874895140971585
		Inclination		2.0944893841518715
		AscendingNode	89.72915499297144
		ArgOfPericen	216.60345242978033
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 484"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.859380337109492e-08
	Radius		35.728656486996215

	RotationPeriod	6.916187345401971

	Obliquity		235.48447360979543

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1915904109236464
		Eccentricity	0.06042506474257621
		Inclination		0.9611479667001338
		AscendingNode	275.6300683911458
		ArgOfPericen	30.118663366075378
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 484.1"
{
	ParentBody	"Erebos 484"
	Class		"Asteroid"
	Mass		5.863579168489298e-10
	Radius		6.473230572558256

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.5551118385586575e-06
		Eccentricity	0.003129686615136648
		Inclination		12.62525963586724
		AscendingNode	353.59983007817436
		ArgOfPericen	165.4082629499211
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 485"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1545685083690212e-07
	Radius		46.54163376751438

	RotationPeriod	6.395935120839233

	Obliquity		200.3731639569602

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4051041546287824
		Eccentricity	0.042336830181843775
		Inclination		-0.33453146888172547
		AscendingNode	85.03627255428847
		ArgOfPericen	227.0462236464073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 486"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.524854148479093e-07
	Radius		46.10499604442041

	RotationPeriod	4.389205882615425

	Obliquity		249.82918332715948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.330138142656799
		Eccentricity	0.043459936687055827
		Inclination		-2.499441503259627
		AscendingNode	55.9223162825956
		ArgOfPericen	106.50940781861352
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 487"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.809061064190793e-08
	Radius		34.27455819808579

	RotationPeriod	3.4073494613152393

	Obliquity		223.86392248923838

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.217746100741729
		Eccentricity	0.0490201443661949
		Inclination		2.062590815108139
		AscendingNode	183.7378988926681
		ArgOfPericen	39.77018834009335
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 488"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.998998473214819e-07
	Radius		76.23179957734101

	RotationPeriod	3.9243841055309723

	Obliquity		341.23370908662866

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.366754180180013
		Eccentricity	0.0823356006269653
		Inclination		-0.8100658703734546
		AscendingNode	102.8745143410846
		ArgOfPericen	323.83690326017876
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 489"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.6760379032088966e-07
	Radius		58.38007113969103

	RotationPeriod	5.201028450849628

	Obliquity		66.72735651837955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.276914706583548
		Eccentricity	0.043812619632270525
		Inclination		0.9765387133039402
		AscendingNode	182.58527520041358
		ArgOfPericen	201.231634044008
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 490"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7105952162082762e-07
	Radius		44.54069857410272

	RotationPeriod	10.62114959024468

	Obliquity		82.60561104116023

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3041292690507227
		Eccentricity	0.07247233744728235
		Inclination		1.3963808183647073
		AscendingNode	82.44804637619885
		ArgOfPericen	79.76649500226999
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 491"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2036210465096704e-07
	Radius		36.97194664381138

	RotationPeriod	1.4116089268720033

	Obliquity		119.45872580354364

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2219072649931944
		Eccentricity	0.05746497854596107
		Inclination		-1.1785988041763744
		AscendingNode	182.34322242345885
		ArgOfPericen	62.38349222098802
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 492"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.423598453258393e-08
	Radius		20.05614613135618

	RotationPeriod	5.066924682264748

	Obliquity		205.2270857738418

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.373966873201305
		Eccentricity	0.029855751885461867
		Inclination		0.2928082236341563
		AscendingNode	312.423153734607
		ArgOfPericen	245.67365141515953
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 493"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.068059704786506e-07
	Radius		66.88977764435299

	RotationPeriod	5.79114050611262

	Obliquity		174.73315401288954

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3272175352654503
		Eccentricity	0.06481355590213984
		Inclination		-0.2720245698067365
		AscendingNode	283.36454432494725
		ArgOfPericen	135.297300403882
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 494"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.331768717361064
		Eccentricity	0.055461563826496245
		Inclination		-0.8064057222996147
		AscendingNode	64.39839813613564
		ArgOfPericen	76.82163130013696
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 494 A"
{
	ParentBody	"Erebos 494"
	Class		"Asteroid"
	Mass		1.0075618399089452e-06
	Radius		80.08133482577759

	Orbit
	{
		Epoch			2457395.5
		Period			0.008022212712979895
		Eccentricity	0.003001932457381199
		Inclination		206.72725833197185
		AscendingNode	320.64988121197297
		ArgOfPericen	283.72040455483017
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 494 B"
{
	ParentBody	"Erebos 494"
	Class		"Asteroid"
	Mass		1.8393425525525185e-07
	Radius		45.42848698079077

	Orbit
	{
		Epoch			2457395.5
		Period			0.008022212712979895
		Eccentricity	0.003001932457381199
		Inclination		206.72725833197185
		AscendingNode	320.64988121197297
		ArgOfPericen	103.72040455483017
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 495"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.193205696708255e-07
	Radius		48.038537473138426

	RotationPeriod	4.981934836418993

	Obliquity		70.22945687548746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2746511848159896
		Eccentricity	0.07425700319573225
		Inclination		-0.32563750221902343
		AscendingNode	194.44490129502225
		ArgOfPericen	279.27415604947174
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 496"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3058186453931705e-07
	Radius		47.80702907182742

	RotationPeriod	5.987805538329326

	Obliquity		83.85410569508079

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2650572806461673
		Eccentricity	0.058865409499881866
		Inclination		1.5319484849568634
		AscendingNode	164.09608201395346
		ArgOfPericen	226.99604889251668
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 497"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.348779615882507e-07
	Radius		69.39150370129481

	RotationPeriod	4.398022824839607

	Obliquity		157.09696978895084

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3455539357088764
		Eccentricity	0.03537437847668444
		Inclination		0.9636411100493671
		AscendingNode	196.98284306218216
		ArgOfPericen	171.181868178748
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 498"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1959728287230386e-07
	Radius		36.66505973459796

	RotationPeriod	9.66172716934884

	Obliquity		141.1459113755438

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3636433618204
		Eccentricity	0.047441500602469995
		Inclination		-0.05936326401844365
		AscendingNode	138.0962152982621
		ArgOfPericen	308.34008401259615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 499"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.668910333710246e-07
	Radius		41.57955459522925

	RotationPeriod	4.18053009791283

	Obliquity		217.31992052044936

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2939298833254687
		Eccentricity	0.032411022274056706
		Inclination		0.29067175463353173
		AscendingNode	179.7041137954656
		ArgOfPericen	240.4713999201057
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 500"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2023058539362085e-07
	Radius		45.02460392196993

	RotationPeriod	7.736213625272105

	Obliquity		67.81998239484749

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.350796720253645
		Eccentricity	0.033780900730096396
		Inclination		-2.393212934823702
		AscendingNode	112.8092871800319
		ArgOfPericen	274.4402099932549
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 501"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.790053677678176e-07
	Radius		42.27860098249552

	RotationPeriod	4.979641523885495

	Obliquity		303.90341968283997

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3074078095348813
		Eccentricity	0.04879333162837974
		Inclination		-1.288625746481588
		AscendingNode	218.77612929699663
		ArgOfPericen	75.96068469613162
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 502"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0905142166974974e-07
	Radius		38.08190680744734

	RotationPeriod	4.085064097433831

	Obliquity		222.5171579477463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2590315564186216
		Eccentricity	0.08217663701414996
		Inclination		-4.020647966660758
		AscendingNode	244.69638805321375
		ArgOfPericen	89.74617039725956
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 503"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.344602498707807e-07
	Radius		61.80627408535372

	RotationPeriod	6.847120747814564

	Obliquity		68.34506865539507

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.311712842281678
		Eccentricity	0.059426556154359926
		Inclination		-1.0292015773949577
		AscendingNode	84.23767433671787
		ArgOfPericen	4.306992481089904
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 503.1"
{
	ParentBody	"Erebos 503"
	Class		"Asteroid"
	Mass		2.9301492848015808e-09
	Radius		10.898264461289163

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.611557834980553e-06
		Eccentricity	0.005703513660081394
		Inclination		-4.153626628455266
		AscendingNode	231.4316685361335
		ArgOfPericen	87.6014022951427
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 504"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7187496179052737e-07
	Radius		44.24318012495389

	RotationPeriod	7.748847621276004

	Obliquity		260.97753946237907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.32778035253676
		Eccentricity	0.054005719476886385
		Inclination		-2.9875435400027546
		AscendingNode	263.1372686968536
		ArgOfPericen	203.5207933723598
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 505"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.780045692544157e-07
	Radius		43.04301550306393

	RotationPeriod	4.043208296703011

	Obliquity		122.60145840501002

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2936894763496873
		Eccentricity	0.055630502098644015
		Inclination		0.053549227469256215
		AscendingNode	114.1259353695961
		ArgOfPericen	127.72082709961846
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 506"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.343556189078317e-08
	Radius		34.59661932579466

	RotationPeriod	5.651711581439494

	Obliquity		185.24606382919907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3147671608294167
		Eccentricity	0.05128836087819296
		Inclination		-0.6701253437061543
		AscendingNode	104.57178929262787
		ArgOfPericen	299.815534652623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 507"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0930353520519364e-07
	Radius		47.271346262045874

	RotationPeriod	5.0407710197047075

	Obliquity		294.0411291662263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2233159427255087
		Eccentricity	0.06349334486320256
		Inclination		0.7821109240746945
		AscendingNode	227.50546593188298
		ArgOfPericen	353.8435038875915
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 508"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.019280972434343e-07
	Radius		67.56230360494523

	RotationPeriod	7.156677896733235

	Obliquity		23.272787965716656

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3151080471297414
		Eccentricity	0.058112819394493594
		Inclination		-1.5519323655165869
		AscendingNode	92.02258656237018
		ArgOfPericen	344.345190630731
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 508.1"
{
	ParentBody	"Erebos 508"
	Class		"Asteroid"
	Mass		2.7319469632262824e-10
	Radius		5.19214722014635

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4000598619399617e-06
		Eccentricity	0.0038985111444220684
		Inclination		19.751575824911768
		AscendingNode	175.28870187242
		ArgOfPericen	27.53668837166093
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 508.2"
{
	ParentBody	"Erebos 508"
	Class		"Asteroid"
	Mass		4.475846370211268e-09
	Radius		13.18705954640927

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.2139425801600656e-06
		Eccentricity	0.002934363760204154
		Inclination		-4.192860197121228
		AscendingNode	18.85296298445478
		ArgOfPericen	113.45314234863297
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 508.3"
{
	ParentBody	"Erebos 508"
	Class		"Asteroid"
	Mass		5.697262216349882e-09
	Radius		14.291516430069283

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.551802248105747e-06
		Eccentricity	0.006138627718661511
		Inclination		-8.595730088531605
		AscendingNode	97.92960092499212
		ArgOfPericen	130.06512704956276
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 509"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.607696315343769e-07
	Radius		70.72478666451595

	RotationPeriod	5.441755374579731

	Obliquity		245.2087277255824

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.319760833196914
		Eccentricity	0.06250506981732697
		Inclination		0.3289735997788642
		AscendingNode	69.77303021760768
		ArgOfPericen	166.5581137718991
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 510"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.42568934313281e-07
	Radius		64.89115022970572

	RotationPeriod	6.345757045011526

	Obliquity		300.4387943606672

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2939601145330233
		Eccentricity	0.0596102008264323
		Inclination		-0.5223726569919119
		AscendingNode	238.0458761294241
		ArgOfPericen	261.366607898425
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 510.1"
{
	ParentBody	"Erebos 510"
	Class		"Asteroid"
	Mass		1.6511324476094973e-10
	Radius		4.364767702707525

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.59595536711129e-06
		Eccentricity	0.008375511705582421
		Inclination		16.485157264286777
		AscendingNode	106.42377526201142
		ArgOfPericen	146.76250674617796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 511"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.091579201467695e-07
	Radius		68.89224972308425

	RotationPeriod	5.511371593822294

	Obliquity		100.15293751977993

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3092281058672572
		Eccentricity	0.04769997796260055
		Inclination		-0.39483449801866216
		AscendingNode	167.83389581239916
		ArgOfPericen	38.195857697343655
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 512"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.264314134542936e-07
	Radius		61.01194507052704

	RotationPeriod	5.994566742374879

	Obliquity		256.03070960381433

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3785409191325417
		Eccentricity	0.0598662331866584
		Inclination		4.286956668129816
		AscendingNode	358.5915037529487
		ArgOfPericen	285.0096986054626
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 512.1"
{
	ParentBody	"Erebos 512"
	Class		"Asteroid"
	Mass		2.7918934597846333e-09
	Radius		10.639810313816394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.795668714655292e-06
		Eccentricity	0.0061766573117841474
		Inclination		-1.856855302084781
		AscendingNode	316.3582721455577
		ArgOfPericen	50.313983681005006
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 513"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9399129525394987e-07
	Radius		48.055658092807576

	RotationPeriod	7.4240620669503326

	Obliquity		22.123814223584006

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.266436069503587
		Eccentricity	0.058729817883246785
		Inclination		2.508328798380302
		AscendingNode	226.83163170091845
		ArgOfPericen	183.62331275036001
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 514"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.554561009534339e-08
	Radius		31.32921258301693

	RotationPeriod	4.091216496669427

	Obliquity		254.6239833412762

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3274766863181924
		Eccentricity	0.06343264371717335
		Inclination		-2.6242553893698797
		AscendingNode	240.11714049053472
		ArgOfPericen	233.45211873476674
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 515"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.819311430890008e-07
	Radius		59.33950805242063

	RotationPeriod	7.777321284373084

	Obliquity		359.0312788490017

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3042542363528087
		Eccentricity	0.06039824069332468
		Inclination		0.540873849641271
		AscendingNode	171.97594326388344
		ArgOfPericen	198.11704340609083
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 516"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.450981074795378e-07
	Radius		70.41020398179813

	RotationPeriod	7.180028276644409

	Obliquity		233.97547520413488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.296374326812398
		Eccentricity	0.06592317961021192
		Inclination		2.78279464157353
		AscendingNode	33.74117625756477
		ArgOfPericen	1.3900508598904526
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 517"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2847942093857774
		Eccentricity	0.03254666253185494
		Inclination		0.2260006567692188
		AscendingNode	98.2082802395768
		ArgOfPericen	106.9104698533805
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 517 A"
{
	ParentBody	"Erebos 517"
	Class		"Asteroid"
	Mass		3.8831740104165255e-07
	Radius		58.2107497268674

	Orbit
	{
		Epoch			2457395.5
		Period			0.007067423274181324
		Eccentricity	0.004207249202276566
		Inclination		264.77068319792784
		AscendingNode	298.71232699178944
		ArgOfPericen	235.15094174441796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 517 B"
{
	ParentBody	"Erebos 517"
	Class		"Asteroid"
	Mass		1.0598708003051966e-07
	Radius		37.75941157660008

	Orbit
	{
		Epoch			2457395.5
		Period			0.007067423274181324
		Eccentricity	0.004207249202276566
		Inclination		264.77068319792784
		AscendingNode	298.71232699178944
		ArgOfPericen	55.15094174441799
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 518"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.158827525368519e-07
	Radius		36.855031882074655

	RotationPeriod	7.054866525170965

	Obliquity		316.8608913823904

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.340567330586067
		Eccentricity	0.045179093499048334
		Inclination		1.6096001263473223
		AscendingNode	299.7072399294498
		ArgOfPericen	339.33483265121714
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 518.1"
{
	ParentBody	"Erebos 518"
	Class		"Asteroid"
	Mass		7.340189096155666e-10
	Radius		6.819087657155235

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9314154650767968e-06
		Eccentricity	0.0030917828508214185
		Inclination		26.5772633051637
		AscendingNode	42.00050795312665
		ArgOfPericen	293.80906380023055
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 519"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.900167183833424e-08
	Radius		27.189255319300024

	RotationPeriod	7.585568260773765

	Obliquity		130.59385141364996

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.340142860586118
		Eccentricity	0.05522149880704894
		Inclination		-0.734152295362566
		AscendingNode	204.99204749748773
		ArgOfPericen	250.67997801426063
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 520"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9551600195483064e-07
	Radius		49.653171196052924

	RotationPeriod	5.7382827710496755

	Obliquity		181.05065420954054

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2385410699674577
		Eccentricity	0.07068146059984876
		Inclination		-1.0742111324641872
		AscendingNode	92.25686730930713
		ArgOfPericen	104.10280980965476
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 520.1"
{
	ParentBody	"Erebos 520"
	Class		"Asteroid"
	Mass		9.959464769284688e-10
	Radius		7.444439242934445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.11361402558365e-06
		Eccentricity	0.001178197978941445
		Inclination		12.585607144576532
		AscendingNode	268.5167764198177
		ArgOfPericen	111.93469646271731
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 520.2"
{
	ParentBody	"Erebos 520"
	Class		"Asteroid"
	Mass		2.4517501475875593e-10
	Radius		4.665648962951863

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.728328721668413e-06
		Eccentricity	0.004921956646949473
		Inclination		5.881729813042403
		AscendingNode	343.7979402475513
		ArgOfPericen	256.6307325530439
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 520.3"
{
	ParentBody	"Erebos 520"
	Class		"Asteroid"
	Mass		2.2443459913462129e-10
	Radius		4.530191834893456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3899927446500808e-06
		Eccentricity	0.004055914009617845
		Inclination		-20.468913602638985
		AscendingNode	60.31599602081712
		ArgOfPericen	129.9898006605559
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 521"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.931601830075795e-07
	Radius		69.10881803368325

	RotationPeriod	5.009440634274845

	Obliquity		321.64061894281986

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3332543212691492
		Eccentricity	0.052859581976319105
		Inclination		0.17142898849862845
		AscendingNode	73.48895414468947
		ArgOfPericen	354.86310270241916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 522"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3343455336949686
		Eccentricity	0.06095990411395859
		Inclination		2.475365903466509
		AscendingNode	119.39213844552656
		ArgOfPericen	269.48285857908235
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 522 A"
{
	ParentBody	"Erebos 522"
	Class		"Asteroid"
	Mass		9.892219204932962e-08
	Radius		36.30780662404144

	Orbit
	{
		Epoch			2457395.5
		Period			0.006004765670538302
		Eccentricity	0.00454475346567982
		Inclination		278.5945220393878
		AscendingNode	244.33231155946845
		ArgOfPericen	355.8124328353503
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 522 B"
{
	ParentBody	"Erebos 522"
	Class		"Asteroid"
	Mass		8.733923788386809e-08
	Radius		34.83147794710901

	Orbit
	{
		Epoch			2457395.5
		Period			0.006004765670538302
		Eccentricity	0.00454475346567982
		Inclination		278.5945220393878
		AscendingNode	244.33231155946845
		ArgOfPericen	175.81243283535036
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 523"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1383229372828407e-07
	Radius		45.05380844820282

	RotationPeriod	8.5083819585078

	Obliquity		245.562924472359

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3435241145624577
		Eccentricity	0.028692383256014857
		Inclination		0.544884347757229
		AscendingNode	46.073036558874406
		ArgOfPericen	70.4704231652509
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 524"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.632586611430358e-07
	Radius		75.05330955080214

	RotationPeriod	10.735928478247503

	Obliquity		185.8936370295584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3047877466670146
		Eccentricity	0.0397268288289202
		Inclination		-0.35566945997918475
		AscendingNode	138.9185483891295
		ArgOfPericen	296.8775248479406
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 525"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3265118926788503e-07
	Radius		39.90842191551911

	RotationPeriod	5.649631969406768

	Obliquity		138.87831411489643

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.264874601233274
		Eccentricity	0.056488998045817355
		Inclination		1.327383514707971
		AscendingNode	267.1777290164514
		ArgOfPericen	127.63612053467381
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 525.1"
{
	ParentBody	"Erebos 525"
	Class		"Asteroid"
	Mass		2.4902531344294362e-11
	Radius		2.2851182078547145

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2665476626550298e-06
		Eccentricity	0.005532596402165247
		Inclination		-3.213632359710652
		AscendingNode	332.3500174667725
		ArgOfPericen	251.4151804928587
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 526"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3297439622271603
		Eccentricity	0.057712412757547724
		Inclination		-2.7991608676305852
		AscendingNode	39.52320003552951
		ArgOfPericen	318.3573082548657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 526 A"
{
	ParentBody	"Erebos 526"
	Class		"Asteroid"
	Mass		2.1282916999589283e-07
	Radius		46.11601931789585

	Orbit
	{
		Epoch			2457395.5
		Period			0.005143723920614801
		Eccentricity	0.00201780659853376
		Inclination		140.79215181845638
		AscendingNode	347.08882172353736
		ArgOfPericen	69.32087941162933
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 526 B"
{
	ParentBody	"Erebos 526"
	Class		"Asteroid"
	Mass		2.427879948997034e-08
	Radius		22.365768814550556

	Orbit
	{
		Epoch			2457395.5
		Period			0.005143723920614801
		Eccentricity	0.00201780659853376
		Inclination		140.79215181845638
		AscendingNode	347.08882172353736
		ArgOfPericen	249.32087941162933
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 527"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.185646940166966e-08
	Radius		34.21483137613741

	RotationPeriod	7.623139646793423

	Obliquity		162.55628809501872

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.237597301789272
		Eccentricity	0.06614312569826114
		Inclination		1.1163151581287278
		AscendingNode	157.7067373283955
		ArgOfPericen	341.55738378268853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 528"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.325525073055157
		Eccentricity	0.04941631606694377
		Inclination		1.43844536761417
		AscendingNode	192.66012113470808
		ArgOfPericen	318.58411136697646
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 528 A"
{
	ParentBody	"Erebos 528"
	Class		"Asteroid"
	Mass		9.098641202319421e-08
	Radius		36.39040280882324

	Orbit
	{
		Epoch			2457395.5
		Period			0.006669644053342617
		Eccentricity	0.00884614795392933
		Inclination		236.5735176527809
		AscendingNode	250.92294174332363
		ArgOfPericen	102.61197233193685
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 528 B"
{
	ParentBody	"Erebos 528"
	Class		"Asteroid"
	Mass		3.356051831393157e-08
	Radius		26.097820291140074

	Orbit
	{
		Epoch			2457395.5
		Period			0.006669644053342617
		Eccentricity	0.00884614795392933
		Inclination		236.5735176527809
		AscendingNode	250.92294174332363
		ArgOfPericen	282.61197233193684
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 529"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1262298641064384e-07
	Radius		39.01492508114818

	RotationPeriod	3.4407268310392793

	Obliquity		34.350464496982454

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.283697297278074
		Eccentricity	0.05495120571675577
		Inclination		-0.6019213961631084
		AscendingNode	113.65359907207375
		ArgOfPericen	349.7169241713947
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 530"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5545703788705167e-08
	Radius		23.465915691241072

	RotationPeriod	6.676673381711704

	Obliquity		54.00098426354975

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.356231219548865
		Eccentricity	0.0435736511064265
		Inclination		2.6451961223118987
		AscendingNode	38.8835801538515
		ArgOfPericen	157.6166965763957
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 531"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.0125208865994235e-07
	Radius		59.979124058777714

	RotationPeriod	6.04131036584025

	Obliquity		273.47142116147967

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2223730115547204
		Eccentricity	0.046777857789915486
		Inclination		0.16660969302480022
		AscendingNode	107.5466863862705
		ArgOfPericen	69.09883597047265
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 532"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.697050061735452e-07
	Radius		61.61113540246485

	RotationPeriod	8.666998983030334

	Obliquity		117.05350068253412

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3477692861927766
		Eccentricity	0.05949732526110364
		Inclination		1.6677084998780078
		AscendingNode	28.512862930244758
		ArgOfPericen	31.171248993657265
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 533"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.010625246577254e-07
	Radius		56.6404999513374

	RotationPeriod	7.276213102192315

	Obliquity		99.3719403510284

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2773797321549134
		Eccentricity	0.04573444013945728
		Inclination		-1.3190415336418846
		AscendingNode	254.5576911621612
		ArgOfPericen	279.5445873706419
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 534"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2723720580080538
		Eccentricity	0.06275229688520635
		Inclination		1.4770040968565943
		AscendingNode	184.5309147832143
		ArgOfPericen	76.2273572328311
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 534 A"
{
	ParentBody	"Erebos 534"
	Class		"Asteroid"
	Mass		2.2180266903317964e-07
	Radius		51.34990338171389

	Orbit
	{
		Epoch			2457395.5
		Period			0.007286632043641563
		Eccentricity	0.002013251695891137
		Inclination		285.3832889677446
		AscendingNode	79.06599517886802
		ArgOfPericen	339.0261244681653
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 534 B"
{
	ParentBody	"Erebos 534"
	Class		"Asteroid"
	Mass		1.825016740686001e-08
	Radius		22.33433327017604

	Orbit
	{
		Epoch			2457395.5
		Period			0.007286632043641563
		Eccentricity	0.002013251695891137
		Inclination		285.3832889677446
		AscendingNode	79.06599517886802
		ArgOfPericen	159.02612446816534
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 535"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.4198869549269596e-07
	Radius		57.83748747667039

	RotationPeriod	9.74834292661319

	Obliquity		327.5852333223915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3259048031551077
		Eccentricity	0.060334634373259234
		Inclination		-2.101398710397194
		AscendingNode	245.8694642887417
		ArgOfPericen	58.47914865116431
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 536"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.175553983668345e-07
	Radius		69.3957247512123

	RotationPeriod	4.070524822890015

	Obliquity		266.3730330116711

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3597027631175242
		Eccentricity	0.032294578915164476
		Inclination		-0.5856088107727517
		AscendingNode	201.22844188100788
		ArgOfPericen	76.10308128831996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 537"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3011876670338607
		Eccentricity	0.03568139167733063
		Inclination		-3.261422874150587
		AscendingNode	50.06178521839737
		ArgOfPericen	292.18209607781927
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 537 A"
{
	ParentBody	"Erebos 537"
	Class		"Asteroid"
	Mass		4.2374966042422237e-07
	Radius		57.04096195780406

	Orbit
	{
		Epoch			2457395.5
		Period			0.001423871524659389
		Eccentricity	0.0050716848389797025
		Inclination		8.478672656917112
		AscendingNode	138.25096096050655
		ArgOfPericen	135.84124150310407
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 537 B"
{
	ParentBody	"Erebos 537"
	Class		"Asteroid"
	Mass		5.221433289707717e-08
	Radius		28.384437871989736

	Orbit
	{
		Epoch			2457395.5
		Period			0.001423871524659389
		Eccentricity	0.0050716848389797025
		Inclination		8.478672656917112
		AscendingNode	138.25096096050655
		ArgOfPericen	315.8412415031041
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 538"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.586203366310361e-07
	Radius		50.846478250568104

	RotationPeriod	7.213333239488792

	Obliquity		54.11100879259291

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3300979127555634
		Eccentricity	0.06547829979209942
		Inclination		-1.5855120653697812
		AscendingNode	226.3948905570372
		ArgOfPericen	262.3194533822061
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 539"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0303343998489458e-06
	Radius		80.11896567670038

	RotationPeriod	9.826099565272045

	Obliquity		181.4472536657545

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3281244898941824
		Eccentricity	0.05574406889610353
		Inclination		0.17776371355866638
		AscendingNode	72.44025243298762
		ArgOfPericen	328.79595212138116
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 540"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3905614269340774
		Eccentricity	0.08475667277607962
		Inclination		0.9358431786542243
		AscendingNode	43.417496490703094
		ArgOfPericen	250.45912688221284
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 540 A"
{
	ParentBody	"Erebos 540"
	Class		"Asteroid"
	Mass		5.159687579977349e-07
	Radius		65.24517048067453

	Orbit
	{
		Epoch			2457395.5
		Period			0.005610600836579996
		Eccentricity	0.004640373653650772
		Inclination		228.08932081459565
		AscendingNode	188.3616025579564
		ArgOfPericen	270.3228202563106
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 540 B"
{
	ParentBody	"Erebos 540"
	Class		"Asteroid"
	Mass		1.510264417337664e-08
	Radius		20.107507146974996

	Orbit
	{
		Epoch			2457395.5
		Period			0.005610600836579996
		Eccentricity	0.004640373653650772
		Inclination		228.08932081459565
		AscendingNode	188.3616025579564
		ArgOfPericen	90.32282025631059
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 541"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3545004537719074
		Eccentricity	0.029832305676687845
		Inclination		0.9303633429528739
		AscendingNode	77.62430687801194
		ArgOfPericen	135.64420216326965
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 541 A"
{
	ParentBody	"Erebos 541"
	Class		"Asteroid"
	Mass		3.524542583359562e-07
	Radius		52.550147660865015

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012347934313993647
		Eccentricity	0.0030488622523424875
		Inclination		51.3347418055392
		AscendingNode	317.32396351262156
		ArgOfPericen	239.59745999083805
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 541 B"
{
	ParentBody	"Erebos 541"
	Class		"Asteroid"
	Mass		1.659443600961752e-07
	Radius		40.88153419778325

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012347934313993647
		Eccentricity	0.0030488622523424875
		Inclination		51.3347418055392
		AscendingNode	317.32396351262156
		ArgOfPericen	59.59745999083805
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 542"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.542662409449784e-07
	Radius		61.83894901640717

	RotationPeriod	6.000516595872156

	Obliquity		155.86205375694814

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2931560944738414
		Eccentricity	0.05851289098712043
		Inclination		0.22176708254723182
		AscendingNode	271.2017160083275
		ArgOfPericen	248.607596998611
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 543"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.207757872330584e-07
	Radius		38.950932152507704

	RotationPeriod	2.865387494822066

	Obliquity		340.2627149097728

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.362038681655977
		Eccentricity	0.03895528538092506
		Inclination		-1.6327701293925587
		AscendingNode	117.05290107246233
		ArgOfPericen	298.71510943711263
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 544"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.063482212040212e-07
	Radius		62.91645023658631

	RotationPeriod	7.582320888651019

	Obliquity		218.2310885130488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286581059686072
		Eccentricity	0.05750854845069728
		Inclination		-0.6983636916098934
		AscendingNode	146.40072145382442
		ArgOfPericen	198.1823237769842
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 545"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8860197919634606e-07
	Radius		42.48834652484831

	RotationPeriod	6.134151216441495

	Obliquity		58.23088219950071

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2817178869680705
		Eccentricity	0.03056674023404774
		Inclination		1.8918629478955844
		AscendingNode	201.09459464667827
		ArgOfPericen	184.37607014412603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 545.1"
{
	ParentBody	"Erebos 545"
	Class		"Asteroid"
	Mass		6.785054579361491e-10
	Radius		6.510367886532257

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.397030019869428e-06
		Eccentricity	0.004556507380732172
		Inclination		-21.71000749251871
		AscendingNode	170.24470195220223
		ArgOfPericen	200.91125205338545
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 546"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.435751381485128e-07
	Radius		68.61699318357873

	RotationPeriod	5.462696868498131

	Obliquity		283.02506190181896

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.260294003914305
		Eccentricity	0.05623254586867485
		Inclination		-0.7665745272642865
		AscendingNode	184.3358261136337
		ArgOfPericen	271.4835229809855
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 547"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0164344850321795e-07
	Radius		36.52149075932842

	RotationPeriod	4.670270407584566

	Obliquity		174.2443669010063

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2544825186843784
		Eccentricity	0.047191218597068416
		Inclination		2.2504138792752473
		AscendingNode	68.9410585719551
		ArgOfPericen	65.88213647488311
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 548"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3051917667650526
		Eccentricity	0.05477617526586282
		Inclination		-0.9562768590518277
		AscendingNode	23.09255309681387
		ArgOfPericen	66.92622661233777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 548 A"
{
	ParentBody	"Erebos 548"
	Class		"Asteroid"
	Mass		1.4277881830053133e-07
	Radius		41.80045194466487

	Orbit
	{
		Epoch			2457395.5
		Period			0.007898846826235099
		Eccentricity	0.00849513666400401
		Inclination		77.58981073751795
		AscendingNode	31.063507405602117
		ArgOfPericen	160.3714294744867
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 548 B"
{
	ParentBody	"Erebos 548"
	Class		"Asteroid"
	Mass		9.533101444452025e-09
	Radius		16.957862952611983

	Orbit
	{
		Epoch			2457395.5
		Period			0.007898846826235099
		Eccentricity	0.00849513666400401
		Inclination		77.58981073751795
		AscendingNode	31.063507405602117
		ArgOfPericen	340.3714294744867
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 549"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2964603814945375
		Eccentricity	0.1
		Inclination		-1.8903419942782411
		AscendingNode	11.71783928359912
		ArgOfPericen	90.07280605163635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 549 A"
{
	ParentBody	"Erebos 549"
	Class		"Asteroid"
	Mass		1.5445077328736926e-08
	Radius		18.279953539243266

	Orbit
	{
		Epoch			2457395.5
		Period			0.005009810233970894
		Eccentricity	0.005268119373322335
		Inclination		144.7856756787862
		AscendingNode	286.0676147342718
		ArgOfPericen	97.2741322536032
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 549 B"
{
	ParentBody	"Erebos 549"
	Class		"Asteroid"
	Mass		2.5168543425705956e-09
	Radius		9.98460954274173

	Orbit
	{
		Epoch			2457395.5
		Period			0.005009810233970894
		Eccentricity	0.005268119373322335
		Inclination		144.7856756787862
		AscendingNode	286.0676147342718
		ArgOfPericen	277.27413225360317
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 550"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1051201160213416e-07
	Radius		44.244490002341976

	RotationPeriod	8.751198415496413

	Obliquity		165.74924851231842

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3311101305973603
		Eccentricity	0.04927655174910284
		Inclination		0.1846903466038522
		AscendingNode	160.52533074121473
		ArgOfPericen	15.381950672804603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 551"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.307319871445035e-07
	Radius		55.33501662072901

	RotationPeriod	7.535261415793573

	Obliquity		265.71040186615875

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.273968833456928
		Eccentricity	0.0779402636106848
		Inclination		3.8291889265656183
		AscendingNode	355.1184972574938
		ArgOfPericen	168.15385186453736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 551.1"
{
	ParentBody	"Erebos 551"
	Class		"Asteroid"
	Mass		2.4324274465904417e-10
	Radius		4.994836496386911

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.120474225579156e-06
		Eccentricity	0.00500444853514397
		Inclination		-27.28848148781414
		AscendingNode	227.08210556555994
		ArgOfPericen	317.67848914623926
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 552"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1384885145404274e-07
	Radius		40.31409159050016

	RotationPeriod	6.243901394021478

	Obliquity		228.71128737323005

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3159117869672903
		Eccentricity	0.04411601540735134
		Inclination		-1.4269267244058972
		AscendingNode	310.0822202638471
		ArgOfPericen	334.3372113979477
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 553"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1028409588131531e-07
	Radius		46.43312060492226

	RotationPeriod	5.9822399374372255

	Obliquity		174.4028269631236

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.393431690438025
		Eccentricity	0.027770847746722227
		Inclination		-1.2923440715040793
		AscendingNode	169.3632571285964
		ArgOfPericen	104.18049506632207
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 554"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3283208692923254
		Eccentricity	0.06899550979652702
		Inclination		0.46300214989191607
		AscendingNode	317.03755073865545
		ArgOfPericen	108.53909085517165
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 554 A"
{
	ParentBody	"Erebos 554"
	Class		"Asteroid"
	Mass		9.266074706815913e-07
	Radius		78.619736778701

	Orbit
	{
		Epoch			2457395.5
		Period			0.003656022075032695
		Eccentricity	0.005600038054078046
		Inclination		180.81664876892378
		AscendingNode	338.2853690897545
		ArgOfPericen	331.9428873837818
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 554 B"
{
	ParentBody	"Erebos 554"
	Class		"Asteroid"
	Mass		3.496814966591589e-07
	Radius		56.81424029397282

	Orbit
	{
		Epoch			2457395.5
		Period			0.003656022075032695
		Eccentricity	0.005600038054078046
		Inclination		180.81664876892378
		AscendingNode	338.2853690897545
		ArgOfPericen	151.9428873837818
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 555"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3817950688302017e-07
	Radius		42.56744068061261

	RotationPeriod	5.593205537710849

	Obliquity		285.09340760776087

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3665240287307907
		Eccentricity	0.0576282490762064
		Inclination		0.7962220079171083
		AscendingNode	171.51667041375316
		ArgOfPericen	62.74720292140128
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 555.1"
{
	ParentBody	"Erebos 555"
	Class		"Asteroid"
	Mass		1.0104450450274282e-09
	Radius		8.262292382052618

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.114407599303831e-06
		Eccentricity	0.006960419013544772
		Inclination		-44.82375517356729
		AscendingNode	87.58911730462977
		ArgOfPericen	309.0384953261629
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 556"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.834664941704306e-07
	Radius		74.6448891568209

	RotationPeriod	8.69974409298248

	Obliquity		349.3373350022854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3336790172485355
		Eccentricity	0.03669668539948993
		Inclination		-0.67854820300778
		AscendingNode	196.5549385205721
		ArgOfPericen	211.32686627362705
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 557"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.621400622724804e-07
	Radius		45.11333682626774

	RotationPeriod	7.399130891241469

	Obliquity		244.4774496263515

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1843210177746624
		Eccentricity	0.01679286004218443
		Inclination		-1.9136567366138428
		AscendingNode	84.12777185141236
		ArgOfPericen	336.3457952853298
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 558"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0395879493223767e-06
	Radius		73.40756072773085

	RotationPeriod	3.6115932283539105

	Obliquity		357.66412885382863

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2360583242755108
		Eccentricity	0.06639471499615725
		Inclination		-1.0250043321888702
		AscendingNode	111.53732576833848
		ArgOfPericen	158.0806040171447
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 559"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.306664143750463
		Eccentricity	0.009645315274092792
		Inclination		-2.222562669571434
		AscendingNode	90.7074252123218
		ArgOfPericen	164.50802453479875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 559 A"
{
	ParentBody	"Erebos 559"
	Class		"Asteroid"
	Mass		6.365873255352721e-07
	Radius		67.55033549804135

	Orbit
	{
		Epoch			2457395.5
		Period			0.005593531013283558
		Eccentricity	0.0047761226536457155
		Inclination		322.7682132050435
		AscendingNode	320.7121684610979
		ArgOfPericen	56.30625187984926
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 559 B"
{
	ParentBody	"Erebos 559"
	Class		"Asteroid"
	Mass		3.5923123107224713e-07
	Radius		55.82124819857467

	Orbit
	{
		Epoch			2457395.5
		Period			0.005593531013283558
		Eccentricity	0.0047761226536457155
		Inclination		322.7682132050435
		AscendingNode	320.7121684610979
		ArgOfPericen	236.30625187984927
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 560"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.203577537461243e-07
	Radius		70.08354892392163

	RotationPeriod	4.6408852214064495

	Obliquity		241.932795752611

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.315472656170706
		Eccentricity	0.03393030980337577
		Inclination		-0.7984414005938639
		AscendingNode	337.95321176893043
		ArgOfPericen	184.81371198317058
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 560.1"
{
	ParentBody	"Erebos 560"
	Class		"Asteroid"
	Mass		9.549136031584084e-09
	Radius		16.586498000788634

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.533943227241559e-06
		Eccentricity	0.005655971694460662
		Inclination		17.50783644482027
		AscendingNode	310.891022205076
		ArgOfPericen	276.0510683440575
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 561"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1305329687527568e-07
	Radius		44.996493691082065

	RotationPeriod	6.833909925310799

	Obliquity		78.14047361957532

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2879187408417554
		Eccentricity	0.02856266955367132
		Inclination		-0.03484338456079732
		AscendingNode	343.3829640325345
		ArgOfPericen	221.69772858313542
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 561.1"
{
	ParentBody	"Erebos 561"
	Class		"Asteroid"
	Mass		3.964127782790256e-10
	Radius		5.534331065725471

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.284232487564191e-06
		Eccentricity	0.0025752456414347056
		Inclination		24.07478780864976
		AscendingNode	356.29234934787405
		ArgOfPericen	102.0877369615629
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 562"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1322868622001882e-07
	Radius		39.64236078786255

	RotationPeriod	4.748214058180523

	Obliquity		140.26590632277828

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3084722612372746
		Eccentricity	0.05046788937443067
		Inclination		-2.8965283038594394
		AscendingNode	223.16409691539351
		ArgOfPericen	320.85918417029166
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 562.1"
{
	ParentBody	"Erebos 562"
	Class		"Asteroid"
	Mass		7.665054575464509e-10
	Radius		7.499156853445926

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.452702881693721e-06
		Eccentricity	0.006857634058633109
		Inclination		-11.929402102061923
		AscendingNode	192.52620521348766
		ArgOfPericen	286.2983919767118
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 563"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.527373908713865e-07
	Radius		78.53956410422889

	RotationPeriod	4.935490622578689

	Obliquity		167.76829611156447

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3827758653173827
		Eccentricity	0.04261568493373854
		Inclination		-0.6099766399782757
		AscendingNode	10.78364706842638
		ArgOfPericen	19.405078190934915
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 564"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.293057954224522e-07
	Radius		71.47969469646655

	RotationPeriod	6.887907166910034

	Obliquity		290.9471790309128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2772696812409823
		Eccentricity	0.03702158239324131
		Inclination		-1.8691629142085657
		AscendingNode	230.95649984956188
		ArgOfPericen	283.2749874718118
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 565"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.261121004126267
		Eccentricity	0.04531736050208603
		Inclination		-0.7222779240997131
		AscendingNode	73.10447946664621
		ArgOfPericen	331.98329945819563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 565 A"
{
	ParentBody	"Erebos 565"
	Class		"Asteroid"
	Mass		2.389844565460399e-07
	Radius		48.7575131477837

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014420104417959194
		Eccentricity	0.005813884488623393
		Inclination		313.0725368812968
		AscendingNode	151.72355455626408
		ArgOfPericen	72.47573212779464
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 565 B"
{
	ParentBody	"Erebos 565"
	Class		"Asteroid"
	Mass		1.005119049314696e-07
	Radius		36.53065809279194

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014420104417959194
		Eccentricity	0.005813884488623393
		Inclination		313.0725368812968
		AscendingNode	151.72355455626408
		ArgOfPericen	252.47573212779463
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 566"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.386222923163064e-07
	Radius		57.296476797742024

	RotationPeriod	5.126595057965439

	Obliquity		351.8308726081951

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2295771834712483
		Eccentricity	0.02178443999925473
		Inclination		0.019024865584794264
		AscendingNode	335.73772628406516
		ArgOfPericen	73.3691075195224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 567"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.945645598504781e-07
	Radius		63.77613201058726

	RotationPeriod	5.4374368069840475

	Obliquity		60.54063421971839

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.321074659134001
		Eccentricity	0.04921532384126513
		Inclination		-0.6980222135577928
		AscendingNode	128.53651647456402
		ArgOfPericen	254.49757362164658
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 567.1"
{
	ParentBody	"Erebos 567"
	Class		"Asteroid"
	Mass		4.220886019009e-09
	Radius		12.257250014370092

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4516513974415066e-06
		Eccentricity	0.004845533353235677
		Inclination		-5.595872220299775
		AscendingNode	251.49340305716913
		ArgOfPericen	168.53484292030222
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 568"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.765642636481232e-07
	Radius		70.02113246185317

	RotationPeriod	6.148320826369768

	Obliquity		335.53477593644124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.262107397314088
		Eccentricity	0.05106850789099635
		Inclination		0.8728482860952491
		AscendingNode	349.7684043495405
		ArgOfPericen	153.83712899523056
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 568.1"
{
	ParentBody	"Erebos 568"
	Class		"Asteroid"
	Mass		6.854103600599202e-09
	Radius		15.151059384723649

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.524876194820078e-07
		Eccentricity	0.005295197301321998
		Inclination		20.83226663427742
		AscendingNode	325.3031155319791
		ArgOfPericen	2.080957626248736
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 569"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.2064373743935244e-07
	Radius		51.334330518406844

	RotationPeriod	3.420233921807475

	Obliquity		249.398628781043

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3577079282296283
		Eccentricity	0.04462183592471938
		Inclination		0.9491803808644077
		AscendingNode	220.7229453318683
		ArgOfPericen	69.50013422970434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 570"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.685805028040987e-08
	Radius		34.99251997025349

	RotationPeriod	8.16916078436875

	Obliquity		189.0045533065321

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286494019940117
		Eccentricity	0.05684127176223136
		Inclination		-0.5014806601442726
		AscendingNode	171.0678972848254
		ArgOfPericen	33.45558030748729
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 571"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.01092306023235e-07
	Radius		52.94650629150275

	RotationPeriod	4.772992130658091

	Obliquity		19.884205344502732

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3408666507482776
		Eccentricity	0.07850046897041085
		Inclination		-3.2737434659762616
		AscendingNode	194.33207450950817
		ArgOfPericen	140.67534601918382
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 572"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1889871427218723e-07
	Radius		37.905030627597924

	RotationPeriod	6.992315612573778

	Obliquity		264.67937214426155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2716871282614552
		Eccentricity	0.03993653779050945
		Inclination		0.41264137891305686
		AscendingNode	6.01444622870146
		ArgOfPericen	312.3367556401629
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 573"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.370646585787674e-07
	Radius		64.22534152467111

	RotationPeriod	5.072871490869748

	Obliquity		48.16938594180909

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2484391627431006
		Eccentricity	0.046408017228713475
		Inclination		1.6933615307288024
		AscendingNode	28.269910337779145
		ArgOfPericen	123.92218376415526
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 574"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.720929257686523e-08
	Radius		29.602915649714916

	RotationPeriod	8.17260658431378

	Obliquity		325.38908289797087

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.269638617947128
		Eccentricity	0.056188097072726664
		Inclination		-1.257136152365719
		AscendingNode	92.23149139201314
		ArgOfPericen	245.44031462824898
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 575"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.409526319694399e-07
	Radius		50.709249975416704

	RotationPeriod	7.6499047230495325

	Obliquity		41.244704327428074

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3271874842037232
		Eccentricity	0.06253375683397372
		Inclination		2.9272676464596086
		AscendingNode	351.46307169658206
		ArgOfPericen	191.01088179214878
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 575.1"
{
	ParentBody	"Erebos 575"
	Class		"Asteroid"
	Mass		1.2484012351879457e-09
	Radius		8.774614096091263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.845359042852243e-07
		Eccentricity	0.005209022232772753
		Inclination		-74.9190975111554
		AscendingNode	242.4216248814842
		ArgOfPericen	160.21138107689745
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 576"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.431442727761735e-07
	Radius		72.81192044290447

	RotationPeriod	7.950077821463256

	Obliquity		104.20932399227169

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2812395692973184
		Eccentricity	0.05233841865675526
		Inclination		-2.6376832946241344
		AscendingNode	99.35684061153783
		ArgOfPericen	233.15873066514888
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 577"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.781411078835856e-07
	Radius		76.12420149771873

	RotationPeriod	5.987111154918026

	Obliquity		243.94530661705107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.385160892213194
		Eccentricity	0.08106772550057799
		Inclination		0.17641028662006095
		AscendingNode	149.72987025567622
		ArgOfPericen	117.83364891236141
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 578"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4340178257743338e-07
	Radius		45.32183670597097

	RotationPeriod	8.200964135099907

	Obliquity		69.12703474177457

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3271389753093916
		Eccentricity	0.027405976026496488
		Inclination		0.9617504605649512
		AscendingNode	134.26305873042094
		ArgOfPericen	164.31682175781236
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 579"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.758097616931485e-07
	Radius		58.76956329394591

	RotationPeriod	8.856454305580641

	Obliquity		280.64578243425836

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3289965969881434
		Eccentricity	0.04866571960098815
		Inclination		-0.9244405479919245
		AscendingNode	73.09923794928059
		ArgOfPericen	134.8022025140093
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 580"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.249345139350715e-07
	Radius		60.779897630782976

	RotationPeriod	6.746001439572617

	Obliquity		15.229922409668335

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.265127934489387
		Eccentricity	0.07467580673324609
		Inclination		1.8917743467770676
		AscendingNode	72.37565984511359
		ArgOfPericen	78.72843895584325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 580.1"
{
	ParentBody	"Erebos 580"
	Class		"Asteroid"
	Mass		4.56076752151882e-09
	Radius		12.495037580275412

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.919448536964658e-06
		Eccentricity	0.004338263687851021
		Inclination		53.254571979750914
		AscendingNode	357.8863300129789
		ArgOfPericen	268.7009096723361
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 581"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3278351956081003
		Eccentricity	0.020314609771261392
		Inclination		-2.6076437741131704
		AscendingNode	102.78918601625912
		ArgOfPericen	101.71807177315465
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 581 A"
{
	ParentBody	"Erebos 581"
	Class		"Asteroid"
	Mass		1.8732222940328427e-07
	Radius		42.69228319149728

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024334414229047656
		Eccentricity	0.005876236945371654
		Inclination		250.85360823751518
		AscendingNode	331.3586927388041
		ArgOfPericen	350.57953375764936
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 581 B"
{
	ParentBody	"Erebos 581"
	Class		"Asteroid"
	Mass		1.096969933506051e-08
	Radius		16.578727137155806

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024334414229047656
		Eccentricity	0.005876236945371654
		Inclination		250.85360823751518
		AscendingNode	331.3586927388041
		ArgOfPericen	170.57953375764941
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 582"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.412814233832099e-08
	Radius		34.75354872715977

	RotationPeriod	5.7215423289948975

	Obliquity		79.66686496638629

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2632134530441212
		Eccentricity	0.04608495505690616
		Inclination		-1.2830161162158802
		AscendingNode	112.48522129225758
		ArgOfPericen	306.76996383269744
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 583"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.461892468411642e-07
	Radius		40.05706007005048

	RotationPeriod	6.404617590584518

	Obliquity		317.10225748682575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3784052348642497
		Eccentricity	0.06021017239587498
		Inclination		-1.380226288951298
		AscendingNode	32.2848339107546
		ArgOfPericen	118.02717633949429
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 584"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1393399522719532e-07
	Radius		37.26986759306847

	RotationPeriod	6.577593041457103

	Obliquity		189.8310504351241

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.35853644155505
		Eccentricity	0.0424515419040789
		Inclination		1.2188625045772201
		AscendingNode	244.6684808438846
		ArgOfPericen	265.68287269824873
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 585"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.707302043708681e-08
	Radius		34.71837852952907

	RotationPeriod	6.371406242005877

	Obliquity		319.07401174041945

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1974230609645233
		Eccentricity	0.07561927318762615
		Inclination		2.716587850403856
		AscendingNode	326.2893495928058
		ArgOfPericen	327.13093330010247
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 586"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0099113620109736e-07
	Radius		33.20863143692749

	RotationPeriod	5.787227647454257

	Obliquity		130.46013403604698

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.243424691527865
		Eccentricity	0.04155275142902084
		Inclination		3.077545508908449
		AscendingNode	7.637086142351364
		ArgOfPericen	200.69375571972776
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 587"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9715621570780692e-07
	Radius		44.730689271274365

	RotationPeriod	5.168483843187201

	Obliquity		150.85977710706496

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2904181852294125
		Eccentricity	0.03416768109290161
		Inclination		-3.2558704174738207
		AscendingNode	299.0643989977725
		ArgOfPericen	277.2625960991316
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 587.1"
{
	ParentBody	"Erebos 587"
	Class		"Asteroid"
	Mass		2.2766627436359482e-10
	Radius		4.692831917689261

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3984606805876052e-06
		Eccentricity	0.004954661052478461
		Inclination		-23.066247205500662
		AscendingNode	243.8240842960376
		ArgOfPericen	218.6752827769072
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 588"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3521632317512626
		Eccentricity	0.04913047786245946
		Inclination		-0.6632880965198722
		AscendingNode	143.39785064346214
		ArgOfPericen	12.517813257840418
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 588 A"
{
	ParentBody	"Erebos 588"
	Class		"Asteroid"
	Mass		8.112691776964615e-09
	Radius		15.96475082728071

	Orbit
	{
		Epoch			2457395.5
		Period			0.00794423881188757
		Eccentricity	0.006579838827012826
		Inclination		73.40972345829321
		AscendingNode	280.88901441883974
		ArgOfPericen	335.1530964513856
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 588 B"
{
	ParentBody	"Erebos 588"
	Class		"Asteroid"
	Mass		7.191843603512133e-09
	Radius		15.33629889232146

	Orbit
	{
		Epoch			2457395.5
		Period			0.00794423881188757
		Eccentricity	0.006579838827012826
		Inclination		73.40972345829321
		AscendingNode	280.88901441883974
		ArgOfPericen	155.15309645138564
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 589"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.406876273095394
		Eccentricity	0.05482701857716105
		Inclination		-2.9640859043379613
		AscendingNode	251.17838150388812
		ArgOfPericen	92.71921731416516
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 589 A"
{
	ParentBody	"Erebos 589"
	Class		"Asteroid"
	Mass		9.986268887893748e-08
	Radius		36.01953098591915

	Orbit
	{
		Epoch			2457395.5
		Period			0.00479962630292063
		Eccentricity	0.0031280238025359537
		Inclination		104.12467042090324
		AscendingNode	146.8848873211487
		ArgOfPericen	331.8997764183428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 589 B"
{
	ParentBody	"Erebos 589"
	Class		"Asteroid"
	Mass		5.939838103510211e-09
	Radius		14.06031890101564

	Orbit
	{
		Epoch			2457395.5
		Period			0.00479962630292063
		Eccentricity	0.0031280238025359537
		Inclination		104.12467042090324
		AscendingNode	146.8848873211487
		ArgOfPericen	151.8997764183428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 590"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.195894339795918e-07
	Radius		51.299851571749464

	RotationPeriod	5.1353680829307855

	Obliquity		281.1363089816101

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.290937385339472
		Eccentricity	0.02818714817037432
		Inclination		-0.992328678608702
		AscendingNode	328.74852712381147
		ArgOfPericen	329.3750750195019
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 591"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.846241482083542e-07
	Radius		66.73960940647201

	RotationPeriod	5.095737337142819

	Obliquity		51.14312636723675

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.307230045566926
		Eccentricity	0.057159460339680494
		Inclination		-1.1313869842553756
		AscendingNode	352.564439581558
		ArgOfPericen	85.83567397570297
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 591.1"
{
	ParentBody	"Erebos 591"
	Class		"Asteroid"
	Mass		2.489588111438802e-09
	Radius		10.817674537500864

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.5645983995133626e-06
		Eccentricity	0.006664791409075494
		Inclination		-23.04687313092518
		AscendingNode	242.8904724077672
		ArgOfPericen	31.797575919140254
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 592"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2942668923041647
		Eccentricity	0.08675791159775649
		Inclination		-1.9671340648933016
		AscendingNode	7.084143528146134
		ArgOfPericen	345.46298331516783
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 592 A"
{
	ParentBody	"Erebos 592"
	Class		"Asteroid"
	Mass		8.037718515408328e-08
	Radius		31.630922391130905

	Orbit
	{
		Epoch			2457395.5
		Period			0.00303381862899127
		Eccentricity	0.004754948715078981
		Inclination		230.49517207794412
		AscendingNode	44.24222183946383
		ArgOfPericen	192.60773732275595
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 592 B"
{
	ParentBody	"Erebos 592"
	Class		"Asteroid"
	Mass		1.605103544564236e-08
	Radius		18.488511320751055

	Orbit
	{
		Epoch			2457395.5
		Period			0.00303381862899127
		Eccentricity	0.004754948715078981
		Inclination		230.49517207794412
		AscendingNode	44.24222183946383
		ArgOfPericen	12.607737322755952
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 593"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.205345587056286
		Eccentricity	0.0740686156819709
		Inclination		-0.14088220454022446
		AscendingNode	282.25090016496483
		ArgOfPericen	118.26698229916913
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 593 A"
{
	ParentBody	"Erebos 593"
	Class		"Asteroid"
	Mass		5.280902023760897e-08
	Radius		31.202722434690383

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024565104409483385
		Eccentricity	0.0056386662158648985
		Inclination		178.35362353544204
		AscendingNode	53.938669089516196
		ArgOfPericen	328.4774804647809
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 593 B"
{
	ParentBody	"Erebos 593"
	Class		"Asteroid"
	Mass		1.178388267571189e-08
	Radius		18.925727721509716

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024565104409483385
		Eccentricity	0.0056386662158648985
		Inclination		178.35362353544204
		AscendingNode	53.938669089516196
		ArgOfPericen	148.4774804647809
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 594"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9661484189027757e-07
	Radius		54.21255530350812

	RotationPeriod	8.830962194168048

	Obliquity		304.30053511930754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.314404957134411
		Eccentricity	0.04245152168147324
		Inclination		1.2521735762091428
		AscendingNode	159.90110720581396
		ArgOfPericen	164.13858259709306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 594.1"
{
	ParentBody	"Erebos 594"
	Class		"Asteroid"
	Mass		2.2640161810630993e-09
	Radius		10.674038401595887

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.204488382910594e-07
		Eccentricity	0.004674280922467945
		Inclination		15.034480216524948
		AscendingNode	2.00678653342778
		ArgOfPericen	306.74220801031925
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 595"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.445664806347389e-07
	Radius		41.038326042312974

	RotationPeriod	6.026561972408712

	Obliquity		286.92886792723675

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.276086852206908
		Eccentricity	0.04796843802535172
		Inclination		2.0891351216538396
		AscendingNode	19.10340993935167
		ArgOfPericen	290.14359631245134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 596"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.361449410990494e-07
	Radius		65.8647458849639

	RotationPeriod	7.7169441477879035

	Obliquity		234.97792016154347

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.346172942347455
		Eccentricity	0.030697514408078715
		Inclination		0.894512832644472
		AscendingNode	183.79416656288944
		ArgOfPericen	263.5288015529195
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 596.1"
{
	ParentBody	"Erebos 596"
	Class		"Asteroid"
	Mass		4.2298212753364724e-09
	Radius		12.385351421628188

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.853180904877382e-06
		Eccentricity	0.006563102025094182
		Inclination		-7.616679923913863
		AscendingNode	264.99845724657894
		ArgOfPericen	312.50051102964375
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 597"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.607473359635027e-07
	Radius		51.8518776298966

	RotationPeriod	6.3553472526218036

	Obliquity		110.35136940841477

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.276076896800002
		Eccentricity	0.09125287109277164
		Inclination		0.9798214976307279
		AscendingNode	271.58395403875284
		ArgOfPericen	322.01081039695504
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 598"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.067786871369415e-07
	Radius		75.23448123022436

	RotationPeriod	3.2602488053081413

	Obliquity		311.5056017713343

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2466194644629076
		Eccentricity	0.058196585463303
		Inclination		-1.1588908296488718
		AscendingNode	239.0126591997557
		ArgOfPericen	138.30341176092008
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 599"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.358709226919729
		Eccentricity	0.03588749047432019
		Inclination		1.2116055448661425
		AscendingNode	344.84302806592575
		ArgOfPericen	289.7951494026825
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 599 A"
{
	ParentBody	"Erebos 599"
	Class		"Asteroid"
	Mass		1.1893370915803124e-06
	Radius		77.71298057021619

	Orbit
	{
		Epoch			2457395.5
		Period			0.005231550926084874
		Eccentricity	0.005694416607345786
		Inclination		326.133320934886
		AscendingNode	24.277279015970457
		ArgOfPericen	323.83431549664397
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 599 B"
{
	ParentBody	"Erebos 599"
	Class		"Asteroid"
	Mass		1.149756639018161e-06
	Radius		76.84115549295676

	Orbit
	{
		Epoch			2457395.5
		Period			0.005231550926084874
		Eccentricity	0.005694416607345786
		Inclination		326.133320934886
		AscendingNode	24.277279015970457
		ArgOfPericen	143.83431549664397
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 600"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0783740819388923e-07
	Radius		39.2497658294069

	RotationPeriod	6.0500635991817155

	Obliquity		144.8466956077895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2640335818274666
		Eccentricity	0.061729375991656385
		Inclination		-3.1989817063718426
		AscendingNode	77.90893317300123
		ArgOfPericen	336.18791509909767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 600.1"
{
	ParentBody	"Erebos 600"
	Class		"Asteroid"
	Mass		1.6271194929602983e-09
	Radius		9.698853637441937

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.753160379354203e-06
		Eccentricity	0.00576527087202189
		Inclination		-70.79236764557699
		AscendingNode	315.55831699900597
		ArgOfPericen	49.848635247398306
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 601"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.589310893949675e-07
	Radius		53.18156166541793

	RotationPeriod	5.894195034213036

	Obliquity		140.0765945218297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.33898034859058
		Eccentricity	0.08459364584112468
		Inclination		3.636751482793436
		AscendingNode	270.9608808354596
		ArgOfPericen	350.2384762597502
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 602"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.711496235566567e-07
	Radius		67.9248720688919

	RotationPeriod	5.455060482087298

	Obliquity		264.16853319894534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.310988906570898
		Eccentricity	0.06173651493974902
		Inclination		-1.4856891059518105
		AscendingNode	212.22679570904447
		ArgOfPericen	335.3901418847886
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 603"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3557610421667223
		Eccentricity	0.009051309151328069
		Inclination		2.0090078326669185
		AscendingNode	46.16431282391904
		ArgOfPericen	297.23988321701944
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 603 A"
{
	ParentBody	"Erebos 603"
	Class		"Asteroid"
	Mass		1.6140893202748342e-07
	Radius		44.95717054089961

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029135108908698113
		Eccentricity	0.006579659874647863
		Inclination		329.72684511817454
		AscendingNode	201.12812612624717
		ArgOfPericen	188.5167085941156
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 603 B"
{
	ParentBody	"Erebos 603"
	Class		"Asteroid"
	Mass		3.754914558220919e-08
	Radius		27.64966043294422

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029135108908698113
		Eccentricity	0.006579659874647863
		Inclination		329.72684511817454
		AscendingNode	201.12812612624717
		ArgOfPericen	8.516708594115585
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 604"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.972992066380569e-07
	Radius		62.584632873938844

	RotationPeriod	4.617066925535833

	Obliquity		200.9331434837618

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3458152391230223
		Eccentricity	0.053251274873699565
		Inclination		0.36009458994358623
		AscendingNode	222.81914916863087
		ArgOfPericen	212.09906395129184
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 605"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.529308274437311e-08
	Radius		25.561236707842387

	RotationPeriod	3.8105121457321527

	Obliquity		283.08988717462887

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3131666013889185
		Eccentricity	0.07620562948098332
		Inclination		-1.2100212711240907
		AscendingNode	52.39340847563003
		ArgOfPericen	40.650020982752054
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 606"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.055897041806365e-08
	Radius		30.04057475677177

	RotationPeriod	8.186106170820512

	Obliquity		316.1556970489031

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.322446849722153
		Eccentricity	0.08105068040079462
		Inclination		-2.3959530902697916
		AscendingNode	298.044305495343
		ArgOfPericen	270.75671062431917
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 607"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.270190149857372
		Eccentricity	0.04379004270296516
		Inclination		-0.3740727792294054
		AscendingNode	250.02424665618886
		ArgOfPericen	324.93010808848044
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 607 A"
{
	ParentBody	"Erebos 607"
	Class		"Asteroid"
	Mass		6.114548902537368e-07
	Radius		69.33902391651543

	Orbit
	{
		Epoch			2457395.5
		Period			0.004306366405701333
		Eccentricity	0.0062137692932812015
		Inclination		189.28368869986448
		AscendingNode	250.6039860463456
		ArgOfPericen	146.34515817222353
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 607 B"
{
	ParentBody	"Erebos 607"
	Class		"Asteroid"
	Mass		1.9771963313209515e-07
	Radius		47.592609182115986

	Orbit
	{
		Epoch			2457395.5
		Period			0.004306366405701333
		Eccentricity	0.0062137692932812015
		Inclination		189.28368869986448
		AscendingNode	250.6039860463456
		ArgOfPericen	326.34515817222353
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 608"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.544912067568526e-07
	Radius		67.91487651458085

	RotationPeriod	7.673080828276795

	Obliquity		43.50592596993688

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2470708256201606
		Eccentricity	0.059074427278883214
		Inclination		2.5583516817774274
		AscendingNode	290.55646551727705
		ArgOfPericen	325.5277422423121
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 608.1"
{
	ParentBody	"Erebos 608"
	Class		"Asteroid"
	Mass		1.5459430531256859e-09
	Radius		9.044713347015808

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.409120718402386e-06
		Eccentricity	0.006592853576151007
		Inclination		38.450045421577535
		AscendingNode	154.56273326124858
		ArgOfPericen	169.00225488379184
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 609"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.9848593776645915e-07
	Radius		52.74514415366868

	RotationPeriod	3.1881320136059372

	Obliquity		251.22572015568156

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.318309120313258
		Eccentricity	0.045009014068818264
		Inclination		2.0524354606358712
		AscendingNode	76.05994180950094
		ArgOfPericen	201.75299145228948
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 610"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2926494173274394e-07
	Radius		49.99513965904068

	RotationPeriod	4.969257997286441

	Obliquity		62.312875995448806

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2519424530744985
		Eccentricity	0.05186653895031714
		Inclination		0.15425094306461187
		AscendingNode	141.16214363855394
		ArgOfPericen	322.19831861577194
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 611"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.993734272153697e-08
	Radius		31.60343937556714

	RotationPeriod	7.188107407321117

	Obliquity		79.94678098999219

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.436158023114927
		Eccentricity	0.048433493687426256
		Inclination		-0.6497474873789297
		AscendingNode	172.22741634556797
		ArgOfPericen	57.070286409344575
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 612"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.067261040777147e-07
	Radius		56.91614406019709

	RotationPeriod	8.738624752320204

	Obliquity		202.08494625063452

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2751835640177522
		Eccentricity	0.057752240436547156
		Inclination		0.3076713360514443
		AscendingNode	235.49199148307432
		ArgOfPericen	94.06911315918714
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 613"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.5333812126637924e-07
	Radius		53.83030751125108

	RotationPeriod	5.0839553102373305

	Obliquity		289.7010259691624

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.34398238811979
		Eccentricity	0.06830254123272883
		Inclination		0.8777076007406298
		AscendingNode	149.54985047225122
		ArgOfPericen	145.41040331603745
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 614"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1367747998557818e-06
	Radius		82.55910611485562

	RotationPeriod	6.250791983802721

	Obliquity		203.4315545093163

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.308539110289984
		Eccentricity	0.08220823763276025
		Inclination		-1.9042372381751338
		AscendingNode	311.2766395248803
		ArgOfPericen	223.12457488745034
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 615"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4189571306798845e-07
	Radius		47.131248742280796

	RotationPeriod	4.548809341125974

	Obliquity		314.67615242636003

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.29412049007653
		Eccentricity	0.03105534742063231
		Inclination		1.8685807484190864
		AscendingNode	37.29716678082097
		ArgOfPericen	290.84177793168413
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 615.1"
{
	ParentBody	"Erebos 615"
	Class		"Asteroid"
	Mass		3.2622456027916488e-09
	Radius		11.218594246299883

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.659357193301635e-06
		Eccentricity	0.0027047206154000706
		Inclination		-4.241302651025088
		AscendingNode	261.64468241956405
		ArgOfPericen	62.35311954630671
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 616"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.837773462268241e-07
	Radius		55.86198201209414

	RotationPeriod	7.676209949671578

	Obliquity		228.42662427498917

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3050433774231287
		Eccentricity	0.05441509948874895
		Inclination		-0.991272788628869
		AscendingNode	195.2832300157689
		ArgOfPericen	92.30910822666745
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 616.1"
{
	ParentBody	"Erebos 616"
	Class		"Asteroid"
	Mass		4.3371690430358955e-10
	Radius		5.81869167707516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.529517370397099e-06
		Eccentricity	0.007142943774294232
		Inclination		-4.041778017512039
		AscendingNode	306.6487759487752
		ArgOfPericen	5.155892730741649
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 617"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2968942511675032
		Eccentricity	0.06003481011781328
		Inclination		-0.8256204889597862
		AscendingNode	92.41481322827806
		ArgOfPericen	289.1470331260608
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 617 A"
{
	ParentBody	"Erebos 617"
	Class		"Asteroid"
	Mass		6.96289670481884e-08
	Radius		31.115419400944962

	Orbit
	{
		Epoch			2457395.5
		Period			0.006947483018364963
		Eccentricity	0.005884817003890513
		Inclination		103.64696355118008
		AscendingNode	170.7509706750691
		ArgOfPericen	25.48199695155969
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 617 B"
{
	ParentBody	"Erebos 617"
	Class		"Asteroid"
	Mass		5.865213996713756e-08
	Radius		29.385987923767562

	Orbit
	{
		Epoch			2457395.5
		Period			0.006947483018364963
		Eccentricity	0.005884817003890513
		Inclination		103.64696355118008
		AscendingNode	170.7509706750691
		ArgOfPericen	205.4819969515597
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 618"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.723491581977594e-07
	Radius		55.19885865445727

	RotationPeriod	7.006481177022271

	Obliquity		190.53177784081387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.253691207745706
		Eccentricity	0.07255401187915889
		Inclination		3.4411663611919847
		AscendingNode	295.7061057598634
		ArgOfPericen	8.96830603813671
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 619"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.775418321564474e-07
	Radius		55.98168511149446

	RotationPeriod	6.56970876166126

	Obliquity		11.799032468312438

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.201559775767664
		Eccentricity	0.03512498035932755
		Inclination		-5.0
		AscendingNode	216.64486989805258
		ArgOfPericen	210.7207370370245
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 619.1"
{
	ParentBody	"Erebos 619"
	Class		"Asteroid"
	Mass		2.3934303124462447e-10
	Radius		5.328562684329437

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.955299715980337e-06
		Eccentricity	0.007317365194708651
		Inclination		-5.327483545017738
		AscendingNode	32.432204176069334
		ArgOfPericen	344.01811625243243
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 620"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.348926096495779
		Eccentricity	0.06778823140556478
		Inclination		0.9849526442339109
		AscendingNode	249.27751457069576
		ArgOfPericen	28.167636029584475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 620 A"
{
	ParentBody	"Erebos 620"
	Class		"Asteroid"
	Mass		7.121462170612032e-07
	Radius		72.10847077243767

	Orbit
	{
		Epoch			2457395.5
		Period			0.007169633383690188
		Eccentricity	0.005235996686314144
		Inclination		258.8060120374489
		AscendingNode	334.4804356448059
		ArgOfPericen	117.08518031197046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 620 B"
{
	ParentBody	"Erebos 620"
	Class		"Asteroid"
	Mass		4.143761360529027e-08
	Radius		27.942256415488494

	Orbit
	{
		Epoch			2457395.5
		Period			0.007169633383690188
		Eccentricity	0.005235996686314144
		Inclination		258.8060120374489
		AscendingNode	334.4804356448059
		ArgOfPericen	297.0851803119705
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 621"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.150572026826674e-07
	Radius		53.715684226071204

	RotationPeriod	6.220415664729061

	Obliquity		144.9591284639806

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.370002631594535
		Eccentricity	0.05560427906116023
		Inclination		4.5558602183196
		AscendingNode	146.38587449673915
		ArgOfPericen	105.09424330963232
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 622"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.28777120862764
		Eccentricity	0.05431277954761707
		Inclination		1.4725628713627759
		AscendingNode	89.3532219057059
		ArgOfPericen	32.037487734518145
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 622 A"
{
	ParentBody	"Erebos 622"
	Class		"Asteroid"
	Mass		4.167733148930727e-08
	Radius		27.17077459912978

	Orbit
	{
		Epoch			2457395.5
		Period			0.005680350802150288
		Eccentricity	0.006687425037934305
		Inclination		299.3114838030978
		AscendingNode	117.7982144635465
		ArgOfPericen	106.52018729316693
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 622 B"
{
	ParentBody	"Erebos 622"
	Class		"Asteroid"
	Mass		1.4236011163428008e-09
	Radius		8.815862845029883

	Orbit
	{
		Epoch			2457395.5
		Period			0.005680350802150288
		Eccentricity	0.006687425037934305
		Inclination		299.3114838030978
		AscendingNode	117.7982144635465
		ArgOfPericen	286.52018729316694
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 623"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.328322799840234
		Eccentricity	0.04275654561380428
		Inclination		-0.2742098203648518
		AscendingNode	127.95167230278682
		ArgOfPericen	263.2366768804683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 623 A"
{
	ParentBody	"Erebos 623"
	Class		"Asteroid"
	Mass		1.5870688474857442e-07
	Radius		43.58355761635892

	Orbit
	{
		Epoch			2457395.5
		Period			0.007116543242201787
		Eccentricity	0.004758387782775416
		Inclination		267.93818349313347
		AscendingNode	16.064455884264902
		ArgOfPericen	341.2969142115143
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 623 B"
{
	ParentBody	"Erebos 623"
	Class		"Asteroid"
	Mass		4.990620262949013e-08
	Radius		29.63754756141991

	Orbit
	{
		Epoch			2457395.5
		Period			0.007116543242201787
		Eccentricity	0.004758387782775416
		Inclination		267.93818349313347
		AscendingNode	16.064455884264902
		ArgOfPericen	161.29691421151438
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 624"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.34767872426256e-08
	Radius		37.75337766332195

	RotationPeriod	6.134447083241853

	Obliquity		84.75110301749008

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3017602231393264
		Eccentricity	0.04402798835982598
		Inclination		1.7831891472930592
		AscendingNode	216.43379633507269
		ArgOfPericen	262.11966678190544
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 625"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.7543336472936924e-08
	Radius		30.93961084335343

	RotationPeriod	8.032031901654321

	Obliquity		85.29530717004292

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3502492927624385
		Eccentricity	0.04572274743185986
		Inclination		-2.222962410553452
		AscendingNode	357.51478447656996
		ArgOfPericen	191.70997772424982
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 626"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1334308869022442e-07
	Radius		45.7616120748154

	RotationPeriod	5.394703543513882

	Obliquity		178.60452634566394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.281314376796186
		Eccentricity	0.041927859513712744
		Inclination		2.4506129552727636
		AscendingNode	215.64619096850151
		ArgOfPericen	133.12439801845878
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 627"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.483502984323291e-07
	Radius		77.50506039192352

	RotationPeriod	8.80576133926028

	Obliquity		101.03840651406182

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.365104049488492
		Eccentricity	0.05216472445287927
		Inclination		-1.6747304992043155
		AscendingNode	18.853515972195737
		ArgOfPericen	206.89822443247877
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 628"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3798412518109337e-07
	Radius		49.2280006883966

	RotationPeriod	3.7150061709767432

	Obliquity		269.5320553860795

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.292930964876054
		Eccentricity	0.058899387644534805
		Inclination		1.933907279210857
		AscendingNode	280.936975276229
		ArgOfPericen	74.31278640330393
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 629"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.652853622725457e-07
	Radius		68.67463129728316

	RotationPeriod	3.561451898287327

	Obliquity		179.10310719088872

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.294359140022051
		Eccentricity	0.09232212794205331
		Inclination		1.5233469957894306
		AscendingNode	157.34326832238187
		ArgOfPericen	262.55821019612205
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 629.1"
{
	ParentBody	"Erebos 629"
	Class		"Asteroid"
	Mass		4.375150279204865e-09
	Radius		12.279655768713397

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.491241982722134e-07
		Eccentricity	0.009439032277052808
		Inclination		-25.896466033118845
		AscendingNode	324.66219406317117
		ArgOfPericen	209.1343702090079
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 630"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2327358448945325
		Eccentricity	0.04508010040203765
		Inclination		-0.29986762598615124
		AscendingNode	245.7956967302727
		ArgOfPericen	159.40411239522794
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 630 A"
{
	ParentBody	"Erebos 630"
	Class		"Asteroid"
	Mass		2.157669682965833e-07
	Radius		45.00581646593412

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006066050636324272
		Eccentricity	0.0028284999287951974
		Inclination		266.01552959721334
		AscendingNode	11.112905335819846
		ArgOfPericen	79.96958912708675
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 630 B"
{
	ParentBody	"Erebos 630"
	Class		"Asteroid"
	Mass		1.1821198726644226e-08
	Radius		17.09336230050579

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006066050636324272
		Eccentricity	0.0028284999287951974
		Inclination		266.01552959721334
		AscendingNode	11.112905335819846
		ArgOfPericen	259.96958912708675
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 631"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.760987681178941e-08
	Radius		37.4655759661432

	RotationPeriod	4.593617001713669

	Obliquity		293.82047427090276

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3600388645849555
		Eccentricity	0.017109071279834617
		Inclination		-0.5386602469440607
		AscendingNode	54.644599647641215
		ArgOfPericen	168.81186066333728
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 632"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0992598892778893e-08
	Radius		21.729499846590734

	RotationPeriod	5.512136289636774

	Obliquity		288.7019820908698

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.340403024474228
		Eccentricity	0.055575910806621096
		Inclination		-0.4201839337171223
		AscendingNode	185.18240656218762
		ArgOfPericen	205.44399186900984
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 633"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8072000868459315e-07
	Radius		46.13517907600476

	RotationPeriod	6.247492422541782

	Obliquity		116.43801900680907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.404092936500586
		Eccentricity	0.01982986407611239
		Inclination		-0.6081936936591419
		AscendingNode	154.1477253188584
		ArgOfPericen	278.69686627004177
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 634"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8677453613178583e-08
	Radius		21.029214038301873

	RotationPeriod	7.162995889708522

	Obliquity		157.24874197808856

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3190790042360576
		Eccentricity	0.07531444534239852
		Inclination		0.26233397527029095
		AscendingNode	129.7971009108982
		ArgOfPericen	189.29119784650393
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 635"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3164443420971548
		Eccentricity	0.01470778115523684
		Inclination		0.15065055738733546
		AscendingNode	132.692781835622
		ArgOfPericen	330.557375423995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 635 A"
{
	ParentBody	"Erebos 635"
	Class		"Asteroid"
	Mass		3.6057015163529596e-07
	Radius		52.75244620174977

	Orbit
	{
		Epoch			2457395.5
		Period			0.007126866430593711
		Eccentricity	0.005994804824274231
		Inclination		231.99221164818567
		AscendingNode	53.5681540138389
		ArgOfPericen	165.8258872130264
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 635 B"
{
	ParentBody	"Erebos 635"
	Class		"Asteroid"
	Mass		1.371114291676173e-08
	Radius		17.739330767176945

	Orbit
	{
		Epoch			2457395.5
		Period			0.007126866430593711
		Eccentricity	0.005994804824274231
		Inclination		231.99221164818567
		AscendingNode	53.5681540138389
		ArgOfPericen	345.82588721302636
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 636"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0797716967481883e-07
	Radius		46.83710512028492

	RotationPeriod	5.604282854037091

	Obliquity		349.4580186741622

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3457964938441407
		Eccentricity	0.03567214624077297
		Inclination		-1.675046669247106
		AscendingNode	285.51285873996414
		ArgOfPericen	3.1234564785248953
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 636.1"
{
	ParentBody	"Erebos 636"
	Class		"Asteroid"
	Mass		3.3719797603754175e-10
	Radius		5.5023280107329215

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2209463709907004e-06
		Eccentricity	0.0016023646937537808
		Inclination		6.811434805060771
		AscendingNode	105.13122249302681
		ArgOfPericen	204.41724283592018
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 637"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.847543806266657e-07
	Radius		64.7615764055632

	RotationPeriod	5.0177383931592905

	Obliquity		25.332623441275853

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3925566288427764
		Eccentricity	0.05842585668784966
		Inclination		2.0728120252147524
		AscendingNode	19.007991228303176
		ArgOfPericen	247.5986485420358
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 637.1"
{
	ParentBody	"Erebos 637"
	Class		"Asteroid"
	Mass		5.437295742661594e-09
	Radius		13.61822699319495

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.721825162843851e-06
		Eccentricity	0.007194888040929786
		Inclination		36.01526545527092
		AscendingNode	156.86761497769157
		ArgOfPericen	240.54527074266704
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 638"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0249072998387375e-07
	Radius		43.57716489394808

	RotationPeriod	7.497362253311653

	Obliquity		243.6641973032972

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2394796448833634
		Eccentricity	0.035910350640343834
		Inclination		-0.01432454611955975
		AscendingNode	226.6828969026974
		ArgOfPericen	0.6727392484261596
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 639"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5356630876777817e-08
	Radius		22.49756911945552

	RotationPeriod	6.751083164230873

	Obliquity		76.43743117989682

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2757269984586976
		Eccentricity	0.04761429499845225
		Inclination		-0.3224699904853929
		AscendingNode	223.2109720535056
		ArgOfPericen	202.78614608975565
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 640"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6741490429981093e-07
	Radius		42.22795945571367

	RotationPeriod	3.6101742850874676

	Obliquity		256.86022760225603

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.374851903113886
		Eccentricity	0.09781126846889152
		Inclination		0.9444875949516864
		AscendingNode	25.782224997050868
		ArgOfPericen	320.48507287739216
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 640.1"
{
	ParentBody	"Erebos 640"
	Class		"Asteroid"
	Mass		8.135157294427131e-10
	Radius		7.152491896307787

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5117667179872813e-07
		Eccentricity	0.004718624315269929
		Inclination		-0.6796291790851533
		AscendingNode	281.30510903232874
		ArgOfPericen	334.34849307433484
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 641"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.870839947703379e-07
	Radius		50.548342224578505

	RotationPeriod	5.955602533071683

	Obliquity		136.2881694788247

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2225968023377867
		Eccentricity	0.05092335016315147
		Inclination		2.196698509864432
		AscendingNode	130.92361270272568
		ArgOfPericen	278.096849293534
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 642"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.333174842070514
		Eccentricity	0.06570681090950417
		Inclination		-1.2803750295990626
		AscendingNode	8.749461981150777
		ArgOfPericen	330.76391485795875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 642 A"
{
	ParentBody	"Erebos 642"
	Class		"Asteroid"
	Mass		1.6615152150656128e-07
	Radius		39.08831587013744

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012241538925689733
		Eccentricity	0.0025845486486059605
		Inclination		258.7904619966244
		AscendingNode	263.2108793475862
		ArgOfPericen	286.6782622616966
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 642 B"
{
	ParentBody	"Erebos 642"
	Class		"Asteroid"
	Mass		1.015066320024049e-07
	Radius		33.16731567885847

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012241538925689733
		Eccentricity	0.0025845486486059605
		Inclination		258.7904619966244
		AscendingNode	263.2108793475862
		ArgOfPericen	106.6782622616966
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 643"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.319242302449777
		Eccentricity	0.056100777099078306
		Inclination		-2.8301171634816864
		AscendingNode	311.73561497293593
		ArgOfPericen	175.28556417071883
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 643 A"
{
	ParentBody	"Erebos 643"
	Class		"Asteroid"
	Mass		9.98641137649613e-07
	Radius		76.3422997654742

	Orbit
	{
		Epoch			2457395.5
		Period			0.002235700547459492
		Eccentricity	0.00695004182241464
		Inclination		93.30342046872961
		AscendingNode	47.06589873125728
		ArgOfPericen	133.76882876269678
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 643 B"
{
	ParentBody	"Erebos 643"
	Class		"Asteroid"
	Mass		2.0106366434510127e-07
	Radius		44.7445301798291

	Orbit
	{
		Epoch			2457395.5
		Period			0.002235700547459492
		Eccentricity	0.00695004182241464
		Inclination		93.30342046872961
		AscendingNode	47.06589873125728
		ArgOfPericen	313.7688287626968
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 644"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.203837963605516
		Eccentricity	0.02084774402829724
		Inclination		-1.2898514502307807
		AscendingNode	320.9238118286883
		ArgOfPericen	36.20552916218013
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 644 A"
{
	ParentBody	"Erebos 644"
	Class		"Asteroid"
	Mass		1.3851233980323262e-06
	Radius		89.98778939829677

	Orbit
	{
		Epoch			2457395.5
		Period			0.007695494515658084
		Eccentricity	0.0025025000247990378
		Inclination		108.55404463762497
		AscendingNode	15.879846369690483
		ArgOfPericen	263.9388331941825
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 644 B"
{
	ParentBody	"Erebos 644"
	Class		"Asteroid"
	Mass		3.2100439000877924e-08
	Radius		25.65612632639705

	Orbit
	{
		Epoch			2457395.5
		Period			0.007695494515658084
		Eccentricity	0.0025025000247990378
		Inclination		108.55404463762497
		AscendingNode	15.879846369690483
		ArgOfPericen	83.93883319418251
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 645"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.0569193810171523e-07
	Radius		58.52636155187152

	RotationPeriod	7.568191593933566

	Obliquity		92.92254631579097

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2891744419198754
		Eccentricity	0.07957899663622611
		Inclination		0.6930009561614402
		AscendingNode	155.21930962027307
		ArgOfPericen	332.113807052974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 646"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4159759720536267e-06
	Radius		82.89134404200067

	RotationPeriod	5.675168402933416

	Obliquity		201.75031840916628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.433146646642978
		Eccentricity	0.04925245978135838
		Inclination		0.18413529392029043
		AscendingNode	250.8064983696097
		ArgOfPericen	227.22017477479764
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 647"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.913777948914587e-08
	Radius		35.27604503861801

	RotationPeriod	5.890771675131598

	Obliquity		130.30024141568387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.291460906128461
		Eccentricity	0.08348686685455864
		Inclination		-1.389025664113498
		AscendingNode	310.821807670123
		ArgOfPericen	151.0768115188375
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 648"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3601646889178066e-07
	Radius		49.6699946321495

	RotationPeriod	7.330869359709891

	Obliquity		199.4496787072557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.281619141623346
		Eccentricity	0.06893264873804744
		Inclination		2.708680216890911
		AscendingNode	137.97500539463948
		ArgOfPericen	220.50923833166468
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 649"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.798071052486605e-07
	Radius		69.82802532927337

	RotationPeriod	5.263078238401783

	Obliquity		178.64266083720338

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3965628593833985
		Eccentricity	0.05771459378674816
		Inclination		-0.38433604113362785
		AscendingNode	9.641953792180246
		ArgOfPericen	38.402563431118026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 649.1"
{
	ParentBody	"Erebos 649"
	Class		"Asteroid"
	Mass		5.842811891449174e-09
	Radius		14.303483822559373

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.697312336504182e-06
		Eccentricity	0.005375334365258151
		Inclination		-18.577882131638177
		AscendingNode	6.033763731915265
		ArgOfPericen	102.62171722980473
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 649.2"
{
	ParentBody	"Erebos 649"
	Class		"Asteroid"
	Mass		9.397011442623019e-09
	Radius		16.758344458313648

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.251834272816216e-06
		Eccentricity	0.004117216580652924
		Inclination		-6.274421012062646
		AscendingNode	147.97458214974276
		ArgOfPericen	14.516445881579191
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 650"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3469229280675483
		Eccentricity	0.03486261304747644
		Inclination		-0.12986137415955415
		AscendingNode	346.49960632370374
		ArgOfPericen	354.6148220985772
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 650 A"
{
	ParentBody	"Erebos 650"
	Class		"Asteroid"
	Mass		9.409685132472276e-08
	Radius		37.29626658386887

	Orbit
	{
		Epoch			2457395.5
		Period			0.005931564063116653
		Eccentricity	0.005787597570056002
		Inclination		354.42416217664186
		AscendingNode	119.04943894256986
		ArgOfPericen	107.37309950385206
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 650 B"
{
	ParentBody	"Erebos 650"
	Class		"Asteroid"
	Mass		4.992026911728028e-08
	Radius		30.192515826890798

	Orbit
	{
		Epoch			2457395.5
		Period			0.005931564063116653
		Eccentricity	0.005787597570056002
		Inclination		354.42416217664186
		AscendingNode	119.04943894256986
		ArgOfPericen	287.3730995038521
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 651"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.502379444089371e-08
	Radius		32.28539158811891

	RotationPeriod	3.1520594633599432

	Obliquity		183.2904065859754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.258049575985214
		Eccentricity	0.07641251397469204
		Inclination		-1.2758637839209297
		AscendingNode	313.0934677739701
		ArgOfPericen	247.82227827342803
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 652"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.436293036481684e-07
	Radius		48.39001263229571

	RotationPeriod	3.7343985412766094

	Obliquity		34.25163768078014

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.350327538443486
		Eccentricity	0.061320633447063136
		Inclination		-2.0641333521172895
		AscendingNode	354.20146571846976
		ArgOfPericen	140.34658555784046
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 652.1"
{
	ParentBody	"Erebos 652"
	Class		"Asteroid"
	Mass		7.86351290190805e-10
	Radius		7.151296127457856

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.860235942868391e-06
		Eccentricity	0.005809787091929851
		Inclination		53.84734223148881
		AscendingNode	28.363263474988187
		ArgOfPericen	289.80513933216486
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 652.2"
{
	ParentBody	"Erebos 652"
	Class		"Asteroid"
	Mass		3.788281801342738e-09
	Radius		12.077952577522282

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9740805183709646e-06
		Eccentricity	0.0015762421932073584
		Inclination		-47.63112118227534
		AscendingNode	253.80051986947666
		ArgOfPericen	100.9873294175231
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 652.3"
{
	ParentBody	"Erebos 652"
	Class		"Asteroid"
	Mass		3.026679987056796e-09
	Radius		11.207310283476755

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.881527116241423e-06
		Eccentricity	0.008139445320941682
		Inclination		-2.0284231815567733
		AscendingNode	137.19274215646345
		ArgOfPericen	167.92729128967383
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 653"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1911710296135346e-08
	Radius		23.596709944262106

	RotationPeriod	10.391310359190255

	Obliquity		192.04291102225827

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3256689615588657
		Eccentricity	0.05710376871939443
		Inclination		1.217122122047744
		AscendingNode	218.82518945207767
		ArgOfPericen	289.5488218468541
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 653.1"
{
	ParentBody	"Erebos 653"
	Class		"Asteroid"
	Mass		2.4574656237692007e-10
	Radius		4.659763884412049

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.8496073750939427e-06
		Eccentricity	0.0029224148849011566
		Inclination		15.040144924850127
		AscendingNode	77.64868274613433
		ArgOfPericen	10.736607143276405
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 653.2"
{
	ParentBody	"Erebos 653"
	Class		"Asteroid"
	Mass		1.3537502076091928e-10
	Radius		3.8198614065557104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.009868907932817e-06
		Eccentricity	0.004298428586111034
		Inclination		38.57921397533647
		AscendingNode	13.110298603943967
		ArgOfPericen	56.77461092480246
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 654"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3815002291396147e-07
	Radius		47.99435758054236

	RotationPeriod	5.320798350631126

	Obliquity		41.67476875687379

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3447671812558055
		Eccentricity	0.05848705460319626
		Inclination		0.8831315273904824
		AscendingNode	140.26351304777688
		ArgOfPericen	36.270447418642135
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 655"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.4716289881777894e-07
	Radius		52.62816227122482

	RotationPeriod	9.251518431608819

	Obliquity		325.7720777828647

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3286380634384094
		Eccentricity	0.059148589945016386
		Inclination		-0.9587461815575573
		AscendingNode	92.11666355363695
		ArgOfPericen	320.52761275432255
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 656"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.358345630520804e-07
	Radius		65.13278126186813

	RotationPeriod	10.614993357414583

	Obliquity		218.45283485697055

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3353623752019157
		Eccentricity	0.04743685350760006
		Inclination		-0.8363323269554934
		AscendingNode	107.7868967066115
		ArgOfPericen	185.06018932893735
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 657"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.652603203862644e-08
	Radius		34.65203192839957

	RotationPeriod	6.920369535738384

	Obliquity		129.57996329806892

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2593773365844503
		Eccentricity	0.024976519579387194
		Inclination		2.14179901265199
		AscendingNode	151.25716952989515
		ArgOfPericen	67.81471939850495
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 658"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.040006216997389e-08
	Radius		22.296248282458425

	RotationPeriod	4.697143640308062

	Obliquity		207.7220401853317

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.343282554365214
		Eccentricity	0.03136313660840517
		Inclination		0.024583233598649463
		AscendingNode	328.7303320270921
		ArgOfPericen	345.24528481502597
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 659"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.237364396174011e-08
	Radius		31.90526393100732

	RotationPeriod	10.083453869355164

	Obliquity		224.51171425380784

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3272999505825713
		Eccentricity	0.01256376748365861
		Inclination		0.2117295040224997
		AscendingNode	312.48673331698933
		ArgOfPericen	259.5305100514761
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 659.1"
{
	ParentBody	"Erebos 659"
	Class		"Asteroid"
	Mass		4.4162676429229334e-10
	Radius		6.126518714017779

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7541257924175422e-06
		Eccentricity	0.006303174968365263
		Inclination		-22.10003489164133
		AscendingNode	84.00017066271639
		ArgOfPericen	70.28163169330111
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 660"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3107497968274573
		Eccentricity	0.06600970570941703
		Inclination		-2.2778314950749006
		AscendingNode	247.26572394394586
		ArgOfPericen	245.34697825616547
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 660 A"
{
	ParentBody	"Erebos 660"
	Class		"Asteroid"
	Mass		7.123048771069604e-08
	Radius		33.28827963261898

	Orbit
	{
		Epoch			2457395.5
		Period			0.002067390067878153
		Eccentricity	0.00606927088255523
		Inclination		313.6599180263476
		AscendingNode	271.59179149378394
		ArgOfPericen	222.1293251497635
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 660 B"
{
	ParentBody	"Erebos 660"
	Class		"Asteroid"
	Mass		3.0042097694291564e-09
	Radius		11.587225611320392

	Orbit
	{
		Epoch			2457395.5
		Period			0.002067390067878153
		Eccentricity	0.00606927088255523
		Inclination		313.6599180263476
		AscendingNode	271.59179149378394
		ArgOfPericen	42.12932514976353
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 661"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.084389030731851e-08
	Radius		20.608793458660298

	RotationPeriod	5.468241778096169

	Obliquity		135.7627724443107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2919286949971642
		Eccentricity	0.06063193660983
		Inclination		-0.21484337615865454
		AscendingNode	248.7161789491244
		ArgOfPericen	300.6631057769029
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 662"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8032865796235815e-07
	Radius		42.48666956379198

	RotationPeriod	5.8683758345751365

	Obliquity		245.5715854173388

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2313992195882966
		Eccentricity	0.062406826849316636
		Inclination		-1.3817276943911425
		AscendingNode	90.03542647492065
		ArgOfPericen	327.65213488703915
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 663"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8600556512102138e-07
	Radius		44.47940148785579

	RotationPeriod	6.396892440324299

	Obliquity		123.90031035748314

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3317671574166727
		Eccentricity	0.04080678536435251
		Inclination		0.05091109385749517
		AscendingNode	347.6201402316805
		ArgOfPericen	65.32518774791184
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 664"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8234117112695445e-07
	Radius		44.865289129036555

	RotationPeriod	5.759685969711113

	Obliquity		89.80419965873038

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.275168445508485
		Eccentricity	0.07482481763584649
		Inclination		3.7405273003269985
		AscendingNode	345.56121788420666
		ArgOfPericen	131.79244592980356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 665"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2634391031742567
		Eccentricity	0.06835755791355308
		Inclination		1.0219910180352048
		AscendingNode	64.27707463502534
		ArgOfPericen	221.86724662559368
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 665 A"
{
	ParentBody	"Erebos 665"
	Class		"Asteroid"
	Mass		1.723391097620778e-07
	Radius		41.80031104629551

	Orbit
	{
		Epoch			2457395.5
		Period			0.0034696102256152675
		Eccentricity	0.002865375823336025
		Inclination		139.76210552124368
		AscendingNode	280.6832102311821
		ArgOfPericen	256.1743000430478
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 665 B"
{
	ParentBody	"Erebos 665"
	Class		"Asteroid"
	Mass		1.0036144778373663e-08
	Radius		16.202195604026155

	Orbit
	{
		Epoch			2457395.5
		Period			0.0034696102256152675
		Eccentricity	0.002865375823336025
		Inclination		139.76210552124368
		AscendingNode	280.6832102311821
		ArgOfPericen	76.17430004304782
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 666"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.298904586011505
		Eccentricity	0.044059474528824666
		Inclination		0.31563259980443276
		AscendingNode	87.06817312890104
		ArgOfPericen	210.52968005388792
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 666 A"
{
	ParentBody	"Erebos 666"
	Class		"Asteroid"
	Mass		8.282359672827022e-08
	Radius		37.138019978007065

	Orbit
	{
		Epoch			2457395.5
		Period			0.002144884769597321
		Eccentricity	0.009103790718482847
		Inclination		168.41126434852828
		AscendingNode	315.5129972865083
		ArgOfPericen	268.54268264364856
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 666 B"
{
	ParentBody	"Erebos 666"
	Class		"Asteroid"
	Mass		1.4743454073611986e-08
	Radius		20.891380086883075

	Orbit
	{
		Epoch			2457395.5
		Period			0.002144884769597321
		Eccentricity	0.009103790718482847
		Inclination		168.41126434852828
		AscendingNode	315.5129972865083
		ArgOfPericen	88.54268264364856
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 667"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.428901939967707e-08
	Radius		33.95173979687784

	RotationPeriod	4.068626932073903

	Obliquity		67.43118705122377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3319302216949644
		Eccentricity	0.040542488624535036
		Inclination		1.3222130522132505
		AscendingNode	256.88572938229765
		ArgOfPericen	269.1296739362645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 668"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.33456509330315
		Eccentricity	0.08141924035567877
		Inclination		1.3887606420001841
		AscendingNode	269.2702187964928
		ArgOfPericen	197.39496403989227
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 668 A"
{
	ParentBody	"Erebos 668"
	Class		"Asteroid"
	Mass		6.505680295991192e-09
	Radius		14.81342271275168

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022651440519722487
		Eccentricity	0.006789036100875654
		Inclination		17.533912385435116
		AscendingNode	211.74651141459478
		ArgOfPericen	342.60823945232283
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 668 B"
{
	ParentBody	"Erebos 668"
	Class		"Asteroid"
	Mass		3.186115812956197e-09
	Radius		11.676473451395283

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022651440519722487
		Eccentricity	0.006789036100875654
		Inclination		17.533912385435116
		AscendingNode	211.74651141459478
		ArgOfPericen	162.60823945232278
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 669"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1653193621369763e-07
	Radius		38.54098237870365

	RotationPeriod	7.2666529180487975

	Obliquity		324.52976505541324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3894744407581285
		Eccentricity	0.05904596083746062
		Inclination		1.5547661415014546
		AscendingNode	302.6468990376948
		ArgOfPericen	345.36709793998125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 670"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.2625352366401355e-07
	Radius		57.51708927745906

	RotationPeriod	5.866933293217818

	Obliquity		175.02240347581377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.429382737956669
		Eccentricity	0.04423607592224213
		Inclination		3.2457922015114966
		AscendingNode	160.78456756271467
		ArgOfPericen	38.3370719173183
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 671"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.216232049585401
		Eccentricity	0.05554812348980707
		Inclination		-1.0601937050301466
		AscendingNode	315.9817301863793
		ArgOfPericen	167.4497648896547
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 671 A"
{
	ParentBody	"Erebos 671"
	Class		"Asteroid"
	Mass		5.188114939193381e-08
	Radius		28.649654630450534

	Orbit
	{
		Epoch			2457395.5
		Period			0.005803340878296876
		Eccentricity	0.004756714008718291
		Inclination		211.08333156872612
		AscendingNode	186.87506165495805
		ArgOfPericen	311.7802088100601
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 671 B"
{
	ParentBody	"Erebos 671"
	Class		"Asteroid"
	Mass		2.122060761075269e-08
	Radius		21.266799317861523

	Orbit
	{
		Epoch			2457395.5
		Period			0.005803340878296876
		Eccentricity	0.004756714008718291
		Inclination		211.08333156872612
		AscendingNode	186.87506165495805
		ArgOfPericen	131.78020881006012
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 672"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1334203795778463e-07
	Radius		45.817851648963185

	RotationPeriod	4.348264305686057

	Obliquity		135.45932350822014

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286602244508592
		Eccentricity	0.051248283185298435
		Inclination		1.145678549019867
		AscendingNode	327.814441899051
		ArgOfPericen	160.17236462821614
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 672.1"
{
	ParentBody	"Erebos 672"
	Class		"Asteroid"
	Mass		8.842712702465484e-10
	Radius		7.359885878913268

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4546480215717278e-06
		Eccentricity	0.003978994861508987
		Inclination		-31.28961879441049
		AscendingNode	92.38339307988187
		ArgOfPericen	151.69239834952538
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 672.2"
{
	ParentBody	"Erebos 672"
	Class		"Asteroid"
	Mass		2.3288430981406714e-09
	Radius		10.163797064992488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.07725744620738e-06
		Eccentricity	0.006591639704306649
		Inclination		-44.03562737333468
		AscendingNode	219.64468237291823
		ArgOfPericen	275.30784729901256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 673"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.096041899843393e-09
	Radius		12.076313540980344

	RotationPeriod	8.036551220639515

	Obliquity		326.2249295126137

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3681620289138343
		Eccentricity	0.06786421258120814
		Inclination		-1.1681747438132581
		AscendingNode	24.328337529449815
		ArgOfPericen	247.05373085174423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 674"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1655728558776873e-07
	Radius		50.701974004716945

	RotationPeriod	5.413688661659152

	Obliquity		347.1501690395929

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3834405681329796
		Eccentricity	0.05096170351068955
		Inclination		0.9242471027207335
		AscendingNode	99.04386247176426
		ArgOfPericen	143.81786070228253
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 674.1"
{
	ParentBody	"Erebos 674"
	Class		"Asteroid"
	Mass		3.196350339822255e-10
	Radius		5.0865762057864785

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.49255502786142e-06
		Eccentricity	0.004718055369695719
		Inclination		51.50618240564178
		AscendingNode	123.08139573117664
		ArgOfPericen	204.77923836051403
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 675"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.4873534332849423e-07
	Radius		59.59148509731081

	RotationPeriod	0.7847163753586077

	Obliquity		77.63328890009792

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.35198294452714
		Eccentricity	0.03364166947860793
		Inclination		1.7224629687780373
		AscendingNode	200.283749072736
		ArgOfPericen	154.1196271553441
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 676"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.404786554922552e-07
	Radius		71.81123907820091

	RotationPeriod	8.270185317138772

	Obliquity		113.08946574485226

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3799724609138764
		Eccentricity	0.04525065511533087
		Inclination		0.06575310195810183
		AscendingNode	136.29450002460445
		ArgOfPericen	220.60824811803815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 677"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2938409974762672
		Eccentricity	0.06003874020717765
		Inclination		-0.45819237802530105
		AscendingNode	7.534027498074174
		ArgOfPericen	176.4154718267804
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 677 A"
{
	ParentBody	"Erebos 677"
	Class		"Asteroid"
	Mass		1.1948684318625639e-06
	Radius		83.18641123653993

	Orbit
	{
		Epoch			2457395.5
		Period			0.002665242630562688
		Eccentricity	0.004957278008807758
		Inclination		12.249773281844988
		AscendingNode	238.27027184204613
		ArgOfPericen	359.2618508218363
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 677 B"
{
	ParentBody	"Erebos 677"
	Class		"Asteroid"
	Mass		4.324889234542231e-08
	Radius		27.51718620470173

	Orbit
	{
		Epoch			2457395.5
		Period			0.002665242630562688
		Eccentricity	0.004957278008807758
		Inclination		12.249773281844988
		AscendingNode	238.27027184204613
		ArgOfPericen	179.26185082183633
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 678"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4451248223696606e-07
	Radius		47.17540718952653

	RotationPeriod	8.480108207848703

	Obliquity		271.6965856885347

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.300205915383444
		Eccentricity	0.031951597106138596
		Inclination		0.7606883473075814
		AscendingNode	273.9082458449708
		ArgOfPericen	27.567564648236228
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 678.1"
{
	ParentBody	"Erebos 678"
	Class		"Asteroid"
	Mass		2.0878409738255734e-10
	Radius		4.4755641321818285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.942383542979643e-06
		Eccentricity	0.001012022030621112
		Inclination		33.546306839632166
		AscendingNode	216.5746648552701
		ArgOfPericen	198.6865059442327
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 679"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.3429906133089525e-09
	Radius		15.706994506155752

	RotationPeriod	4.729839813842176

	Obliquity		335.06403033224285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.352256631049535
		Eccentricity	0.05042443854478865
		Inclination		-0.23193392290790757
		AscendingNode	96.14963916354557
		ArgOfPericen	346.42061186790295
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 680"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.903958692025271e-07
	Radius		44.045936596777814

	RotationPeriod	4.828495754737915

	Obliquity		192.397591110717

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3725908205945436
		Eccentricity	0.022771848164130967
		Inclination		-1.983867356864023
		AscendingNode	157.83176184632444
		ArgOfPericen	149.35342092374356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 681"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.338263443234711
		Eccentricity	0.026170074045630962
		Inclination		-0.5267453458913287
		AscendingNode	38.63810743594139
		ArgOfPericen	346.5743960435647
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 681 A"
{
	ParentBody	"Erebos 681"
	Class		"Asteroid"
	Mass		4.3546261882645495e-07
	Radius		57.08436836073763

	Orbit
	{
		Epoch			2457395.5
		Period			0.0058992049449628865
		Eccentricity	0.0047136726151207654
		Inclination		53.879585429410525
		AscendingNode	169.52626909814833
		ArgOfPericen	98.57152208649308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 681 B"
{
	ParentBody	"Erebos 681"
	Class		"Asteroid"
	Mass		4.0570981371963776e-08
	Radius		25.878478823640123

	Orbit
	{
		Epoch			2457395.5
		Period			0.0058992049449628865
		Eccentricity	0.0047136726151207654
		Inclination		53.879585429410525
		AscendingNode	169.52626909814833
		ArgOfPericen	278.5715220864931
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 682"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6221603097251024e-07
	Radius		44.87326280282074

	RotationPeriod	6.843423557784395

	Obliquity		111.11893597157574

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.312817670335441
		Eccentricity	0.03925384829146676
		Inclination		0.0016920411559508532
		AscendingNode	77.74953309559311
		ArgOfPericen	286.665726981364
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 683"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.541582809237278e-07
	Radius		72.03060754960623

	RotationPeriod	3.501482576911455

	Obliquity		311.48802332676445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.418662312860645
		Eccentricity	0.06455289856979733
		Inclination		0.6169366108866047
		AscendingNode	300.9996277859078
		ArgOfPericen	136.53526687255476
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 684"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.632752458071568e-08
	Radius		25.76788810574192

	RotationPeriod	10.249687217454884

	Obliquity		334.2705898975099

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.417249645221986
		Eccentricity	0.05023064580266625
		Inclination		2.258058220654084
		AscendingNode	151.7538940288812
		ArgOfPericen	280.1392812720233
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 685"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.380592511243431e-07
	Radius		56.04556094211413

	RotationPeriod	5.278326562796609

	Obliquity		341.22686145657696

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4232075050955353
		Eccentricity	0.018868028538633896
		Inclination		0.5519237355816067
		AscendingNode	356.4510265559272
		ArgOfPericen	167.0336671447338
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 686"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.217678817815151e-07
	Radius		75.47030386287136

	RotationPeriod	6.6845832495419755

	Obliquity		55.998783671422466

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3309253318843375
		Eccentricity	0.05156805985200587
		Inclination		-4.107624059302905
		AscendingNode	357.4821970456039
		ArgOfPericen	85.5680096494597
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 687"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.244322074699498
		Eccentricity	0.06275912041472248
		Inclination		1.0834810573604543
		AscendingNode	214.88702159741032
		ArgOfPericen	310.04469800389904
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 687 A"
{
	ParentBody	"Erebos 687"
	Class		"Asteroid"
	Mass		6.127181302687072e-07
	Radius		67.96182019304116

	Orbit
	{
		Epoch			2457395.5
		Period			0.006871809603068936
		Eccentricity	0.004329633533526148
		Inclination		284.0744212463419
		AscendingNode	118.5531562837818
		ArgOfPericen	261.38434929017797
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 687 B"
{
	ParentBody	"Erebos 687"
	Class		"Asteroid"
	Mass		1.605460697278466e-08
	Radius		20.185738874952648

	Orbit
	{
		Epoch			2457395.5
		Period			0.006871809603068936
		Eccentricity	0.004329633533526148
		Inclination		284.0744212463419
		AscendingNode	118.5531562837818
		ArgOfPericen	81.38434929017797
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 688"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.8781945562357546e-07
	Radius		58.36098472867748

	RotationPeriod	7.783697741918634

	Obliquity		222.01184948592532

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.280837995944638
		Eccentricity	0.0496088720364471
		Inclination		-0.37104616509297667
		AscendingNode	104.43239500952515
		ArgOfPericen	255.86539633999186
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 689"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.982026816907848e-08
	Radius		29.203152297004166

	RotationPeriod	1.673963831578817

	Obliquity		318.7615290274782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.275959831043545
		Eccentricity	0.011948123799475172
		Inclination		1.5578720523065062
		AscendingNode	128.7096075228354
		ArgOfPericen	327.84227377524206
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 690"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3237829809746153
		Eccentricity	0.08003166087519004
		Inclination		0.8701304574233837
		AscendingNode	349.57608875415985
		ArgOfPericen	121.26377815637903
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 690 A"
{
	ParentBody	"Erebos 690"
	Class		"Asteroid"
	Mass		2.54012264342723e-07
	Radius		47.470110371262564

	Orbit
	{
		Epoch			2457395.5
		Period			0.004957458852703589
		Eccentricity	0.001366300247071775
		Inclination		185.6305767492011
		AscendingNode	194.90732508885864
		ArgOfPericen	147.4646888912155
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 690 B"
{
	ParentBody	"Erebos 690"
	Class		"Asteroid"
	Mass		5.995081851191935e-08
	Radius		29.33596542806356

	Orbit
	{
		Epoch			2457395.5
		Period			0.004957458852703589
		Eccentricity	0.001366300247071775
		Inclination		185.6305767492011
		AscendingNode	194.90732508885864
		ArgOfPericen	327.4646888912155
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 691"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1061976214598395e-07
	Radius		52.562397224900046

	RotationPeriod	4.879048059344084

	Obliquity		67.77644826823338

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3299729172456978
		Eccentricity	0.03644380803664399
		Inclination		-2.8424813263213173
		AscendingNode	288.089342414706
		ArgOfPericen	320.1192171325595
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 692"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.238771788371578e-08
	Radius		30.37932726507575

	RotationPeriod	3.4344606718112622

	Obliquity		279.8271889137918

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.305983286466377
		Eccentricity	0.02286551758475068
		Inclination		-2.6101519075865496
		AscendingNode	18.65322522969947
		ArgOfPericen	333.1493142305546
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 693"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2359648307581446
		Eccentricity	0.03331643889610966
		Inclination		-2.172184278498513
		AscendingNode	251.86748991065508
		ArgOfPericen	296.80463134541577
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 693 A"
{
	ParentBody	"Erebos 693"
	Class		"Asteroid"
	Mass		6.52322583896904e-07
	Radius		65.10416218266381

	Orbit
	{
		Epoch			2457395.5
		Period			0.007589258046420923
		Eccentricity	0.0031605539181327087
		Inclination		282.01799181551826
		AscendingNode	359.9688823504542
		ArgOfPericen	251.72371669285695
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 693 B"
{
	ParentBody	"Erebos 693"
	Class		"Asteroid"
	Mass		1.308159528626396e-08
	Radius		17.687842098290865

	Orbit
	{
		Epoch			2457395.5
		Period			0.007589258046420923
		Eccentricity	0.0031605539181327087
		Inclination		282.01799181551826
		AscendingNode	359.9688823504542
		ArgOfPericen	71.72371669285695
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 694"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0795014509084999e-08
	Radius		18.156006894951332

	RotationPeriod	7.995511604532997

	Obliquity		175.90156472452486

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3097569855398037
		Eccentricity	0.06829272459551794
		Inclination		0.20608911359317664
		AscendingNode	322.40191686593136
		ArgOfPericen	221.58284736255084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 694.1"
{
	ParentBody	"Erebos 694"
	Class		"Asteroid"
	Mass		3.480212185628702e-11
	Radius		2.6821383136699817

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6171531368986272e-06
		Eccentricity	0.004539100349264755
		Inclination		-10.13137702388978
		AscendingNode	68.90786741216992
		ArgOfPericen	72.45225631395765
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 694.2"
{
	ParentBody	"Erebos 694"
	Class		"Asteroid"
	Mass		1.3153565321242565e-10
	Radius		4.177922928615976

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.186395435081147e-07
		Eccentricity	0.0038567074895732283
		Inclination		-60.75653655720942
		AscendingNode	287.8468538745614
		ArgOfPericen	187.6117087352171
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 695"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.590832114056077e-07
	Radius		75.05462551848706

	RotationPeriod	4.778766049517817

	Obliquity		38.12284845083925

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2864031821715103
		Eccentricity	0.03699010148846708
		Inclination		0.31172752647020713
		AscendingNode	237.96592227645476
		ArgOfPericen	313.4369606258219
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 696"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.42507148618746e-07
	Radius		43.81961312638837

	RotationPeriod	6.288311662463638

	Obliquity		227.79300242873072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.301776505747111
		Eccentricity	0.030418298391483856
		Inclination		-0.05120498445199455
		AscendingNode	160.35355490747563
		ArgOfPericen	130.80956615946283
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 697"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.773436280158648e-08
	Radius		34.16450998448704

	RotationPeriod	4.887122008819824

	Obliquity		96.20532810194997

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.421845393509153
		Eccentricity	0.022142046365774836
		Inclination		2.554527508717673
		AscendingNode	346.26765434593824
		ArgOfPericen	95.27399717086729
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 698"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.03362455601704e-07
	Radius		70.18003485589128

	RotationPeriod	7.992020114514952

	Obliquity		72.08859341514379

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.272823283628581
		Eccentricity	0.025701802462711466
		Inclination		3.860040583394032
		AscendingNode	274.6899707724777
		ArgOfPericen	113.64078939915892
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 699"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.349004201684684e-07
	Radius		40.03981568478584

	RotationPeriod	9.746382920133376

	Obliquity		82.33601847948981

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.293475640962846
		Eccentricity	0.06668402910387883
		Inclination		-2.7985093461221515
		AscendingNode	293.25300550384077
		ArgOfPericen	128.21411076083317
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 700"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5775737797246097e-07
	Radius		42.46382967867998

	RotationPeriod	5.982956796326297

	Obliquity		287.8664585752166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.291172767359835
		Eccentricity	0.07456920682426116
		Inclination		-1.5999212298810017
		AscendingNode	349.12874572538175
		ArgOfPericen	356.4440297840554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 700.1"
{
	ParentBody	"Erebos 700"
	Class		"Asteroid"
	Mass		1.0503737028658076e-10
	Radius		3.707978547339022

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.132177316011482e-06
		Eccentricity	0.009080942041409686
		Inclination		8.267707314378363
		AscendingNode	70.3319176426398
		ArgOfPericen	32.51508249295265
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 701"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0637505309160498e-06
	Radius		79.92844831491185

	RotationPeriod	6.050075987597252

	Obliquity		312.1076547474897

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3783127715284214
		Eccentricity	0.03203631210560721
		Inclination		1.466689905478283
		AscendingNode	96.56396105226895
		ArgOfPericen	55.576901104104394
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 702"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.155400066031935e-08
	Radius		21.81320350165945

	RotationPeriod	3.584474641219267

	Obliquity		304.4929460449769

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3638685086782103
		Eccentricity	0.038855593896925514
		Inclination		-1.442111189233649
		AscendingNode	251.62040984728992
		ArgOfPericen	159.29884631221086
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 703"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.314073862663648
		Eccentricity	0.04642584829163673
		Inclination		0.37669959964545235
		AscendingNode	96.9411632029852
		ArgOfPericen	258.6014530958737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 703 A"
{
	ParentBody	"Erebos 703"
	Class		"Asteroid"
	Mass		1.3425311546158753e-07
	Radius		42.535738689704594

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011123855596796572
		Eccentricity	0.006532557114561359
		Inclination		350.5575510715715
		AscendingNode	12.741141829770184
		ArgOfPericen	216.5856953900796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 703 B"
{
	ParentBody	"Erebos 703"
	Class		"Asteroid"
	Mass		3.992419343567218e-09
	Radius		13.178254955614456

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011123855596796572
		Eccentricity	0.006532557114561359
		Inclination		350.5575510715715
		AscendingNode	12.741141829770184
		ArgOfPericen	36.58569539007959
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 704"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.70084819708789e-07
	Radius		67.53667503921262

	RotationPeriod	8.71446172118616

	Obliquity		221.83031086366336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.239174768845323
		Eccentricity	0.03918537785010895
		Inclination		2.0856873540424083
		AscendingNode	203.04338749498083
		ArgOfPericen	313.324907383707
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 704.1"
{
	ParentBody	"Erebos 704"
	Class		"Asteroid"
	Mass		5.3419112838276055e-09
	Radius		13.49155390529879

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.330455324737167e-07
		Eccentricity	0
		Inclination		-6.978117385332187
		AscendingNode	97.07090438229409
		ArgOfPericen	152.2758454772386
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 704.2"
{
	ParentBody	"Erebos 704"
	Class		"Asteroid"
	Mass		1.2749821598343517e-10
	Radius		3.884464157592504

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.144125893567505e-06
		Eccentricity	0.00641732700310834
		Inclination		9.377131191910253
		AscendingNode	323.6838873164463
		ArgOfPericen	105.84844741459573
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 705"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.319447264252743e-07
	Radius		54.753059885400226

	RotationPeriod	6.438126188129317

	Obliquity		10.650078875741485

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2027292891308163
		Eccentricity	0.06247075390490131
		Inclination		-1.9290202384479624
		AscendingNode	138.1932672352973
		ArgOfPericen	239.33829875407338
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 706"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.261753107271184e-07
	Radius		50.12739697011422

	RotationPeriod	4.393558962115192

	Obliquity		302.24513914192664

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.298197009919409
		Eccentricity	0.04507713279313613
		Inclination		-1.1792782018691297
		AscendingNode	295.50332395567
		ArgOfPericen	43.674806466464
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 707"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.11992394493229e-07
	Radius		66.02005233392211

	RotationPeriod	4.1775505213958635

	Obliquity		114.33296109835072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4246693892339475
		Eccentricity	0.032032953724366486
		Inclination		0.6118965384031021
		AscendingNode	90.91172524631797
		ArgOfPericen	355.03055251571453
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 708"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.085860478577438e-08
	Radius		26.35901881672944

	RotationPeriod	6.073592670963945

	Obliquity		293.8660182424923

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.385067980653847
		Eccentricity	0.03469941500451191
		Inclination		1.1787866699497789
		AscendingNode	285.3388234269016
		ArgOfPericen	275.21583688972333
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 709"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.68297344377376e-07
	Radius		59.7229041532051

	RotationPeriod	7.559522404154325

	Obliquity		187.38336640257089

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.222573801432761
		Eccentricity	0.049562651843556835
		Inclination		-1.0416411288348613
		AscendingNode	214.28437922014058
		ArgOfPericen	308.9346274594462
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 710"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.800122155440941e-07
	Radius		65.9693101371489

	RotationPeriod	8.313747782168784

	Obliquity		327.336366508969

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.323630253927368
		Eccentricity	0.057285823199708506
		Inclination		-0.8584464134305185
		AscendingNode	139.95768398157276
		ArgOfPericen	306.13718905821116
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 710.1"
{
	ParentBody	"Erebos 710"
	Class		"Asteroid"
	Mass		5.507321973230826e-09
	Radius		13.969355989542454

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.139825599202532e-06
		Eccentricity	0.0022375530829990436
		Inclination		-6.78418702830595
		AscendingNode	44.00750390872488
		ArgOfPericen	288.6845226763504
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 711"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.327976306793305
		Eccentricity	0.044208285366111426
		Inclination		-1.4089004832779233
		AscendingNode	205.86323448051078
		ArgOfPericen	136.58586600732048
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 711 A"
{
	ParentBody	"Erebos 711"
	Class		"Asteroid"
	Mass		8.108985450793756e-07
	Radius		78.12832550757196

	Orbit
	{
		Epoch			2457395.5
		Period			0.004960438476128193
		Eccentricity	0.005597398289985842
		Inclination		57.184367058605915
		AscendingNode	303.4685298362101
		ArgOfPericen	319.97348860900405
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 711 B"
{
	ParentBody	"Erebos 711"
	Class		"Asteroid"
	Mass		4.1839961701148e-08
	Radius		29.085962201058056

	Orbit
	{
		Epoch			2457395.5
		Period			0.004960438476128193
		Eccentricity	0.005597398289985842
		Inclination		57.184367058605915
		AscendingNode	303.4685298362101
		ArgOfPericen	139.97348860900405
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 712"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.567182936415107e-07
	Radius		72.94244051331232

	RotationPeriod	8.123357827413185

	Obliquity		136.04835895547384

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2837434446465776
		Eccentricity	0.0368193508129222
		Inclination		1.173953420673938
		AscendingNode	202.53077533172402
		ArgOfPericen	56.681653345103804
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 713"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.504359917329335e-07
	Radius		52.291082041061664

	RotationPeriod	8.117386881699826

	Obliquity		218.35902225931773

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3423106300563545
		Eccentricity	0.041906329021121784
		Inclination		2.919795921480842
		AscendingNode	257.971998662686
		ArgOfPericen	301.2860229031747
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 714"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.017113748805446e-07
	Radius		67.40491373366213

	RotationPeriod	5.1721423536355955

	Obliquity		286.1313056615449

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3018768751696723
		Eccentricity	0.04619517719627566
		Inclination		-0.041924202660896595
		AscendingNode	19.48904780029522
		ArgOfPericen	39.188760145608434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 715"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0850260837936652e-08
	Radius		20.82980038733755

	RotationPeriod	10.407881021832015

	Obliquity		197.05474038907894

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.317710009627218
		Eccentricity	0.06349030849738238
		Inclination		0.1467980828040797
		AscendingNode	164.64704798547706
		ArgOfPericen	175.2698195417134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 716"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3836052848649624e-07
	Radius		51.18605749348744

	RotationPeriod	6.824836394661906

	Obliquity		268.8845624767368

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.293749727086614
		Eccentricity	0.06507437919308663
		Inclination		2.6940968814667983
		AscendingNode	246.9566729622178
		ArgOfPericen	158.63504566111402
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 717"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.083798584646786e-07
	Radius		69.48691534125932

	RotationPeriod	5.392218021778589

	Obliquity		95.25195231197011

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.40259235497745
		Eccentricity	0.0467684103984846
		Inclination		-1.4019736604933324
		AscendingNode	347.378874560779
		ArgOfPericen	25.44749973891777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 718"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.965294489429829e-08
	Radius		33.60799362091035

	RotationPeriod	6.953398522904247

	Obliquity		35.84133478555839

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3654308324969016
		Eccentricity	0.05979804934777491
		Inclination		-0.38391434397125906
		AscendingNode	303.80047147007883
		ArgOfPericen	155.24116790063096
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 719"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.3114123740482397e-07
	Radius		55.71743359531004

	RotationPeriod	5.896660956749998

	Obliquity		105.88137434789824

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3748799156334375
		Eccentricity	0.046781892341238016
		Inclination		-0.1179504657529455
		AscendingNode	154.17506258794046
		ArgOfPericen	138.23719835981703
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 720"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2963609375755354
		Eccentricity	0.061443188669719324
		Inclination		1.3247804573211155
		AscendingNode	190.16390272808565
		ArgOfPericen	100.64565771117631
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 720 A"
{
	ParentBody	"Erebos 720"
	Class		"Asteroid"
	Mass		6.064799113879701e-08
	Radius		29.859186383583676

	Orbit
	{
		Epoch			2457395.5
		Period			0.005854846306602194
		Eccentricity	0.0037177724646953987
		Inclination		250.09657486533573
		AscendingNode	334.89094538063284
		ArgOfPericen	55.7305282932226
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 720 B"
{
	ParentBody	"Erebos 720"
	Class		"Asteroid"
	Mass		4.681277739258202e-08
	Radius		27.390121945197535

	Orbit
	{
		Epoch			2457395.5
		Period			0.005854846306602194
		Eccentricity	0.0037177724646953987
		Inclination		250.09657486533573
		AscendingNode	334.89094538063284
		ArgOfPericen	235.7305282932226
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 721"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.768878822624264e-07
	Radius		52.09539171617385

	RotationPeriod	2.4666168852422143

	Obliquity		200.16651292980436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3436190125132375
		Eccentricity	0.04084335467095963
		Inclination		1.0500710013158419
		AscendingNode	340.27849719399904
		ArgOfPericen	29.934785145463785
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 722"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5792489384200834e-07
	Radius		41.918754346903995

	RotationPeriod	6.4490378339326195

	Obliquity		278.543169529616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.309304326337996
		Eccentricity	0.045209432792132055
		Inclination		-0.4943162067932098
		AscendingNode	201.47988800165416
		ArgOfPericen	72.72117894992051
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 723"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.77197244608319e-07
	Radius		67.4951194579043

	RotationPeriod	1.7393673942970782

	Obliquity		52.21740158395465

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3080579783324584
		Eccentricity	0.053027449662800645
		Inclination		-0.14533138876589152
		AscendingNode	12.591636026007972
		ArgOfPericen	20.93391496208646
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 723.1"
{
	ParentBody	"Erebos 723"
	Class		"Asteroid"
	Mass		3.5229121088329013e-10
	Radius		5.184766738637841

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.043723533998956e-06
		Eccentricity	0.006113545995710816
		Inclination		-18.689495371420428
		AscendingNode	59.460425006467666
		ArgOfPericen	143.53866605033326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 724"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.588710707877177e-07
	Radius		73.8941497858808

	RotationPeriod	3.0757612004469075

	Obliquity		316.3355507104366

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3048746256658026
		Eccentricity	0.049190646772856554
		Inclination		-0.7704305574846774
		AscendingNode	114.25121114076627
		ArgOfPericen	271.13034477651
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 725"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5073614774043712e-07
	Radius		43.33323445991718

	RotationPeriod	5.516632936363445

	Obliquity		256.96801898570527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2810840664850183
		Eccentricity	0.045794008255183
		Inclination		-0.6762405716743174
		AscendingNode	51.720521403300474
		ArgOfPericen	190.06774549654187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 725.1"
{
	ParentBody	"Erebos 725"
	Class		"Asteroid"
	Mass		8.410581818018857e-10
	Radius		7.6858277886438024

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.463339152919834e-07
		Eccentricity	0.005168690393891955
		Inclination		-7.135179261655183
		AscendingNode	206.80509059871747
		ArgOfPericen	244.04776139302146
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 726"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.162871991983598e-08
	Radius		33.4331381700756

	RotationPeriod	4.854585833698131

	Obliquity		223.29100129560894

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3515934525507904
		Eccentricity	0.0023624452097648213
		Inclination		1.7445963223044934
		AscendingNode	76.39156450142781
		ArgOfPericen	278.4134570836566
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 727"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.0294924663178256e-07
	Radius		63.42725439234092

	RotationPeriod	6.0474378615793425

	Obliquity		317.86672962650374

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.299060692296013
		Eccentricity	0.07551925277672185
		Inclination		0.28378093908417173
		AscendingNode	161.50397534316684
		ArgOfPericen	326.8036880675461
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 728"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.206688945718885e-07
	Radius		71.04873485302724

	RotationPeriod	3.093548362017907

	Obliquity		91.93992889328065

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3722967623865934
		Eccentricity	0.04474050840769728
		Inclination		1.808902579964542
		AscendingNode	247.14458009893167
		ArgOfPericen	179.66855474815543
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 729"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.380474797758535
		Eccentricity	0.04854123362444308
		Inclination		2.268105798433516
		AscendingNode	357.1721870276085
		ArgOfPericen	98.17738985362855
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 729 A"
{
	ParentBody	"Erebos 729"
	Class		"Asteroid"
	Mass		5.560221762985522e-08
	Radius		29.14122850777035

	Orbit
	{
		Epoch			2457395.5
		Period			0.006168631531246358
		Eccentricity	0.0014064453720051412
		Inclination		24.07052070932763
		AscendingNode	187.11176598421108
		ArgOfPericen	15.970264903546486
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 729 B"
{
	ParentBody	"Erebos 729"
	Class		"Asteroid"
	Mass		1.1998310712728246e-08
	Radius		17.479024325308814

	Orbit
	{
		Epoch			2457395.5
		Period			0.006168631531246358
		Eccentricity	0.0014064453720051412
		Inclination		24.07052070932763
		AscendingNode	187.11176598421108
		ArgOfPericen	195.97026490354648
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 730"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.978579875751842e-07
	Radius		57.17678854447976

	RotationPeriod	7.707407967691617

	Obliquity		198.3662248316676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.221624362746298
		Eccentricity	0.0580805422538115
		Inclination		0.3677024320522857
		AscendingNode	184.68713250522876
		ArgOfPericen	194.18244276906378
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 731"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.181994006243931e-07
	Radius		54.86902570841918

	RotationPeriod	5.135575786559187

	Obliquity		248.50320098860658

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.415865091423102
		Eccentricity	0.056114414214234506
		Inclination		-0.48077471968947816
		AscendingNode	87.66065777180808
		ArgOfPericen	193.98395948430388
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 732"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.305449157163425e-07
	Radius		68.72024604025671

	RotationPeriod	7.04415316158111

	Obliquity		334.9642718319185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.209957149682188
		Eccentricity	0.0706749610560712
		Inclination		-1.29366745655227
		AscendingNode	321.4888974765251
		ArgOfPericen	46.68611211084446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 733"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.08796604031441e-08
	Radius		32.12802939132604

	RotationPeriod	6.23717706160528

	Obliquity		288.19826210164473

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.356748666300937
		Eccentricity	0.050716462980711204
		Inclination		-1.1279640356446363
		AscendingNode	120.95527872856255
		ArgOfPericen	191.53219841137874
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 734"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2069703932910297e-07
	Radius		47.47613447635249

	RotationPeriod	6.140236295411245

	Obliquity		149.21103860549485

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.357024350918991
		Eccentricity	0.07044836357838298
		Inclination		1.6769466287630594
		AscendingNode	177.3902125905779
		ArgOfPericen	18.975696728956578
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 735"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7827152614611746e-08
	Radius		19.99154162541562

	RotationPeriod	7.080088482681291

	Obliquity		268.5981459883131

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2457403018522535
		Eccentricity	0.045380580904108875
		Inclination		1.8816433555737726
		AscendingNode	163.2525085309949
		ArgOfPericen	188.98020588783783
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 735.1"
{
	ParentBody	"Erebos 735"
	Class		"Asteroid"
	Mass		1.3743642116280886e-10
	Radius		3.9492949566095032

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0632075208888463e-06
		Eccentricity	0.0023900199931602586
		Inclination		-18.965175604279832
		AscendingNode	110.92545704699852
		ArgOfPericen	162.62701963526442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 736"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9329842375826486e-07
	Radius		43.253899139654926

	RotationPeriod	7.650506727131065

	Obliquity		257.3912063604826

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3887926970447184
		Eccentricity	0.04158888766676999
		Inclination		-1.0453945246408165
		AscendingNode	225.18569156271445
		ArgOfPericen	289.27819260536864
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 737"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3195567302351363
		Eccentricity	0.04707413181516229
		Inclination		1.464363980866492
		AscendingNode	19.37431515237826
		ArgOfPericen	219.92474860933072
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 737 A"
{
	ParentBody	"Erebos 737"
	Class		"Asteroid"
	Mass		1.0716766293692772e-06
	Radius		79.9532520145672

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026426251397930083
		Eccentricity	0.006430521394752456
		Inclination		17.330839557312736
		AscendingNode	311.67127986627185
		ArgOfPericen	92.75334966326679
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 737 B"
{
	ParentBody	"Erebos 737"
	Class		"Asteroid"
	Mass		9.432735288383486e-08
	Radius		35.56537797701424

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026426251397930083
		Eccentricity	0.006430521394752456
		Inclination		17.330839557312736
		AscendingNode	311.67127986627185
		ArgOfPericen	272.7533496632668
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 738"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.518505517826983e-07
	Radius		63.45491751467554

	RotationPeriod	4.743412768895089

	Obliquity		197.49253824564278

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.278327171666199
		Eccentricity	0.03512846777780416
		Inclination		-4.212953090851176
		AscendingNode	311.0533234444086
		ArgOfPericen	274.28564237264663
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 739"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6953712375071322e-07
	Radius		44.44069871442743

	RotationPeriod	5.011292433464007

	Obliquity		321.9385734032739

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3033915960569757
		Eccentricity	0.027185337297581793
		Inclination		1.5899071996619791
		AscendingNode	314.3132378016238
		ArgOfPericen	178.0330435090724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 740"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.87308006595741e-07
	Radius		67.15777856682996

	RotationPeriod	6.777090682667166

	Obliquity		67.97204786411032

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1986807221603555
		Eccentricity	0.012602650232678432
		Inclination		-1.5636044025657698
		AscendingNode	304.428867844213
		ArgOfPericen	31.020846431574252
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 741"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6304136000374038e-07
	Radius		42.686620824397814

	RotationPeriod	8.487166936046009

	Obliquity		322.0387179975879

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4249456314074607
		Eccentricity	0.05089426803371021
		Inclination		0.13851722784817114
		AscendingNode	241.87919676471222
		ArgOfPericen	262.39786390590916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 742"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2828351981113348e-07
	Radius		40.00086784451908

	RotationPeriod	5.340146568054344

	Obliquity		96.16602353629074

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2435663260496317
		Eccentricity	0.07649633019212648
		Inclination		-1.1416185644651047
		AscendingNode	114.16963887751328
		ArgOfPericen	111.23352918156766
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 743"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6606107285374538e-07
	Radius		42.64155262071102

	RotationPeriod	4.02206521229183

	Obliquity		215.41622891329453

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.412471903091669
		Eccentricity	0.07482848466545301
		Inclination		1.5215099146130022
		AscendingNode	46.87571936164131
		ArgOfPericen	334.9003736102764
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 744"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.8227421224362153e-07
	Radius		52.89930839694749

	RotationPeriod	7.57452894733711

	Obliquity		195.23392357322768

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.241298144621443
		Eccentricity	0.04122527848062399
		Inclination		1.3670960520328244
		AscendingNode	233.92293764191996
		ArgOfPericen	297.13832678714954
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 745"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.988261059876452e-08
	Radius		25.487617790507397

	RotationPeriod	5.389335960526167

	Obliquity		250.21173899600146

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.284729864572939
		Eccentricity	0.04803177079221248
		Inclination		-3.5022570182340163
		AscendingNode	7.7361325398841085
		ArgOfPericen	236.69797756208138
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 746"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3552740502148634e-07
	Radius		46.59351381333808

	RotationPeriod	7.638397591783467

	Obliquity		208.42053525333503

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2463477394690936
		Eccentricity	0.06379225023283022
		Inclination		-1.568462756807391
		AscendingNode	164.43835562313527
		ArgOfPericen	118.49424718142123
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 747"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.8030592332635934e-07
	Radius		47.3080460593056

	RotationPeriod	8.771241295145222

	Obliquity		101.49028040857694

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.281419715756517
		Eccentricity	0.05109631916625334
		Inclination		-1.5102619483779534
		AscendingNode	58.347424279323945
		ArgOfPericen	215.39567595196507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 748"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1372848373541057e-07
	Radius		54.764056265088556

	RotationPeriod	6.795229314682196

	Obliquity		61.225608435152

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.24454544713668
		Eccentricity	0.06073491453211234
		Inclination		2.600616086316835
		AscendingNode	267.34740079518474
		ArgOfPericen	107.69906344260949
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 749"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7140322661780123e-07
	Radius		45.04283522220841

	RotationPeriod	6.790026715766212

	Obliquity		206.5427413586168

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3066347828150366
		Eccentricity	0.06263240793344314
		Inclination		-0.8727074754921451
		AscendingNode	316.4561809499494
		ArgOfPericen	0.0685700929960964
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 750"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.749426128085153e-07
	Radius		72.53544651203674

	RotationPeriod	4.886555466078649

	Obliquity		219.23584537712517

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2686862903751823
		Eccentricity	0.05325322475637504
		Inclination		2.0077880864696023
		AscendingNode	349.2777860651832
		ArgOfPericen	122.0967265288432
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 750.1"
{
	ParentBody	"Erebos 750"
	Class		"Asteroid"
	Mass		1.9911842275820106e-09
	Radius		10.403157027103672

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.133038581082328e-06
		Eccentricity	0.0039533248406033745
		Inclination		-12.495570661065404
		AscendingNode	119.42240940074441
		ArgOfPericen	309.4100948858892
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 751"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.664307989008056e-07
	Radius		67.80172893812264

	RotationPeriod	8.283422310518855

	Obliquity		319.5750232010491

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3879260440887626
		Eccentricity	0.03306093546209059
		Inclination		0.09330869503313938
		AscendingNode	160.37335550150834
		ArgOfPericen	276.1135267955408
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 752"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.536259398577679e-07
	Radius		50.63419638277008

	RotationPeriod	8.332087323422233

	Obliquity		246.36737667178994

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2846461673792504
		Eccentricity	0.04027620718812134
		Inclination		1.0235285359814517
		AscendingNode	1.1946373052895298
		ArgOfPericen	351.4778955701919
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 753"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.5061311957974805e-09
	Radius		11.429348730570588

	RotationPeriod	2.941923120002707

	Obliquity		18.7585685483551

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.293057816199527
		Eccentricity	0.030648434157920956
		Inclination		-2.6453347709015484
		AscendingNode	106.56107429981508
		ArgOfPericen	179.7215486255106
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 754"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0646095165498167e-07
	Radius		38.61526281736819

	RotationPeriod	6.673099114157767

	Obliquity		100.29836276247434

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3295618395721363
		Eccentricity	0.057372988080520416
		Inclination		4.1767482373195355
		AscendingNode	81.48753324310921
		ArgOfPericen	309.4341813216918
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 755"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.670420689672836e-11
	Radius		3.360779776504927

	RotationPeriod	7.5301853935852625

	Obliquity		59.20646044442097

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2505719136052305
		Eccentricity	0.0541669637577965
		Inclination		1.7391406397340614
		AscendingNode	164.4356054518122
		ArgOfPericen	241.96278235964536
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 756"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.283085498312788e-08
	Radius		23.64862343306877

	RotationPeriod	5.841653975998534

	Obliquity		321.9839745224368

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2766718889187776
		Eccentricity	0.02677792479509761
		Inclination		2.485285777673864
		AscendingNode	161.30358219455874
		ArgOfPericen	254.3588222471073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 757"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2215071319694097e-06
	Radius		82.74019233644444

	RotationPeriod	6.856790424239108

	Obliquity		168.23608762081776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3755738824685135
		Eccentricity	0.04747418430911661
		Inclination		-1.0783189379619798
		AscendingNode	188.1685176391535
		ArgOfPericen	206.7985030262977
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 757.1"
{
	ParentBody	"Erebos 757"
	Class		"Asteroid"
	Mass		1.1229465456266612e-09
	Radius		8.045213091135585

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9119994652869564e-06
		Eccentricity	0.003754004799001736
		Inclination		-16.653437140055853
		AscendingNode	268.639727986482
		ArgOfPericen	293.65029007010656
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 758"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.342678720755385
		Eccentricity	0.060432115505362885
		Inclination		3.275751958459109
		AscendingNode	265.1210147592357
		ArgOfPericen	66.63973255097356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 758 A"
{
	ParentBody	"Erebos 758"
	Class		"Asteroid"
	Mass		3.4680997383603706e-08
	Radius		25.801427506701305

	Orbit
	{
		Epoch			2457395.5
		Period			0.007381083138973918
		Eccentricity	0.005090864600144176
		Inclination		52.941092016264115
		AscendingNode	277.27724496431836
		ArgOfPericen	357.0742544212725
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 758 B"
{
	ParentBody	"Erebos 758"
	Class		"Asteroid"
	Mass		9.066848064481706e-09
	Radius		16.498026157346178

	Orbit
	{
		Epoch			2457395.5
		Period			0.007381083138973918
		Eccentricity	0.005090864600144176
		Inclination		52.941092016264115
		AscendingNode	277.27724496431836
		ArgOfPericen	177.07425442127249
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 759"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.976057249167898e-07
	Radius		62.17195718795801

	RotationPeriod	6.813347747989658

	Obliquity		4.521014351447432

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.465208364645763
		Eccentricity	0.04059543834275124
		Inclination		1.7977703430576524
		AscendingNode	280.975922906547
		ArgOfPericen	356.9169165849148
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 760"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7234079768860665e-07
	Radius		53.408010359739166

	RotationPeriod	8.54688435181996

	Obliquity		71.12054765146851

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.303753512268499
		Eccentricity	0.028893586470920576
		Inclination		1.7088944060193978
		AscendingNode	332.1891259546182
		ArgOfPericen	6.288111245062349
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 761"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.107482472838962e-07
	Radius		59.68766281847553

	RotationPeriod	7.925349409404444

	Obliquity		36.5735623134571

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2721923772861237
		Eccentricity	0.06890100690088627
		Inclination		-1.8673884150324809
		AscendingNode	240.94756638483383
		ArgOfPericen	94.83614578186757
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 761.1"
{
	ParentBody	"Erebos 761"
	Class		"Asteroid"
	Mass		3.6437775119921564e-09
	Radius		12.355963528608033

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.188778133846616e-06
		Eccentricity	0.0068678228721373415
		Inclination		4.81144112394104
		AscendingNode	180.9945223555996
		ArgOfPericen	153.81672588080852
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 762"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.331049343764002
		Eccentricity	0.03263188806157887
		Inclination		1.8593824205693918
		AscendingNode	24.21756186796509
		ArgOfPericen	76.47505232305558
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 762 A"
{
	ParentBody	"Erebos 762"
	Class		"Asteroid"
	Mass		6.690804028610693e-07
	Radius		69.5956646628649

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018931344320852516
		Eccentricity	0.004946053992259182
		Inclination		106.94080030195948
		AscendingNode	263.0627673495735
		ArgOfPericen	62.32742496264967
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 762 B"
{
	ParentBody	"Erebos 762"
	Class		"Asteroid"
	Mass		6.60722947150249e-08
	Radius		32.1683817280412

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018931344320852516
		Eccentricity	0.004946053992259182
		Inclination		106.94080030195948
		AscendingNode	263.0627673495735
		ArgOfPericen	242.32742496264967
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 763"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.381235169264243
		Eccentricity	0.05045008738118063
		Inclination		-2.6538553747678244
		AscendingNode	174.69155200156302
		ArgOfPericen	209.23950414997358
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 763 A"
{
	ParentBody	"Erebos 763"
	Class		"Asteroid"
	Mass		7.614975584040563e-08
	Radius		35.26598277284708

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055027352319439666
		Eccentricity	0.005552569211279149
		Inclination		244.98227401795194
		AscendingNode	307.2795908848208
		ArgOfPericen	177.0564317549285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 763 B"
{
	ParentBody	"Erebos 763"
	Class		"Asteroid"
	Mass		8.0710864196026e-09
	Radius		16.689518929527463

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055027352319439666
		Eccentricity	0.005552569211279149
		Inclination		244.98227401795194
		AscendingNode	307.2795908848208
		ArgOfPericen	357.0564317549285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 764"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.303213762416256e-07
	Radius		73.38783392092122

	RotationPeriod	4.123762794599221

	Obliquity		94.87473654620486

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2595909900732125
		Eccentricity	0.05373909002965155
		Inclination		-1.593371805971928
		AscendingNode	251.61811144008942
		ArgOfPericen	78.71247411757055
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 765"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.309274019966707e-07
	Radius		67.18197176985205

	RotationPeriod	7.158341245515857

	Obliquity		347.7793381435088

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2658230031825854
		Eccentricity	0.06210252474979465
		Inclination		0.515396671290027
		AscendingNode	338.9998172912039
		ArgOfPericen	260.3129095246027
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 766"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1662819732924551e-07
	Radius		38.92547548856422

	RotationPeriod	8.897310781345439

	Obliquity		340.53504475801697

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.313861506545676
		Eccentricity	0.012236121551609178
		Inclination		-0.2365768541866673
		AscendingNode	177.2114975407688
		ArgOfPericen	201.40713147182004
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 767"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.803284277094307e-07
	Radius		56.78995981195067

	RotationPeriod	7.6168183956996875

	Obliquity		57.690179792125505

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3426463343249257
		Eccentricity	0.08136607525941612
		Inclination		2.3703027675828867
		AscendingNode	47.45891070819781
		ArgOfPericen	255.66614461758985
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 768"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.657260484688973e-07
	Radius		71.38635642173556

	RotationPeriod	7.861075752853904

	Obliquity		229.32448462592427

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.382647978057026
		Eccentricity	0.08310784442909408
		Inclination		1.4252257295330746
		AscendingNode	95.36737425495646
		ArgOfPericen	223.95839791622407
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 769"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6973514864807035e-07
	Radius		42.48887435876501

	RotationPeriod	1.041408023764265

	Obliquity		22.397871686353863

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.322802077963405
		Eccentricity	0.04994571730106729
		Inclination		4.159839730119831
		AscendingNode	18.376059936476143
		ArgOfPericen	141.53151976809227
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 770"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.126287481766362e-07
	Radius		73.70382862913947

	RotationPeriod	6.054547138161607

	Obliquity		169.77459737481365

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3378201456641374
		Eccentricity	0.0368433830606888
		Inclination		0.014327493013983946
		AscendingNode	84.2181897739763
		ArgOfPericen	326.73223060158085
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 771"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.288846384419904e-07
	Radius		77.46291657186474

	RotationPeriod	8.217630298138904

	Obliquity		356.3951030449387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4448115802446018
		Eccentricity	0.06549812380034743
		Inclination		-2.315202666699795
		AscendingNode	334.1057886786229
		ArgOfPericen	173.98699495376263
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 772"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.280210037382805
		Eccentricity	0.05385116548916066
		Inclination		-1.0511624735579037
		AscendingNode	224.087062515041
		ArgOfPericen	267.22243681178384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 772 A"
{
	ParentBody	"Erebos 772"
	Class		"Asteroid"
	Mass		1.3669192684749443e-07
	Radius		43.45756886239679

	Orbit
	{
		Epoch			2457395.5
		Period			0.003513189700226922
		Eccentricity	0.0054479616437184885
		Inclination		65.06109535546265
		AscendingNode	30.701132782885576
		ArgOfPericen	145.066356747945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 772 B"
{
	ParentBody	"Erebos 772"
	Class		"Asteroid"
	Mass		3.455689366734923e-08
	Radius		27.47869080880969

	Orbit
	{
		Epoch			2457395.5
		Period			0.003513189700226922
		Eccentricity	0.0054479616437184885
		Inclination		65.06109535546265
		AscendingNode	30.701132782885576
		ArgOfPericen	325.066356747945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 773"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.407001666087352e-07
	Radius		41.7235719802562

	RotationPeriod	3.5651990910181044

	Obliquity		289.8019879594942

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.262865961044178
		Eccentricity	0.017094487604753086
		Inclination		-0.6862671176289052
		AscendingNode	163.00537968797508
		ArgOfPericen	80.63064011812443
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 773.1"
{
	ParentBody	"Erebos 773"
	Class		"Asteroid"
	Mass		1.2420188688871668e-09
	Radius		8.623018984340034

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.6402164398620865e-06
		Eccentricity	0.0052685630744627706
		Inclination		-11.941873378483116
		AscendingNode	260.15969952118263
		ArgOfPericen	24.695529925894597
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 773.2"
{
	ParentBody	"Erebos 773"
	Class		"Asteroid"
	Mass		5.680799434823805e-11
	Radius		3.0838016026414183

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.8249100337198955e-06
		Eccentricity	0.0025341863206833973
		Inclination		-43.80833946138014
		AscendingNode	46.81904967443381
		ArgOfPericen	145.28806451722724
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 774"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.995775147477672e-08
	Radius		21.659449309663035

	RotationPeriod	5.785097477638334

	Obliquity		56.17788183133036

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.237066520100412
		Eccentricity	0.0612612225755249
		Inclination		-1.5015948244430923
		AscendingNode	152.39199021723334
		ArgOfPericen	253.27229847823418
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 775"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.487356282687278e-08
	Radius		29.15986232590939

	RotationPeriod	8.164291489562583

	Obliquity		358.7501086805465

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.333289225744323
		Eccentricity	0.06050028680252311
		Inclination		0.7379799168972387
		AscendingNode	357.74623474060417
		ArgOfPericen	48.574770792554816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 776"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3150592493107647
		Eccentricity	0.0437155665491501
		Inclination		-1.7895632762829727
		AscendingNode	335.71977385529254
		ArgOfPericen	240.49200359278424
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 776 A"
{
	ParentBody	"Erebos 776"
	Class		"Asteroid"
	Mass		2.7618045268522337e-07
	Radius		48.25895126035779

	Orbit
	{
		Epoch			2457395.5
		Period			0.006954846584354868
		Eccentricity	0.003898718940268381
		Inclination		131.2259130976613
		AscendingNode	283.3199568532406
		ArgOfPericen	68.07456112643145
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 776 B"
{
	ParentBody	"Erebos 776"
	Class		"Asteroid"
	Mass		1.1049150255943674e-08
	Radius		16.505291314775178

	Orbit
	{
		Epoch			2457395.5
		Period			0.006954846584354868
		Eccentricity	0.003898718940268381
		Inclination		131.2259130976613
		AscendingNode	283.3199568532406
		ArgOfPericen	248.07456112643143
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 777"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.280019083069627
		Eccentricity	0.044473898546928445
		Inclination		-1.2092479006946961
		AscendingNode	11.220028882462746
		ArgOfPericen	297.7297666281252
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 777 A"
{
	ParentBody	"Erebos 777"
	Class		"Asteroid"
	Mass		6.466887440601433e-07
	Radius		65.63415548433746

	Orbit
	{
		Epoch			2457395.5
		Period			0.00285999292173912
		Eccentricity	0.006094819492011875
		Inclination		222.44511515481082
		AscendingNode	229.6774775171014
		ArgOfPericen	292.9050915945849
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 777 B"
{
	ParentBody	"Erebos 777"
	Class		"Asteroid"
	Mass		1.658336699653103e-08
	Radius		19.354815609993075

	Orbit
	{
		Epoch			2457395.5
		Period			0.00285999292173912
		Eccentricity	0.006094819492011875
		Inclination		222.44511515481082
		AscendingNode	229.6774775171014
		ArgOfPericen	112.90509159458492
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 778"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.2337736182280307e-07
	Radius		57.09068937242861

	RotationPeriod	6.350374195123411

	Obliquity		337.8802396298091

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.285995219640349
		Eccentricity	0.047598044504329716
		Inclination		-0.007827981879596196
		AscendingNode	275.4481845289127
		ArgOfPericen	169.6785031920376
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 779"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8875702768958087e-07
	Radius		44.712075994367524

	RotationPeriod	6.717851187279921

	Obliquity		343.8410245271

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.345909018539878
		Eccentricity	0.043097793120024736
		Inclination		0.7053287738222805
		AscendingNode	9.23365989178603
		ArgOfPericen	50.03573133795169
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 779.1"
{
	ParentBody	"Erebos 779"
	Class		"Asteroid"
	Mass		2.197866322477986e-09
	Radius		10.134232948765309

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.906404927107294e-07
		Eccentricity	0.002977871555830007
		Inclination		45.65513736717052
		AscendingNode	219.10546162093303
		ArgOfPericen	11.318190285935454
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 780"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9085485304518375e-07
	Radius		42.01355821336814

	RotationPeriod	6.673867482511706

	Obliquity		323.0198805505264

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.298270240156293
		Eccentricity	0.034493220906022644
		Inclination		-0.32513548890134714
		AscendingNode	55.41770218321347
		ArgOfPericen	48.819401367720296
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 781"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5293041216872593e-07
	Radius		50.73473733921576

	RotationPeriod	6.958818247993789

	Obliquity		18.62477539351574

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.315508417970416
		Eccentricity	0.053753908412356236
		Inclination		0.6515105845176894
		AscendingNode	269.4092710745724
		ArgOfPericen	172.5827088925724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 782"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.878842584381537e-07
	Radius		60.334821595681376

	RotationPeriod	5.261844492160889

	Obliquity		181.03716102136488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.318686216966572
		Eccentricity	0.06505437310146209
		Inclination		-1.599105672613757
		AscendingNode	324.2484520178632
		ArgOfPericen	201.11352990886706
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 783"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.618980710939123e-07
	Radius		59.216592494254805

	RotationPeriod	3.1445139208760295

	Obliquity		257.802693304398

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3289599643128547
		Eccentricity	0.05609652664197578
		Inclination		0.14357280421999968
		AscendingNode	150.7173534199383
		ArgOfPericen	348.23510707770623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 784"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.6876504966899105e-07
	Radius		55.147710874894926

	RotationPeriod	7.776292665264464

	Obliquity		330.22994494870426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2395922977558422
		Eccentricity	0.058650797099254984
		Inclination		-0.21186805798694452
		AscendingNode	273.0902515355709
		ArgOfPericen	107.62426815864444
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 785"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.055599601479522e-07
	Radius		51.07958791222483

	RotationPeriod	8.365449810806851

	Obliquity		137.20399059344456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.192016965317875
		Eccentricity	0.048128268890266536
		Inclination		-3.067585877883054
		AscendingNode	123.35269147347012
		ArgOfPericen	185.19703068227372
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 786"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2712414137255785
		Eccentricity	0.030531170206559342
		Inclination		-0.021620125301262297
		AscendingNode	347.32625329521153
		ArgOfPericen	308.1538769356848
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 786 A"
{
	ParentBody	"Erebos 786"
	Class		"Asteroid"
	Mass		9.892950369953296e-08
	Radius		39.74623175780023

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024950984596456534
		Eccentricity	0.007033145319117105
		Inclination		119.81670594043032
		AscendingNode	330.8240009024626
		ArgOfPericen	215.31152803355948
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 786 B"
{
	ParentBody	"Erebos 786"
	Class		"Asteroid"
	Mass		6.768116142637039e-08
	Radius		35.02218877959138

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024950984596456534
		Eccentricity	0.007033145319117105
		Inclination		119.81670594043032
		AscendingNode	330.8240009024626
		ArgOfPericen	35.31152803355951
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 787"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.552702715413398e-07
	Radius		45.98948710207657

	RotationPeriod	6.891368421707396

	Obliquity		123.60717813610617

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.286084711919173
		Eccentricity	0.03512305560235026
		Inclination		-0.630747063720049
		AscendingNode	123.06487801442978
		ArgOfPericen	62.931847033297586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 788"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5046198538191752e-06
	Radius		85.63182010486551

	RotationPeriod	7.5336925593026995

	Obliquity		310.48527101986434

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3510458420200777
		Eccentricity	0.06834506521727757
		Inclination		-2.703361791806194
		AscendingNode	238.64398928369638
		ArgOfPericen	61.89621081188129
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 789"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4995639555227866e-07
	Radius		50.78654693756515

	RotationPeriod	4.310848082029972

	Obliquity		274.103774790132

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2605180213099585
		Eccentricity	0.04464020477920953
		Inclination		2.5921998850670662
		AscendingNode	273.9963671633022
		ArgOfPericen	359.98012432430517
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 790"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2960012795704534
		Eccentricity	0.06669205588687037
		Inclination		0.8589594917107028
		AscendingNode	96.37451119225835
		ArgOfPericen	66.00738248268102
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 790 A"
{
	ParentBody	"Erebos 790"
	Class		"Asteroid"
	Mass		5.298897722635714e-07
	Radius		64.10568390512817

	Orbit
	{
		Epoch			2457395.5
		Period			0.008087151381423631
		Eccentricity	0.0038052143143375424
		Inclination		175.44783740369866
		AscendingNode	64.36893514499839
		ArgOfPericen	221.34853746357507
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 790 B"
{
	ParentBody	"Erebos 790"
	Class		"Asteroid"
	Mass		3.530100275148519e-08
	Radius		25.98745235519625

	Orbit
	{
		Epoch			2457395.5
		Period			0.008087151381423631
		Eccentricity	0.0038052143143375424
		Inclination		175.44783740369866
		AscendingNode	64.36893514499839
		ArgOfPericen	41.3485374635751
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 791"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.4085582539631733e-07
	Radius		60.18715156044914

	RotationPeriod	8.16123762085783

	Obliquity		104.81662472271142

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3106633148917184
		Eccentricity	0.04517836793745286
		Inclination		2.0013153785989934
		AscendingNode	101.67329523509214
		ArgOfPericen	259.75055700915755
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 792"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7715926031509977e-07
	Radius		44.953309261798765

	RotationPeriod	8.26017782482796

	Obliquity		149.76214657632107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.333542532562805
		Eccentricity	0.03733855947273287
		Inclination		1.1594011097838872
		AscendingNode	303.57133616751946
		ArgOfPericen	124.05566866987515
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 793"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.186195331470084e-07
	Radius		61.89143507131815

	RotationPeriod	3.9390617758525877

	Obliquity		44.100906380698156

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3182256706113473
		Eccentricity	0.0730730176332906
		Inclination		-1.2823560900906124
		AscendingNode	122.33725406187256
		ArgOfPericen	216.06354880171017
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 794"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.910128952411545e-07
	Radius		52.320149790867426

	RotationPeriod	7.185714938149779

	Obliquity		233.4568138794301

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3171727257012873
		Eccentricity	0.027904055010958783
		Inclination		-0.7053796732204131
		AscendingNode	292.2565804818019
		ArgOfPericen	3.595076116374134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 795"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.267476506958811e-07
	Radius		66.1150193345742

	RotationPeriod	6.816044529297563

	Obliquity		216.75327691568458

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.41813231003536
		Eccentricity	0.04534822887192008
		Inclination		0.17501640226626144
		AscendingNode	342.82534384113444
		ArgOfPericen	64.52257340547158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 796"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2929973424564647
		Eccentricity	0.021954535874483816
		Inclination		1.2750367856806404
		AscendingNode	126.1133804510942
		ArgOfPericen	230.83227927530675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 796 A"
{
	ParentBody	"Erebos 796"
	Class		"Asteroid"
	Mass		3.6833524030433155e-07
	Radius		54.16069254457846

	Orbit
	{
		Epoch			2457395.5
		Period			0.007689890721379474
		Eccentricity	0.00339818418105519
		Inclination		120.21602690646125
		AscendingNode	213.72530189620068
		ArgOfPericen	1.0560692973789987
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 796 B"
{
	ParentBody	"Erebos 796"
	Class		"Asteroid"
	Mass		1.688071629396092e-07
	Radius		41.75739605357581

	Orbit
	{
		Epoch			2457395.5
		Period			0.007689890721379474
		Eccentricity	0.00339818418105519
		Inclination		120.21602690646125
		AscendingNode	213.72530189620068
		ArgOfPericen	181.056069297379
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 797"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.405612726964854e-06
	Radius		86.06345104858858

	RotationPeriod	8.588670357918357

	Obliquity		295.9046378903494

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2797390792479333
		Eccentricity	0.06449014942732517
		Inclination		1.892149088236993
		AscendingNode	348.99993245672766
		ArgOfPericen	333.9166469232704
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 798"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.534532109498421e-07
	Radius		54.56778631236617

	RotationPeriod	5.9021017557240665

	Obliquity		161.33299796298874

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.324382607344632
		Eccentricity	0.0522922343871428
		Inclination		0.11116396905540468
		AscendingNode	163.53444602777887
		ArgOfPericen	50.49137303647235
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 799"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2741797678867566
		Eccentricity	0.011325576454195074
		Inclination		-5.0
		AscendingNode	14.420498564964458
		ArgOfPericen	346.1748910334671
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 799 A"
{
	ParentBody	"Erebos 799"
	Class		"Asteroid"
	Mass		2.372217558203649e-07
	Radius		45.86656266632432

	Orbit
	{
		Epoch			2457395.5
		Period			0.006901006781710014
		Eccentricity	0.0053509757511000285
		Inclination		193.27094750442043
		AscendingNode	67.03833100104538
		ArgOfPericen	182.0977917042778
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 799 B"
{
	ParentBody	"Erebos 799"
	Class		"Asteroid"
	Mass		1.1960124250215835e-08
	Radius		16.94428520728393

	Orbit
	{
		Epoch			2457395.5
		Period			0.006901006781710014
		Eccentricity	0.0053509757511000285
		Inclination		193.27094750442043
		AscendingNode	67.03833100104538
		ArgOfPericen	2.0977917042778245
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 800"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.146055136637752e-07
	Radius		58.20435388257482

	RotationPeriod	6.574259609097696

	Obliquity		95.46940560214033

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3788639191959926
		Eccentricity	0.011325240617996446
		Inclination		1.2366933160540632
		AscendingNode	297.3414673470531
		ArgOfPericen	351.9586511947885
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 801"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.611653411728952e-07
	Radius		55.659091223142525

	RotationPeriod	1.268623887432157

	Obliquity		58.69118233121769

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2707104325884324
		Eccentricity	0.039281972762143305
		Inclination		-0.675646921110041
		AscendingNode	230.0756615970187
		ArgOfPericen	80.40887067232875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 802"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6541038673019888e-07
	Radius		41.44700865552191

	RotationPeriod	5.3226961115404565

	Obliquity		249.4003064260794

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.26949588564904
		Eccentricity	0.01750594421824863
		Inclination		2.1102949992323357
		AscendingNode	56.382236446926065
		ArgOfPericen	312.1177127194147
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 802.1"
{
	ParentBody	"Erebos 802"
	Class		"Asteroid"
	Mass		4.044184408052334e-10
	Radius		5.5836207982373836

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.55620715838118e-07
		Eccentricity	0.0040220903529710654
		Inclination		-27.91624602227491
		AscendingNode	71.30841229943567
		ArgOfPericen	234.47919119814495
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 803"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3927436722635074
		Eccentricity	0.03940321800951144
		Inclination		0.4501459841535904
		AscendingNode	79.07450546182888
		ArgOfPericen	266.7802295095597
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 803 A"
{
	ParentBody	"Erebos 803"
	Class		"Asteroid"
	Mass		5.483359937707768e-07
	Radius		59.5233992049623

	Orbit
	{
		Epoch			2457395.5
		Period			0.005149120109552653
		Eccentricity	0.005122724281713551
		Inclination		259.12197433146287
		AscendingNode	240.38208265026051
		ArgOfPericen	34.14636454116661
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 803 B"
{
	ParentBody	"Erebos 803"
	Class		"Asteroid"
	Mass		7.2980297990355e-08
	Radius		30.390698619312477

	Orbit
	{
		Epoch			2457395.5
		Period			0.005149120109552653
		Eccentricity	0.005122724281713551
		Inclination		259.12197433146287
		AscendingNode	240.38208265026051
		ArgOfPericen	214.1463645411666
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 804"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7843949025615394e-07
	Radius		45.68342551508816

	RotationPeriod	9.097367242278104

	Obliquity		266.6414533255472

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3167602229834947
		Eccentricity	0.03198191964513582
		Inclination		-0.994904876828116
		AscendingNode	294.27543803859055
		ArgOfPericen	151.46115748307315
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 804.1"
{
	ParentBody	"Erebos 804"
	Class		"Asteroid"
	Mass		8.79012441924452e-11
	Radius		3.6079458513227576

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2285819288268917e-06
		Eccentricity	0.005007234622475999
		Inclination		2.7734020626202716
		AscendingNode	177.91191520209813
		ArgOfPericen	50.392276583264845
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 805"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2598428184368475
		Eccentricity	0.062022879718155254
		Inclination		-1.374636506787382
		AscendingNode	327.49418574981655
		ArgOfPericen	203.80009770280185
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 805 A"
{
	ParentBody	"Erebos 805"
	Class		"Asteroid"
	Mass		5.813418530831153e-07
	Radius		67.30401752182198

	Orbit
	{
		Epoch			2457395.5
		Period			0.004659769318404019
		Eccentricity	0.00515286248250739
		Inclination		323.92268566087967
		AscendingNode	196.69390505320487
		ArgOfPericen	142.00448001318287
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 805 B"
{
	ParentBody	"Erebos 805"
	Class		"Asteroid"
	Mass		7.08329790466228e-08
	Radius		33.36636998898669

	Orbit
	{
		Epoch			2457395.5
		Period			0.004659769318404019
		Eccentricity	0.00515286248250739
		Inclination		323.92268566087967
		AscendingNode	196.69390505320487
		ArgOfPericen	322.00448001318284
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 806"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.4965956600793653e-07
	Radius		46.853367809507866

	RotationPeriod	4.8260307291531355

	Obliquity		94.4989603931381

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2589531981128608
		Eccentricity	0.0030696105902059123
		Inclination		0.26039326893079207
		AscendingNode	293.75361922122545
		ArgOfPericen	332.9996577278861
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 807"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.568569829553267e-07
	Radius		63.11066262581642

	RotationPeriod	5.305733570559599

	Obliquity		306.39648750553755

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3811779839198763
		Eccentricity	0.07889084129983212
		Inclination		-0.5782053691020713
		AscendingNode	68.58359233377345
		ArgOfPericen	0.9838556822264799
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 808"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.692539878683371e-07
	Radius		53.37003029650403

	RotationPeriod	3.9648758678110974

	Obliquity		153.86824600064068

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.300460712043381
		Eccentricity	0.017919546405343947
		Inclination		-2.129667331439598
		AscendingNode	296.3700297567911
		ArgOfPericen	119.16260835845569
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 809"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.046030845995926e-08
	Radius		33.18937262072322

	RotationPeriod	6.048749973627921

	Obliquity		73.79671372343195

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.370523463997352
		Eccentricity	0.05890405133794555
		Inclination		1.8175452752264476
		AscendingNode	98.5463901867754
		ArgOfPericen	50.94290006003422
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 810"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.274988003489305e-07
	Radius		54.815058766699785

	RotationPeriod	7.935179963095677

	Obliquity		58.8602809673196

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.348774219845623
		Eccentricity	0.04695477186664988
		Inclination		1.966058754991784
		AscendingNode	122.80906250367246
		ArgOfPericen	22.384879892515727
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 811"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.589568042835982e-07
	Radius		48.58285000328449

	RotationPeriod	9.409517079827793

	Obliquity		105.14161118711411

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.319010555459134
		Eccentricity	0.05310804917618527
		Inclination		1.4452484786220563
		AscendingNode	21.526856619472888
		ArgOfPericen	305.08377545829336
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 812"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5958138816142233e-07
	Radius		44.115060913934535

	RotationPeriod	5.206737679701573

	Obliquity		214.83875437259988

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3090889398289782
		Eccentricity	0.06503315408982255
		Inclination		-3.5528485215881997
		AscendingNode	323.360091931376
		ArgOfPericen	66.13019372337328
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 813"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1621572600799093e-07
	Radius		47.772834213962916

	RotationPeriod	6.507816830590335

	Obliquity		273.8215668017109

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2924459335211216
		Eccentricity	0.07281624094866883
		Inclination		-0.025344180240538458
		AscendingNode	186.57155776710965
		ArgOfPericen	61.100476028897816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 814"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.882644589182572e-07
	Radius		75.81325736800014

	RotationPeriod	7.319444635023708

	Obliquity		281.3850175736043

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3595367515961163
		Eccentricity	0.0428697541754371
		Inclination		-1.2686099958997472
		AscendingNode	251.8717192840827
		ArgOfPericen	279.70474508713147
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 815"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.539663206955492e-08
	Radius		18.632690390576965

	RotationPeriod	6.950341352300848

	Obliquity		71.03191309107814

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3029371185463767
		Eccentricity	0.06909549062257798
		Inclination		-2.4919408374782424
		AscendingNode	49.062689608237065
		ArgOfPericen	6.143388915818346
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 815.1"
{
	ParentBody	"Erebos 815"
	Class		"Asteroid"
	Mass		1.231099523608942e-10
	Radius		3.725901574308478

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0173993769772446e-06
		Eccentricity	0.003119160574055601
		Inclination		-18.798104684557075
		AscendingNode	189.9154048814463
		ArgOfPericen	274.5464364967317
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 816"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.233993837364306e-08
	Radius		32.558145824653096

	RotationPeriod	8.218848861069448

	Obliquity		242.78877071142867

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3857980262556318
		Eccentricity	0.07168345713886695
		Inclination		-0.20296141591761904
		AscendingNode	139.8620237168355
		ArgOfPericen	166.68403677844591
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 817"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.344712221026861
		Eccentricity	0.07689276124329193
		Inclination		-0.06855069854673514
		AscendingNode	106.90910386152433
		ArgOfPericen	333.9141477173126
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 817 A"
{
	ParentBody	"Erebos 817"
	Class		"Asteroid"
	Mass		2.6490173853340455e-07
	Radius		50.21417434008857

	Orbit
	{
		Epoch			2457395.5
		Period			0.003094973053517422
		Eccentricity	0.005353515856546511
		Inclination		242.04150511399848
		AscendingNode	208.52915331030897
		ArgOfPericen	102.04058836504514
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 817 B"
{
	ParentBody	"Erebos 817"
	Class		"Asteroid"
	Mass		8.330493645698575e-09
	Radius		15.84972150763723

	Orbit
	{
		Epoch			2457395.5
		Period			0.003094973053517422
		Eccentricity	0.005353515856546511
		Inclination		242.04150511399848
		AscendingNode	208.52915331030897
		ArgOfPericen	282.04058836504515
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 818"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.064394740131852e-07
	Radius		50.365603436477095

	RotationPeriod	8.439719231157598

	Obliquity		150.3131481538603

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2342090586911
		Eccentricity	0.037615189499630164
		Inclination		-0.2448446685792531
		AscendingNode	359.6331865082138
		ArgOfPericen	35.6682461114892
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 819"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3141835064535994
		Eccentricity	0.031043332231513874
		Inclination		-0.590372160485209
		AscendingNode	162.67302449264884
		ArgOfPericen	106.42612484735778
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 819 A"
{
	ParentBody	"Erebos 819"
	Class		"Asteroid"
	Mass		3.0851221629836364e-07
	Radius		51.99129519253366

	Orbit
	{
		Epoch			2457395.5
		Period			0.005255816593748091
		Eccentricity	0.004742141577689634
		Inclination		188.27735260013
		AscendingNode	320.3043493821543
		ArgOfPericen	101.19835135500459
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 819 B"
{
	ParentBody	"Erebos 819"
	Class		"Asteroid"
	Mass		4.928229918560587e-08
	Radius		28.210026990760145

	Orbit
	{
		Epoch			2457395.5
		Period			0.005255816593748091
		Eccentricity	0.004742141577689634
		Inclination		188.27735260013
		AscendingNode	320.3043493821543
		ArgOfPericen	281.1983513550046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 820"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.316571402826712
		Eccentricity	0.0803581282608037
		Inclination		0.48230380730513095
		AscendingNode	303.05316680233244
		ArgOfPericen	264.44699166546883
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 820 A"
{
	ParentBody	"Erebos 820"
	Class		"Asteroid"
	Mass		3.601694091275197e-07
	Radius		53.20023798053529

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019518254093506715
		Eccentricity	0.004790421362170738
		Inclination		283.23005305550595
		AscendingNode	55.65259493842928
		ArgOfPericen	118.79313031794901
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 820 B"
{
	ParentBody	"Erebos 820"
	Class		"Asteroid"
	Mass		4.644611084966739e-08
	Radius		26.877843364475424

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019518254093506715
		Eccentricity	0.004790421362170738
		Inclination		283.23005305550595
		AscendingNode	55.65259493842928
		ArgOfPericen	298.793130317949
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 821"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3487672922576897
		Eccentricity	0.04855983688560685
		Inclination		-1.3158873302467349
		AscendingNode	307.5498212174773
		ArgOfPericen	213.32382185010565
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 821 A"
{
	ParentBody	"Erebos 821"
	Class		"Asteroid"
	Mass		7.361453554348026e-07
	Radius		69.58532090180002

	Orbit
	{
		Epoch			2457395.5
		Period			0.001231324184893419
		Eccentricity	0.003900071931958261
		Inclination		244.34118145708808
		AscendingNode	350.80072593158354
		ArgOfPericen	291.5862770483629
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 821 B"
{
	ParentBody	"Erebos 821"
	Class		"Asteroid"
	Mass		2.3259244634359568e-07
	Radius		47.39453985172559

	Orbit
	{
		Epoch			2457395.5
		Period			0.001231324184893419
		Eccentricity	0.003900071931958261
		Inclination		244.34118145708808
		AscendingNode	350.80072593158354
		ArgOfPericen	111.58627704836289
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 822"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.798466425730843e-07
	Radius		56.772351224344575

	RotationPeriod	9.651179270850815

	Obliquity		139.79041255375068

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3268628390321076
		Eccentricity	0.07556112205669407
		Inclination		-2.1794167572617105
		AscendingNode	60.92997695922592
		ArgOfPericen	36.6233132203172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 823"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3591304288804387
		Eccentricity	0.05288104169026423
		Inclination		-1.3172791481111867
		AscendingNode	245.86418277701085
		ArgOfPericen	215.89032932720448
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 823 A"
{
	ParentBody	"Erebos 823"
	Class		"Asteroid"
	Mass		7.81196131487722e-07
	Radius		65.36801374641638

	Orbit
	{
		Epoch			2457395.5
		Period			0.002362125267147087
		Eccentricity	0.005270504586552734
		Inclination		113.83755937343027
		AscendingNode	316.66785924495775
		ArgOfPericen	121.7811405334945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 823 B"
{
	ParentBody	"Erebos 823"
	Class		"Asteroid"
	Mass		6.075358190001677e-07
	Radius		60.11311365417736

	Orbit
	{
		Epoch			2457395.5
		Period			0.002362125267147087
		Eccentricity	0.005270504586552734
		Inclination		113.83755937343027
		AscendingNode	316.66785924495775
		ArgOfPericen	301.7811405334945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 824"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.821233054070951e-07
	Radius		64.92475145172689

	RotationPeriod	5.399121080113295

	Obliquity		32.23653452024897

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.368984404379261
		Eccentricity	0.059180073501666805
		Inclination		-3.926951481251537
		AscendingNode	279.2380651588189
		ArgOfPericen	289.8356798516702
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 825"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2206921058954816e-08
	Radius		21.716956111843956

	RotationPeriod	7.299194695247381

	Obliquity		330.92597220724247

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3770303608428986
		Eccentricity	0.055819567277905685
		Inclination		0.17955703906755044
		AscendingNode	23.059839339055284
		ArgOfPericen	83.3496505739976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 825.1"
{
	ParentBody	"Erebos 825"
	Class		"Asteroid"
	Mass		3.330030745947033e-11
	Radius		2.485720258870788

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.139678493431552e-07
		Eccentricity	0.003991522906207743
		Inclination		4.880932849051625
		AscendingNode	358.6814096309608
		ArgOfPericen	325.47252362102694
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 826"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8195854581565465e-07
	Radius		40.75965714224898

	RotationPeriod	8.456938082408458

	Obliquity		99.61949141219445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1831199960060834
		Eccentricity	0.028111631960834577
		Inclination		-2.5611515016988933
		AscendingNode	142.50830423855578
		ArgOfPericen	2.162195298800227
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 826.1"
{
	ParentBody	"Erebos 826"
	Class		"Asteroid"
	Mass		1.644606244711402e-09
	Radius		8.490377781927345

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.165028892341e-06
		Eccentricity	0.0065848588228080394
		Inclination		9.247049450129245
		AscendingNode	349.62201812014393
		ArgOfPericen	15.704194914019446
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 827"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.6683070604661213e-08
	Radius		22.917964275170085

	RotationPeriod	8.41276015996223

	Obliquity		354.91505851567933

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3274238516667842
		Eccentricity	0.04700359541879195
		Inclination		-3.1245530173179543
		AscendingNode	337.7059645419861
		ArgOfPericen	179.795762473518
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 828"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0229071626412839e-07
	Radius		37.73601790960753

	RotationPeriod	5.109696306064098

	Obliquity		252.56994087603732

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2256273775199205
		Eccentricity	0.04176900046198847
		Inclination		-2.9481632172211074
		AscendingNode	133.23079547038063
		ArgOfPericen	37.535407834300344
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 829"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3864514104926642e-07
	Radius		39.29804779855125

	RotationPeriod	3.558158432671871

	Obliquity		109.4683781877151

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4256858681512954
		Eccentricity	0.056882006559411266
		Inclination		0.921547845524906
		AscendingNode	194.17321421483192
		ArgOfPericen	335.39084775635285
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 830"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.649542380884337e-07
	Radius		62.290957519070226

	RotationPeriod	10.416896404778953

	Obliquity		221.02175672457562

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.342485921668253
		Eccentricity	0.03589916833368938
		Inclination		-1.6296721647140486
		AscendingNode	195.74752883183078
		ArgOfPericen	213.20420160747673
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 831"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.8679754005380493e-07
	Radius		53.77779883262875

	RotationPeriod	7.5862370315547505

	Obliquity		123.29835991062075

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.37001467606328
		Eccentricity	0.06314698646394185
		Inclination		0.04516570930405991
		AscendingNode	198.41428803983672
		ArgOfPericen	358.6656348629232
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 832"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.40616525958343e-07
	Radius		51.325375481670406

	RotationPeriod	7.8282681187573395

	Obliquity		159.12985186258607

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2805451114794146
		Eccentricity	0.05518168516918884
		Inclination		1.2280008181842497
		AscendingNode	2.266949466857673
		ArgOfPericen	153.97319893333867
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 833"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3611972432318043e-07
	Radius		43.31042160299017

	RotationPeriod	6.612172140614889

	Obliquity		252.06900236007132

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.323724411830651
		Eccentricity	0.01612657985524646
		Inclination		1.7241641801840095
		AscendingNode	149.9565337299449
		ArgOfPericen	356.5623814306301
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 834"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.322101466336208
		Eccentricity	0.040642624843981824
		Inclination		2.0827368544861353
		AscendingNode	39.10132953689326
		ArgOfPericen	261.85797286435127
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 834 A"
{
	ParentBody	"Erebos 834"
	Class		"Asteroid"
	Mass		1.555223436363622e-06
	Radius		87.5937729585171

	Orbit
	{
		Epoch			2457395.5
		Period			0.007760922956393734
		Eccentricity	0.007491885171541366
		Inclination		134.37447777321222
		AscendingNode	23.435617396362286
		ArgOfPericen	220.1840761686183
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 834 B"
{
	ParentBody	"Erebos 834"
	Class		"Asteroid"
	Mass		2.476792612259117e-07
	Radius		47.479432245893285

	Orbit
	{
		Epoch			2457395.5
		Period			0.007760922956393734
		Eccentricity	0.007491885171541366
		Inclination		134.37447777321222
		AscendingNode	23.435617396362286
		ArgOfPericen	40.184076168618276
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 835"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.361569161108175e-07
	Radius		57.43580443267083

	RotationPeriod	7.278963215899759

	Obliquity		56.1360849380361

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2325152523619973
		Eccentricity	0.04059858177962524
		Inclination		-0.7227235857649932
		AscendingNode	202.41910629216497
		ArgOfPericen	255.04626171552675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 836"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.2182506777557906e-07
	Radius		58.702946006722144

	RotationPeriod	3.7887538538642813

	Obliquity		157.78277123995267

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.328860583103147
		Eccentricity	0.0011147159782097307
		Inclination		0.6556042018921852
		AscendingNode	134.04593016357586
		ArgOfPericen	41.588558657728626
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 837"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6303425678113686e-07
	Radius		42.49987275769547

	RotationPeriod	4.610665792637852

	Obliquity		104.8049624529781

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1905492728932794
		Eccentricity	0.039128460134405144
		Inclination		-1.7042515055274208
		AscendingNode	255.84261784962072
		ArgOfPericen	320.48101980377595
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 838"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0658697299687753e-07
	Radius		36.04699571861239

	RotationPeriod	5.104009838030906

	Obliquity		246.96847253582115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.23078378706632
		Eccentricity	0.036237638714997335
		Inclination		0.6095533474136887
		AscendingNode	232.84893379453135
		ArgOfPericen	106.78076642250808
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 839"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.454347937454679e-07
	Radius		56.52369771520933

	RotationPeriod	9.179310909805562

	Obliquity		321.97013561512745

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.194106327851762
		Eccentricity	0.04916780132818027
		Inclination		-0.9828183339716939
		AscendingNode	350.89368492677136
		ArgOfPericen	325.09312191584706
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 840"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5794547190838724e-07
	Radius		46.77110165162784

	RotationPeriod	3.1469324744097076

	Obliquity		327.3506627188256

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1958080375264655
		Eccentricity	0.04328485966591293
		Inclination		-2.117421443641498
		AscendingNode	272.80321021879774
		ArgOfPericen	277.7963817244913
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 841"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.7103204632095896e-07
	Radius		58.76723934083624

	RotationPeriod	9.449894623957777

	Obliquity		69.45832837231882

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.339123231833852
		Eccentricity	0.03188614891180762
		Inclination		-2.4547165647234483
		AscendingNode	156.24327096690556
		ArgOfPericen	11.43184034454146
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 841.1"
{
	ParentBody	"Erebos 841"
	Class		"Asteroid"
	Mass		2.982241092339428e-09
	Radius		11.77187745716278

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.655701446120243e-07
		Eccentricity	0.007081767596176618
		Inclination		10.902270524235272
		AscendingNode	4.3927427384487405
		ArgOfPericen	49.786927684526496
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 842"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.039916030140083e-08
	Radius		21.26232389335049

	RotationPeriod	3.63894302236674

	Obliquity		133.9227857872582

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.35943244931324
		Eccentricity	0.03143487484511453
		Inclination		-0.1525017007648678
		AscendingNode	85.94156118836692
		ArgOfPericen	83.09569794961192
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 842.1"
{
	ParentBody	"Erebos 842"
	Class		"Asteroid"
	Mass		5.116643657372579e-11
	Radius		2.888916726007448

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3769822284190963e-06
		Eccentricity	0.008359993752573232
		Inclination		15.56540578812575
		AscendingNode	127.39489178396117
		ArgOfPericen	254.58602460615097
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 843"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7234126438202477e-07
	Radius		48.270505327168856

	RotationPeriod	3.525241327496339

	Obliquity		356.13193001171453

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3078560407507465
		Eccentricity	0.07188345738439876
		Inclination		2.1687350338702056
		AscendingNode	126.64521403661665
		ArgOfPericen	111.35651543534803
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 844"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.9165181199861037e-07
	Radius		44.92831797797303

	RotationPeriod	4.939327632566768

	Obliquity		331.7637726962542

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4024182950447734
		Eccentricity	0.042945014432024656
		Inclination		-0.475389973115594
		AscendingNode	98.95633339307298
		ArgOfPericen	36.04640676306565
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 844.1"
{
	ParentBody	"Erebos 844"
	Class		"Asteroid"
	Mass		3.745098919642196e-10
	Radius		5.616989529722694

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.603130503798302e-06
		Eccentricity	0.007140169158564391
		Inclination		4.699786318965294
		AscendingNode	135.29636443161056
		ArgOfPericen	64.96744034190046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 845"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.25892153577282e-07
	Radius		65.34303678806887

	RotationPeriod	6.313830060529148

	Obliquity		190.40994466465673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3422515271522175
		Eccentricity	0.06649375192336324
		Inclination		-0.9221705252125231
		AscendingNode	111.68714742249536
		ArgOfPericen	297.775010157332
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 846"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.470827389738937e-07
	Radius		63.298269170617715

	RotationPeriod	3.697904745026541

	Obliquity		78.23082040981444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.404258742192568
		Eccentricity	0.03828171413775035
		Inclination		-1.279282655148967
		AscendingNode	103.85030154983755
		ArgOfPericen	147.69529509132758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 847"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.772329221252466e-07
	Radius		50.624031961928296

	RotationPeriod	4.148761109088291

	Obliquity		205.79112547105032

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3809853117998787
		Eccentricity	0.04676900439354128
		Inclination		-0.9101193883400632
		AscendingNode	343.1267475065798
		ArgOfPericen	182.90205997474789
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 848"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.125529407455792e-07
	Radius		64.89029743996205

	RotationPeriod	7.963791357123501

	Obliquity		82.52607248877514

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.340324905654455
		Eccentricity	0.024939130550972157
		Inclination		-0.9175345249217994
		AscendingNode	351.37833894171126
		ArgOfPericen	108.8663227045905
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 848.1"
{
	ParentBody	"Erebos 848"
	Class		"Asteroid"
	Mass		7.076463336263224e-09
	Radius		14.669117099131926

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.34173430814161e-07
		Eccentricity	0.00386965191801385
		Inclination		-6.8650858275084214
		AscendingNode	54.03566333409481
		ArgOfPericen	322.6269364611423
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 849"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.32190214314199
		Eccentricity	0.03135301838672896
		Inclination		1.6870612470905493
		AscendingNode	187.36333087174165
		ArgOfPericen	49.76040719747215
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 849 A"
{
	ParentBody	"Erebos 849"
	Class		"Asteroid"
	Mass		5.419321432344326e-08
	Radius		30.01485143712932

	Orbit
	{
		Epoch			2457395.5
		Period			0.0045159722497776986
		Eccentricity	0.00544915897107761
		Inclination		77.98085951501886
		AscendingNode	260.2344241407464
		ArgOfPericen	127.60534963917401
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 849 B"
{
	ParentBody	"Erebos 849"
	Class		"Asteroid"
	Mass		2.8622437546863433e-08
	Radius		24.261823182394227

	Orbit
	{
		Epoch			2457395.5
		Period			0.0045159722497776986
		Eccentricity	0.00544915897107761
		Inclination		77.98085951501886
		AscendingNode	260.2344241407464
		ArgOfPericen	307.605349639174
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 850"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.855952034844068e-07
	Radius		62.62067048440434

	RotationPeriod	4.86654157270926

	Obliquity		325.01397795882025

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2987014959787206
		Eccentricity	0.03263963444516543
		Inclination		-0.19547492839751696
		AscendingNode	161.58771114335423
		ArgOfPericen	147.42974837766565
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 851"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8043895309719068e-07
	Radius		43.30107683364964

	RotationPeriod	6.956870656693855

	Obliquity		124.59277423235707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2205345974158215
		Eccentricity	0.05218690846996695
		Inclination		1.3806630039237395
		AscendingNode	354.32638721929834
		ArgOfPericen	340.5087587398462
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 852"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.296238279017253
		Eccentricity	0.05465882730400494
		Inclination		1.118045503733786
		AscendingNode	101.74002683910606
		ArgOfPericen	281.1994378689683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 852 A"
{
	ParentBody	"Erebos 852"
	Class		"Asteroid"
	Mass		9.337402107724804e-07
	Radius		79.10549286440599

	Orbit
	{
		Epoch			2457395.5
		Period			0.002076032257957613
		Eccentricity	0.0024149529714969802
		Inclination		283.5725916153257
		AscendingNode	11.210958139421301
		ArgOfPericen	335.622377504976
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 852 B"
{
	ParentBody	"Erebos 852"
	Class		"Asteroid"
	Mass		2.137907883691182e-08
	Radius		22.46264790576312

	Orbit
	{
		Epoch			2457395.5
		Period			0.002076032257957613
		Eccentricity	0.0024149529714969802
		Inclination		283.5725916153257
		AscendingNode	11.210958139421301
		ArgOfPericen	155.62237750497593
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 853"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.478456456620721e-07
	Radius		71.50604835561899

	RotationPeriod	4.650879690573114

	Obliquity		352.43912443929287

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3139353149704016
		Eccentricity	0.060718915728826796
		Inclination		-1.5237240826859546
		AscendingNode	284.2185704858471
		ArgOfPericen	52.304414851503395
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 854"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1463856886821969e-06
	Radius		81.13247917443293

	RotationPeriod	7.490597795088464

	Obliquity		157.75156137606277

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2634795786689565
		Eccentricity	0.03887681142257826
		Inclination		-0.22807919431845353
		AscendingNode	311.917065028816
		ArgOfPericen	173.3266444973463
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 854.1"
{
	ParentBody	"Erebos 854"
	Class		"Asteroid"
	Mass		8.344528805844339e-09
	Radius		15.723592060912434

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.5438785978270845e-06
		Eccentricity	0.0017278062638491159
		Inclination		36.15913720957234
		AscendingNode	330.90927596776845
		ArgOfPericen	104.6472532553239
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 855"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.937489689777058e-08
	Radius		31.431661179074563

	RotationPeriod	5.964739818988928

	Obliquity		101.14759910315557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2313715912958023
		Eccentricity	0.044345789241916185
		Inclination		-1.720440204520786
		AscendingNode	19.690411725884882
		ArgOfPericen	214.02759443234683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 856"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.150057277730786e-07
	Radius		38.68946464515023

	RotationPeriod	6.047873102796087

	Obliquity		268.9114072761018

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.409986393913274
		Eccentricity	0.035588979914523644
		Inclination		0.0240020425239097
		AscendingNode	40.16118765720153
		ArgOfPericen	174.7089837094425
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 857"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2948404973620375
		Eccentricity	0.05597410172147913
		Inclination		-1.0237306241824158
		AscendingNode	257.3611570126163
		ArgOfPericen	319.23207763191687
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 857 A"
{
	ParentBody	"Erebos 857"
	Class		"Asteroid"
	Mass		2.937670115553757e-07
	Radius		52.07617635342011

	Orbit
	{
		Epoch			2457395.5
		Period			0.005714829974097583
		Eccentricity	0.003155507611831117
		Inclination		134.73717216048408
		AscendingNode	110.35390526678941
		ArgOfPericen	276.92002803520904
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 857 B"
{
	ParentBody	"Erebos 857"
	Class		"Asteroid"
	Mass		5.99503620030837e-08
	Radius		30.659755268332276

	Orbit
	{
		Epoch			2457395.5
		Period			0.005714829974097583
		Eccentricity	0.003155507611831117
		Inclination		134.73717216048408
		AscendingNode	110.35390526678941
		ArgOfPericen	96.92002803520904
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 858"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3463130981156586
		Eccentricity	0.05252886143285176
		Inclination		-0.6067357485001924
		AscendingNode	105.68951473543706
		ArgOfPericen	308.2548260338882
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 858 A"
{
	ParentBody	"Erebos 858"
	Class		"Asteroid"
	Mass		4.210532237063936e-08
	Radius		27.765460077265516

	Orbit
	{
		Epoch			2457395.5
		Period			0.007784089716464965
		Eccentricity	0.006059361915321878
		Inclination		292.81987263300937
		AscendingNode	32.62163153462107
		ArgOfPericen	182.32690909495363
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 858 B"
{
	ParentBody	"Erebos 858"
	Class		"Asteroid"
	Mass		8.247103256475729e-09
	Radius		16.12475108725243

	Orbit
	{
		Epoch			2457395.5
		Period			0.007784089716464965
		Eccentricity	0.006059361915321878
		Inclination		292.81987263300937
		AscendingNode	32.62163153462107
		ArgOfPericen	2.326909094953635
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 859"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1496504120180741e-07
	Radius		38.487125044068605

	RotationPeriod	5.736788874447584

	Obliquity		289.71609599804196

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.284401508193885
		Eccentricity	0.03499218938311567
		Inclination		-2.0447299491686195
		AscendingNode	248.3845902012025
		ArgOfPericen	213.92538993883025
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 860"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1708064415200716e-07
	Radius		41.629221769698106

	RotationPeriod	3.2034841735760775

	Obliquity		67.99114151535565

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3833450937988236
		Eccentricity	0.05179279592065465
		Inclination		0.28316728342000186
		AscendingNode	221.14475125404556
		ArgOfPericen	311.51323481664485
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 861"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.767003001824124e-07
	Radius		67.84043378525219

	RotationPeriod	4.32002180410968

	Obliquity		257.7440734611573

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.278103347081059
		Eccentricity	0.04935134855734662
		Inclination		-2.1224030523628277
		AscendingNode	202.45319568673364
		ArgOfPericen	30.686001415881563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 861.1"
{
	ParentBody	"Erebos 861"
	Class		"Asteroid"
	Mass		1.4300005686896933e-09
	Radius		9.182282015526056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.4441586715383e-06
		Eccentricity	0.0048538868799178694
		Inclination		19.37088799902854
		AscendingNode	257.40678029200774
		ArgOfPericen	120.38842212056186
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 861.2"
{
	ParentBody	"Erebos 861"
	Class		"Asteroid"
	Mass		8.40760184650916e-09
	Radius		16.572801781888614

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.56567525737103e-06
		Eccentricity	0.003944612936375458
		Inclination		34.44094572923761
		AscendingNode	209.73910566092084
		ArgOfPericen	72.96203668626492
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 862"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2334708136226333
		Eccentricity	0.07235102569824717
		Inclination		0.20679382431743956
		AscendingNode	18.446675134161236
		ArgOfPericen	193.12804459865328
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 862 A"
{
	ParentBody	"Erebos 862"
	Class		"Asteroid"
	Mass		1.855316768624932e-06
	Radius		94.31409526354383

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015062095780118926
		Eccentricity	0.0056267701671320735
		Inclination		225.87100048065187
		AscendingNode	300.64935555306533
		ArgOfPericen	274.06821292979964
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 862 B"
{
	ParentBody	"Erebos 862"
	Class		"Asteroid"
	Mass		4.48870247912962e-07
	Radius		58.76844323977251

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015062095780118926
		Eccentricity	0.0056267701671320735
		Inclination		225.87100048065187
		AscendingNode	300.64935555306533
		ArgOfPericen	94.06821292979964
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 863"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.277323106215852e-08
	Radius		25.858999805530427

	RotationPeriod	8.062408039619033

	Obliquity		47.948827857718584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.332930705787002
		Eccentricity	0.031069311182834444
		Inclination		-1.535274610457763
		AscendingNode	164.16939236065113
		ArgOfPericen	165.31546720138
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 864"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.545169583757939e-07
	Radius		43.06763252769231

	RotationPeriod	8.493072303368905

	Obliquity		325.24883556313614

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2523282382976815
		Eccentricity	0.06335052668019239
		Inclination		-0.3766900413605688
		AscendingNode	205.21848656858265
		ArgOfPericen	27.467586898213156
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 865"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4821515175899682e-07
	Radius		40.40951834160807

	RotationPeriod	8.10992981662837

	Obliquity		86.68425818705308

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.298861306919207
		Eccentricity	0.0642410790358417
		Inclination		-1.0558169785490064
		AscendingNode	216.0415153467401
		ArgOfPericen	84.29744481410472
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 866"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.123830444258211e-07
	Radius		56.49105618608518

	RotationPeriod	5.568681770997494

	Obliquity		291.83122199896394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.348200449791398
		Eccentricity	0.05982573342412237
		Inclination		-3.3292433614585883
		AscendingNode	273.52106557895013
		ArgOfPericen	132.6223056588676
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 867"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.006123004131339e-08
	Radius		33.38820406283365

	RotationPeriod	3.577012172322737

	Obliquity		293.7891104218572

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.419047770811534
		Eccentricity	0.07230518598314639
		Inclination		0.09532267572126212
		AscendingNode	71.01074123827453
		ArgOfPericen	40.185732101272315
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 868"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.70277863708452e-07
	Radius		76.35657392417707

	RotationPeriod	7.198423841507938

	Obliquity		214.89660324082394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3551772046467003
		Eccentricity	0.055146303319551
		Inclination		0.2226905498235601
		AscendingNode	290.49113372080365
		ArgOfPericen	288.92010727737073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 869"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.198567192811948e-07
	Radius		62.81162628335683

	RotationPeriod	6.406050586689785

	Obliquity		246.75765939813283

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2731796834789213
		Eccentricity	0.031777603430610715
		Inclination		-0.21356687798400648
		AscendingNode	297.97096159656127
		ArgOfPericen	221.56327702155295
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 870"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.9694693776309587e-07
	Radius		54.98132366451417

	RotationPeriod	7.379319252944604

	Obliquity		311.85181211008523

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.29416737675971
		Eccentricity	0.0130170734615642
		Inclination		0.2649447911166981
		AscendingNode	221.74177402617056
		ArgOfPericen	359.27223444925284
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 871"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.3128836199977414e-07
	Radius		60.233061271939185

	RotationPeriod	7.5893306793976265

	Obliquity		297.4831117849751

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.22511500497317
		Eccentricity	0.04970406237003004
		Inclination		-5.0
		AscendingNode	305.4841767954567
		ArgOfPericen	180.70396426399606
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 872"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.259163860852814e-09
	Radius		14.514707210857907

	RotationPeriod	5.809795065957048

	Obliquity		218.49630627024573

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3960897295335988
		Eccentricity	0.07065613634417894
		Inclination		-2.0599924934272837
		AscendingNode	286.70562029631037
		ArgOfPericen	303.4940368160628
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 872.1"
{
	ParentBody	"Erebos 872"
	Class		"Asteroid"
	Mass		7.884539099075794e-11
	Radius		3.214436494834747

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.0652318925030755e-07
		Eccentricity	0.0041719000502881565
		Inclination		2.5245791078970994
		AscendingNode	280.2218545065319
		ArgOfPericen	103.9108337292867
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 873"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.685995899044114e-07
	Radius		70.88102402782059

	RotationPeriod	5.689781806054103

	Obliquity		17.213553994505688

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.365236577778381
		Eccentricity	0.03031080267247768
		Inclination		-0.6579709988983693
		AscendingNode	27.661749029358056
		ArgOfPericen	30.861375176266712
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 874"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8052642555961624e-07
	Radius		44.389270642623806

	RotationPeriod	6.413712655388253

	Obliquity		131.3436503199329

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2843632233465514
		Eccentricity	0.07623683027058745
		Inclination		-0.40947023712705427
		AscendingNode	329.5758681530306
		ArgOfPericen	321.7366504681548
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 875"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1788133950072012e-07
	Radius		38.54012568163115

	RotationPeriod	4.419899469452448

	Obliquity		83.92682482716167

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3500996111094308
		Eccentricity	0.03526294297788661
		Inclination		0.7823076558440173
		AscendingNode	25.120912523465527
		ArgOfPericen	80.39717620120734
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 876"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.559421836416054e-07
	Radius		63.71084543185569

	RotationPeriod	6.320391507876657

	Obliquity		64.59393805687053

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3370287827352283
		Eccentricity	0.06532904698084602
		Inclination		0.6248321696750745
		AscendingNode	263.9860179892974
		ArgOfPericen	308.3988865013741
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 876.1"
{
	ParentBody	"Erebos 876"
	Class		"Asteroid"
	Mass		2.9578524215938457e-10
	Radius		5.162526878539112

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.7631494486144744e-06
		Eccentricity	0.0086924176500954
		Inclination		12.264752379889451
		AscendingNode	21.264293479006753
		ArgOfPericen	279.15542592766167
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 877"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1724429044043686e-07
	Radius		44.81918760622025

	RotationPeriod	4.100331459160553

	Obliquity		103.40431833708026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2683973743990995
		Eccentricity	0.04347836998819698
		Inclination		0.3669548020277882
		AscendingNode	196.3464906766025
		ArgOfPericen	312.8090654316603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 878"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.636985359346937e-07
	Radius		76.38486567146822

	RotationPeriod	4.126378429165674

	Obliquity		336.8393166898359

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2260927762204963
		Eccentricity	0.0
		Inclination		0.2712885889024964
		AscendingNode	177.00651134863665
		ArgOfPericen	282.8530617533492
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 879"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2731046139501627e-07
	Radius		50.8527094549964

	RotationPeriod	4.880459351572103

	Obliquity		150.49513670154192

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.323029195381956
		Eccentricity	0.059056547991005535
		Inclination		1.4504304734364872
		AscendingNode	114.94747877735185
		ArgOfPericen	291.12177889878774
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 880"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.682862437049132e-07
	Radius		49.293352210999316

	RotationPeriod	2.376794222543191

	Obliquity		8.38510929223332

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.212194426742993
		Eccentricity	0.055929932343402
		Inclination		0.3548238301436195
		AscendingNode	263.0884790973158
		ArgOfPericen	92.50240718241778
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 881"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.774981561748112e-07
	Radius		62.36251964563794

	RotationPeriod	8.38723254444167

	Obliquity		58.86579664532445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.361852442590969
		Eccentricity	0.03935550774890958
		Inclination		-2.600193066180318
		AscendingNode	130.70155055587512
		ArgOfPericen	290.37004603478795
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 881.1"
{
	ParentBody	"Erebos 881"
	Class		"Asteroid"
	Mass		3.9192391789660415e-09
	Radius		11.19493399152126

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.859876150413745e-06
		Eccentricity	0.003610734784724374
		Inclination		21.39116698774344
		AscendingNode	186.92345171064517
		ArgOfPericen	49.698186959049885
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 882"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.532817720025627e-08
	Radius		38.46026060039477

	RotationPeriod	5.867718443140687

	Obliquity		158.2723334902851

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.322253842018373
		Eccentricity	0.045337874522146306
		Inclination		-0.4263698576725988
		AscendingNode	311.29075724432124
		ArgOfPericen	239.5808702814201
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 883"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.559546011255863e-07
	Radius		68.74976485620786

	RotationPeriod	7.0714894790506655

	Obliquity		150.64696487060908

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3078112511870272
		Eccentricity	0.07371127779010536
		Inclination		1.6764207400438784
		AscendingNode	292.1358999782151
		ArgOfPericen	28.039775004209282
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 884"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8871573949641625e-07
	Radius		46.83592067533832

	RotationPeriod	3.857229965501027

	Obliquity		87.84097344328981

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3212908841486044
		Eccentricity	0.04773859246539931
		Inclination		-0.5368352080163845
		AscendingNode	122.93442097631494
		ArgOfPericen	61.66587926555658
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 884.1"
{
	ParentBody	"Erebos 884"
	Class		"Asteroid"
	Mass		1.558230100217795e-09
	Radius		9.466444298631854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3370467586471554e-06
		Eccentricity	0.0009683954943449178
		Inclination		-66.36209395595672
		AscendingNode	268.9205272777767
		ArgOfPericen	27.836324345072505
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 885"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.508784840971614e-07
	Radius		58.96639076388738

	RotationPeriod	5.8914378749331835

	Obliquity		108.07123808557574

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.276892240149873
		Eccentricity	0.05488561450078931
		Inclination		-2.092070134861905
		AscendingNode	318.5646249280384
		ArgOfPericen	219.4119053088414
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 886"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.038534381103077e-07
	Radius		64.13451176759165

	RotationPeriod	4.247153329926792

	Obliquity		158.7562987537076

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3168406637164707
		Eccentricity	0.05712034138427838
		Inclination		-2.3592872437692076
		AscendingNode	209.98156262174157
		ArgOfPericen	288.53783795534133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 887"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3769500040145313
		Eccentricity	0.031558595918447764
		Inclination		-1.2256837313876496
		AscendingNode	339.9568394850712
		ArgOfPericen	35.15801472697879
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 887 A"
{
	ParentBody	"Erebos 887"
	Class		"Asteroid"
	Mass		4.132845612465749e-07
	Radius		66.5460433279611

	Orbit
	{
		Epoch			2457395.5
		Period			0.00602894070694363
		Eccentricity	0.005188719437474185
		Inclination		256.6509528433128
		AscendingNode	334.02640164626905
		ArgOfPericen	162.7197654374169
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 887 B"
{
	ParentBody	"Erebos 887"
	Class		"Asteroid"
	Mass		8.26531067543183e-08
	Radius		38.91576497875291

	Orbit
	{
		Epoch			2457395.5
		Period			0.00602894070694363
		Eccentricity	0.005188719437474185
		Inclination		256.6509528433128
		AscendingNode	334.02640164626905
		ArgOfPericen	342.71976543741687
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 888"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.1371158581747605e-07
	Radius		56.21039483814379

	RotationPeriod	3.0932517185876067

	Obliquity		175.32300986301226

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.354393275359556
		Eccentricity	0.04647001546414765
		Inclination		-0.3381229384509805
		AscendingNode	196.20812062327676
		ArgOfPericen	258.52442079567106
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 889"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.117346564738567e-07
	Radius		67.83140994831871

	RotationPeriod	6.715658859144789

	Obliquity		41.35272305101398

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3361458762436764
		Eccentricity	0.04864903597902017
		Inclination		0.2824991640946385
		AscendingNode	259.5347963534798
		ArgOfPericen	213.47261449042307
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 889.1"
{
	ParentBody	"Erebos 889"
	Class		"Asteroid"
	Mass		1.711002648440353e-09
	Radius		9.08674555522313

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.575729632172498e-07
		Eccentricity	0.003941861375454216
		Inclination		-30.18925326801763
		AscendingNode	160.54924644168693
		ArgOfPericen	30.041807047070776
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 890"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.6585284190759315e-07
	Radius		56.014631186781635

	RotationPeriod	9.20326850507871

	Obliquity		153.86539715843924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.273393867164733
		Eccentricity	0.06286999251422272
		Inclination		-1.829875339491762
		AscendingNode	70.38973530780419
		ArgOfPericen	221.77818450503244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 891"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.124120198227096e-07
	Radius		69.10289193879076

	RotationPeriod	10.688467681573547

	Obliquity		317.16654605597233

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2464547271098363
		Eccentricity	0.06590666774926382
		Inclination		0.5407392918837838
		AscendingNode	233.542876315986
		ArgOfPericen	195.12623591144762
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 892"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.455606741427708e-07
	Radius		71.95762247004589

	RotationPeriod	6.597488190574258

	Obliquity		135.49244786670494

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3547353640326367
		Eccentricity	0.055151650776318076
		Inclination		0.5378962568058218
		AscendingNode	249.0996151838172
		ArgOfPericen	284.7466287442317
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 893"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.91319263757392e-07
	Radius		43.89435649690942

	RotationPeriod	5.117223661675523

	Obliquity		299.06880496522456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.324408358556402
		Eccentricity	0.05914569225091493
		Inclination		-0.6987759705008859
		AscendingNode	168.43586956297847
		ArgOfPericen	138.0484200125238
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 894"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4742572982368542e-07
	Radius		42.45410827375097

	RotationPeriod	5.801008761263861

	Obliquity		281.27272980520644

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3543210684590288
		Eccentricity	0.060780096798835524
		Inclination		-1.9503759281981279
		AscendingNode	173.5154373597483
		ArgOfPericen	16.381203314024695
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 895"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.376340428919567
		Eccentricity	0.05905576150014273
		Inclination		-2.022111790095341
		AscendingNode	290.58826958939386
		ArgOfPericen	320.2662809999337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 895 A"
{
	ParentBody	"Erebos 895"
	Class		"Asteroid"
	Mass		3.488994275811323e-07
	Radius		50.76991604111674

	Orbit
	{
		Epoch			2457395.5
		Period			0.005412879879415664
		Eccentricity	0.005722107459724515
		Inclination		17.17381966044739
		AscendingNode	345.7834234357364
		ArgOfPericen	226.62807583337832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 895 B"
{
	ParentBody	"Erebos 895"
	Class		"Asteroid"
	Mass		1.257246318180806e-07
	Radius		36.12821325062183

	Orbit
	{
		Epoch			2457395.5
		Period			0.005412879879415664
		Eccentricity	0.005722107459724515
		Inclination		17.17381966044739
		AscendingNode	345.7834234357364
		ArgOfPericen	46.62807583337832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 896"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.825194036748767e-08
	Radius		28.87494820216188

	RotationPeriod	3.6572288897058995

	Obliquity		228.20026627480743

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2910064819170315
		Eccentricity	0.05351666555660971
		Inclination		1.9546448505065726
		AscendingNode	190.92126697209727
		ArgOfPericen	134.6550105754546
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 897"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.350794507985661e-08
	Radius		33.245577148268154

	RotationPeriod	6.317867458976925

	Obliquity		128.33201038877732

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2904580185681
		Eccentricity	0.035930364114358584
		Inclination		2.520639886933533
		AscendingNode	283.5355914181596
		ArgOfPericen	34.12229940802997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 898"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.760302604354983e-07
	Radius		65.52038256053335

	RotationPeriod	8.520397998358952

	Obliquity		171.01671994525762

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.2965361882636057
		Eccentricity	0.028899577293159007
		Inclination		-1.6721256134377003
		AscendingNode	92.96578862750118
		ArgOfPericen	104.84695496662096
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Erebos 899"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3627957651583276
		Eccentricity	0.05915966186270099
		Inclination		-0.5517819700886223
		AscendingNode	313.13479043952566
		ArgOfPericen	148.58412828611063
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 899 A"
{
	ParentBody	"Erebos 899"
	Class		"Asteroid"
	Mass		1.6243003013959864e-07
	Radius		43.11778991305526

	Orbit
	{
		Epoch			2457395.5
		Period			0.006215949291357634
		Eccentricity	0.007536498677319825
		Inclination		14.243847642939862
		AscendingNode	194.68345358251113
		ArgOfPericen	55.081457271963586
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Erebos 899 B"
{
	ParentBody	"Erebos 899"
	Class		"Asteroid"
	Mass		1.273774372203952e-07
	Radius		39.76172519436998

	Orbit
	{
		Epoch			2457395.5
		Period			0.006215949291357634
		Eccentricity	0.007536498677319825
		Inclination		14.243847642939862
		AscendingNode	194.68345358251113
		ArgOfPericen	235.0814572719636
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Erebos 900"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.226735242613151e-07
	Radius		66.25851137613023

	RotationPeriod	6.774978554733649

	Obliquity		132.21986413065747

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.19058508257797
		Eccentricity	0.04047552556115023
		Inclination		-2.57991477326535
		AscendingNode	173.71519400577128
		ArgOfPericen	70.73696620622313
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Ouranos asteroid belt -------------------------------------------------------
//------------------------------------------------------------------------------
Barycenter "Ouranos 1"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9683653861061499
		Eccentricity	0.015784782983646203
		Inclination		-1.5365716064907384
		AscendingNode	357.8009637914783
		ArgOfPericen	343.4755175484763
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 1 A"
{
	ParentBody	"Ouranos 1"
	Class		"Asteroid"
	Mass		6.811159581647299e-07
	Radius		63.46799689517214

	Orbit
	{
		Epoch			2457395.5
		Period			0.005590228684626542
		Eccentricity	0.006163374940424777
		Inclination		299.98007255739367
		AscendingNode	352.37288810828056
		ArgOfPericen	101.09179629074066
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 1 B"
{
	ParentBody	"Ouranos 1"
	Class		"Asteroid"
	Mass		6.801517611270542e-07
	Radius		63.43803403150274

	Orbit
	{
		Epoch			2457395.5
		Period			0.005590228684626542
		Eccentricity	0.006163374940424777
		Inclination		299.98007255739367
		AscendingNode	352.37288810828056
		ArgOfPericen	281.09179629074066
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 2"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.844279531433933e-07
	Radius		76.55501125940994

	RotationPeriod	6.952927161907935

	Obliquity		66.08653376632839

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9727699158145481
		Eccentricity	0.06136107223864001
		Inclination		1.3532745838989801
		AscendingNode	253.93091959501237
		ArgOfPericen	320.55014693446253
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 3"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.035530502775072e-07
	Radius		47.617413951594855

	RotationPeriod	3.786747238511195

	Obliquity		295.04280616951166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9942010313824672
		Eccentricity	0.06433385794350484
		Inclination		1.7314820511456939
		AscendingNode	250.72608205016354
		ArgOfPericen	138.13558861359687
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 3.1"
{
	ParentBody	"Ouranos 3"
	Class		"Asteroid"
	Mass		4.1642007868740926e-11
	Radius		2.805759797039072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.450530172779273e-06
		Eccentricity	0.007018580298094137
		Inclination		-12.841290065068955
		AscendingNode	343.8328339722876
		ArgOfPericen	189.97134121266834
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 4"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.106871134907923e-07
	Radius		61.15098139372226

	RotationPeriod	3.074717574079183

	Obliquity		81.64131518366776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9987017424932895
		Eccentricity	0.0586539398335545
		Inclination		-1.4284675156750926
		AscendingNode	33.20409179062696
		ArgOfPericen	277.2447794856687
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 5"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.362770892058224e-08
	Radius		33.57953031470713

	RotationPeriod	3.734122271386281

	Obliquity		247.9315983276171

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9673791491374973
		Eccentricity	0.0596410765796021
		Inclination		1.315794994538636
		AscendingNode	284.4229796660104
		ArgOfPericen	41.5189733235148
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 6"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4929683257359884e-07
	Radius		41.724781346879425

	RotationPeriod	11.355671040405179

	Obliquity		56.069414480659646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9544369638315321
		Eccentricity	0.045178622257053734
		Inclination		0.48239066155865035
		AscendingNode	65.67618899180448
		ArgOfPericen	54.25574062687491
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 7"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9540249673456536
		Eccentricity	0.05974717863146462
		Inclination		-1.3208092763626962
		AscendingNode	37.007952346734626
		ArgOfPericen	307.5855751831066
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 7 A"
{
	ParentBody	"Ouranos 7"
	Class		"Asteroid"
	Mass		1.2515547527603445e-07
	Radius		41.24421427970941

	Orbit
	{
		Epoch			2457395.5
		Period			0.002027799790881393
		Eccentricity	0.00567892862409037
		Inclination		139.11570295633217
		AscendingNode	279.84931487178955
		ArgOfPericen	100.73875058508133
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 7 B"
{
	ParentBody	"Ouranos 7"
	Class		"Asteroid"
	Mass		4.251723996730021e-09
	Radius		13.357794914447512

	Orbit
	{
		Epoch			2457395.5
		Period			0.002027799790881393
		Eccentricity	0.00567892862409037
		Inclination		139.11570295633217
		AscendingNode	279.84931487178955
		ArgOfPericen	280.73875058508133
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 8"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0362590133827003
		Eccentricity	0.04076296594873162
		Inclination		1.4685990221309078
		AscendingNode	157.68773704065745
		ArgOfPericen	304.4087901978816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 8 A"
{
	ParentBody	"Ouranos 8"
	Class		"Asteroid"
	Mass		6.262962557910924e-08
	Radius		31.394026505665064

	Orbit
	{
		Epoch			2457395.5
		Period			0.0048690662198465325
		Eccentricity	0.009020031698332015
		Inclination		314.4258263952515
		AscendingNode	346.6440065779395
		ArgOfPericen	213.16714993183012
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 8 B"
{
	ParentBody	"Ouranos 8"
	Class		"Asteroid"
	Mass		5.052610865523293e-08
	Radius		29.22530368723344

	Orbit
	{
		Epoch			2457395.5
		Period			0.0048690662198465325
		Eccentricity	0.009020031698332015
		Inclination		314.4258263952515
		AscendingNode	346.6440065779395
		ArgOfPericen	33.167149931830124
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 9"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.356749806528586e-07
	Radius		38.92714041690337

	RotationPeriod	6.9070311897872605

	Obliquity		27.12210262697758

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9819201895475002
		Eccentricity	0.02836705693318481
		Inclination		1.187786750449251
		AscendingNode	14.613494064949283
		ArgOfPericen	358.08310687584833
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 9.1"
{
	ParentBody	"Ouranos 9"
	Class		"Asteroid"
	Mass		6.207067700027141e-10
	Radius		6.462215048565154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.937338122172898e-06
		Eccentricity	0.005129114437447811
		Inclination		28.991010178290015
		AscendingNode	119.5095017802483
		ArgOfPericen	225.9854641637606
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 10"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.764000196662158e-07
	Radius		70.37846743182229

	RotationPeriod	4.903644725851931

	Obliquity		31.29880286711615

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9867700105931123
		Eccentricity	0.048266056134543454
		Inclination		-1.1848061541539385
		AscendingNode	123.89759422001316
		ArgOfPericen	120.05979581831792
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 11"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0118437399356457
		Eccentricity	0.04186737146658002
		Inclination		0.2422555711794163
		AscendingNode	107.24042425641588
		ArgOfPericen	308.29196301237033
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 11 A"
{
	ParentBody	"Ouranos 11"
	Class		"Asteroid"
	Mass		1.4735336928877553e-07
	Radius		39.948461613886536

	Orbit
	{
		Epoch			2457395.5
		Period			0.001594203217653574
		Eccentricity	0.006975822728696167
		Inclination		66.66002411566116
		AscendingNode	95.84093353268943
		ArgOfPericen	342.1717222166629
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 11 B"
{
	ParentBody	"Ouranos 11"
	Class		"Asteroid"
	Mass		2.2456786202401846e-08
	Radius		21.33843532220006

	Orbit
	{
		Epoch			2457395.5
		Period			0.001594203217653574
		Eccentricity	0.006975822728696167
		Inclination		66.66002411566116
		AscendingNode	95.84093353268943
		ArgOfPericen	162.17172221666283
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 12"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.9853372066764586e-07
	Radius		45.18033973307379

	RotationPeriod	7.24387496269145

	Obliquity		225.427442702089

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0487217675169316
		Eccentricity	0.1
		Inclination		0.8308875026215224
		AscendingNode	358.37536557228873
		ArgOfPericen	336.84023111272313
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 12.1"
{
	ParentBody	"Ouranos 12"
	Class		"Asteroid"
	Mass		3.389809920910139e-10
	Radius		5.4000342435621

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.155005415790745e-06
		Eccentricity	0.004499236904805892
		Inclination		-14.878731776057963
		AscendingNode	153.92683978513
		ArgOfPericen	347.043216912955
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 13"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.341979781098116e-07
	Radius		43.75242426825334

	RotationPeriod	4.452215283489087

	Obliquity		5.736185166019325

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0013433414382884
		Eccentricity	0.06447909181771079
		Inclination		0.7662742277738545
		AscendingNode	52.585142390110555
		ArgOfPericen	270.5387803751373
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 13.1"
{
	ParentBody	"Ouranos 13"
	Class		"Asteroid"
	Mass		4.6116111267093965e-10
	Radius		6.602438385190107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.314909554350059e-06
		Eccentricity	0.005541755932548337
		Inclination		-15.221681820926547
		AscendingNode	158.70780608211672
		ArgOfPericen	152.99997181524301
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 14"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.6024927760872207e-07
	Radius		48.72905886675157

	RotationPeriod	9.05093511277206

	Obliquity		21.448529143796

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.963309066840366
		Eccentricity	0.04679396601751458
		Inclination		1.8146367218052928
		AscendingNode	155.22067979425682
		ArgOfPericen	56.33763525642108
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 15"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.6226838481645567e-09
	Radius		12.140496094130036

	RotationPeriod	11.59554520163643

	Obliquity		134.97107497065858

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.964873714036938
		Eccentricity	0.04106627957367606
		Inclination		-0.33221381776209136
		AscendingNode	71.04785644681189
		ArgOfPericen	289.74090712025185
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 16"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9674148194670272
		Eccentricity	0.0652181353669059
		Inclination		2.9806929635602124
		AscendingNode	113.89856529289402
		ArgOfPericen	143.66258946053588
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 16 A"
{
	ParentBody	"Ouranos 16"
	Class		"Asteroid"
	Mass		6.275227374095686e-08
	Radius		30.80324900245911

	Orbit
	{
		Epoch			2457395.5
		Period			0.0045828866267588215
		Eccentricity	0.0040500650709145766
		Inclination		193.69730746478896
		AscendingNode	119.12022663650485
		ArgOfPericen	247.81351774639182
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 16 B"
{
	ParentBody	"Ouranos 16"
	Class		"Asteroid"
	Mass		5.8651818919515465e-08
	Radius		30.117149590129554

	Orbit
	{
		Epoch			2457395.5
		Period			0.0045828866267588215
		Eccentricity	0.0040500650709145766
		Inclination		193.69730746478896
		AscendingNode	119.12022663650485
		ArgOfPericen	67.81351774639182
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 17"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.768142015947304e-07
	Radius		52.36884493714164

	RotationPeriod	2.390623672805574

	Obliquity		57.43618049753565

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9500687054550104
		Eccentricity	0.02276583742553608
		Inclination		0.04399473012657825
		AscendingNode	45.684105516487634
		ArgOfPericen	137.98653986729587
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 18"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.8083235139113616e-07
	Radius		48.67856202990257

	RotationPeriod	9.313564854462903

	Obliquity		100.57850818826662

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0168540170777707
		Eccentricity	0.08542717343751723
		Inclination		1.152725351458109
		AscendingNode	91.02143056956757
		ArgOfPericen	279.50511816647935
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 19"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.211225569918857e-07
	Radius		62.997762142995704

	RotationPeriod	7.638125876650558

	Obliquity		353.8657438365485

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9840744232447731
		Eccentricity	0.05003393906221447
		Inclination		0.3286081138820462
		AscendingNode	42.08000529066256
		ArgOfPericen	21.510124411097813
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 19.1"
{
	ParentBody	"Ouranos 19"
	Class		"Asteroid"
	Mass		8.86489021251668e-09
	Radius		15.281188829257616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.883050837435051e-07
		Eccentricity	0.005824698354051495
		Inclination		10.622731340239895
		AscendingNode	311.30007481660067
		ArgOfPericen	319.00880620871413
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 20"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.38742523789042e-07
	Radius		63.13106544553509

	RotationPeriod	7.1162038730093355

	Obliquity		100.17104813042198

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.979470345441437
		Eccentricity	0.041446364010679165
		Inclination		-1.5227085750449412
		AscendingNode	66.44204637244859
		ArgOfPericen	247.09374559382786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 20.1"
{
	ParentBody	"Ouranos 20"
	Class		"Asteroid"
	Mass		1.2255762365952177e-10
	Radius		3.853861863575402

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.722419698332185e-06
		Eccentricity	0.005889151266104814
		Inclination		-8.082697852660102
		AscendingNode	43.60795078179668
		ArgOfPericen	327.09143284738843
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 20.2"
{
	ParentBody	"Ouranos 20"
	Class		"Asteroid"
	Mass		2.6654708656876754e-10
	Radius		4.993143106248606

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.386337154410846e-06
		Eccentricity	0.005666218103067552
		Inclination		-50.51872467895783
		AscendingNode	303.62855310571445
		ArgOfPericen	31.636649696245584
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 21"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.8145710397588245e-08
	Radius		20.346311068682475

	RotationPeriod	7.705877422735638

	Obliquity		95.19267820309264

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0057141588755159
		Eccentricity	0.06064915984518068
		Inclination		0.26282232782068465
		AscendingNode	292.223018335869
		ArgOfPericen	140.73772543960857
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 22"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.73872053944483e-07
	Radius		61.56747393839631

	RotationPeriod	7.499053707446983

	Obliquity		78.12150611559719

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0187879351836429
		Eccentricity	0.05887936695954489
		Inclination		0.8755732230908535
		AscendingNode	94.83537437620845
		ArgOfPericen	143.69618937343554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 23"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.762830594055542e-07
	Radius		44.986711941732295

	RotationPeriod	9.321275490536786

	Obliquity		76.72842598613171

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0240855056678513
		Eccentricity	0.06272949412410006
		Inclination		2.4360323922345155
		AscendingNode	341.53104506105166
		ArgOfPericen	0.6828035352144379
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 24"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.689080745671636e-07
	Radius		60.66377839564421

	RotationPeriod	8.782124860373541

	Obliquity		59.92209640448283

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.953945317785167
		Eccentricity	0.08115179846524961
		Inclination		-1.0525794121163163
		AscendingNode	119.69169391783882
		ArgOfPericen	105.60331842684715
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 25"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.8790726127507136e-07
	Radius		56.62484613610086

	RotationPeriod	6.509517994919391

	Obliquity		171.3837368017843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0181333390403515
		Eccentricity	0.03990677739973079
		Inclination		0.9201292651067493
		AscendingNode	94.90379536127318
		ArgOfPericen	358.32045300756505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 26"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0837088610768745e-06
	Radius		79.95662245432894

	RotationPeriod	6.537897792733009

	Obliquity		236.63198757682053

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9858006884251004
		Eccentricity	0.07737655842448032
		Inclination		-0.8133786193286474
		AscendingNode	181.06357576886083
		ArgOfPericen	206.4157458102748
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 27"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.330003870137165e-07
	Radius		42.37800767976345

	RotationPeriod	3.6797719408223926

	Obliquity		312.51368427484067

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9711178889614941
		Eccentricity	0.0446062103770457
		Inclination		3.7559034527593482
		AscendingNode	294.6236414564796
		ArgOfPericen	91.5402211529365
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 28"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.208719047700603e-07
	Radius		49.641033227162794

	RotationPeriod	3.9051824227675183

	Obliquity		277.0798958951335

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9772733341342694
		Eccentricity	0.03702861927111159
		Inclination		-2.6688082465024157
		AscendingNode	137.6204984456766
		ArgOfPericen	209.5156492772723
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 28.1"
{
	ParentBody	"Ouranos 28"
	Class		"Asteroid"
	Mass		8.312200898892942e-11
	Radius		3.5839834640004273

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.853062897136045e-06
		Eccentricity	0.005582146502221301
		Inclination		-89.2483934735671
		AscendingNode	76.91600426216527
		ArgOfPericen	222.96154739317655
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 28.2"
{
	ParentBody	"Ouranos 28"
	Class		"Asteroid"
	Mass		3.2381502294060525e-09
	Radius		12.14953485461714

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.914904615658364e-06
		Eccentricity	0.0035289013344078886
		Inclination		15.986851950041775
		AscendingNode	16.402380225999984
		ArgOfPericen	242.85045388385836
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 29"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.5958794038734425e-07
	Radius		49.29935992712071

	RotationPeriod	5.094692909958554

	Obliquity		72.91488463082445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0180253607175338
		Eccentricity	0.05935706226156057
		Inclination		-0.7506496281836804
		AscendingNode	342.07598045586843
		ArgOfPericen	317.4986241913369
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 30"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.715652372126306e-07
	Radius		69.93646639921222

	RotationPeriod	5.743480288570289

	Obliquity		229.87493007606375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9959793350807359
		Eccentricity	0.06357610572851141
		Inclination		-2.248292386621396
		AscendingNode	165.3696854222648
		ArgOfPericen	91.18300376143428
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 31"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9455180333579961
		Eccentricity	0.06598654776347751
		Inclination		-0.31986366988668685
		AscendingNode	12.724106563415356
		ArgOfPericen	63.35297023651545
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 31 A"
{
	ParentBody	"Ouranos 31"
	Class		"Asteroid"
	Mass		1.4912892887504884e-07
	Radius		42.89890811065342

	Orbit
	{
		Epoch			2457395.5
		Period			0.0070925434706680945
		Eccentricity	0.006369364771182383
		Inclination		265.0404094862579
		AscendingNode	51.83522811712416
		ArgOfPericen	250.7651624323324
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 31 B"
{
	ParentBody	"Ouranos 31"
	Class		"Asteroid"
	Mass		7.080522184425328e-09
	Radius		15.533907026855776

	Orbit
	{
		Epoch			2457395.5
		Period			0.0070925434706680945
		Eccentricity	0.006369364771182383
		Inclination		265.0404094862579
		AscendingNode	51.83522811712416
		ArgOfPericen	70.76516243233243
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 32"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.1546012090518266e-09
	Radius		10.541899197621284

	RotationPeriod	7.5963109272564715

	Obliquity		68.79614726681001

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9861058010455961
		Eccentricity	0.03130442306435742
		Inclination		-0.7595622875956177
		AscendingNode	317.82042561713365
		ArgOfPericen	208.0975533322463
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 33"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.304447513107842e-07
	Radius		74.3538543514309

	RotationPeriod	9.01571716332092

	Obliquity		312.463425513424

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9869722970739511
		Eccentricity	0.05489435716624956
		Inclination		-1.6277184836813652
		AscendingNode	209.6188592212366
		ArgOfPericen	206.1790294646485
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 33.1"
{
	ParentBody	"Ouranos 33"
	Class		"Asteroid"
	Mass		4.169849607261515e-09
	Radius		12.258765953280044

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.095510215160378e-06
		Eccentricity	0.004023228478916729
		Inclination		31.536438650709453
		AscendingNode	149.34011496835558
		ArgOfPericen	6.429882377490226
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 34"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.540958464809109e-07
	Radius		59.253901591235234

	RotationPeriod	9.46653320807088

	Obliquity		67.75494362874821

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0210064080965626
		Eccentricity	0.036907588740309076
		Inclination		0.9330709903182004
		AscendingNode	52.754890036129474
		ArgOfPericen	289.01730249828285
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 34.1"
{
	ParentBody	"Ouranos 34"
	Class		"Asteroid"
	Mass		6.931525241459988e-11
	Radius		3.1667276328208627

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.256108659965211e-06
		Eccentricity	0.003889105179148843
		Inclination		-1.5710367600037802
		AscendingNode	202.47977702464084
		ArgOfPericen	261.9269089404351
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 35"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1917707082446268e-07
	Radius		35.910627690926205

	RotationPeriod	9.297841469286041

	Obliquity		164.34140950215212

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9676511230053636
		Eccentricity	0.045216231378237784
		Inclination		-1.834077870905289
		AscendingNode	215.12118840477544
		ArgOfPericen	174.316362890026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 36"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.894642353381314e-07
	Radius		60.15596889391101

	RotationPeriod	3.8924795481232826

	Obliquity		59.17898992302611

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0036095028474497
		Eccentricity	0.06985697592005227
		Inclination		0.710641416579836
		AscendingNode	130.90214180829588
		ArgOfPericen	277.23059674747674
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 37"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0471618212089249
		Eccentricity	0.06744381968877514
		Inclination		0.5314433490497158
		AscendingNode	42.61896424699359
		ArgOfPericen	201.61854408530684
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 37 A"
{
	ParentBody	"Ouranos 37"
	Class		"Asteroid"
	Mass		6.277427743243737e-07
	Radius		65.80135434401022

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014264965611099243
		Eccentricity	0.006055674703041546
		Inclination		263.6181147399433
		AscendingNode	284.8665627343375
		ArgOfPericen	67.94238492423106
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 37 B"
{
	ParentBody	"Ouranos 37"
	Class		"Asteroid"
	Mass		2.6276289610552514e-07
	Radius		49.22234177874771

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014264965611099243
		Eccentricity	0.006055674703041546
		Inclination		263.6181147399433
		AscendingNode	284.8665627343375
		ArgOfPericen	247.94238492423108
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 38"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.66958061267935e-07
	Radius		66.26328745068561

	RotationPeriod	5.676006932217159

	Obliquity		175.37734872287615

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0225018731055082
		Eccentricity	0.057442601599865944
		Inclination		0.20997323889359304
		AscendingNode	245.28425702615763
		ArgOfPericen	174.61689263164087
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 39"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.5913514051323148e-07
	Radius		43.51525123061588

	RotationPeriod	7.146058701588808

	Obliquity		161.72250898851883

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9926551286428641
		Eccentricity	0.07135720303171428
		Inclination		2.214723037350081
		AscendingNode	275.48718951901975
		ArgOfPericen	36.65922440505793
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 39.1"
{
	ParentBody	"Ouranos 39"
	Class		"Asteroid"
	Mass		1.9562602934269095e-09
	Radius		10.042958727591529

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.304073820935229e-06
		Eccentricity	0.005748992265144528
		Inclination		3.467066730112114
		AscendingNode	139.00434451930678
		ArgOfPericen	226.92808923671015
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 39.2"
{
	ParentBody	"Ouranos 39"
	Class		"Asteroid"
	Mass		2.273911702768934e-10
	Radius		4.90129297771532

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.580796505902346e-06
		Eccentricity	0.0030220128981178784
		Inclination		52.64419956242647
		AscendingNode	174.59393077555816
		ArgOfPericen	57.88041075308787
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 40"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.822198471267506e-09
	Radius		16.99227325139531

	RotationPeriod	9.068615075115977

	Obliquity		212.12494048633846

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9873646661107475
		Eccentricity	0.044474863464599765
		Inclination		0.5375042835584465
		AscendingNode	345.0298210118388
		ArgOfPericen	66.94310331490638
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 41"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.759574850091345e-07
	Radius		65.97253636477423

	RotationPeriod	8.356997289734204

	Obliquity		164.111428259945

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9931540132954519
		Eccentricity	0.052722034702259946
		Inclination		-1.6890230513936366
		AscendingNode	182.50136994048927
		ArgOfPericen	312.4982327492342
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 42"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3584873625728962e-08
	Radius		18.095820457232612

	RotationPeriod	6.665931536358166

	Obliquity		333.94747499216675

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9340334515031754
		Eccentricity	0.06190729039788742
		Inclination		0.2744532986906178
		AscendingNode	309.40674411949533
		ArgOfPericen	117.70645458976233
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 43"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0459117404816505
		Eccentricity	0.03394350828722242
		Inclination		0.45233328946211887
		AscendingNode	39.467998877060225
		ArgOfPericen	238.77892992173614
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 43 A"
{
	ParentBody	"Ouranos 43"
	Class		"Asteroid"
	Mass		6.809082258407815e-07
	Radius		66.88577376972714

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005187325279423856
		Eccentricity	0.0025055948730896005
		Inclination		167.41351366955206
		AscendingNode	73.71287473714612
		ArgOfPericen	314.501005099393
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 43 B"
{
	ParentBody	"Ouranos 43"
	Class		"Asteroid"
	Mass		3.740717901493339e-07
	Radius		54.78006559957256

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005187325279423856
		Eccentricity	0.0025055948730896005
		Inclination		167.41351366955206
		AscendingNode	73.71287473714612
		ArgOfPericen	134.501005099393
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 44"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9743980791647638
		Eccentricity	0.06595717993541993
		Inclination		-1.1472267015112767
		AscendingNode	322.21493423660166
		ArgOfPericen	325.49906446434704
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 44 A"
{
	ParentBody	"Ouranos 44"
	Class		"Asteroid"
	Mass		6.594993249002443e-07
	Radius		71.52258912395538

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007749298161625916
		Eccentricity	0.00415079805606933
		Inclination		355.6507146481953
		AscendingNode	211.26071150126006
		ArgOfPericen	230.21517890711442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 44 B"
{
	ParentBody	"Ouranos 44"
	Class		"Asteroid"
	Mass		6.081137693259844e-08
	Radius		32.31221437581357

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007749298161625916
		Eccentricity	0.00415079805606933
		Inclination		355.6507146481953
		AscendingNode	211.26071150126006
		ArgOfPericen	50.21517890711442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 45"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.173042430353528e-07
	Radius		52.346252870432465

	RotationPeriod	6.040328661971724

	Obliquity		279.7947796633219

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0111479046468903
		Eccentricity	0.02099889506546949
		Inclination		-1.7892601987088852
		AscendingNode	104.75871660295745
		ArgOfPericen	342.8100019121124
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 46"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0811882601105968e-07
	Radius		37.26960815768926

	RotationPeriod	5.026381635233164

	Obliquity		271.2743354257659

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9604852863615293
		Eccentricity	0.062361478061940576
		Inclination		-2.5396864265322923
		AscendingNode	84.66791166200268
		ArgOfPericen	88.84946303260115
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 47"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3540395140839836e-07
	Radius		39.4374403315473

	RotationPeriod	4.8603749613304394

	Obliquity		325.9475602545787

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9822419265919883
		Eccentricity	0.046246765161071623
		Inclination		2.427066442446541
		AscendingNode	333.1488802277767
		ArgOfPericen	339.1590964719948
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 48"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.978324844065805e-08
	Radius		23.754507273383123

	RotationPeriod	8.84490604181943

	Obliquity		229.34283753586442

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9756908684842375
		Eccentricity	0.03374664688596116
		Inclination		0.13029843654215892
		AscendingNode	219.06029300959284
		ArgOfPericen	310.89195676412663
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 48.1"
{
	ParentBody	"Ouranos 48"
	Class		"Asteroid"
	Mass		5.7009485052187845e-12
	Radius		1.3690029306435196

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4242451871002056e-06
		Eccentricity	0.005328742655398759
		Inclination		2.4430066898855505
		AscendingNode	270.8504238464537
		ArgOfPericen	85.79470825399551
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 49"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3281600682723677e-07
	Radius		38.44754988283589

	RotationPeriod	6.01064303802122

	Obliquity		34.577386281691254

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0068175297192394
		Eccentricity	0.05031912256767653
		Inclination		1.3584238417506236
		AscendingNode	156.19419886519435
		ArgOfPericen	115.12707688516682
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 49.1"
{
	ParentBody	"Ouranos 49"
	Class		"Asteroid"
	Mass		3.3063614742970504e-11
	Radius		2.4186255706653066

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.721130602905172e-06
		Eccentricity	0.004739617513160553
		Inclination		-19.942122277224236
		AscendingNode	335.91718893097163
		ArgOfPericen	205.8583271617609
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 50"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.075181723951415e-07
	Radius		36.43741440674684

	RotationPeriod	4.399397342979629

	Obliquity		195.71873300270346

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.03841357303705
		Eccentricity	0.04621098386886043
		Inclination		3.2774464302050506
		AscendingNode	287.77264926848
		ArgOfPericen	287.16865921740776
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 50.1"
{
	ParentBody	"Ouranos 50"
	Class		"Asteroid"
	Mass		7.734788910473653e-10
	Radius		7.034011640583056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.9620757579344796e-06
		Eccentricity	0.004184975279181057
		Inclination		-23.658068064573236
		AscendingNode	41.75204522032219
		ArgOfPericen	1.113144636138843
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 51"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.5528469237647175e-07
	Radius		55.46271855639506

	RotationPeriod	7.717288406054172

	Obliquity		92.69282947708919

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9885270193580769
		Eccentricity	0.04496820791123576
		Inclination		-1.7222220981189567
		AscendingNode	263.6728645629403
		ArgOfPericen	203.42404307949923
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 52"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.807732505252833e-07
	Radius		57.892425623367494

	RotationPeriod	7.488649459364498

	Obliquity		114.90773427646161

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0187916899215346
		Eccentricity	0.050744013242016314
		Inclination		-0.7880834446646825
		AscendingNode	28.60220163430902
		ArgOfPericen	30.579560134363422
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 53"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1917690374683882e-06
	Radius		87.65281653847364

	RotationPeriod	10.963806688091871

	Obliquity		138.9933631109715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9969027922109978
		Eccentricity	0.0411461761865424
		Inclination		0.6712213036048805
		AscendingNode	295.8895075006636
		ArgOfPericen	190.66398249869223
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 54"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9778829244970535
		Eccentricity	0.08105878183792183
		Inclination		1.6261591954732935
		AscendingNode	302.9114148298483
		ArgOfPericen	264.6232903738161
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 54 A"
{
	ParentBody	"Ouranos 54"
	Class		"Asteroid"
	Mass		1.3971077814581904e-07
	Radius		40.884224247801896

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024155204598607463
		Eccentricity	0.0026494117766823677
		Inclination		318.64698555274794
		AscendingNode	165.6821147537746
		ArgOfPericen	104.51969071164567
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 54 B"
{
	ParentBody	"Ouranos 54"
	Class		"Asteroid"
	Mass		9.779716189780118e-09
	Radius		16.849533254155

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024155204598607463
		Eccentricity	0.0026494117766823677
		Inclination		318.64698555274794
		AscendingNode	165.6821147537746
		ArgOfPericen	284.5196907116457
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 55"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.058005293419204e-08
	Radius		30.152375600756727

	RotationPeriod	7.879141146836524

	Obliquity		305.0155691515134

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9886426866043815
		Eccentricity	0.05131631593721321
		Inclination		-2.3347375162634085
		AscendingNode	256.53367337465244
		ArgOfPericen	201.0091632377507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 56"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.536721287224301e-07
	Radius		66.3861302343193

	RotationPeriod	7.723225767848574

	Obliquity		97.85592311809435

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0048305139868865
		Eccentricity	0.018617926448772026
		Inclination		-0.6822867089487414
		AscendingNode	259.00036062133114
		ArgOfPericen	43.811239825024
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 57"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.6654504235077548e-06
	Radius		87.85667341680755

	RotationPeriod	4.218921937525906

	Obliquity		186.34725760404444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0363966830960922
		Eccentricity	0.06008478665152076
		Inclination		0.312750317395342
		AscendingNode	88.09790631987923
		ArgOfPericen	41.899440072047234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 58"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.606404741490069e-08
	Radius		26.270803997152143

	RotationPeriod	7.643360102744028

	Obliquity		74.58170661813558

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9718720995102189
		Eccentricity	0.05136356101460567
		Inclination		-1.1125839049120316
		AscendingNode	293.34452883488365
		ArgOfPericen	47.15010270693257
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 59"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.731369826444164e-08
	Radius		30.691023085674374

	RotationPeriod	5.081226766142801

	Obliquity		113.68436150600458

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0275967794762808
		Eccentricity	0.07738538505780171
		Inclination		-1.2157225686032938
		AscendingNode	272.78024487317475
		ArgOfPericen	299.13414518001736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 60"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.12880658487863e-07
	Radius		45.91667202180907

	RotationPeriod	5.799474380830611

	Obliquity		200.34706984818956

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0150083366511014
		Eccentricity	0.06528509187425471
		Inclination		0.43851030604797914
		AscendingNode	258.9699613358962
		ArgOfPericen	77.86262173670357
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 61"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.115547794228678e-07
	Radius		74.46344815757554

	RotationPeriod	7.352407515441694

	Obliquity		323.3005933840967

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.994799508827265
		Eccentricity	0.03938846877724564
		Inclination		-1.7197730370545825
		AscendingNode	15.719013913273475
		ArgOfPericen	93.06820120407475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 62"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4499126299038046e-07
	Radius		42.10409783584667

	RotationPeriod	8.076044230690853

	Obliquity		89.99914735857242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0203874861864095
		Eccentricity	0.04451925098010455
		Inclination		1.6747699668774039
		AscendingNode	326.2648696795355
		ArgOfPericen	20.9902315302892
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 63"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.491647451747994e-07
	Radius		64.1748435561013

	RotationPeriod	8.529164804907015

	Obliquity		20.516329759381634

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9630544909847998
		Eccentricity	0.06826056057690591
		Inclination		1.7009882629462878
		AscendingNode	242.59731015862587
		ArgOfPericen	216.9306075953269
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 64"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.9717760209995375e-07
	Radius		52.47457600799896

	RotationPeriod	10.311698803994398

	Obliquity		48.920991789857105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.977420110954844
		Eccentricity	0.03825779104232691
		Inclination		2.603077063808676
		AscendingNode	312.9114048205776
		ArgOfPericen	40.573688663882095
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 64.1"
{
	ParentBody	"Ouranos 64"
	Class		"Asteroid"
	Mass		1.5250474508238149e-09
	Radius		9.051169523050223

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.641420024837801e-06
		Eccentricity	0.0029743283197142343
		Inclination		-1.6276203489456271
		AscendingNode	77.0347620503867
		ArgOfPericen	7.31177230193262
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 65"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2050648885354166e-07
	Radius		39.01180365166767

	RotationPeriod	6.398063287175908

	Obliquity		238.48967053148147

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9916658554446778
		Eccentricity	0.048306914345446865
		Inclination		-4.576923724819678
		AscendingNode	241.66979210991855
		ArgOfPericen	307.8923160647552
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 65.1"
{
	ParentBody	"Ouranos 65"
	Class		"Asteroid"
	Mass		2.6104490617747247e-10
	Radius		5.047747548219456

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.175838700492716e-06
		Eccentricity	0.004083190384342075
		Inclination		-2.283078177780028
		AscendingNode	6.1455032608351345
		ArgOfPericen	94.22204510128782
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 66"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.341674726459226e-07
	Radius		66.82237687065543

	RotationPeriod	5.834322770082345

	Obliquity		314.7995423770711

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0480676105502003
		Eccentricity	0.035698790034873
		Inclination		-2.4437845257264033
		AscendingNode	299.4278544564409
		ArgOfPericen	101.2862428773163
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 67"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0045511790350254
		Eccentricity	0.0640138401327752
		Inclination		0.9028059153422479
		AscendingNode	13.572477263047787
		ArgOfPericen	213.44247226262235
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 67 A"
{
	ParentBody	"Ouranos 67"
	Class		"Asteroid"
	Mass		2.6552578198295385e-07
	Radius		50.9398074900421

	Orbit
	{
		Epoch			2457395.5
		Period			0.005699975142747498
		Eccentricity	0.006691370258683372
		Inclination		90.72548676456337
		AscendingNode	42.4791354724801
		ArgOfPericen	311.2248823074454
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 67 B"
{
	ParentBody	"Ouranos 67"
	Class		"Asteroid"
	Mass		1.6261259702719772e-07
	Radius		43.25866664585302

	Orbit
	{
		Epoch			2457395.5
		Period			0.005699975142747498
		Eccentricity	0.006691370258683372
		Inclination		90.72548676456337
		AscendingNode	42.4791354724801
		ArgOfPericen	131.2248823074454
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 68"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.732846901391125e-08
	Radius		34.0200348650184

	RotationPeriod	9.510714878012802

	Obliquity		238.01231616880688

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0133947945426616
		Eccentricity	0.04455516757644294
		Inclination		-1.0505705466788162
		AscendingNode	37.94000010039257
		ArgOfPericen	134.26694967166665
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 69"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.1813731265568435e-07
	Radius		49.36487124518858

	RotationPeriod	7.238548328289776

	Obliquity		102.09742217943041

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9794731346193983
		Eccentricity	0.030883169826503565
		Inclination		2.3112171413848213
		AscendingNode	95.20130120598374
		ArgOfPericen	305.9782302829553
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 69.1"
{
	ParentBody	"Ouranos 69"
	Class		"Asteroid"
	Mass		1.308915485503476e-10
	Radius		4.163691632341285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9168939606138906e-06
		Eccentricity	0.007169543939938198
		Inclination		33.502926923657874
		AscendingNode	89.27872068267277
		ArgOfPericen	5.239211359808844
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 70"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9722476521126895
		Eccentricity	0.03611832715530548
		Inclination		-0.8159330317525725
		AscendingNode	229.92710306222642
		ArgOfPericen	68.2341752329138
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 70 A"
{
	ParentBody	"Ouranos 70"
	Class		"Asteroid"
	Mass		9.679165725793216e-08
	Radius		36.1626897407558

	Orbit
	{
		Epoch			2457395.5
		Period			0.005295469140784129
		Eccentricity	0.003601718018715473
		Inclination		326.14457316895465
		AscendingNode	186.0659078371977
		ArgOfPericen	101.8087768960679
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 70 B"
{
	ParentBody	"Ouranos 70"
	Class		"Asteroid"
	Mass		2.4579475730245494e-08
	Radius		22.900183120104895

	Orbit
	{
		Epoch			2457395.5
		Period			0.005295469140784129
		Eccentricity	0.003601718018715473
		Inclination		326.14457316895465
		AscendingNode	186.0659078371977
		ArgOfPericen	281.8087768960679
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 71"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.6954979755393362e-07
	Radius		44.46755078963409

	RotationPeriod	6.803887036123525

	Obliquity		233.53093618828126

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0346954906828811
		Eccentricity	0.07363403458402452
		Inclination		0.7419579762636006
		AscendingNode	168.42999971147546
		ArgOfPericen	287.5364144577172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 72"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.504478233162515e-07
	Radius		71.75649757919832

	RotationPeriod	10.943702125579652

	Obliquity		246.63967371451398

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9609295789762498
		Eccentricity	0.021580378542453715
		Inclination		0.5517191413287958
		AscendingNode	245.73019231541747
		ArgOfPericen	58.028953333667225
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 73"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9706932920182193
		Eccentricity	0.05416622154081812
		Inclination		-0.5879442291457735
		AscendingNode	111.37863626654133
		ArgOfPericen	44.61703366487741
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 73 A"
{
	ParentBody	"Ouranos 73"
	Class		"Asteroid"
	Mass		6.052713044721221e-07
	Radius		66.60549860222974

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003249194305802355
		Eccentricity	0.003913845873791587
		Inclination		70.84405220659474
		AscendingNode	103.73277768726071
		ArgOfPericen	320.18516070462783
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 73 B"
{
	ParentBody	"Ouranos 73"
	Class		"Asteroid"
	Mass		5.500481054201035e-07
	Radius		64.51493734808646

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003249194305802355
		Eccentricity	0.003913845873791587
		Inclination		70.84405220659474
		AscendingNode	103.73277768726071
		ArgOfPericen	140.18516070462783
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 74"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.856466694029257e-07
	Radius		61.49574449816717

	RotationPeriod	4.049794096029819

	Obliquity		230.99605882978926

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9932728941457655
		Eccentricity	0.05323942410435193
		Inclination		0.9212823919137338
		AscendingNode	285.42183987069666
		ArgOfPericen	183.12422827178696
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 75"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9579732784516107
		Eccentricity	0.03020860293945102
		Inclination		0.45654376952928316
		AscendingNode	123.87125717705716
		ArgOfPericen	52.80223394007914
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 75 A"
{
	ParentBody	"Ouranos 75"
	Class		"Asteroid"
	Mass		5.656304380466136e-07
	Radius		62.00309766843014

	Orbit
	{
		Epoch			2457395.5
		Period			0.0056055478535426
		Eccentricity	0.0038013194254947298
		Inclination		326.50260618322096
		AscendingNode	237.15420248486436
		ArgOfPericen	255.25754347424214
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 75 B"
{
	ParentBody	"Ouranos 75"
	Class		"Asteroid"
	Mass		6.275575192135938e-08
	Radius		29.79341658917108

	Orbit
	{
		Epoch			2457395.5
		Period			0.0056055478535426
		Eccentricity	0.0038013194254947298
		Inclination		326.50260618322096
		AscendingNode	237.15420248486436
		ArgOfPericen	75.25754347424214
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 76"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.379535997165539e-08
	Radius		34.682484496883696

	RotationPeriod	7.026049275901925

	Obliquity		131.72475179664818

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9846707941592803
		Eccentricity	0.06900267390332915
		Inclination		-3.04437114056258
		AscendingNode	308.93479105602796
		ArgOfPericen	222.88834517729086
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 77"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.698198985100413e-07
	Radius		68.17935735488844

	RotationPeriod	5.871349841484894

	Obliquity		235.71005704621788

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9733314647480696
		Eccentricity	0.07935697871285796
		Inclination		-1.6763472754909963
		AscendingNode	99.93908152100191
		ArgOfPericen	309.5721367740398
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 78"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.740515759651582e-08
	Radius		30.583945788730333

	RotationPeriod	5.294374327399367

	Obliquity		299.1570892718795

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9590444259062962
		Eccentricity	0.04515041141259314
		Inclination		-1.8403081007991737
		AscendingNode	55.12609941092276
		ArgOfPericen	227.43630005877475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 79"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.4559226240619477e-07
	Radius		51.60247583384514

	RotationPeriod	6.627374687427578

	Obliquity		84.6425477060276

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0172634017260416
		Eccentricity	0.0375292861701991
		Inclination		1.0421650679010872
		AscendingNode	9.056098897760837
		ArgOfPericen	81.27918938105341
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 80"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.870492569434196e-07
	Radius		66.94830713775966

	RotationPeriod	9.158833597424483

	Obliquity		302.59721055344374

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.058626928719096
		Eccentricity	0.0661579501766208
		Inclination		-0.08303696010342024
		AscendingNode	218.62750095123099
		ArgOfPericen	231.6014673649355
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 81"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9910033393606894
		Eccentricity	0.04965089549978563
		Inclination		-1.508335748521596
		AscendingNode	20.860465580658992
		ArgOfPericen	316.64157680870346
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 81 A"
{
	ParentBody	"Ouranos 81"
	Class		"Asteroid"
	Mass		5.342313615592312e-07
	Radius		65.45388943971443

	Orbit
	{
		Epoch			2457395.5
		Period			0.002982787443652682
		Eccentricity	0.006040933199432711
		Inclination		222.66919808213154
		AscendingNode	346.0002948690473
		ArgOfPericen	277.5282834538326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 81 B"
{
	ParentBody	"Ouranos 81"
	Class		"Asteroid"
	Mass		1.5828742775924157e-08
	Radius		20.25386010829513

	Orbit
	{
		Epoch			2457395.5
		Period			0.002982787443652682
		Eccentricity	0.006040933199432711
		Inclination		222.66919808213154
		AscendingNode	346.0002948690473
		ArgOfPericen	97.52828345383261
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 82"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.8392817425779534e-07
	Radius		56.65192631457558

	RotationPeriod	6.090599986744517

	Obliquity		130.02548631931631

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0076776234704978
		Eccentricity	0.06698171715648701
		Inclination		-1.328868939683646
		AscendingNode	97.63852776846704
		ArgOfPericen	84.41715941753101
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 82.1"
{
	ParentBody	"Ouranos 82"
	Class		"Asteroid"
	Mass		7.226661499687232e-10
	Radius		6.994831512836857

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.260081079052494e-06
		Eccentricity	0.004343176423357702
		Inclination		3.1957554018437833
		AscendingNode	341.7269162414006
		ArgOfPericen	54.81889051102038
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 82.2"
{
	ParentBody	"Ouranos 82"
	Class		"Asteroid"
	Mass		3.6435738477156357e-09
	Radius		11.994271607969683

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.987532829299e-06
		Eccentricity	0.003511853377554097
		Inclination		14.484815157283238
		AscendingNode	205.29518699155497
		ArgOfPericen	347.4375122892977
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 82.3"
{
	ParentBody	"Ouranos 82"
	Class		"Asteroid"
	Mass		1.8380434936696823e-10
	Radius		4.4318319256026415

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3084959462468266e-06
		Eccentricity	0.004196059970336376
		Inclination		0.8165561158816306
		AscendingNode	153.67469982993015
		ArgOfPericen	93.66090211585421
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 83"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9695412253594737
		Eccentricity	0.04692033258197174
		Inclination		2.18821917203473
		AscendingNode	117.33663770252589
		ArgOfPericen	141.73125248013113
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 83 A"
{
	ParentBody	"Ouranos 83"
	Class		"Asteroid"
	Mass		1.370443654291204e-07
	Radius		39.28308049938366

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033108078643147255
		Eccentricity	0.00555912244963
		Inclination		67.30333848842092
		AscendingNode	28.648866427391823
		ArgOfPericen	171.74673606386833
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 83 B"
{
	ParentBody	"Ouranos 83"
	Class		"Asteroid"
	Mass		9.091666098682319e-09
	Radius		15.902532848246256

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033108078643147255
		Eccentricity	0.00555912244963
		Inclination		67.30333848842092
		AscendingNode	28.648866427391823
		ArgOfPericen	351.7467360638683
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 84"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9968262017028354
		Eccentricity	0.02100167823527845
		Inclination		-1.9447309844250282
		AscendingNode	255.5994777033692
		ArgOfPericen	329.97083399933535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 84 A"
{
	ParentBody	"Ouranos 84"
	Class		"Asteroid"
	Mass		1.2655417470929444e-07
	Radius		41.25423006314276

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033373926355640664
		Eccentricity	0.004323111127569238
		Inclination		42.14662387204711
		AscendingNode	176.28425205659326
		ArgOfPericen	168.6554589801296
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 84 B"
{
	ParentBody	"Ouranos 84"
	Class		"Asteroid"
	Mass		2.8638672811334046e-08
	Radius		25.13973083256125

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033373926355640664
		Eccentricity	0.004323111127569238
		Inclination		42.14662387204711
		AscendingNode	176.28425205659326
		ArgOfPericen	348.6554589801296
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 85"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2337576623594093e-06
	Radius		79.7881296852689

	RotationPeriod	4.864581048997747

	Obliquity		117.30987392638603

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9775442198099185
		Eccentricity	0.04938618765408186
		Inclination		-0.5860423700254878
		AscendingNode	128.35203116853543
		ArgOfPericen	272.06974418454195
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 86"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.804533664287391e-07
	Radius		62.654501894077335

	RotationPeriod	5.871639462627034

	Obliquity		107.04781448342604

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9828485958955373
		Eccentricity	0.06207023631769903
		Inclination		1.8013095060813087
		AscendingNode	88.87441494908971
		ArgOfPericen	43.86221152942903
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 87"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9846217882764892
		Eccentricity	0.0015612683127091062
		Inclination		2.0460318881500514
		AscendingNode	259.38059463089735
		ArgOfPericen	3.917219916901411
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 87 A"
{
	ParentBody	"Ouranos 87"
	Class		"Asteroid"
	Mass		2.2442585193520234e-07
	Radius		48.72419590831452

	Orbit
	{
		Epoch			2457395.5
		Period			0.006123931766321584
		Eccentricity	0.00802049481392527
		Inclination		267.6132517455391
		AscendingNode	269.5579843860646
		ArgOfPericen	124.81696030727657
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 87 B"
{
	ParentBody	"Ouranos 87"
	Class		"Asteroid"
	Mass		9.083024886320429e-08
	Radius		36.04103226371703

	Orbit
	{
		Epoch			2457395.5
		Period			0.006123931766321584
		Eccentricity	0.00802049481392527
		Inclination		267.6132517455391
		AscendingNode	269.5579843860646
		ArgOfPericen	304.8169603072766
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 88"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0266093539917291
		Eccentricity	0.051045786058426926
		Inclination		0.7188171687561108
		AscendingNode	320.15584881746526
		ArgOfPericen	272.33860164205146
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 88 A"
{
	ParentBody	"Ouranos 88"
	Class		"Asteroid"
	Mass		6.087455115446984e-07
	Radius		64.43667753421909

	Orbit
	{
		Epoch			2457395.5
		Period			0.008136799971571728
		Eccentricity	0.0014904469318948819
		Inclination		152.35484277525705
		AscendingNode	80.8897162421064
		ArgOfPericen	329.20562398188235
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 88 B"
{
	ParentBody	"Ouranos 88"
	Class		"Asteroid"
	Mass		2.843960099811634e-07
	Radius		49.99912241716564

	Orbit
	{
		Epoch			2457395.5
		Period			0.008136799971571728
		Eccentricity	0.0014904469318948819
		Inclination		152.35484277525705
		AscendingNode	80.8897162421064
		ArgOfPericen	149.20562398188235
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 89"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.866245412739723e-07
	Radius		50.01266572234299

	RotationPeriod	6.791180256370902

	Obliquity		15.706127115319726

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9456509838785032
		Eccentricity	0.04448499881068643
		Inclination		-0.6812195046912233
		AscendingNode	238.6888615051704
		ArgOfPericen	7.561482660748302
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 90"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0887598214469786e-07
	Radius		36.550411914959994

	RotationPeriod	4.097325538557968

	Obliquity		30.120413480979575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9811254777641847
		Eccentricity	0.057642238535751664
		Inclination		0.20883169646703598
		AscendingNode	159.0128568568338
		ArgOfPericen	16.114987182325216
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 91"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9959264291904295
		Eccentricity	0.058449410097572055
		Inclination		0.6136997997652609
		AscendingNode	190.7450872988172
		ArgOfPericen	295.0747086929569
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 91 A"
{
	ParentBody	"Ouranos 91"
	Class		"Asteroid"
	Mass		3.955689295679007e-08
	Radius		27.097126936296053

	Orbit
	{
		Epoch			2457395.5
		Period			0.006195393125592513
		Eccentricity	0.007931265483880809
		Inclination		214.741974102655
		AscendingNode	339.90948006176524
		ArgOfPericen	354.86695998135133
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 91 B"
{
	ParentBody	"Ouranos 91"
	Class		"Asteroid"
	Mass		8.335144506818664e-09
	Radius		16.124523874328485

	Orbit
	{
		Epoch			2457395.5
		Period			0.006195393125592513
		Eccentricity	0.007931265483880809
		Inclination		214.741974102655
		AscendingNode	339.90948006176524
		ArgOfPericen	174.86695998135133
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 92"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9722255553102754
		Eccentricity	0.032465719780748865
		Inclination		1.3598077110644065
		AscendingNode	22.88162677096203
		ArgOfPericen	227.48732081185406
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 92 A"
{
	ParentBody	"Ouranos 92"
	Class		"Asteroid"
	Mass		1.2725931188195215e-07
	Radius		38.848486748785454

	Orbit
	{
		Epoch			2457395.5
		Period			0.002836811262269612
		Eccentricity	0.006324171009936551
		Inclination		49.28302095420413
		AscendingNode	306.5220214840072
		ArgOfPericen	192.5825396943555
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 92 B"
{
	ParentBody	"Ouranos 92"
	Class		"Asteroid"
	Mass		6.051718239550452e-08
	Radius		30.322882488720413

	Orbit
	{
		Epoch			2457395.5
		Period			0.002836811262269612
		Eccentricity	0.006324171009936551
		Inclination		49.28302095420413
		AscendingNode	306.5220214840072
		ArgOfPericen	12.58253969435549
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 93"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.6210249963493103e-07
	Radius		60.20992558553726

	RotationPeriod	5.428379223654189

	Obliquity		184.46142483708672

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9569479064966515
		Eccentricity	0.07625123778422513
		Inclination		0.37709374773848414
		AscendingNode	167.81894140709773
		ArgOfPericen	275.3898497338706
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 94"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0074957243186382
		Eccentricity	0.05380236190635341
		Inclination		-0.8330144881539363
		AscendingNode	270.24910902863843
		ArgOfPericen	242.19795236126544
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 94 A"
{
	ParentBody	"Ouranos 94"
	Class		"Asteroid"
	Mass		3.924726216803479e-07
	Radius		56.49699192186968

	Orbit
	{
		Epoch			2457395.5
		Period			0.007794036300502903
		Eccentricity	0.0077007498739372635
		Inclination		112.37023740207722
		AscendingNode	344.33873233344417
		ArgOfPericen	19.140605499869974
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 94 B"
{
	ParentBody	"Ouranos 94"
	Class		"Asteroid"
	Mass		7.350694992537415e-09
	Radius		15.003698807911173

	Orbit
	{
		Epoch			2457395.5
		Period			0.007794036300502903
		Eccentricity	0.0077007498739372635
		Inclination		112.37023740207722
		AscendingNode	344.33873233344417
		ArgOfPericen	199.14060549986996
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 95"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.3865994878884317e-07
	Radius		58.654936222403805

	RotationPeriod	3.1011655239764258

	Obliquity		142.21211915353945

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9826819249420381
		Eccentricity	0.04653044102681724
		Inclination		-0.17549731007814937
		AscendingNode	280.4438525718197
		ArgOfPericen	115.9206112880124
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 96"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.2956617950757824e-07
	Radius		48.25877731682673

	RotationPeriod	6.695334805884094

	Obliquity		43.35298775839095

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9965125527643746
		Eccentricity	0.04273210843602193
		Inclination		1.9054429018199985
		AscendingNode	88.13567701795623
		ArgOfPericen	95.36044476253154
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 97"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0330227589163063
		Eccentricity	0.048550046922302956
		Inclination		-1.7805258883849615
		AscendingNode	179.29083501103418
		ArgOfPericen	241.14295235615452
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 97 A"
{
	ParentBody	"Ouranos 97"
	Class		"Asteroid"
	Mass		3.33606756253973e-09
	Radius		11.847831251584957

	Orbit
	{
		Epoch			2457395.5
		Period			0.00396824310174948
		Eccentricity	0.006497246332887928
		Inclination		118.4476722559184
		AscendingNode	156.03494240369452
		ArgOfPericen	163.11797517371912
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 97 B"
{
	ParentBody	"Ouranos 97"
	Class		"Asteroid"
	Mass		2.3889104083182547e-09
	Radius		10.599707189459288

	Orbit
	{
		Epoch			2457395.5
		Period			0.00396824310174948
		Eccentricity	0.006497246332887928
		Inclination		118.4476722559184
		AscendingNode	156.03494240369452
		ArgOfPericen	343.1179751737191
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 98"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.9873226712893956e-08
	Radius		24.590953220097052

	RotationPeriod	9.540179382195966

	Obliquity		61.164500764999204

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9899673156566163
		Eccentricity	0.03464919175903296
		Inclination		1.843473295847529
		AscendingNode	5.421142858994856
		ArgOfPericen	145.07726801553133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 99"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9406593637423895
		Eccentricity	0.06065351148615449
		Inclination		3.9546551669123016
		AscendingNode	113.76080535854167
		ArgOfPericen	164.6934165598936
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 99 A"
{
	ParentBody	"Ouranos 99"
	Class		"Asteroid"
	Mass		4.391286688748927e-08
	Radius		27.767940379832066

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013390485539010208
		Eccentricity	0.006583596836649795
		Inclination		6.491597370062774
		AscendingNode	305.8431910387126
		ArgOfPericen	124.37566417125042
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 99 B"
{
	ParentBody	"Ouranos 99"
	Class		"Asteroid"
	Mass		1.542510167543889e-08
	Radius		19.5924651478319

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013390485539010208
		Eccentricity	0.006583596836649795
		Inclination		6.491597370062774
		AscendingNode	305.8431910387126
		ArgOfPericen	304.37566417125043
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 100"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.773281154036803e-07
	Radius		65.71132736956113

	RotationPeriod	7.655403163147282

	Obliquity		278.12114180722847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9960730097502453
		Eccentricity	0.023109427816550166
		Inclination		-0.7239388134552017
		AscendingNode	220.265739241041
		ArgOfPericen	41.85781797183262
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 101"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.318253412425649e-08
	Radius		35.57640371466165

	RotationPeriod	3.2999517650525587

	Obliquity		51.31441033297679

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0200014930559764
		Eccentricity	0.046005887603743634
		Inclination		-2.1808519611588535
		AscendingNode	57.49605980952918
		ArgOfPericen	57.92660938118778
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 102"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.716810115771465e-07
	Radius		73.51218142853486

	RotationPeriod	6.3263839570363505

	Obliquity		280.7462365709696

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9984765072167389
		Eccentricity	0.04293305490361044
		Inclination		-1.2201622071425546
		AscendingNode	153.97892066662064
		ArgOfPericen	69.70037676721009
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 103"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.8225236437730334e-07
	Radius		52.36266743494343

	RotationPeriod	7.558415258059609

	Obliquity		293.4273275211573

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0004727106337317
		Eccentricity	0.04630247325387831
		Inclination		1.2624764581484222
		AscendingNode	214.2044171346127
		ArgOfPericen	313.3002605669918
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 104"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.008429931923254e-08
	Radius		32.48294878134351

	RotationPeriod	7.054287042333085

	Obliquity		269.0559443718155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9455381432823585
		Eccentricity	0.030720830548796936
		Inclination		-0.7598569951733684
		AscendingNode	141.96775026910404
		ArgOfPericen	55.26605447121161
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 104.1"
{
	ParentBody	"Ouranos 104"
	Class		"Asteroid"
	Mass		2.3184444542383788e-10
	Radius		5.094880617803067

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.114145929258344e-06
		Eccentricity	0.003913318088401338
		Inclination		11.399651942750744
		AscendingNode	256.7989466846968
		ArgOfPericen	202.21789760646257
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 105"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.202768846453583e-08
	Radius		34.19867145056785

	RotationPeriod	5.79703817197272

	Obliquity		239.4871947556066

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9685288429102906
		Eccentricity	0.08307060236473049
		Inclination		1.5285198903336819
		AscendingNode	110.86681084079595
		ArgOfPericen	312.07121168476573
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 105.1"
{
	ParentBody	"Ouranos 105"
	Class		"Asteroid"
	Mass		4.974778139413689e-10
	Radius		6.512793598172998

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.152605905669557e-07
		Eccentricity	0.0037218948710528565
		Inclination		2.396942028762916
		AscendingNode	154.2049520166205
		ArgOfPericen	271.8885038276119
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 106"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.960851841166281e-07
	Radius		46.42164125782448

	RotationPeriod	6.426967562980188

	Obliquity		108.19117382209215

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0479354171172406
		Eccentricity	0.06138401842135871
		Inclination		0.004896944952974099
		AscendingNode	168.73184511336555
		ArgOfPericen	341.7362732653096
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 107"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.661350640290372e-07
	Radius		63.3122802868828

	RotationPeriod	5.752291063403018

	Obliquity		355.0118819506159

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9778969676143252
		Eccentricity	0.068666389193972
		Inclination		1.760684001401605
		AscendingNode	130.83786958225383
		ArgOfPericen	190.0816604593514
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 108"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.6454548496894752e-07
	Radius		42.38482105063767

	RotationPeriod	5.193715687592057

	Obliquity		225.82873975344782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9798891135383734
		Eccentricity	0.01519060149470039
		Inclination		-0.5961192259312907
		AscendingNode	181.35009247725108
		ArgOfPericen	92.81171804576404
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 108.1"
{
	ParentBody	"Ouranos 108"
	Class		"Asteroid"
	Mass		5.165511247648082e-10
	Radius		6.206109982660956

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.8513587515165354e-06
		Eccentricity	0.006545456537746569
		Inclination		3.022508357342672
		AscendingNode	47.357860342538665
		ArgOfPericen	326.6466963202042
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 108.2"
{
	ParentBody	"Ouranos 108"
	Class		"Asteroid"
	Mass		1.1046420440994749e-10
	Radius		3.71126717325847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.411169768424125e-06
		Eccentricity	0.005267510739819285
		Inclination		9.495521458590822
		AscendingNode	219.8311171709064
		ArgOfPericen	58.730909430638256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 109"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.300885787378878e-07
	Radius		38.41311609197876

	RotationPeriod	6.916338875274783

	Obliquity		155.5636485280713

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9778458582543019
		Eccentricity	0.07227557953357902
		Inclination		1.7170933931909982
		AscendingNode	258.62729648407094
		ArgOfPericen	145.4842126386477
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 110"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.218140358151764e-07
	Radius		38.28686377638391

	RotationPeriod	6.9794971055281

	Obliquity		48.76328666208854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0043916940719286
		Eccentricity	0.04574615850079077
		Inclination		-1.325784538816709
		AscendingNode	121.75377680577694
		ArgOfPericen	103.35602982140703
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 111"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2233903293876765e-07
	Radius		39.33841218012864

	RotationPeriod	6.473021166835538

	Obliquity		271.84967672247404

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0222910726564398
		Eccentricity	0.03738992084237426
		Inclination		2.082741656892539
		AscendingNode	278.0516702539175
		ArgOfPericen	249.19040449515833
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 112"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.063672614308429e-08
	Radius		35.82621080586283

	RotationPeriod	5.009075169031594

	Obliquity		260.1265567217938

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.983857059566951
		Eccentricity	0.03957829786770613
		Inclination		3.058166000223574
		AscendingNode	287.40601554379543
		ArgOfPericen	207.03814396270806
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 113"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.3252908800892334e-07
	Radius		49.54393987390903

	RotationPeriod	7.871899625596938

	Obliquity		208.35430246720733

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0087488470013366
		Eccentricity	0.06301421606142572
		Inclination		-0.38311621018040365
		AscendingNode	15.092182413991582
		ArgOfPericen	60.83723299376759
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 113.1"
{
	ParentBody	"Ouranos 113"
	Class		"Asteroid"
	Mass		2.717390385328181e-09
	Radius		11.242997704663853

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.899147049490885e-07
		Eccentricity	0.006236296454375404
		Inclination		35.29013447826126
		AscendingNode	207.3137493502544
		ArgOfPericen	1.114753966767963
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 114"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9437313043361193
		Eccentricity	0.04228443262925125
		Inclination		0.011390940270546311
		AscendingNode	356.4433568741893
		ArgOfPericen	109.25765873894069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 114 A"
{
	ParentBody	"Ouranos 114"
	Class		"Asteroid"
	Mass		3.813008610573682e-07
	Radius		56.46365535183259

	Orbit
	{
		Epoch			2457395.5
		Period			0.005050640992803885
		Eccentricity	0.006188425652234435
		Inclination		305.63250664330667
		AscendingNode	300.2346772497199
		ArgOfPericen	133.27576102579803
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 114 B"
{
	ParentBody	"Ouranos 114"
	Class		"Asteroid"
	Mass		1.4862138938254573e-08
	Radius		19.144329793510703

	Orbit
	{
		Epoch			2457395.5
		Period			0.005050640992803885
		Eccentricity	0.006188425652234435
		Inclination		305.63250664330667
		AscendingNode	300.2346772497199
		ArgOfPericen	313.27576102579803
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 115"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.567804508460242e-07
	Radius		58.799407817338206

	RotationPeriod	8.316401884582316

	Obliquity		245.09785874625538

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9960920685719374
		Eccentricity	0.03358545556415567
		Inclination		0.45842203215216615
		AscendingNode	231.53402107849143
		ArgOfPericen	145.6093752417896
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 116"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.6758218277245465e-07
	Radius		49.952756893971554

	RotationPeriod	8.642885271689277

	Obliquity		340.6762106423266

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.987831595110537
		Eccentricity	0.028650590910453938
		Inclination		-1.9047799324983927
		AscendingNode	169.32958190169632
		ArgOfPericen	174.2445535752769
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 117"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.147026622314244e-08
	Radius		17.577654961282384

	RotationPeriod	2.3038214222379625

	Obliquity		219.41758002971378

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0135527817224343
		Eccentricity	0.08169811932668675
		Inclination		-2.0461767150368533
		AscendingNode	29.525197011295376
		ArgOfPericen	183.69140643415193
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 118"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9615481408414119
		Eccentricity	0.061679284764006664
		Inclination		2.5301061990708846
		AscendingNode	11.473044228252402
		ArgOfPericen	215.45779581030226
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 118 A"
{
	ParentBody	"Ouranos 118"
	Class		"Asteroid"
	Mass		7.129211074540345e-08
	Radius		35.001655698133625

	Orbit
	{
		Epoch			2457395.5
		Period			0.006525526593918476
		Eccentricity	0.005601586495214016
		Inclination		49.65421618754969
		AscendingNode	310.77612480947846
		ArgOfPericen	55.77410047287718
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 118 B"
{
	ParentBody	"Ouranos 118"
	Class		"Asteroid"
	Mass		9.110841315452082e-09
	Radius		17.630349630284375

	Orbit
	{
		Epoch			2457395.5
		Period			0.006525526593918476
		Eccentricity	0.005601586495214016
		Inclination		49.65421618754969
		AscendingNode	310.77612480947846
		ArgOfPericen	235.7741004728772
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 119"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.892102792945387e-08
	Radius		28.934962604864662

	RotationPeriod	3.775347897006515

	Obliquity		301.3357912973628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0404753786359422
		Eccentricity	0.04568690167303795
		Inclination		1.0519614356781044
		AscendingNode	205.91228458179287
		ArgOfPericen	207.6905884379329
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 120"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.1722392455536284e-07
	Radius		55.086814801876145

	RotationPeriod	3.9129634841482757

	Obliquity		265.7273424506498

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9723976948043879
		Eccentricity	0.04813754311624889
		Inclination		-0.25147315808424214
		AscendingNode	333.7431321935374
		ArgOfPericen	344.53825989227244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 121"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.210244746335041e-07
	Radius		40.37425991051792

	RotationPeriod	6.639946854419012

	Obliquity		181.462660727948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9914535819595105
		Eccentricity	0.042127626259339246
		Inclination		0.7020187300109538
		AscendingNode	21.150934813501955
		ArgOfPericen	325.0677319941474
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 122"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0454708683663043e-07
	Radius		34.71115090322555

	RotationPeriod	8.377011000940744

	Obliquity		2.0023149006901297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9839498203762486
		Eccentricity	0.02566949234927286
		Inclination		-1.14560712596364
		AscendingNode	222.82994305269122
		ArgOfPericen	65.6448323582605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 123"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9732157182495995
		Eccentricity	0.08483482106849248
		Inclination		1.0074340083542561
		AscendingNode	297.57720493222774
		ArgOfPericen	325.0212155852542
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 123 A"
{
	ParentBody	"Ouranos 123"
	Class		"Asteroid"
	Mass		1.809201237027668e-07
	Radius		45.6362594077137

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008563769368566073
		Eccentricity	0.007142735196729085
		Inclination		247.50761234004335
		AscendingNode	265.13624655957386
		ArgOfPericen	304.4212685638791
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 123 B"
{
	ParentBody	"Ouranos 123"
	Class		"Asteroid"
	Mass		2.7694508213971818e-08
	Radius		24.412502491224792

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008563769368566073
		Eccentricity	0.007142735196729085
		Inclination		247.50761234004335
		AscendingNode	265.13624655957386
		ArgOfPericen	124.4212685638791
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 124"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9967088737676564
		Eccentricity	0.07360466389199759
		Inclination		0.3140934261490635
		AscendingNode	117.70699484040827
		ArgOfPericen	241.6053473875827
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 124 A"
{
	ParentBody	"Ouranos 124"
	Class		"Asteroid"
	Mass		6.738632721052775e-07
	Radius		70.7338619057555

	Orbit
	{
		Epoch			2457395.5
		Period			0.0032641256760844394
		Eccentricity	0.009456718839568314
		Inclination		182.52236246388313
		AscendingNode	40.00989302405238
		ArgOfPericen	292.69732750123524
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 124 B"
{
	ParentBody	"Ouranos 124"
	Class		"Asteroid"
	Mass		6.420840124817386e-07
	Radius		69.60397785604874

	Orbit
	{
		Epoch			2457395.5
		Period			0.0032641256760844394
		Eccentricity	0.009456718839568314
		Inclination		182.52236246388313
		AscendingNode	40.00989302405238
		ArgOfPericen	112.69732750123524
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 125"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3889580463260704e-07
	Radius		40.17247068293126

	RotationPeriod	4.681853351316904

	Obliquity		189.78848638485877

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9915359774840038
		Eccentricity	0.050094801054193394
		Inclination		0.3369161976052793
		AscendingNode	239.03222857581065
		ArgOfPericen	131.32573626190663
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 125.1"
{
	ParentBody	"Ouranos 125"
	Class		"Asteroid"
	Mass		3.358115052631256e-10
	Radius		5.391761711001326

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5351334716236553e-06
		Eccentricity	0.009449083793668142
		Inclination		-5.747179261964272
		AscendingNode	138.2271871863668
		ArgOfPericen	139.21255681180332
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 126"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.191038484527885e-07
	Radius		61.3617456588416

	RotationPeriod	6.886279447596747

	Obliquity		265.50255060567247

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9798300755503654
		Eccentricity	0.045368928154885975
		Inclination		0.9028621184674195
		AscendingNode	359.6502291940896
		ArgOfPericen	79.5802257839114
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 126.1"
{
	ParentBody	"Ouranos 126"
	Class		"Asteroid"
	Mass		4.8912163616825994e-09
	Radius		12.960405249711041

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.540739695999046e-06
		Eccentricity	0.0038704326821782558
		Inclination		34.239881397072246
		AscendingNode	352.6175009602426
		ArgOfPericen	56.38244490194635
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 126.2"
{
	ParentBody	"Ouranos 126"
	Class		"Asteroid"
	Mass		5.064165400724997e-09
	Radius		13.11139548031717

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.607543517903136e-06
		Eccentricity	0.005614800647406413
		Inclination		26.56790737834572
		AscendingNode	193.31700366542327
		ArgOfPericen	87.93675447719615
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 127"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1833027357270636e-07
	Radius		36.38697529302183

	RotationPeriod	8.859665182049243

	Obliquity		209.66736683191772

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9480657621874773
		Eccentricity	0.05430490246747699
		Inclination		-1.4307425817272554
		AscendingNode	101.61196480728083
		ArgOfPericen	93.23527024702229
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 128"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.5156133010509916e-07
	Radius		43.319884812393866

	RotationPeriod	2.575523740033448

	Obliquity		226.6848885716682

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.003385439589681
		Eccentricity	0.069326510200667
		Inclination		-0.024789852691578552
		AscendingNode	325.8030211984862
		ArgOfPericen	260.8585333509403
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 128.1"
{
	ParentBody	"Ouranos 128"
	Class		"Asteroid"
	Mass		5.582646698853656e-10
	Radius		6.690181066218814

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.458593178505521e-07
		Eccentricity	0.0045063003281563836
		Inclination		18.466763313501342
		AscendingNode	297.14670452474195
		ArgOfPericen	354.0688440307395
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 129"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.9738772055005613e-07
	Radius		58.32457281914003

	RotationPeriod	3.4824116276336423

	Obliquity		242.78951673488842

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0488783696491866
		Eccentricity	0.06123990044019875
		Inclination		-0.731716270043712
		AscendingNode	235.03268631466332
		ArgOfPericen	319.33018334121084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 130"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.412455159336127e-07
	Radius		49.477879657671885

	RotationPeriod	8.567910277815107

	Obliquity		325.0228497037848

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9720049160930024
		Eccentricity	0.0572542275011455
		Inclination		4.242226083857025
		AscendingNode	199.1378488972356
		ArgOfPericen	256.9452946500374
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 131"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.621601516126518e-07
	Radius		50.8772170110468

	RotationPeriod	4.674748793016909

	Obliquity		14.36049870247043

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9655598737289929
		Eccentricity	0.03673751755420912
		Inclination		-1.1718462139686312
		AscendingNode	132.95670572634106
		ArgOfPericen	231.1012695869348
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 131.1"
{
	ParentBody	"Ouranos 131"
	Class		"Asteroid"
	Mass		4.103268427820527e-10
	Radius		5.907146799137242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.286321252259604e-06
		Eccentricity	0.004322363134069276
		Inclination		2.2660467647266804
		AscendingNode	267.5949471157015
		ArgOfPericen	258.341868981964
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 132"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.898061691383423e-09
	Radius		11.906029830633457

	RotationPeriod	7.527564525853176

	Obliquity		101.18498797555017

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0043117584884822
		Eccentricity	0.012859278470534731
		Inclination		1.4481925315262696
		AscendingNode	255.92632435084636
		ArgOfPericen	85.42060163744064
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 133"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.277383767913137e-07
	Radius		51.80965259812456

	RotationPeriod	8.373245811914716

	Obliquity		122.02536176443678

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9865781097726507
		Eccentricity	0.04151737466957891
		Inclination		-2.7339429439845184
		AscendingNode	285.3555356365403
		ArgOfPericen	231.59627267863488
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 133.1"
{
	ParentBody	"Ouranos 133"
	Class		"Asteroid"
	Mass		4.3367023228993525e-09
	Radius		12.254288997954292

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.625474714293654e-06
		Eccentricity	0.005337052946509918
		Inclination		-14.512642577000474
		AscendingNode	303.14140600653013
		ArgOfPericen	119.20003015262868
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 134"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.6866107346436834e-07
	Radius		49.57450358968939

	RotationPeriod	4.414014620431527

	Obliquity		264.7900973463673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9847909993838323
		Eccentricity	0.05558335396122906
		Inclination		0.7153570509891597
		AscendingNode	197.56642144676238
		ArgOfPericen	154.51945109451677
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 134.1"
{
	ParentBody	"Ouranos 134"
	Class		"Asteroid"
	Mass		9.958365595569233e-11
	Radius		3.5611162214032364

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.27695884110206e-06
		Eccentricity	0.005054645432080944
		Inclination		26.332055266613814
		AscendingNode	237.1488685752815
		ArgOfPericen	195.5945684659865
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 134.2"
{
	ParentBody	"Ouranos 134"
	Class		"Asteroid"
	Mass		3.5624966217416456e-09
	Radius		11.733879193843606

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.644568923165344e-06
		Eccentricity	0.004047375215078221
		Inclination		27.145764193219414
		AscendingNode	40.099071271890054
		ArgOfPericen	102.25370727210142
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 134.3"
{
	ParentBody	"Ouranos 134"
	Class		"Asteroid"
	Mass		3.332715630994312e-09
	Radius		11.475973719808945

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.132137042546656e-06
		Eccentricity	0.004228560607148809
		Inclination		36.524306979119764
		AscendingNode	65.86244404043329
		ArgOfPericen	58.88819629838033
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 134.4"
{
	ParentBody	"Ouranos 134"
	Class		"Asteroid"
	Mass		1.0913134374673678e-09
	Radius		7.909941892948699

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.248629014215171e-06
		Eccentricity	0.005296489117548798
		Inclination		-2.5961415677856063
		AscendingNode	217.4782583350356
		ArgOfPericen	138.97113366710258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 135"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.326905842809439e-07
	Radius		78.50012628565155

	RotationPeriod	4.290301750202702

	Obliquity		1.2694254291927543

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9975494599152713
		Eccentricity	0.08072688952001118
		Inclination		0.6588902564653735
		AscendingNode	117.19403190394219
		ArgOfPericen	274.9202879960957
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 136"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.3356594712296082e-07
	Radius		48.336249274888665

	RotationPeriod	5.697666406644627

	Obliquity		334.62981327296933

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9876713294213904
		Eccentricity	0.05997823432362538
		Inclination		-2.1106718748815667
		AscendingNode	104.74685076283765
		ArgOfPericen	317.29076212991845
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 136.1"
{
	ParentBody	"Ouranos 136"
	Class		"Asteroid"
	Mass		7.012455025387829e-11
	Radius		3.2366305992789206

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4850917705036714e-06
		Eccentricity	0.004755461459128874
		Inclination		19.243300601989333
		AscendingNode	296.43361344656495
		ArgOfPericen	86.28889876553686
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 136.2"
{
	ParentBody	"Ouranos 136"
	Class		"Asteroid"
	Mass		1.702350294177084e-09
	Radius		9.371722404069436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.2436757348702865e-06
		Eccentricity	0.008510447174173399
		Inclination		16.032354267861145
		AscendingNode	257.9210479441934
		ArgOfPericen	359.9690527858355
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 137"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.9332451488967547e-07
	Radius		45.75049891072271

	RotationPeriod	8.373574249797866

	Obliquity		265.6785695305685

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.004536626845804
		Eccentricity	0.037414737628141695
		Inclination		-0.1282854163869408
		AscendingNode	211.00950769529558
		ArgOfPericen	94.28700010652034
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 138"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0204723030286166e-06
	Radius		81.63225328651194

	RotationPeriod	6.624832365354083

	Obliquity		356.3871520362075

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9790461181014997
		Eccentricity	0.024057011034031465
		Inclination		2.524055888583762
		AscendingNode	351.4258640652429
		ArgOfPericen	280.86804103702787
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 139"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.843435807418738e-07
	Radius		48.98254684489087

	RotationPeriod	7.220562716848572

	Obliquity		105.80129448647176

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0065727905316784
		Eccentricity	0.04527694868925228
		Inclination		0.9112387540540384
		AscendingNode	36.79128781529066
		ArgOfPericen	57.71794407462965
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 140"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.524999263452208e-08
	Radius		35.718052659433255

	RotationPeriod	4.267184373504282

	Obliquity		152.83401891780528

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9437449816467817
		Eccentricity	0.027025829150677624
		Inclination		-1.6701452534498793
		AscendingNode	246.5297981497668
		ArgOfPericen	152.92889630823123
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 140.1"
{
	ParentBody	"Ouranos 140"
	Class		"Asteroid"
	Mass		6.710675840462089e-10
	Radius		6.847334484871015

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.640704097689115e-06
		Eccentricity	0.006209955219479918
		Inclination		-10.91381888941623
		AscendingNode	7.820880910355412
		ArgOfPericen	242.10195244312078
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 141"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.6122026487760523e-07
	Radius		54.91349073532693

	RotationPeriod	8.27105452470197

	Obliquity		128.00223038470924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9545982373364362
		Eccentricity	0.024188329764780487
		Inclination		-0.8513554106675786
		AscendingNode	163.3600380666464
		ArgOfPericen	228.5174030395683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 142"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9629231117000439
		Eccentricity	0.03377178940095607
		Inclination		0.4916410898213645
		AscendingNode	308.0343242818689
		ArgOfPericen	182.12046518105936
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 142 A"
{
	ParentBody	"Ouranos 142"
	Class		"Asteroid"
	Mass		1.6221575951300567e-08
	Radius		20.143239276552002

	Orbit
	{
		Epoch			2457395.5
		Period			0.003659365993212306
		Eccentricity	0.005064298434421847
		Inclination		166.74350753471708
		AscendingNode	271.56832761084104
		ArgOfPericen	77.07692032938668
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 142 B"
{
	ParentBody	"Ouranos 142"
	Class		"Asteroid"
	Mass		8.320839827595889e-09
	Radius		16.12454062952336

	Orbit
	{
		Epoch			2457395.5
		Period			0.003659365993212306
		Eccentricity	0.005064298434421847
		Inclination		166.74350753471708
		AscendingNode	271.56832761084104
		ArgOfPericen	257.07692032938667
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 143"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0176661564803553
		Eccentricity	0.049128034882659065
		Inclination		-0.2351993034397236
		AscendingNode	177.22217548383492
		ArgOfPericen	327.35502203338984
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 143 A"
{
	ParentBody	"Ouranos 143"
	Class		"Asteroid"
	Mass		1.419576638107409e-07
	Radius		41.04786175829109

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026236740933390026
		Eccentricity	0.0022885905899482093
		Inclination		150.14179037229457
		AscendingNode	49.9054219759021
		ArgOfPericen	9.399622744770815
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 143 B"
{
	ParentBody	"Ouranos 143"
	Class		"Asteroid"
	Mass		4.231356509424934e-08
	Radius		27.419790389167883

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026236740933390026
		Eccentricity	0.0022885905899482093
		Inclination		150.14179037229457
		AscendingNode	49.9054219759021
		ArgOfPericen	189.39962274477082
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 144"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.503281313979561e-08
	Radius		39.65759553385371

	RotationPeriod	2.584115198270854

	Obliquity		165.31716111311826

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9900698667614664
		Eccentricity	0.03719046846613858
		Inclination		1.0632737472825828
		AscendingNode	148.3268119509626
		ArgOfPericen	309.24974073948266
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 144.1"
{
	ParentBody	"Ouranos 144"
	Class		"Asteroid"
	Mass		1.920626919997048e-10
	Radius		5.013982970396311

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.861940759088713e-06
		Eccentricity	0.005115852630942713
		Inclination		-8.28207581424573
		AscendingNode	129.90781716397882
		ArgOfPericen	111.91392718107915
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 144.2"
{
	ParentBody	"Ouranos 144"
	Class		"Asteroid"
	Mass		8.966011081982155e-11
	Radius		3.8895701427456015

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.411802597759882e-06
		Eccentricity	0.0019277931970180396
		Inclination		-44.47309157168968
		AscendingNode	224.74245975193938
		ArgOfPericen	136.308686686401
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 144.3"
{
	ParentBody	"Ouranos 144"
	Class		"Asteroid"
	Mass		1.4536495414923773e-11
	Radius		2.120907636766837

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6529139463150982e-06
		Eccentricity	0.004935307028102761
		Inclination		-26.56648328596307
		AscendingNode	201.36549734978811
		ArgOfPericen	333.5233004885769
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 145"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.790376325151351e-07
	Radius		49.314054839565514

	RotationPeriod	2.6555253063644657

	Obliquity		99.15187617979747

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9766423633028528
		Eccentricity	0.06123103667796593
		Inclination		1.0184486121768692
		AscendingNode	222.3501572550622
		ArgOfPericen	244.6086258224777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 145.1"
{
	ParentBody	"Ouranos 145"
	Class		"Asteroid"
	Mass		4.608309615628599e-11
	Radius		2.705600502870476

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2871449668210879e-06
		Eccentricity	0.0026890274015119444
		Inclination		-3.860149595734681
		AscendingNode	314.220510712364
		ArgOfPericen	156.71253242003405
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 145.2"
{
	ParentBody	"Ouranos 145"
	Class		"Asteroid"
	Mass		7.750496334127146e-10
	Radius		6.932017110296823

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.3060887142134357e-06
		Eccentricity	0.00500168433264615
		Inclination		-9.24961934316125
		AscendingNode	40.90260851963721
		ArgOfPericen	35.188111546320926
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 146"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.490789814300379e-07
	Radius		65.11739085903378

	RotationPeriod	3.9205819502935824

	Obliquity		86.42908829382104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9910226632959931
		Eccentricity	0.0415813876532203
		Inclination		1.4381479556934624
		AscendingNode	109.45031980371239
		ArgOfPericen	69.75801268312384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 147"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.044782047943894e-07
	Radius		68.99086127410754

	RotationPeriod	5.444501986481552

	Obliquity		70.58395550650421

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9676593084308724
		Eccentricity	0.07355885048929303
		Inclination		2.5239819673022663
		AscendingNode	189.41435998955185
		ArgOfPericen	208.24136432914744
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 148"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.953063032199703
		Eccentricity	0.047756254924233785
		Inclination		-0.027107395577604422
		AscendingNode	84.7102932660309
		ArgOfPericen	52.352596920593676
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 148 A"
{
	ParentBody	"Ouranos 148"
	Class		"Asteroid"
	Mass		9.987024723154726e-09
	Radius		17.675372516740197

	Orbit
	{
		Epoch			2457395.5
		Period			0.004450434978184888
		Eccentricity	0.004157682020678742
		Inclination		148.79579764445882
		AscendingNode	137.5388501186173
		ArgOfPericen	214.27979628259848
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 148 B"
{
	ParentBody	"Ouranos 148"
	Class		"Asteroid"
	Mass		1.7608782062055887e-10
	Radius		4.600442850351694

	Orbit
	{
		Epoch			2457395.5
		Period			0.004450434978184888
		Eccentricity	0.004157682020678742
		Inclination		148.79579764445882
		AscendingNode	137.5388501186173
		ArgOfPericen	34.279796282598454
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 149"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.1863403160629703e-07
	Radius		48.049380357680334

	RotationPeriod	8.520132620240958

	Obliquity		88.48693991238004

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0068979139334617
		Eccentricity	0.03817721985980539
		Inclination		1.123751419008634
		AscendingNode	282.635175865069
		ArgOfPericen	223.85273368471377
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 150"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.8222775973971867e-07
	Radius		45.41992992493827

	RotationPeriod	3.6136599124900504

	Obliquity		336.0699799373488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.021051627832137
		Eccentricity	0.01963066328742967
		Inclination		-1.4382675534683091
		AscendingNode	139.49911643068384
		ArgOfPericen	237.5134304825623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 151"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.5186327995062356e-07
	Radius		41.826323324590184

	RotationPeriod	6.1186028174499425

	Obliquity		226.92052203799813

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9654263118282925
		Eccentricity	0.03804268491015384
		Inclination		2.5052803892161313
		AscendingNode	17.385176948853633
		ArgOfPericen	31.53135603610277
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 152"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.035837323253965e-07
	Radius		73.75451921885808

	RotationPeriod	7.939639654059491

	Obliquity		298.80753113879575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9872969091570513
		Eccentricity	0.05939677981705042
		Inclination		0.33701792767456074
		AscendingNode	205.62250808369524
		ArgOfPericen	305.9107468792087
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 153"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.026503208639607
		Eccentricity	0.06910804725516677
		Inclination		0.1822699444709496
		AscendingNode	182.56579799697548
		ArgOfPericen	260.7330280437978
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 153 A"
{
	ParentBody	"Ouranos 153"
	Class		"Asteroid"
	Mass		7.29144235178538e-08
	Radius		31.898562850102465

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014906967155925888
		Eccentricity	0.008065036806178578
		Inclination		61.57606827223614
		AscendingNode	241.26942960753092
		ArgOfPericen	95.49520468053595
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 153 B"
{
	ParentBody	"Ouranos 153"
	Class		"Asteroid"
	Mass		2.368009481070902e-09
	Radius		10.177187606132483

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014906967155925888
		Eccentricity	0.008065036806178578
		Inclination		61.57606827223614
		AscendingNode	241.26942960753092
		ArgOfPericen	275.49520468053595
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 154"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.1604717712853874e-07
	Radius		48.9572452638076

	RotationPeriod	8.454603363920224

	Obliquity		6.0894305858025755

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9688346903539116
		Eccentricity	0.0308737591997564
		Inclination		-0.8594279468549759
		AscendingNode	354.64372978793637
		ArgOfPericen	346.94203115171547
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 155"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9998113181532047
		Eccentricity	0.07039886201363545
		Inclination		-1.074605348765879
		AscendingNode	234.03513286971307
		ArgOfPericen	83.18334411989468
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 155 A"
{
	ParentBody	"Ouranos 155"
	Class		"Asteroid"
	Mass		1.9892156518696812e-07
	Radius		50.134019396576385

	Orbit
	{
		Epoch			2457395.5
		Period			0.006641655453449581
		Eccentricity	0.006026744693010528
		Inclination		295.35323840204217
		AscendingNode	110.29256626828695
		ArgOfPericen	182.15558559974318
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 155 B"
{
	ParentBody	"Ouranos 155"
	Class		"Asteroid"
	Mass		1.5198921466097243e-07
	Radius		45.83277565466043

	Orbit
	{
		Epoch			2457395.5
		Period			0.006641655453449581
		Eccentricity	0.006026744693010528
		Inclination		295.35323840204217
		AscendingNode	110.29256626828695
		ArgOfPericen	2.1555855997431763
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 156"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7172725652377557e-07
	Radius		42.79105644620867

	RotationPeriod	4.122316513132425

	Obliquity		101.2711110559638

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9841766556913403
		Eccentricity	0.05327224395803945
		Inclination		-0.8088082456439074
		AscendingNode	116.24574498225816
		ArgOfPericen	24.620767278348517
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 157"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.323129238345839e-08
	Radius		30.77518373320793

	RotationPeriod	10.62886938510038

	Obliquity		268.02963973737394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.004188469049742
		Eccentricity	0.021078480667425365
		Inclination		0.5570597967917917
		AscendingNode	1.8336821201134113
		ArgOfPericen	34.73658753193041
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 158"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.751193254549392e-07
	Radius		68.89871931931759

	RotationPeriod	5.738367605636021

	Obliquity		320.29355304953805

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0456702610026927
		Eccentricity	0.02278247570110691
		Inclination		-0.82180678730255
		AscendingNode	228.09033690737175
		ArgOfPericen	190.04789301597395
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 159"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.74311860829644e-07
	Radius		61.44400820005473

	RotationPeriod	5.0595209068126215

	Obliquity		229.05334373653997

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0429427109756393
		Eccentricity	0.05989763206584154
		Inclination		0.4109813087158866
		AscendingNode	157.42312230358579
		ArgOfPericen	140.3970750808402
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 160"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.459761934976458e-07
	Radius		58.291965848198146

	RotationPeriod	1.2693738067625402

	Obliquity		34.356398249160904

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9928182382713769
		Eccentricity	0.042131373940322805
		Inclination		1.1233803545092214
		AscendingNode	38.42631761154784
		ArgOfPericen	270.2359002697687
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 161"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.997950963016713e-07
	Radius		66.53712438500807

	RotationPeriod	9.487856316010019

	Obliquity		140.47214842268303

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0067621406612282
		Eccentricity	0.0498545024131818
		Inclination		-0.8568603957305118
		AscendingNode	61.337436013929114
		ArgOfPericen	311.94761155992813
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 162"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1360171531321846e-07
	Radius		39.23625030038494

	RotationPeriod	8.216061046706969

	Obliquity		39.1288355417897

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9745553008726722
		Eccentricity	0.06557451646646469
		Inclination		-2.0034334082322856
		AscendingNode	33.77378036644094
		ArgOfPericen	143.20583964529274
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 163"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.0320998771930833e-07
	Radius		43.12159001580792

	RotationPeriod	2.524819232716521

	Obliquity		228.33248554297847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9921933040176856
		Eccentricity	0.020422834217320517
		Inclination		0.6358135987962055
		AscendingNode	36.21279087849372
		ArgOfPericen	24.940006404214515
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 164"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9666342314906303
		Eccentricity	0.05498084314023878
		Inclination		-1.87541164209497
		AscendingNode	6.621465595797087
		ArgOfPericen	168.83814340593742
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 164 A"
{
	ParentBody	"Ouranos 164"
	Class		"Asteroid"
	Mass		2.525343556967389e-07
	Radius		48.08205678385606

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026729338574352905
		Eccentricity	0.004147543657511908
		Inclination		320.44142956312686
		AscendingNode	263.183121468455
		ArgOfPericen	147.27308634877272
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 164 B"
{
	ParentBody	"Ouranos 164"
	Class		"Asteroid"
	Mass		5.4394582825080623e-08
	Radius		28.822264362780054

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026729338574352905
		Eccentricity	0.004147543657511908
		Inclination		320.44142956312686
		AscendingNode	263.183121468455
		ArgOfPericen	327.2730863487727
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 165"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.995142088162829
		Eccentricity	0.04013593265195228
		Inclination		-1.4881467196207987
		AscendingNode	189.45597231681649
		ArgOfPericen	160.42987599015277
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 165 A"
{
	ParentBody	"Ouranos 165"
	Class		"Asteroid"
	Mass		3.989425214838619e-07
	Radius		59.57158449866678

	Orbit
	{
		Epoch			2457395.5
		Period			0.004873051601531446
		Eccentricity	0.004596227627830177
		Inclination		225.59701376922192
		AscendingNode	149.5074092930033
		ArgOfPericen	15.422373849340758
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 165 B"
{
	ParentBody	"Ouranos 165"
	Class		"Asteroid"
	Mass		1.0929721856779688e-07
	Radius		38.69059533565803

	Orbit
	{
		Epoch			2457395.5
		Period			0.004873051601531446
		Eccentricity	0.004596227627830177
		Inclination		225.59701376922192
		AscendingNode	149.5074092930033
		ArgOfPericen	195.42237384934077
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 166"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2223339735261944e-07
	Radius		43.01361266463623

	RotationPeriod	3.6035648656114008

	Obliquity		212.28636939572306

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.971217115543082
		Eccentricity	0.05533819103132143
		Inclination		4.393250284319125
		AscendingNode	171.32660859279156
		ArgOfPericen	207.49669386353446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 167"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.916234387289974e-07
	Radius		52.1566602160223

	RotationPeriod	6.4542951747235

	Obliquity		219.17390391919113

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9767796034713495
		Eccentricity	0.07426327014147455
		Inclination		-2.15362977668562
		AscendingNode	52.6968538601084
		ArgOfPericen	55.07234363520865
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 167.1"
{
	ParentBody	"Ouranos 167"
	Class		"Asteroid"
	Mass		2.041556695692186e-09
	Radius		9.977523980700145

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.3977636110137896e-06
		Eccentricity	0.004323877684783311
		Inclination		69.31027877237555
		AscendingNode	236.7679497232582
		ArgOfPericen	358.422440513551
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 168"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.364926428624937e-07
	Radius		61.801569960687765

	RotationPeriod	8.951259267194699

	Obliquity		100.53212298891546

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9897333352222752
		Eccentricity	0.0666290762406268
		Inclination		-1.5322374423835687
		AscendingNode	174.5593789315542
		ArgOfPericen	192.38925063843104
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 169"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0148802385402462
		Eccentricity	0.03591015246017535
		Inclination		-0.32887452771528347
		AscendingNode	48.07675049312533
		ArgOfPericen	35.2722735598898
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 169 A"
{
	ParentBody	"Ouranos 169"
	Class		"Asteroid"
	Mass		4.5585041854537506e-07
	Radius		57.04221175537465

	Orbit
	{
		Epoch			2457395.5
		Period			0.006289216603529997
		Eccentricity	0.004206465153935242
		Inclination		97.66236197672471
		AscendingNode	214.46044960053922
		ArgOfPericen	176.50655239122693
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 169 B"
{
	ParentBody	"Ouranos 169"
	Class		"Asteroid"
	Mass		1.4432384638758628e-07
	Radius		38.87779291494994

	Orbit
	{
		Epoch			2457395.5
		Period			0.006289216603529997
		Eccentricity	0.004206465153935242
		Inclination		97.66236197672471
		AscendingNode	214.46044960053922
		ArgOfPericen	356.50655239122693
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 170"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.928183796648249e-08
	Radius		31.51275558168039

	RotationPeriod	7.799218970382405

	Obliquity		275.29961803520706

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9626393707216316
		Eccentricity	0.0616873920968642
		Inclination		-0.9704932505038943
		AscendingNode	53.4493872490027
		ArgOfPericen	294.57470732240535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 170.1"
{
	ParentBody	"Ouranos 170"
	Class		"Asteroid"
	Mass		2.3537184374876964e-11
	Radius		2.1988625566757216

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.1410345288620485e-06
		Eccentricity	0.0037360931532519678
		Inclination		-46.07806090694964
		AscendingNode	169.48255179206717
		ArgOfPericen	5.686028972366706
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 171"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.140583940488886e-07
	Radius		82.62690964083637

	RotationPeriod	7.459337729951442

	Obliquity		348.89453477556435

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9662685351588461
		Eccentricity	0.031989237946457846
		Inclination		-0.6731101931575411
		AscendingNode	51.27344325794812
		ArgOfPericen	110.37240923413863
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 172"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9969707235758403
		Eccentricity	0.07475885902375005
		Inclination		-0.33395359662282426
		AscendingNode	206.93525133627315
		ArgOfPericen	5.909869673348758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 172 A"
{
	ParentBody	"Ouranos 172"
	Class		"Asteroid"
	Mass		1.8697093722780384e-07
	Radius		45.47283575492973

	Orbit
	{
		Epoch			2457395.5
		Period			0.007303339412307157
		Eccentricity	0.0061642856952478925
		Inclination		225.65740268900032
		AscendingNode	100.7860587269168
		ArgOfPericen	316.8750688123424
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 172 B"
{
	ParentBody	"Ouranos 172"
	Class		"Asteroid"
	Mass		4.458117677171128e-09
	Radius		13.088137411173124

	Orbit
	{
		Epoch			2457395.5
		Period			0.007303339412307157
		Eccentricity	0.0061642856952478925
		Inclination		225.65740268900032
		AscendingNode	100.7860587269168
		ArgOfPericen	136.87506881234242
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 173"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.4902156603021653e-07
	Radius		51.00409434647048

	RotationPeriod	6.037081926737615

	Obliquity		46.39391513344779

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9731250093228684
		Eccentricity	0.05302092979946814
		Inclination		0.15583133906280455
		AscendingNode	4.215739675014913
		ArgOfPericen	125.6785516061729
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 173.1"
{
	ParentBody	"Ouranos 173"
	Class		"Asteroid"
	Mass		5.554049905628031e-10
	Radius		6.663912915248426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.0006343563273122e-06
		Eccentricity	0.006248395946989673
		Inclination		32.21742547092256
		AscendingNode	52.48840544276282
		ArgOfPericen	24.738837086329607
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 174"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9811728491276863
		Eccentricity	0.04710500540637316
		Inclination		-2.4339484376192795
		AscendingNode	344.23376151004754
		ArgOfPericen	10.306660229925463
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 174 A"
{
	ParentBody	"Ouranos 174"
	Class		"Asteroid"
	Mass		3.205837282095914e-07
	Radius		54.24449979768595

	Orbit
	{
		Epoch			2457395.5
		Period			0.006505538921939721
		Eccentricity	0.003645857191163449
		Inclination		118.77986298545734
		AscendingNode	274.93024291952304
		ArgOfPericen	309.169969465636
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 174 B"
{
	ParentBody	"Ouranos 174"
	Class		"Asteroid"
	Mass		1.661085692769073e-08
	Radius		20.222704208629654

	Orbit
	{
		Epoch			2457395.5
		Period			0.006505538921939721
		Eccentricity	0.003645857191163449
		Inclination		118.77986298545734
		AscendingNode	274.93024291952304
		ArgOfPericen	129.16996946563597
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 175"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.598647469666207e-07
	Radius		75.28009029078447

	RotationPeriod	8.087377861566178

	Obliquity		238.85485864193782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9951063554808733
		Eccentricity	0.037314932227322614
		Inclination		0.6259466722470738
		AscendingNode	102.22522384393814
		ArgOfPericen	123.28369497799265
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 176"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.378940685987105e-08
	Radius		29.51443835737487

	RotationPeriod	5.703669325552639

	Obliquity		351.9765825841427

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0032675437474177
		Eccentricity	0.02920437476026214
		Inclination		1.1940467959924057
		AscendingNode	47.65432881876861
		ArgOfPericen	62.20838046613095
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 177"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7722834728526883e-07
	Radius		44.54221377192353

	RotationPeriod	6.364590277042779

	Obliquity		333.0909311241948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9602005185680049
		Eccentricity	0.021047126765258106
		Inclination		0.1757123145843673
		AscendingNode	168.8170263828397
		ArgOfPericen	341.79028601128505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 178"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9757797918396766
		Eccentricity	0.023833284926313435
		Inclination		-2.856612117890455
		AscendingNode	286.4567128576433
		ArgOfPericen	89.3084646535563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 178 A"
{
	ParentBody	"Ouranos 178"
	Class		"Asteroid"
	Mass		1.4114665785707372e-07
	Radius		41.76166143599897

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037965712327771447
		Eccentricity	0.005923562802520587
		Inclination		16.680483628040136
		AscendingNode	63.189595243653784
		ArgOfPericen	223.6999723590645
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 178 B"
{
	ParentBody	"Ouranos 178"
	Class		"Asteroid"
	Mass		1.0156756693023779e-08
	Radius		17.370243964621505

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037965712327771447
		Eccentricity	0.005923562802520587
		Inclination		16.680483628040136
		AscendingNode	63.189595243653784
		ArgOfPericen	43.69997235906453
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 179"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.8191948794529206e-07
	Radius		55.11789207276527

	RotationPeriod	5.797428311824129

	Obliquity		242.81887351313745

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9814447839418263
		Eccentricity	0.02994632982050665
		Inclination		-1.427811539358623
		AscendingNode	216.56290506464646
		ArgOfPericen	112.66570708289811
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 180"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9426458763577275
		Eccentricity	0.05956715015880483
		Inclination		-1.310736566739475
		AscendingNode	83.26627682037827
		ArgOfPericen	243.57225259530648
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 180 A"
{
	ParentBody	"Ouranos 180"
	Class		"Asteroid"
	Mass		4.653147194951877e-07
	Radius		62.79103590738053

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010981378802706078
		Eccentricity	0.008419305362304863
		Inclination		23.44812116015604
		AscendingNode	37.945206042804
		ArgOfPericen	316.727298213796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 180 B"
{
	ParentBody	"Ouranos 180"
	Class		"Asteroid"
	Mass		1.7137085857424775e-07
	Radius		45.008482977172655

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010981378802706078
		Eccentricity	0.008419305362304863
		Inclination		23.44812116015604
		AscendingNode	37.945206042804
		ArgOfPericen	136.72729821379602
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 181"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.980229465906954
		Eccentricity	0.04854224271332547
		Inclination		0.23039464346084473
		AscendingNode	260.1414589557472
		ArgOfPericen	97.53914071036435
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 181 A"
{
	ParentBody	"Ouranos 181"
	Class		"Asteroid"
	Mass		7.431939429705553e-07
	Radius		71.35433832310049

	Orbit
	{
		Epoch			2457395.5
		Period			0.006271265354378882
		Eccentricity	0.005216914225532202
		Inclination		287.2746914553721
		AscendingNode	78.39377422928506
		ArgOfPericen	99.04663477919428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 181 B"
{
	ParentBody	"Ouranos 181"
	Class		"Asteroid"
	Mass		3.114915422621805e-07
	Radius		53.399240785990706

	Orbit
	{
		Epoch			2457395.5
		Period			0.006271265354378882
		Eccentricity	0.005216914225532202
		Inclination		287.2746914553721
		AscendingNode	78.39377422928506
		ArgOfPericen	279.0466347791943
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 182"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.853741204410212e-07
	Radius		55.04085338558024

	RotationPeriod	7.911878273994526

	Obliquity		320.7653703784226

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9802707409902939
		Eccentricity	0.07067025178960501
		Inclination		2.2375716010305755
		AscendingNode	119.46295144164432
		ArgOfPericen	76.52553147147896
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 183"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.586758428267164e-08
	Radius		26.25701965616687

	RotationPeriod	7.077327200909863

	Obliquity		3.1710210251611226

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0001048075252663
		Eccentricity	0.03950096057957977
		Inclination		-2.13953513122664
		AscendingNode	349.6428359705219
		ArgOfPericen	252.98970339219017
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 184"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.917036824225822e-07
	Radius		51.22544213438719

	RotationPeriod	7.222446327894244

	Obliquity		240.00036767045256

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9575909243706536
		Eccentricity	0.08438932128449167
		Inclination		0.5188778366431583
		AscendingNode	151.72330483760823
		ArgOfPericen	162.61476005731
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 184.1"
{
	ParentBody	"Ouranos 184"
	Class		"Asteroid"
	Mass		4.116745695608949e-09
	Radius		12.379119585917824

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7663601753367009e-06
		Eccentricity	0.006870297047040786
		Inclination		-29.702844757317852
		AscendingNode	57.921520909892855
		ArgOfPericen	73.10530883149185
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 185"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.08435513085765e-08
	Radius		33.96656573877326

	RotationPeriod	6.086957273399346

	Obliquity		190.81789100151542

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9925148592050975
		Eccentricity	0.028626718462731994
		Inclination		-0.9923016520213473
		AscendingNode	63.207833645345126
		ArgOfPericen	133.20495655623566
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 186"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.223512027394052e-07
	Radius		66.51629417536837

	RotationPeriod	4.882835669550857

	Obliquity		202.19987633833892

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9679280961083684
		Eccentricity	0.04689507614244279
		Inclination		-1.079965485481573
		AscendingNode	286.91511107606743
		ArgOfPericen	230.3828509101913
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 187"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9679566426734572
		Eccentricity	0.043830426999304894
		Inclination		-0.3823392052897027
		AscendingNode	47.78281132576473
		ArgOfPericen	303.74696891229326
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 187 A"
{
	ParentBody	"Ouranos 187"
	Class		"Asteroid"
	Mass		5.367343023067963e-07
	Radius		59.83422948030815

	Orbit
	{
		Epoch			2457395.5
		Period			0.006060465290267432
		Eccentricity	0.005443497014148534
		Inclination		149.6325408305018
		AscendingNode	216.1241348680114
		ArgOfPericen	251.15963973176042
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 187 B"
{
	ParentBody	"Ouranos 187"
	Class		"Asteroid"
	Mass		4.759336915389653e-07
	Radius		57.48379105550955

	Orbit
	{
		Epoch			2457395.5
		Period			0.006060465290267432
		Eccentricity	0.005443497014148534
		Inclination		149.6325408305018
		AscendingNode	216.1241348680114
		ArgOfPericen	71.15963973176042
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 188"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.743646412013353e-07
	Radius		48.54456165259032

	RotationPeriod	5.6817960002909995

	Obliquity		16.13854792451397

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.051983877270258
		Eccentricity	0.054969891711230665
		Inclination		0.469372402267587
		AscendingNode	219.94434853243388
		ArgOfPericen	94.93232159791631
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 189"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.102529317980086e-07
	Radius		71.72750562158005

	RotationPeriod	6.663936859478699

	Obliquity		167.72271946827001

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.98628649609143
		Eccentricity	0.0291450166424597
		Inclination		3.1105111274213257
		AscendingNode	330.7138645111428
		ArgOfPericen	141.95306200862726
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 189.1"
{
	ParentBody	"Ouranos 189"
	Class		"Asteroid"
	Mass		8.483332413902721e-10
	Radius		8.005183009845531

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.358974394374421e-07
		Eccentricity	0.0061571571761710586
		Inclination		7.329001622779756
		AscendingNode	322.3306572792947
		ArgOfPericen	51.397986302168796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 189.2"
{
	ParentBody	"Ouranos 189"
	Class		"Asteroid"
	Mass		4.06809503408295e-09
	Radius		13.4993482104991

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.1401887061815323e-06
		Eccentricity	0.004728613404437132
		Inclination		-5.241584270142161
		AscendingNode	77.35068001239956
		ArgOfPericen	228.68055144595598
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 190"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.146382126442287e-07
	Radius		75.04377665519408

	RotationPeriod	7.920728059467288

	Obliquity		66.7385592554406

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9846731895592948
		Eccentricity	0.03603734611853131
		Inclination		1.1211378253767852
		AscendingNode	319.0320575692353
		ArgOfPericen	70.65690401488764
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 191"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.937498796068941e-07
	Radius		69.13422661979288

	RotationPeriod	5.88535915489597

	Obliquity		180.5352760790821

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9193706107904229
		Eccentricity	0.03623210374592919
		Inclination		0.30553543177467074
		AscendingNode	176.8202869750651
		ArgOfPericen	58.58182751112303
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 192"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.6493687556711345e-07
	Radius		42.26284490068705

	RotationPeriod	6.038322339540888

	Obliquity		104.09324521424023

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9726365577989053
		Eccentricity	0.03636467009085762
		Inclination		1.1361785189673186
		AscendingNode	125.45865946086639
		ArgOfPericen	175.54228244978054
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 193"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.474931723409868e-07
	Radius		49.75965677302041

	RotationPeriod	5.636284668587043

	Obliquity		279.802692274721

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9814843769580874
		Eccentricity	0.020089351013988413
		Inclination		2.9788637712299626
		AscendingNode	300.52186367871184
		ArgOfPericen	48.99608732138225
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 194"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.7048924017182707e-07
	Radius		51.872399841755175

	RotationPeriod	6.690450622187204

	Obliquity		265.3296302777704

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0210942302952872
		Eccentricity	0.03961099381099879
		Inclination		-4.033820572004773
		AscendingNode	201.07237350153085
		ArgOfPericen	353.0123140441319
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 195"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.781051824727173e-07
	Radius		67.73886492595844

	RotationPeriod	5.993534218330351

	Obliquity		22.69008635083337

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0299378294049026
		Eccentricity	0.04909037778339913
		Inclination		-0.012414652510477584
		AscendingNode	186.9162764976898
		ArgOfPericen	195.69430580999585
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 196"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.244046591501883e-07
	Radius		65.01922857483088

	RotationPeriod	4.078422098942246

	Obliquity		333.84434198299874

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9823573992454758
		Eccentricity	0.05863697066691061
		Inclination		-0.4917086683803529
		AscendingNode	276.77506065003763
		ArgOfPericen	136.82808170725895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 196.1"
{
	ParentBody	"Ouranos 196"
	Class		"Asteroid"
	Mass		1.9266714048441868e-09
	Radius		10.032800639575074

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.9327650333324e-06
		Eccentricity	0.005078144721451438
		Inclination		-19.55156149049666
		AscendingNode	305.34504839259387
		ArgOfPericen	23.282433351139062
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 197"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.752834771960754e-07
	Radius		44.81344707696878

	RotationPeriod	4.454016992707993

	Obliquity		339.24840515754835

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0064072587152713
		Eccentricity	0.048299577624957506
		Inclination		0.4507044925924586
		AscendingNode	201.12637727509954
		ArgOfPericen	311.7879520509591
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 198"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4402309558635148e-07
	Radius		40.33800998232437

	RotationPeriod	10.455586310355894

	Obliquity		163.2420892884125

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9547020000446257
		Eccentricity	0.06625363170051177
		Inclination		-1.0271191122512102
		AscendingNode	110.06719970738955
		ArgOfPericen	277.7135996042385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 199"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.6999370727100676e-07
	Radius		52.984721010502895

	RotationPeriod	6.787159886812018

	Obliquity		134.74176173577524

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9884734260919581
		Eccentricity	0.04247982126740395
		Inclination		-1.4336786534857857
		AscendingNode	148.21283307137878
		ArgOfPericen	249.73663996360364
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 200"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0405138716226144e-07
	Radius		36.4164075144893

	RotationPeriod	4.9713480603726286

	Obliquity		234.66382434612888

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9973481568988668
		Eccentricity	0.060159816569704934
		Inclination		-3.5888034024050706
		AscendingNode	95.47409085950133
		ArgOfPericen	260.0924825280321
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 200.1"
{
	ParentBody	"Ouranos 200"
	Class		"Asteroid"
	Mass		1.6526587947700026e-10
	Radius		4.248890530002921

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6389236074929425e-06
		Eccentricity	0.003669433384117798
		Inclination		1.1343295764670052
		AscendingNode	316.11311766919147
		ArgOfPericen	151.43176507161152
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 201"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.589738310828053e-08
	Radius		22.515639412927086

	RotationPeriod	3.6779928761911314

	Obliquity		56.501741785247155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9996418014855817
		Eccentricity	0.04859526883556431
		Inclination		0.6870650053922044
		AscendingNode	165.54933173555094
		ArgOfPericen	156.75238537241373
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 201.1"
{
	ParentBody	"Ouranos 201"
	Class		"Asteroid"
	Mass		9.753546311807483e-12
	Radius		1.6259973787847242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.631450417664376e-06
		Eccentricity	0.006415312713034273
		Inclination		12.010145063607853
		AscendingNode	208.32543341912267
		ArgOfPericen	44.15630978398801
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 202"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9966152848250199
		Eccentricity	0.06530614956375012
		Inclination		-0.07981570251423183
		AscendingNode	318.69087418658523
		ArgOfPericen	293.6469269311962
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 202 A"
{
	ParentBody	"Ouranos 202"
	Class		"Asteroid"
	Mass		5.444384363402349e-07
	Radius		61.14430661522823

	Orbit
	{
		Epoch			2457395.5
		Period			0.007395084350601103
		Eccentricity	0.004264033224066192
		Inclination		24.354399683740738
		AscendingNode	57.87438025469182
		ArgOfPericen	113.76300544628634
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 202 B"
{
	ParentBody	"Ouranos 202"
	Class		"Asteroid"
	Mass		3.4190003863828156e-08
	Radius		24.303723465810336

	Orbit
	{
		Epoch			2457395.5
		Period			0.007395084350601103
		Eccentricity	0.004264033224066192
		Inclination		24.354399683740738
		AscendingNode	57.87438025469182
		ArgOfPericen	293.76300544628634
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 203"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0379158272471962
		Eccentricity	0.05684508960029869
		Inclination		0.35250232992977854
		AscendingNode	173.16691058845564
		ArgOfPericen	221.7616143536039
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 203 A"
{
	ParentBody	"Ouranos 203"
	Class		"Asteroid"
	Mass		4.857127692939695e-07
	Radius		57.77728361289454

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012550079598961984
		Eccentricity	0.008793525558263321
		Inclination		291.1204852246375
		AscendingNode	76.70122032670477
		ArgOfPericen	158.63758176404212
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 203 B"
{
	ParentBody	"Ouranos 203"
	Class		"Asteroid"
	Mass		1.3903215059571045e-07
	Radius		38.07755255532326

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012550079598961984
		Eccentricity	0.008793525558263321
		Inclination		291.1204852246375
		AscendingNode	76.70122032670477
		ArgOfPericen	338.6375817640421
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 204"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.960149030610069
		Eccentricity	0.03187497488160801
		Inclination		-2.1128260372329173
		AscendingNode	324.43654797061856
		ArgOfPericen	94.655639263868
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 204 A"
{
	ParentBody	"Ouranos 204"
	Class		"Asteroid"
	Mass		2.994691523179909e-07
	Radius		53.884823069699266

	Orbit
	{
		Epoch			2457395.5
		Period			0.004639543138094366
		Eccentricity	0.005075642689811464
		Inclination		237.62183520559103
		AscendingNode	222.2756394804003
		ArgOfPericen	244.83894625932052
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 204 B"
{
	ParentBody	"Ouranos 204"
	Class		"Asteroid"
	Mass		1.4708423994131903e-07
	Radius		42.51457189967686

	Orbit
	{
		Epoch			2457395.5
		Period			0.004639543138094366
		Eccentricity	0.005075642689811464
		Inclination		237.62183520559103
		AscendingNode	222.2756394804003
		ArgOfPericen	64.83894625932055
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 205"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.790124710674848e-07
	Radius		52.55301919681757

	RotationPeriod	4.979567392161631

	Obliquity		184.01039299432418

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.00588449586095
		Eccentricity	0.05196805180474012
		Inclination		1.1873698786970215
		AscendingNode	273.6544336904817
		ArgOfPericen	238.09090855895496
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 206"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.481081616984523e-07
	Radius		67.98223267420103

	RotationPeriod	8.911942467156695

	Obliquity		247.70852748390666

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0062968575164701
		Eccentricity	0.049520097797760294
		Inclination		1.3368616247821303
		AscendingNode	81.79204309875163
		ArgOfPericen	278.551309965134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 207"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.768372591624164e-07
	Radius		51.694126581169236

	RotationPeriod	4.733224527392371

	Obliquity		149.2897370601206

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9871326677302223
		Eccentricity	0.05439007536512344
		Inclination		2.1080437871403963
		AscendingNode	250.12927092758537
		ArgOfPericen	280.102765608119
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 208"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.230426546272738e-10
	Radius		7.285892913623606

	RotationPeriod	9.092686439185169

	Obliquity		73.04843748224724

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0092788426924566
		Eccentricity	0.05555557152050016
		Inclination		-0.7058112509468115
		AscendingNode	187.332732446714
		ArgOfPericen	113.79515843945197
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 208.1"
{
	ParentBody	"Ouranos 208"
	Class		"Asteroid"
	Mass		1.6059691600500837e-12
	Radius		0.9104464420328862

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.582932425538945e-07
		Eccentricity	0.006372185052785354
		Inclination		12.727639074290732
		AscendingNode	112.12173937852543
		ArgOfPericen	249.2925686548831
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 209"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.386226321766974e-07
	Radius		51.8153474292527

	RotationPeriod	4.90978887713563

	Obliquity		359.4078650916374

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0086489931149412
		Eccentricity	0.021569984344796626
		Inclination		0.3572942703915111
		AscendingNode	193.65757435737265
		ArgOfPericen	128.01488241146066
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 210"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.783742889928743e-07
	Radius		44.4553385605891

	RotationPeriod	5.853208671827387

	Obliquity		150.8579888610821

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0115267003400465
		Eccentricity	0.0495257060083309
		Inclination		-0.9344149577002625
		AscendingNode	173.99134853711678
		ArgOfPericen	299.20515841390466
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 210.1"
{
	ParentBody	"Ouranos 210"
	Class		"Asteroid"
	Mass		1.7381122636176448e-10
	Radius		4.407298290589752

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.985928146995996e-06
		Eccentricity	0.0032227356171038463
		Inclination		9.63805593548732
		AscendingNode	287.3041057312867
		ArgOfPericen	234.6652660533303
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 211"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.033864553994907e-07
	Radius		59.66099379172909

	RotationPeriod	8.13155596568685

	Obliquity		22.129802640671855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.936157831845207
		Eccentricity	0.05925894866748426
		Inclination		1.0885499577233595
		AscendingNode	44.038177152537095
		ArgOfPericen	290.7404572561637
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 211.1"
{
	ParentBody	"Ouranos 211"
	Class		"Asteroid"
	Mass		5.996290519839771e-11
	Radius		3.1604161186194224

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.085146075677768e-06
		Eccentricity	0.004337926184177736
		Inclination		-4.740629794802525
		AscendingNode	63.65168646696136
		ArgOfPericen	172.9982919967269
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 212"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9920833543168858
		Eccentricity	0.0392930820539712
		Inclination		-0.2514023131860932
		AscendingNode	279.9622886385329
		ArgOfPericen	264.2617605715795
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 212 A"
{
	ParentBody	"Ouranos 212"
	Class		"Asteroid"
	Mass		8.64139891328266e-08
	Radius		34.30141479305669

	Orbit
	{
		Epoch			2457395.5
		Period			0.00032357517574801964
		Eccentricity	0.005706958684417356
		Inclination		203.7394935727584
		AscendingNode	303.7446881732158
		ArgOfPericen	18.009025080837002
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 212 B"
{
	ParentBody	"Ouranos 212"
	Class		"Asteroid"
	Mass		1.4541363173985172e-08
	Radius		18.93734345130558

	Orbit
	{
		Epoch			2457395.5
		Period			0.00032357517574801964
		Eccentricity	0.005706958684417356
		Inclination		203.7394935727584
		AscendingNode	303.7446881732158
		ArgOfPericen	198.009025080837
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 213"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7858572876610377e-07
	Radius		44.24497012693333

	RotationPeriod	5.786743069865853

	Obliquity		133.31682485442957

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9733821391080223
		Eccentricity	0.059304621666994524
		Inclination		-1.7323167033490758
		AscendingNode	205.08253457624127
		ArgOfPericen	357.98362808185544
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 214"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.109011804624232e-08
	Radius		36.50351185807014

	RotationPeriod	3.8583241524806255

	Obliquity		174.4459446548313

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9696541974535571
		Eccentricity	0.04974429097131139
		Inclination		0.2398465624789245
		AscendingNode	272.8560558477256
		ArgOfPericen	358.2680765935747
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 214.1"
{
	ParentBody	"Ouranos 214"
	Class		"Asteroid"
	Mass		1.8928638504979503e-11
	Radius		2.162141033628395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.329981754596762e-06
		Eccentricity	0.004751257972585576
		Inclination		41.599084972361865
		AscendingNode	322.77855663854405
		ArgOfPericen	168.65602279293657
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 214.2"
{
	ParentBody	"Ouranos 214"
	Class		"Asteroid"
	Mass		8.751081842641817e-10
	Radius		7.760055161819167

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.2856617301984575e-06
		Eccentricity	0.006767612373188315
		Inclination		0.6053654918690722
		AscendingNode	97.41087860660357
		ArgOfPericen	272.72794375143366
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 214.3"
{
	ParentBody	"Ouranos 214"
	Class		"Asteroid"
	Mass		8.191116215745332e-10
	Radius		7.59087644387362

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.327067764837051e-06
		Eccentricity	0.005600355718703792
		Inclination		-10.55375311442376
		AscendingNode	317.2406042724254
		ArgOfPericen	15.643021348085941
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 215"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.3982138397388124e-07
	Radius		56.13495469437891

	RotationPeriod	5.594453009783103

	Obliquity		316.56152033482823

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9921564898606328
		Eccentricity	0.015547519826303438
		Inclination		1.238656461691374
		AscendingNode	349.42645741061267
		ArgOfPericen	33.48972495572226
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 216"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4447547721557262e-07
	Radius		38.302690013914315

	RotationPeriod	7.6443594852373575

	Obliquity		58.172091846202726

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9451304430998916
		Eccentricity	0.06225838556078625
		Inclination		-0.2578881682310729
		AscendingNode	151.59698539362722
		ArgOfPericen	285.72821317047186
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 216.1"
{
	ParentBody	"Ouranos 216"
	Class		"Asteroid"
	Mass		7.704401693994946e-10
	Radius		6.691819259652535

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.1107677718041873e-06
		Eccentricity	0.005544027269019845
		Inclination		9.934721586566445
		AscendingNode	276.41096927232553
		ArgOfPericen	35.90154065318005
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 216.2"
{
	ParentBody	"Ouranos 216"
	Class		"Asteroid"
	Mass		5.962900358956518e-10
	Radius		6.143988780037999

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.451053247984332e-06
		Eccentricity	0.004107459601396333
		Inclination		23.31652507710841
		AscendingNode	218.2009378258014
		ArgOfPericen	138.15652559796925
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 217"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0007251351547455
		Eccentricity	0.05593363607784541
		Inclination		-0.3474001509336765
		AscendingNode	19.270576764936713
		ArgOfPericen	53.31261488707344
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 217 A"
{
	ParentBody	"Ouranos 217"
	Class		"Asteroid"
	Mass		6.6327504277125635e-09
	Radius		14.078724486153405

	Orbit
	{
		Epoch			2457395.5
		Period			0.005578852483480929
		Eccentricity	0.006856188759733614
		Inclination		232.53835046796843
		AscendingNode	186.48547121677663
		ArgOfPericen	166.12026598260073
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 217 B"
{
	ParentBody	"Ouranos 217"
	Class		"Asteroid"
	Mass		2.1458610466033374e-10
	Radius		4.486069077983243

	Orbit
	{
		Epoch			2457395.5
		Period			0.005578852483480929
		Eccentricity	0.006856188759733614
		Inclination		232.53835046796843
		AscendingNode	186.48547121677663
		ArgOfPericen	346.1202659826007
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 218"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9775908536777109
		Eccentricity	0.04503468718731707
		Inclination		0.11164117192839602
		AscendingNode	64.45192144703005
		ArgOfPericen	273.4834285580754
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 218 A"
{
	ParentBody	"Ouranos 218"
	Class		"Asteroid"
	Mass		4.4102539444909734e-07
	Radius		60.105339443846304

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026254509917895976
		Eccentricity	0.006348930033220112
		Inclination		265.93626434038225
		AscendingNode	205.4653009354312
		ArgOfPericen	341.0144519220855
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 218 B"
{
	ParentBody	"Ouranos 218"
	Class		"Asteroid"
	Mass		2.967779104648186e-08
	Radius		24.447570811869603

	Orbit
	{
		Epoch			2457395.5
		Period			0.0026254509917895976
		Eccentricity	0.006348930033220112
		Inclination		265.93626434038225
		AscendingNode	205.4653009354312
		ArgOfPericen	161.01445192208553
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 219"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.954703478700399e-07
	Radius		59.83333854273606

	RotationPeriod	9.325446750199804

	Obliquity		315.9899325641937

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9639872627435947
		Eccentricity	0.03466270840716834
		Inclination		-0.7461241463797558
		AscendingNode	105.51968027041711
		ArgOfPericen	320.41411278396265
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 219.1"
{
	ParentBody	"Ouranos 219"
	Class		"Asteroid"
	Mass		3.4583875913064514e-09
	Radius		11.434799865604939

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.581448605180885e-06
		Eccentricity	0.004605204527982759
		Inclination		-56.52609724300319
		AscendingNode	216.71759997930408
		ArgOfPericen	244.22894979324133
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 220"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7949632067118592e-07
	Radius		45.954925317096006

	RotationPeriod	4.304322786299898

	Obliquity		322.2210351470302

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.99572779822882
		Eccentricity	0.025436454773773765
		Inclination		-0.5985557902615667
		AscendingNode	113.00758550306523
		ArgOfPericen	174.1191232350847
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 221"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.4074547943889186e-07
	Radius		53.76447832044763

	RotationPeriod	6.841326274491125

	Obliquity		54.389783255113564

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9546980311533727
		Eccentricity	0.06018518025255831
		Inclination		-0.09330370041091149
		AscendingNode	7.888961315771743
		ArgOfPericen	83.10939210727108
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 222"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.2734676404089993e-07
	Radius		49.91492147968577

	RotationPeriod	6.574596341834262

	Obliquity		152.73351355331903

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0061426163211846
		Eccentricity	0.04273171945658816
		Inclination		-0.6723677360487288
		AscendingNode	223.87951439331752
		ArgOfPericen	343.5837569594324
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 223"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.0029089846483088e-07
	Radius		43.493753105607325

	RotationPeriod	3.01007570876487

	Obliquity		81.0406499868476

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9154023947629466
		Eccentricity	0.04519359055833633
		Inclination		0.15189692939825405
		AscendingNode	198.2639370805702
		ArgOfPericen	267.0897833222422
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 223.1"
{
	ParentBody	"Ouranos 223"
	Class		"Asteroid"
	Mass		1.680742539698507e-09
	Radius		8.838397791064846

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.1700787038745289e-06
		Eccentricity	0.006793334141639795
		Inclination		48.274975746337475
		AscendingNode	245.6773523488524
		ArgOfPericen	257.7468682169582
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 224"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.969449889519219e-07
	Radius		64.12088303617213

	RotationPeriod	7.7592043809588

	Obliquity		155.84468392557812

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.005842678540517
		Eccentricity	0.06021441878515499
		Inclination		1.8595724546969592
		AscendingNode	18.893022653063497
		ArgOfPericen	140.64380262114966
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 225"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9945561060629116
		Eccentricity	0.036038701808195586
		Inclination		3.2251209122259823
		AscendingNode	194.4630841705161
		ArgOfPericen	161.55109289955368
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 225 A"
{
	ParentBody	"Ouranos 225"
	Class		"Asteroid"
	Mass		4.87153748768166e-07
	Radius		58.60299203681517

	Orbit
	{
		Epoch			2457395.5
		Period			0.0038793111504198782
		Eccentricity	0.006478617020942667
		Inclination		341.33955084256166
		AscendingNode	77.94665224835038
		ArgOfPericen	228.89805275992487
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 225 B"
{
	ParentBody	"Ouranos 225"
	Class		"Asteroid"
	Mass		1.5415120161991123e-07
	Radius		39.934361510547284

	Orbit
	{
		Epoch			2457395.5
		Period			0.0038793111504198782
		Eccentricity	0.006478617020942667
		Inclination		341.33955084256166
		AscendingNode	77.94665224835038
		ArgOfPericen	48.898052759924894
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 226"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9943013970992547
		Eccentricity	0.027749726576834458
		Inclination		-1.7823842638649865
		AscendingNode	206.9707893299478
		ArgOfPericen	234.90217244048065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 226 A"
{
	ParentBody	"Ouranos 226"
	Class		"Asteroid"
	Mass		4.113756870308395e-07
	Radius		62.89532718117769

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016436964230772295
		Eccentricity	0.005667610248146843
		Inclination		290.32403814438965
		AscendingNode	105.37043792670319
		ArgOfPericen	111.01313426157647
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 226 B"
{
	ParentBody	"Ouranos 226"
	Class		"Asteroid"
	Mass		1.141791589177459e-07
	Radius		41.02681347976425

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016436964230772295
		Eccentricity	0.005667610248146843
		Inclination		290.32403814438965
		AscendingNode	105.37043792670319
		ArgOfPericen	291.01313426157645
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 227"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.600856640827293e-07
	Radius		42.928545461462356

	RotationPeriod	3.2745456733962337

	Obliquity		354.43723736942854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.001260704986122
		Eccentricity	0.033708791295235484
		Inclination		2.834544207468286
		AscendingNode	333.38413618327417
		ArgOfPericen	257.4333085832566
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 228"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9713661186948503
		Eccentricity	0.04700808768282303
		Inclination		-0.5081141166455941
		AscendingNode	249.21458920500595
		ArgOfPericen	82.90707072656527
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 228 A"
{
	ParentBody	"Ouranos 228"
	Class		"Asteroid"
	Mass		6.90779314526598e-07
	Radius		70.95705543574512

	Orbit
	{
		Epoch			2457395.5
		Period			0.0067268994584218245
		Eccentricity	0.00536501134401878
		Inclination		355.1621272445987
		AscendingNode	24.54292845362325
		ArgOfPericen	179.6127914422922
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 228 B"
{
	ParentBody	"Ouranos 228"
	Class		"Asteroid"
	Mass		6.657677703634134e-08
	Radius		32.53294652320845

	Orbit
	{
		Epoch			2457395.5
		Period			0.0067268994584218245
		Eccentricity	0.00536501134401878
		Inclination		355.1621272445987
		AscendingNode	24.54292845362325
		ArgOfPericen	359.6127914422922
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 229"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.931965056166962e-07
	Radius		62.62777873236918

	RotationPeriod	6.558198522056542

	Obliquity		326.66928518229446

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9455424375587473
		Eccentricity	0.03649400927667774
		Inclination		-2.634169183278929
		AscendingNode	244.54506446161702
		ArgOfPericen	213.16494786242401
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 230"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3261531343950612e-07
	Radius		42.22706666106273

	RotationPeriod	5.155820720731049

	Obliquity		288.8925672547712

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9674044574968936
		Eccentricity	0.05658681713416747
		Inclination		0.22616769055292443
		AscendingNode	64.6609226203635
		ArgOfPericen	110.82625161367667
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 230.1"
{
	ParentBody	"Ouranos 230"
	Class		"Asteroid"
	Mass		7.944778714866377e-11
	Radius		3.559756488164516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.2280804492085225e-06
		Eccentricity	0.005122782454965745
		Inclination		-13.15384191434497
		AscendingNode	86.81857807571107
		ArgOfPericen	355.20126825310643
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 231"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.652521677353221e-08
	Radius		39.373156373211

	RotationPeriod	4.416160734065981

	Obliquity		55.28778007492658

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9984227940293604
		Eccentricity	0.0627935370028203
		Inclination		1.1729313201253997
		AscendingNode	249.65287136560778
		ArgOfPericen	330.2906586837708
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 232"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.698622907349809e-07
	Radius		64.67333871190857

	RotationPeriod	1.3720822038185085

	Obliquity		96.22264004737166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9533462130836238
		Eccentricity	0.05660102690205482
		Inclination		0.6753353300064129
		AscendingNode	175.27138017752966
		ArgOfPericen	236.99727651014464
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 233"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9672177259720988
		Eccentricity	0.038275791975787885
		Inclination		-2.5452760460351604
		AscendingNode	67.47547066014273
		ArgOfPericen	169.11794122330963
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 233 A"
{
	ParentBody	"Ouranos 233"
	Class		"Asteroid"
	Mass		2.9995069772676927e-07
	Radius		51.20441656190497

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009655624923647883
		Eccentricity	0.003827667864317978
		Inclination		1.720746490590379
		AscendingNode	26.556442872503222
		ArgOfPericen	83.88692562593889
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 233 B"
{
	ParentBody	"Ouranos 233"
	Class		"Asteroid"
	Mass		9.802305852542053e-09
	Radius		16.37068604062062

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009655624923647883
		Eccentricity	0.003827667864317978
		Inclination		1.720746490590379
		AscendingNode	26.556442872503222
		ArgOfPericen	263.8869256259389
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 234"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.5814853227172996e-07
	Radius		48.592034505598896

	RotationPeriod	6.795136665968219

	Obliquity		108.40167073897129

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9957817083769441
		Eccentricity	0.045634498289418714
		Inclination		2.1956527424052448
		AscendingNode	215.3081255879546
		ArgOfPericen	211.5724579080436
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 234.1"
{
	ParentBody	"Ouranos 234"
	Class		"Asteroid"
	Mass		3.7486065911947935e-10
	Radius		5.502564615300796

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.623191617396687e-06
		Eccentricity	0.004110760283862403
		Inclination		29.912359165768123
		AscendingNode	160.7086928404434
		ArgOfPericen	26.592143898240632
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 235"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.090017761859392e-09
	Radius		15.791787810809716

	RotationPeriod	9.706450891440888

	Obliquity		184.7846030860333

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0190483717909427
		Eccentricity	0.06030274976487582
		Inclination		1.8900813191280645
		AscendingNode	51.302742793532204
		ArgOfPericen	219.7661232811269
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 235.1"
{
	ParentBody	"Ouranos 235"
	Class		"Asteroid"
	Mass		1.832698484551769e-11
	Radius		1.9949869670749965

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.647516970117846e-07
		Eccentricity	0.005311816845731184
		Inclination		0.4353535378810749
		AscendingNode	128.15407838859662
		ArgOfPericen	159.19247369979823
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 236"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.501147493262757e-07
	Radius		57.33011762988526

	RotationPeriod	5.643467718546309

	Obliquity		307.20815606686074

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0068647317823791
		Eccentricity	0.050334674189065925
		Inclination		-2.294965563121858
		AscendingNode	237.73898711536177
		ArgOfPericen	130.57568558059924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 237"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.367036568519821e-07
	Radius		65.04810480088608

	RotationPeriod	2.4025546390493706

	Obliquity		72.36877606442884

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9491224366967166
		Eccentricity	0.04228675457970005
		Inclination		-2.0203225594798875
		AscendingNode	108.65461809272722
		ArgOfPericen	25.167895642931107
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 238"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.8940396973816853e-07
	Radius		44.421581204748634

	RotationPeriod	9.201925244221446

	Obliquity		121.44086144179767

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.989208750540646
		Eccentricity	0.04869279567615489
		Inclination		0.6418360902861676
		AscendingNode	149.0635627852518
		ArgOfPericen	87.27528700289902
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 238.1"
{
	ParentBody	"Ouranos 238"
	Class		"Asteroid"
	Mass		1.7203008665760344e-09
	Radius		9.268279532408652

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.007172473858095e-06
		Eccentricity	0.004657899806271026
		Inclination		23.774675600246358
		AscendingNode	107.96429235602098
		ArgOfPericen	171.2195791178046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 239"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9544576720072504
		Eccentricity	0.07476454878947922
		Inclination		-0.6263810106766527
		AscendingNode	301.54774172681
		ArgOfPericen	204.44080796679592
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 239 A"
{
	ParentBody	"Ouranos 239"
	Class		"Asteroid"
	Mass		1.3462117092036023e-07
	Radius		38.40566489135699

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017024853401309823
		Eccentricity	0.005844371059137258
		Inclination		277.9568436785005
		AscendingNode	99.17831843695402
		ArgOfPericen	83.46545443529247
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 239 B"
{
	ParentBody	"Ouranos 239"
	Class		"Asteroid"
	Mass		5.123642502108525e-08
	Radius		27.832386079004365

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017024853401309823
		Eccentricity	0.005844371059137258
		Inclination		277.9568436785005
		AscendingNode	99.17831843695402
		ArgOfPericen	263.4654544352925
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 240"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0001008266884403e-07
	Radius		35.120958479384825

	RotationPeriod	6.3393341921165245

	Obliquity		173.7653462165556

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9741718005140958
		Eccentricity	0.02521068491122465
		Inclination		-1.8030876147114143
		AscendingNode	107.73643574864406
		ArgOfPericen	74.5920997971592
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 241"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.641355856806241e-07
	Radius		42.82973193719877

	RotationPeriod	9.019346144115795

	Obliquity		112.86231951140259

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0112131139854543
		Eccentricity	0.058552178853056386
		Inclination		-2.0253654450812597
		AscendingNode	263.4871507561296
		ArgOfPericen	34.760907374244084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 241.1"
{
	ParentBody	"Ouranos 241"
	Class		"Asteroid"
	Mass		7.936256539589182e-11
	Radius		3.361628155223719

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.9866783841013665e-06
		Eccentricity	0.00382941655443517
		Inclination		12.636900636231049
		AscendingNode	118.01497950706752
		ArgOfPericen	118.56648858101953
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 242"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.738827397849218e-07
	Radius		51.537489905334134

	RotationPeriod	5.998441704202786

	Obliquity		38.839060058692105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0219273972798575
		Eccentricity	0.045957608821430865
		Inclination		3.327147326998332
		AscendingNode	305.10411824286183
		ArgOfPericen	225.24652260742099
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 242.1"
{
	ParentBody	"Ouranos 242"
	Class		"Asteroid"
	Mass		5.380200779738337e-10
	Radius		6.454578235323302

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.725930799899797e-06
		Eccentricity	0.004585230276027132
		Inclination		9.440857368450269
		AscendingNode	128.44166935623775
		ArgOfPericen	18.25941448595951
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 243"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.968340073986406
		Eccentricity	0.04720329390310271
		Inclination		0.5806439383799975
		AscendingNode	293.57261395713635
		ArgOfPericen	100.69287759643575
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 243 A"
{
	ParentBody	"Ouranos 243"
	Class		"Asteroid"
	Mass		3.853315501422396e-07
	Radius		54.27700643074639

	Orbit
	{
		Epoch			2457395.5
		Period			0.006880028356512603
		Eccentricity	0.0024748988962864735
		Inclination		223.40152878593193
		AscendingNode	339.70851145264123
		ArgOfPericen	326.3153019615983
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 243 B"
{
	ParentBody	"Ouranos 243"
	Class		"Asteroid"
	Mass		1.5908023234599312e-07
	Radius		40.415048326641205

	Orbit
	{
		Epoch			2457395.5
		Period			0.006880028356512603
		Eccentricity	0.0024748988962864735
		Inclination		223.40152878593193
		AscendingNode	339.70851145264123
		ArgOfPericen	146.31530196159832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 244"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.5159376031413562e-07
	Radius		42.55594473055501

	RotationPeriod	3.821159785887828

	Obliquity		26.232397322293217

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9726839741385744
		Eccentricity	0.04851239467718506
		Inclination		0.5774541265267225
		AscendingNode	288.7886395539466
		ArgOfPericen	93.95954753731172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 245"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.648113501043324e-07
	Radius		59.74975959672426

	RotationPeriod	8.202944771683473

	Obliquity		337.73079674295707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9879860820249416
		Eccentricity	0.04508465298419787
		Inclination		0.7397618505748941
		AscendingNode	22.487843675245102
		ArgOfPericen	31.958730780976904
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 245.1"
{
	ParentBody	"Ouranos 245"
	Class		"Asteroid"
	Mass		4.3586285637105354e-09
	Radius		12.599709757236042

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.383663588173465e-06
		Eccentricity	0.0055709318482250235
		Inclination		-67.51684358519029
		AscendingNode	113.02958129272454
		ArgOfPericen	207.29200578349003
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 246"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.019333293023305e-07
	Radius		69.06018293041234

	RotationPeriod	6.347453020049038

	Obliquity		225.52025894709976

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9793231311214647
		Eccentricity	0.06244577374689194
		Inclination		3.1185212852242814
		AscendingNode	164.74836613122758
		ArgOfPericen	300.49898500236395
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 246.1"
{
	ParentBody	"Ouranos 246"
	Class		"Asteroid"
	Mass		4.896393958770765e-09
	Radius		12.62235588869305

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.542534772717261e-06
		Eccentricity	0.003195915187760674
		Inclination		16.476225231296233
		AscendingNode	170.28480085216597
		ArgOfPericen	39.72822297861952
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 247"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.817639646187808e-08
	Radius		34.293760209741734

	RotationPeriod	7.520951178053775

	Obliquity		74.12126620590288

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.991982882971447
		Eccentricity	0.045205894723901456
		Inclination		-2.207563329559623
		AscendingNode	216.17403783024918
		ArgOfPericen	72.90087123345043
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 248"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0230268728681846e-07
	Radius		35.85709014872518

	RotationPeriod	6.693136359055951

	Obliquity		107.09244016395462

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9641927422084737
		Eccentricity	0.06683122171260761
		Inclination		1.1086609377865178
		AscendingNode	250.3049396411055
		ArgOfPericen	173.6603769061158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 249"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.8814246866372294e-07
	Radius		51.389898840963475

	RotationPeriod	4.835927518619204

	Obliquity		110.06928304786396

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0049886069366343
		Eccentricity	0.0694014612893131
		Inclination		1.0856815682401642
		AscendingNode	19.78495287223059
		ArgOfPericen	331.2061366166683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 250"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.5698756659745e-07
	Radius		79.21489802632439

	RotationPeriod	3.9132799214059757

	Obliquity		197.37378689429332

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9892289523671751
		Eccentricity	0.1
		Inclination		-0.9322021011432828
		AscendingNode	180.7492070863237
		ArgOfPericen	52.82085367350324
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 251"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.2787542721674565e-07
	Radius		50.305470783111474

	RotationPeriod	4.5994726761607705

	Obliquity		344.2341766727088

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9784089705476697
		Eccentricity	0.049867131335898686
		Inclination		-1.5369954737923526
		AscendingNode	98.09393236695882
		ArgOfPericen	260.574597527919
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 251.1"
{
	ParentBody	"Ouranos 251"
	Class		"Asteroid"
	Mass		3.0492169829223813e-09
	Radius		11.942965077654652

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.629171117916564e-06
		Eccentricity	0.004813050516770544
		Inclination		15.786104906466447
		AscendingNode	80.16934735512773
		ArgOfPericen	351.1229967136071
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 252"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.989223195957371
		Eccentricity	0.06677929218189975
		Inclination		-0.36997644574658684
		AscendingNode	259.1473070858764
		ArgOfPericen	315.9965576868258
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 252 A"
{
	ParentBody	"Ouranos 252"
	Class		"Asteroid"
	Mass		3.4867558079712786e-07
	Radius		54.295389356430164

	Orbit
	{
		Epoch			2457395.5
		Period			0.005610950334505592
		Eccentricity	0.005124351532218453
		Inclination		73.87355646038223
		AscendingNode	103.4195025349025
		ArgOfPericen	132.00675771393549
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 252 B"
{
	ParentBody	"Ouranos 252"
	Class		"Asteroid"
	Mass		1.1154506561917359e-08
	Radius		17.236108870335205

	Orbit
	{
		Epoch			2457395.5
		Period			0.005610950334505592
		Eccentricity	0.005124351532218453
		Inclination		73.87355646038223
		AscendingNode	103.4195025349025
		ArgOfPericen	312.0067577139355
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 253"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.013763404551408
		Eccentricity	0.033645823798096344
		Inclination		-2.2821930382553974
		AscendingNode	3.8816637733662773
		ArgOfPericen	11.330359708071253
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 253 A"
{
	ParentBody	"Ouranos 253"
	Class		"Asteroid"
	Mass		1.5687324465315292e-07
	Radius		41.63949405289438

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017825575609112744
		Eccentricity	0.0012359702337283581
		Inclination		103.86549739699717
		AscendingNode	19.260764298376266
		ArgOfPericen	31.940689249918872
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 253 B"
{
	ParentBody	"Ouranos 253"
	Class		"Asteroid"
	Mass		2.8094226092461525e-09
	Radius		10.894187405095261

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017825575609112744
		Eccentricity	0.0012359702337283581
		Inclination		103.86549739699717
		AscendingNode	19.260764298376266
		ArgOfPericen	211.94068924991888
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 254"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7490852002208657e-07
	Radius		44.455990786482324

	RotationPeriod	8.549588523745987

	Obliquity		148.07904873359175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9933485821325319
		Eccentricity	0.07752910959605944
		Inclination		1.2324643560655488
		AscendingNode	338.08326845705795
		ArgOfPericen	93.93831695084323
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 254.1"
{
	ParentBody	"Ouranos 254"
	Class		"Asteroid"
	Mass		2.008836592300412e-09
	Radius		10.030167269834653

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.980018055348004e-06
		Eccentricity	0.0037100488312704874
		Inclination		-47.42056738174174
		AscendingNode	170.98294040076445
		ArgOfPericen	62.304812948933105
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 254.2"
{
	ParentBody	"Ouranos 254"
	Class		"Asteroid"
	Mass		1.672206161496154e-10
	Radius		4.37948703699351

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.4214584342086253e-06
		Eccentricity	0.004790804507807722
		Inclination		31.675377055121448
		AscendingNode	135.1187417813562
		ArgOfPericen	301.0240645171869
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 255"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.3555776164287503e-07
	Radius		54.90748268245328

	RotationPeriod	9.043901588375139

	Obliquity		31.956429229414248

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.982677184234906
		Eccentricity	0.03922389039476953
		Inclination		1.0566225552016382
		AscendingNode	3.786446437223012
		ArgOfPericen	354.779990756621
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 256"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.517325357307423e-07
	Radius		41.0695202292397

	RotationPeriod	4.603226755306223

	Obliquity		188.89702432487013

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0508847317042525
		Eccentricity	0.04991662121824364
		Inclination		-1.3688517018927224
		AscendingNode	130.53810254668693
		ArgOfPericen	123.82806023067585
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 256.1"
{
	ParentBody	"Ouranos 256"
	Class		"Asteroid"
	Mass		2.2390218316459698e-11
	Radius		2.170265335163048

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.241904363379514e-06
		Eccentricity	0.006413646263024503
		Inclination		11.529771452700675
		AscendingNode	140.89931750650857
		ArgOfPericen	269.44513739348105
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 257"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.497301718804559e-07
	Radius		57.292351419770505

	RotationPeriod	9.245581005497224

	Obliquity		258.4501222555474

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9825365122330084
		Eccentricity	0.040309241200998706
		Inclination		-2.710245888236997
		AscendingNode	199.47965656407553
		ArgOfPericen	259.0255566057782
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 258"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.133223353871783e-07
	Radius		54.98696142244803

	RotationPeriod	8.368440400560676

	Obliquity		133.12717684400116

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9891942527963189
		Eccentricity	0.06438802910653862
		Inclination		0.812207352433826
		AscendingNode	223.69399127465942
		ArgOfPericen	125.61538882444623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 258.1"
{
	ParentBody	"Ouranos 258"
	Class		"Asteroid"
	Mass		3.828671450602245e-09
	Radius		12.665197588248464

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.057793724515211e-06
		Eccentricity	0.00476133366414207
		Inclination		-8.24832526220694
		AscendingNode	329.0516615304343
		ArgOfPericen	165.6946441496347
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 259"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9786459593962957
		Eccentricity	0.035570149264897905
		Inclination		-0.3090761764344258
		AscendingNode	331.7416632887632
		ArgOfPericen	51.4091751567245
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 259 A"
{
	ParentBody	"Ouranos 259"
	Class		"Asteroid"
	Mass		5.035916212903167e-07
	Radius		60.57095353535662

	Orbit
	{
		Epoch			2457395.5
		Period			0.006768216987440019
		Eccentricity	0.0025248437531811842
		Inclination		293.20548897931803
		AscendingNode	184.74285228739723
		ArgOfPericen	188.99167612622784
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 259 B"
{
	ParentBody	"Ouranos 259"
	Class		"Asteroid"
	Mass		2.5171557445643204e-08
	Radius		22.31215960294338

	Orbit
	{
		Epoch			2457395.5
		Period			0.006768216987440019
		Eccentricity	0.0025248437531811842
		Inclination		293.20548897931803
		AscendingNode	184.74285228739723
		ArgOfPericen	8.991676126227844
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 260"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4010745603715053e-07
	Radius		38.683066721411436

	RotationPeriod	7.659189261062253

	Obliquity		267.39412452007565

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0256220441433956
		Eccentricity	0.05000535645532351
		Inclination		-0.1879013046726057
		AscendingNode	303.99962057573396
		ArgOfPericen	28.138133206671657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 261"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.6090270360181845e-07
	Radius		42.90895728878514

	RotationPeriod	7.308974055340103

	Obliquity		334.0487110230934

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9237645899275055
		Eccentricity	0.05856786262475788
		Inclination		0.8715463194242024
		AscendingNode	194.97695301182557
		ArgOfPericen	223.53232710781657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 262"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.0994924321719e-07
	Radius		67.00054458525184

	RotationPeriod	6.1665661119991455

	Obliquity		300.41543037898634

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9518663589245887
		Eccentricity	0.04009101926104606
		Inclination		-2.45488923983805
		AscendingNode	144.02783859458228
		ArgOfPericen	31.14715145950739
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 262.1"
{
	ParentBody	"Ouranos 262"
	Class		"Asteroid"
	Mass		5.31714430460877e-10
	Radius		6.400392133436535

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.846574662936325e-06
		Eccentricity	0.006629299257309359
		Inclination		-10.80666328927026
		AscendingNode	168.79146730621898
		ArgOfPericen	183.26803042820137
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 263"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0177986044490588
		Eccentricity	0.07005402127250238
		Inclination		-2.4695738238851095
		AscendingNode	268.86609558113014
		ArgOfPericen	199.82883885972984
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 263 A"
{
	ParentBody	"Ouranos 263"
	Class		"Asteroid"
	Mass		3.894108388014558e-07
	Radius		58.78791728134011

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006567767466262429
		Eccentricity	0.0037782886567264955
		Inclination		82.20257408260437
		AscendingNode	244.1031875413224
		ArgOfPericen	123.76625251750517
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 263 B"
{
	ParentBody	"Ouranos 263"
	Class		"Asteroid"
	Mass		2.8880730406254418e-08
	Radius		24.699497630455078

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006567767466262429
		Eccentricity	0.0037782886567264955
		Inclination		82.20257408260437
		AscendingNode	244.1031875413224
		ArgOfPericen	303.76625251750517
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 264"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.258494715295393e-07
	Radius		53.14679673283431

	RotationPeriod	5.232151385315672

	Obliquity		135.5722147515482

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.991988979510857
		Eccentricity	0.0683079307593156
		Inclination		0.31832710339334513
		AscendingNode	345.06325436490414
		ArgOfPericen	189.57494361512607
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 265"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.274884312392031e-07
	Radius		61.20237511642752

	RotationPeriod	6.141015106419779

	Obliquity		171.16161235748407

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0156834860002664
		Eccentricity	0.04866188314210841
		Inclination		-2.879455580105356
		AscendingNode	32.5879716701725
		ArgOfPericen	231.93680740869
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 266"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.863118108805064e-07
	Radius		70.521451630252

	RotationPeriod	8.046760044866145

	Obliquity		306.37087118327617

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9640221262235207
		Eccentricity	0.06747928563442653
		Inclination		0.11594207100372989
		AscendingNode	161.31823042628727
		ArgOfPericen	310.27654658256273
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 267"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2073715658112722e-06
	Radius		82.74298372581652

	RotationPeriod	7.710652071768041

	Obliquity		12.537210633410552

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9960442715042624
		Eccentricity	0.04517723437111793
		Inclination		-3.5400686288864787
		AscendingNode	340.8977436259768
		ArgOfPericen	127.581145853154
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 267.1"
{
	ParentBody	"Ouranos 267"
	Class		"Asteroid"
	Mass		3.0737086456241543e-10
	Radius		5.244109634153662

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.128263144996845e-07
		Eccentricity	0.004218564455545233
		Inclination		-15.932593129293991
		AscendingNode	104.73397439066683
		ArgOfPericen	49.90223081448718
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 267.2"
{
	ParentBody	"Ouranos 267"
	Class		"Asteroid"
	Mass		5.352230848158531e-09
	Radius		13.592389422042022

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2512338218108877e-06
		Eccentricity	0.004422248669914516
		Inclination		15.064294066734599
		AscendingNode	319.39543572180037
		ArgOfPericen	176.88823313452338
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 268"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.660473226833329e-07
	Radius		64.17436879991102

	RotationPeriod	5.398022032689119

	Obliquity		350.6058678906746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9907392304107341
		Eccentricity	0.08410758864626774
		Inclination		-0.08582116348103075
		AscendingNode	51.09536535456225
		ArgOfPericen	258.8197624130886
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 269"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.3695910805410912e-07
	Radius		47.28747142261655

	RotationPeriod	6.979664992183557

	Obliquity		216.68895158698643

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9953061715742227
		Eccentricity	0.04194663256446732
		Inclination		1.8072881461617671
		AscendingNode	186.7205131034458
		ArgOfPericen	43.02652068263926
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 270"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1346953543558108e-06
	Radius		78.26398151657608

	RotationPeriod	5.412088978855544

	Obliquity		195.74939582675523

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9947300635641007
		Eccentricity	0.05630737583487832
		Inclination		1.4506956854141106
		AscendingNode	198.14469671515388
		ArgOfPericen	112.28396028915489
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 271"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.426205930960622e-08
	Radius		25.455541889212686

	RotationPeriod	5.276510914769204

	Obliquity		37.12550243296272

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9916489071113176
		Eccentricity	0.027607847074866035
		Inclination		-1.6911146411545905
		AscendingNode	297.19829213991534
		ArgOfPericen	74.85268284861378
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 272"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0037824509768816
		Eccentricity	0.06629661764805726
		Inclination		0.3343906037037844
		AscendingNode	3.6402102372973566
		ArgOfPericen	150.13315100071978
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 272 A"
{
	ParentBody	"Ouranos 272"
	Class		"Asteroid"
	Mass		1.8339113414913804e-08
	Radius		21.150676368473377

	Orbit
	{
		Epoch			2457395.5
		Period			0.008066046747032238
		Eccentricity	0.00234602902459207
		Inclination		175.50920448065472
		AscendingNode	181.47804773851823
		ArgOfPericen	327.69505305807047
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 272 B"
{
	ParentBody	"Ouranos 272"
	Class		"Asteroid"
	Mass		6.298523018499783e-09
	Radius		14.811909671421617

	Orbit
	{
		Epoch			2457395.5
		Period			0.008066046747032238
		Eccentricity	0.00234602902459207
		Inclination		175.50920448065472
		AscendingNode	181.47804773851823
		ArgOfPericen	147.69505305807047
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 273"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0062087388441814
		Eccentricity	0.07383621239846896
		Inclination		-1.0009670393841739
		AscendingNode	51.54353205697546
		ArgOfPericen	143.90045628924642
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 273 A"
{
	ParentBody	"Ouranos 273"
	Class		"Asteroid"
	Mass		1.0701187987392564e-07
	Radius		38.658677491794805

	Orbit
	{
		Epoch			2457395.5
		Period			0.0032983402424867354
		Eccentricity	0.0017917767110862104
		Inclination		292.32841386311895
		AscendingNode	19.32546749890625
		ArgOfPericen	192.6371507239208
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 273 B"
{
	ParentBody	"Ouranos 273"
	Class		"Asteroid"
	Mass		4.367285780221747e-09
	Radius		13.309861374125104

	Orbit
	{
		Epoch			2457395.5
		Period			0.0032983402424867354
		Eccentricity	0.0017917767110862104
		Inclination		292.32841386311895
		AscendingNode	19.32546749890625
		ArgOfPericen	12.637150723920797
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 274"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9793416422096612
		Eccentricity	0.09951141578041695
		Inclination		-2.159612135409663
		AscendingNode	190.98885372022983
		ArgOfPericen	284.02109728293675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 274 A"
{
	ParentBody	"Ouranos 274"
	Class		"Asteroid"
	Mass		1.8549371636275277e-07
	Radius		44.61732779913824

	Orbit
	{
		Epoch			2457395.5
		Period			0.00121821815064883
		Eccentricity	0.00714303456974244
		Inclination		58.650935205417
		AscendingNode	241.5395062314229
		ArgOfPericen	208.18102714308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 274 B"
{
	ParentBody	"Ouranos 274"
	Class		"Asteroid"
	Mass		1.2495836214874099e-07
	Radius		39.11250185582202

	Orbit
	{
		Epoch			2457395.5
		Period			0.00121821815064883
		Eccentricity	0.00714303456974244
		Inclination		58.650935205417
		AscendingNode	241.5395062314229
		ArgOfPericen	28.181027143079973
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 275"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9944262667303151
		Eccentricity	0.08583708268903495
		Inclination		0.3473858311132879
		AscendingNode	68.6426866029904
		ArgOfPericen	268.2396750230291
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 275 A"
{
	ParentBody	"Ouranos 275"
	Class		"Asteroid"
	Mass		1.444846493721812e-07
	Radius		40.49179332290048

	Orbit
	{
		Epoch			2457395.5
		Period			0.0040989317992572065
		Eccentricity	0.00370894242710769
		Inclination		323.74019176579196
		AscendingNode	147.16609148740102
		ArgOfPericen	213.85177605821627
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 275 B"
{
	ParentBody	"Ouranos 275"
	Class		"Asteroid"
	Mass		3.92649214206752e-08
	Radius		26.227769176296054

	Orbit
	{
		Epoch			2457395.5
		Period			0.0040989317992572065
		Eccentricity	0.00370894242710769
		Inclination		323.74019176579196
		AscendingNode	147.16609148740102
		ArgOfPericen	33.851776058216274
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 276"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.142957172393384e-07
	Radius		69.7587026016222

	RotationPeriod	4.391998597708376

	Obliquity		277.33429180869194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9965204259266018
		Eccentricity	0.03179827975532178
		Inclination		-0.45006551304283254
		AscendingNode	42.09291903088513
		ArgOfPericen	311.94088886179406
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 277"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.8778928207204534e-07
	Radius		48.65764032541236

	RotationPeriod	5.85677801863894

	Obliquity		69.17121387067789

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9980287119841025
		Eccentricity	0.07373173906637043
		Inclination		0.41801793555029176
		AscendingNode	354.21160097207553
		ArgOfPericen	25.59959889301158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 278"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.464473889981068e-08
	Radius		31.77600033109339

	RotationPeriod	7.114846663079553

	Obliquity		100.11789747044661

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0536481273364564
		Eccentricity	0.05915782154329878
		Inclination		-2.9798737594904834
		AscendingNode	76.99219103045505
		ArgOfPericen	253.04229071545996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 279"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9720184005459456
		Eccentricity	0.06943025787002996
		Inclination		-0.6658990038806664
		AscendingNode	66.66968222427255
		ArgOfPericen	178.42156966605734
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 279 A"
{
	ParentBody	"Ouranos 279"
	Class		"Asteroid"
	Mass		1.0198968577914085e-07
	Radius		35.7420774240949

	Orbit
	{
		Epoch			2457395.5
		Period			0.005861122482927458
		Eccentricity	0.006697906538553715
		Inclination		176.56762023342168
		AscendingNode	161.92210665487755
		ArgOfPericen	53.769978151515076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 279 B"
{
	ParentBody	"Ouranos 279"
	Class		"Asteroid"
	Mass		1.6628194630619772e-08
	Radius		19.525825618909238

	Orbit
	{
		Epoch			2457395.5
		Period			0.005861122482927458
		Eccentricity	0.006697906538553715
		Inclination		176.56762023342168
		AscendingNode	161.92210665487755
		ArgOfPericen	233.7699781515151
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 280"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.814658797376582e-07
	Radius		65.86722201300724

	RotationPeriod	6.219107387953098

	Obliquity		254.04833581487372

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0048960096711468
		Eccentricity	0.07765324720702883
		Inclination		0.9701666898665842
		AscendingNode	278.13933057608165
		ArgOfPericen	10.139454091418024
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 280.1"
{
	ParentBody	"Ouranos 280"
	Class		"Asteroid"
	Mass		5.384168958608206e-09
	Radius		13.831443127135474

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.134075869055354e-06
		Eccentricity	0.00839471827873993
		Inclination		-9.847423879246808
		AscendingNode	182.24356562396522
		ArgOfPericen	230.4577008907851
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 280.2"
{
	ParentBody	"Ouranos 280"
	Class		"Asteroid"
	Mass		6.543004996600422e-09
	Radius		14.760022494373016

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.3254762102684925e-06
		Eccentricity	0.0039984013140480605
		Inclination		-48.274859306213045
		AscendingNode	41.46795008860019
		ArgOfPericen	229.00002445499774
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 281"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.118353406038394e-08
	Radius		32.139002844316785

	RotationPeriod	8.172659523599421

	Obliquity		336.21190206512443

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0080889919149134
		Eccentricity	0.007103001508286265
		Inclination		0.8651457127201849
		AscendingNode	92.34623751025865
		ArgOfPericen	342.2346527804041
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 281.1"
{
	ParentBody	"Ouranos 281"
	Class		"Asteroid"
	Mass		9.239948917659362e-10
	Radius		7.9440884049099445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.0213238706400965e-06
		Eccentricity	0.004492733593356526
		Inclination		37.122686495520206
		AscendingNode	97.12840131037535
		ArgOfPericen	319.3288391750664
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 282"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.7734269724189813e-09
	Radius		10.727973101177213

	RotationPeriod	3.0289365640491446

	Obliquity		312.7475797111906

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0105288283247862
		Eccentricity	0.05806731601173925
		Inclination		-0.26159415159311605
		AscendingNode	202.16916150095267
		ArgOfPericen	350.18188875344697
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 283"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.874575429082962e-07
	Radius		75.95750929134525

	RotationPeriod	5.724580647504683

	Obliquity		189.76775328280013

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0546598228022432
		Eccentricity	0.06570996882502655
		Inclination		-0.8489116810713937
		AscendingNode	102.45844598986848
		ArgOfPericen	304.2683766636303
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 283.1"
{
	ParentBody	"Ouranos 283"
	Class		"Asteroid"
	Mass		1.0013576008817414e-08
	Radius		17.036665114077238

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.554400211581545e-06
		Eccentricity	0.007620645982198196
		Inclination		-21.544334828385075
		AscendingNode	201.48465240603434
		ArgOfPericen	152.08037842949213
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 284"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.805212895745962e-07
	Radius		62.008342222875434

	RotationPeriod	6.260229343966844

	Obliquity		174.94636232364886

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0139067504278656
		Eccentricity	0.05779835296828488
		Inclination		-0.9276830653531739
		AscendingNode	138.08401584667195
		ArgOfPericen	98.80147891108413
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 285"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0091704320759785
		Eccentricity	0.05870474470350866
		Inclination		-3.511081863781663
		AscendingNode	181.51837652149862
		ArgOfPericen	233.34046028357153
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 285 A"
{
	ParentBody	"Ouranos 285"
	Class		"Asteroid"
	Mass		2.671538264376938e-07
	Radius		51.483545462412444

	Orbit
	{
		Epoch			2457395.5
		Period			0.005464348209377415
		Eccentricity	0.0023664739667794608
		Inclination		33.15977335721867
		AscendingNode	274.9744687414427
		ArgOfPericen	324.36601004524766
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 285 B"
{
	ParentBody	"Ouranos 285"
	Class		"Asteroid"
	Mass		4.256007506964098e-08
	Radius		27.909289214454155

	Orbit
	{
		Epoch			2457395.5
		Period			0.005464348209377415
		Eccentricity	0.0023664739667794608
		Inclination		33.15977335721867
		AscendingNode	274.9744687414427
		ArgOfPericen	144.36601004524766
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 286"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.304206780808894e-07
	Radius		73.60441387985935

	RotationPeriod	4.694478961699464

	Obliquity		349.03538498505367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0178117838646026
		Eccentricity	0.0598442335951451
		Inclination		0.5356136219006514
		AscendingNode	349.10698060793527
		ArgOfPericen	90.13074776783638
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 287"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4772427530028964e-07
	Radius		45.03261925296353

	RotationPeriod	8.487925548425462

	Obliquity		253.4472118714559

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0243144628401837
		Eccentricity	0.05721520643595713
		Inclination		0.055549623007625865
		AscendingNode	66.49861856386256
		ArgOfPericen	75.58659872490863
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 288"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.285455866859156e-07
	Radius		64.99793505577335

	RotationPeriod	4.871428896864937

	Obliquity		29.266505565789515

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0092109151938113
		Eccentricity	0.042328488151619284
		Inclination		0.8730447737897301
		AscendingNode	348.30893953141106
		ArgOfPericen	21.19946390045768
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 288.1"
{
	ParentBody	"Ouranos 288"
	Class		"Asteroid"
	Mass		4.91422703721532e-10
	Radius		6.343911975255471

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.0796791016717185e-06
		Eccentricity	0.0036034770478586913
		Inclination		26.705314551508973
		AscendingNode	199.78991976559544
		ArgOfPericen	318.4264696322768
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 289"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9485700390415382
		Eccentricity	0.03631850084190185
		Inclination		1.2502126423541207
		AscendingNode	300.22916329830366
		ArgOfPericen	8.986405134223286
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 289 A"
{
	ParentBody	"Ouranos 289"
	Class		"Asteroid"
	Mass		8.575127244190903e-07
	Radius		76.82939875755025

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015216310847048116
		Eccentricity	0.0069311335899004956
		Inclination		127.7126499705512
		AscendingNode	33.35385491545671
		ArgOfPericen	10.156667980493307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 289 B"
{
	ParentBody	"Ouranos 289"
	Class		"Asteroid"
	Mass		1.1002923527337397e-07
	Radius		38.75103218556699

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015216310847048116
		Eccentricity	0.0069311335899004956
		Inclination		127.7126499705512
		AscendingNode	33.35385491545671
		ArgOfPericen	190.1566679804933
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 290"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.2478722095243015e-08
	Radius		26.11412651567039

	RotationPeriod	2.168995377278838

	Obliquity		180.91726909188915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9992348871306851
		Eccentricity	0.05953347800717993
		Inclination		0.14745470891473653
		AscendingNode	290.84241971095497
		ArgOfPericen	349.5989409178489
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 291"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1006826215506803e-07
	Radius		41.046941101087384

	RotationPeriod	5.462761678089888

	Obliquity		75.57981544992263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0157693570418722
		Eccentricity	0.03552735132970514
		Inclination		-2.268702884251792
		AscendingNode	125.62429721380309
		ArgOfPericen	34.510589905048036
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 292"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.35849292950567e-07
	Radius		60.65453797853647

	RotationPeriod	3.70579299614992

	Obliquity		164.60615817340948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9967781410920397
		Eccentricity	0.04634856964196314
		Inclination		0.431628837979931
		AscendingNode	359.9242822987242
		ArgOfPericen	301.2208745666657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 293"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.2735535300660576e-07
	Radius		56.32968643924116

	RotationPeriod	6.518471357514401

	Obliquity		220.85815788886714

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9963239378293764
		Eccentricity	0.051805424450844656
		Inclination		1.382733536055354
		AscendingNode	284.4083445808203
		ArgOfPericen	173.78782061966953
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 293.1"
{
	ParentBody	"Ouranos 293"
	Class		"Asteroid"
	Mass		7.393310815343597e-10
	Radius		7.390557033723115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.205204409164674e-06
		Eccentricity	0.002065471755797839
		Inclination		32.99267836044527
		AscendingNode	289.8698557782191
		ArgOfPericen	223.46953310557706
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 293.2"
{
	ParentBody	"Ouranos 293"
	Class		"Asteroid"
	Mass		8.299045756180526e-10
	Radius		7.680807918248822

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.855291283144999e-06
		Eccentricity	0.007180398481272143
		Inclination		34.90511399209798
		AscendingNode	211.6044715648232
		ArgOfPericen	287.7550679133075
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 294"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.368461451650699e-08
	Radius		35.415732914923325

	RotationPeriod	8.47165382402282

	Obliquity		219.06168399434654

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9772961984143578
		Eccentricity	0.048318292934919856
		Inclination		2.6512837139390575
		AscendingNode	46.097986239268806
		ArgOfPericen	42.26058234681189
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 295"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.3382822751072576e-07
	Radius		54.662394249926656

	RotationPeriod	9.272238686473488

	Obliquity		265.48225246033036

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9411378219347993
		Eccentricity	0.038615089159573256
		Inclination		1.3327546826338192
		AscendingNode	51.50404782187978
		ArgOfPericen	15.466865705466596
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Ouranos 296"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9594242921352879
		Eccentricity	0.04885858244281638
		Inclination		4.596494795023023
		AscendingNode	146.3173822924847
		ArgOfPericen	82.57348275664692
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 296 A"
{
	ParentBody	"Ouranos 296"
	Class		"Asteroid"
	Mass		1.3992884690146218e-07
	Radius		46.381158932773346

	Orbit
	{
		Epoch			2457395.5
		Period			0.005857607966644896
		Eccentricity	0.008612198254444595
		Inclination		68.76343446702128
		AscendingNode	76.35390017927145
		ArgOfPericen	170.8376501027046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Ouranos 296 B"
{
	ParentBody	"Ouranos 296"
	Class		"Asteroid"
	Mass		3.6960427026732904e-08
	Radius		29.758988885723195

	Orbit
	{
		Epoch			2457395.5
		Period			0.005857607966644896
		Eccentricity	0.008612198254444595
		Inclination		68.76343446702128
		AscendingNode	76.35390017927145
		ArgOfPericen	350.83765010270463
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 297"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.460150425952866e-07
	Radius		60.23169475101042

	RotationPeriod	7.782152663304593

	Obliquity		117.69525382215105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.029651816207278
		Eccentricity	0.067645986484644
		Inclination		0.14811125572727926
		AscendingNode	243.05661195075766
		ArgOfPericen	316.0796346834077
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 298"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.3558979445535096e-07
	Radius		49.756044672222465

	RotationPeriod	3.8485339281633357

	Obliquity		326.93593087400495

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9921063013166739
		Eccentricity	0.05044207532440637
		Inclination		-2.6678463728767414
		AscendingNode	252.41834910502382
		ArgOfPericen	189.6512733102752
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 299"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.671742290992907e-07
	Radius		64.13371308392126

	RotationPeriod	6.927521211642244

	Obliquity		188.15274271847449

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9892147975074426
		Eccentricity	0.03535824837940938
		Inclination		0.7491118124286374
		AscendingNode	130.1109054620869
		ArgOfPericen	277.47492270435777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Ouranos 300"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.26379694015439e-07
	Radius		73.06076957859749

	RotationPeriod	8.55680341803897

	Obliquity		219.05462775981238

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.9627071725256208
		Eccentricity	0.03910127872382146
		Inclination		-1.8509815405582501
		AscendingNode	57.27366476507306
		ArgOfPericen	293.209870445909
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Aeolus asteroid belt A ------------------------------------------------------
//------------------------------------------------------------------------------
Asteroid "Aeolus A 1"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1383581366468233e-07
	Radius		36.940794039317225

	RotationPeriod	4.912047986196325

	Obliquity		71.57778014916907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4005751598282335
		Eccentricity	0.1
		Inclination		0.4813820392867676
		AscendingNode	17.66242320840748
		ArgOfPericen	42.86805986970498
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 1.1"
{
	ParentBody	"Aeolus A 1"
	Class		"Asteroid"
	Mass		3.127318213818793e-10
	Radius		5.173732205539084

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2680856846606939e-06
		Eccentricity	0.0033338015833481102
		Inclination		8.174872439348995
		AscendingNode	75.13438412639347
		ArgOfPericen	127.0415508201255
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 2"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1469457734740387e-06
	Radius		81.65041691954134

	RotationPeriod	7.5625498632487576

	Obliquity		102.91598279461265

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40033619650152136
		Eccentricity	0.1
		Inclination		-2.0299236924708772
		AscendingNode	206.54756812188114
		ArgOfPericen	204.45428257715844
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 3"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4857156537600996e-07
	Radius		53.71029393187002

	RotationPeriod	9.122568464466163

	Obliquity		132.20906253359252

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4080686535788797
		Eccentricity	0.1
		Inclination		1.331582535358235
		AscendingNode	178.8998588042577
		ArgOfPericen	287.74962393311597
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 3.1"
{
	ParentBody	"Aeolus A 3"
	Class		"Asteroid"
	Mass		2.1437157822673716e-10
	Radius		4.567542656229027

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.8835567191564894e-06
		Eccentricity	0.007693642818233535
		Inclination		90
		AscendingNode	112.7015408580485
		ArgOfPericen	28.988556959126555
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 4"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.42
		Eccentricity	0.1
		Inclination		-0.17412902017030155
		AscendingNode	194.75649620709197
		ArgOfPericen	15.040563858608973
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 4 A"
{
	ParentBody	"Aeolus A 4"
	Class		"Asteroid"
	Mass		3.229190432951377e-08
	Radius		23.999094708390512

	Orbit
	{
		Epoch			2457395.5
		Period			0.002212719519236829
		Eccentricity	0.004078862018278468
		Inclination		322.67371051864404
		AscendingNode	172.17708484249414
		ArgOfPericen	159.18208452710334
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 4 B"
{
	ParentBody	"Aeolus A 4"
	Class		"Asteroid"
	Mass		7.986207601438936e-09
	Radius		15.064122513545712

	Orbit
	{
		Epoch			2457395.5
		Period			0.002212719519236829
		Eccentricity	0.004078862018278468
		Inclination		322.67371051864404
		AscendingNode	172.17708484249414
		ArgOfPericen	339.18208452710337
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 5"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4113786247696988
		Eccentricity	0.1
		Inclination		1.154057727166492
		AscendingNode	308.6423312024874
		ArgOfPericen	18.410168192492318
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 5 A"
{
	ParentBody	"Aeolus A 5"
	Class		"Asteroid"
	Mass		1.5445480299000444e-07
	Radius		40.62592477424162

	Orbit
	{
		Epoch			2457395.5
		Period			0.002346763698917532
		Eccentricity	0.0038353354662198766
		Inclination		75.8780891805671
		AscendingNode	108.22810370111868
		ArgOfPericen	249.3160825239832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 5 B"
{
	ParentBody	"Aeolus A 5"
	Class		"Asteroid"
	Mass		1.433946770151071e-08
	Radius		18.395593217092017

	Orbit
	{
		Epoch			2457395.5
		Period			0.002346763698917532
		Eccentricity	0.0038353354662198766
		Inclination		75.8780891805671
		AscendingNode	108.22810370111868
		ArgOfPericen	69.3160825239832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 6"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.8506061958302257e-08
	Radius		29.97947734468376

	RotationPeriod	6.027181773781711

	Obliquity		90.0296095788328

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4106728326890824
		Eccentricity	0.1
		Inclination		-1.4040090904696476
		AscendingNode	54.14987380807416
		ArgOfPericen	31.984231851842907
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 7"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4222638550377847e-08
	Radius		19.461583083691036

	RotationPeriod	8.588544457171706

	Obliquity		117.96724279800227

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4121968863779123
		Eccentricity	0.1
		Inclination		-1.77238139576537
		AscendingNode	331.0764722421653
		ArgOfPericen	62.093383439137554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 7.1"
{
	ParentBody	"Aeolus A 7"
	Class		"Asteroid"
	Mass		5.2942846601575996e-12
	Radius		1.3999758254402224

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.083294784311415e-07
		Eccentricity	0.006627981991141502
		Inclination		-30.323200395068824
		AscendingNode	222.0967774723499
		ArgOfPericen	269.80967982039516
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 8"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0008677299103644e-07
	Radius		37.766686381283165

	RotationPeriod	8.869864871425435

	Obliquity		325.6912653605982

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4166218858585449
		Eccentricity	0.1
		Inclination		2.466497036127073
		AscendingNode	276.92998844596417
		ArgOfPericen	351.9581854812737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 9"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41580966364200017
		Eccentricity	0.1
		Inclination		2.745929678914439
		AscendingNode	273.93076396672734
		ArgOfPericen	87.15201163830069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 9 A"
{
	ParentBody	"Aeolus A 9"
	Class		"Asteroid"
	Mass		1.9332152857122012e-07
	Radius		48.952582652375106

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030482016352251246
		Eccentricity	0.003954953334483146
		Inclination		68.56044037199042
		AscendingNode	356.5226989594381
		ArgOfPericen	343.7737394311286
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 9 B"
{
	ParentBody	"Aeolus A 9"
	Class		"Asteroid"
	Mass		4.34836418253218e-09
	Radius		13.818391912278525

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030482016352251246
		Eccentricity	0.003954953334483146
		Inclination		68.56044037199042
		AscendingNode	356.5226989594381
		ArgOfPericen	163.77373943112866
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 10"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.3941129889584623e-07
	Radius		57.08521943429744

	RotationPeriod	6.028260648321028

	Obliquity		294.7961059715123

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4112379070556887
		Eccentricity	0.1
		Inclination		-0.027256026410961247
		AscendingNode	127.33599346538693
		ArgOfPericen	14.598041406179675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 11"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9764045696964496e-07
	Radius		43.52733093225669

	RotationPeriod	5.133897308326109

	Obliquity		127.90796977772649

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40518754953037306
		Eccentricity	0.1
		Inclination		-2.8720215831508344
		AscendingNode	328.3366536316029
		ArgOfPericen	326.2404393901349
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 12"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.851795114831552e-07
	Radius		59.70763022646662

	RotationPeriod	5.328395127361799

	Obliquity		165.47056927877696

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.407333814686662
		Eccentricity	0.1
		Inclination		0.27066399751272974
		AscendingNode	322.7830752280905
		ArgOfPericen	56.54408988156528
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 13"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.795507942976355e-08
	Radius		32.13984708209199

	RotationPeriod	5.851592955552156

	Obliquity		36.810656394131634

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4142488830848406
		Eccentricity	0.1
		Inclination		-0.11369118589544062
		AscendingNode	329.67165337755495
		ArgOfPericen	9.165451172380624
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 14"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0425289957410403e-07
	Radius		45.1809851103229

	RotationPeriod	7.8894052005405415

	Obliquity		2.1771660924180924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4078906467161902
		Eccentricity	0.1
		Inclination		-0.5423094045581749
		AscendingNode	239.98262784715106
		ArgOfPericen	49.64734780296937
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 15"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.5224258947145155e-07
	Radius		54.602155080401545

	RotationPeriod	4.22283327191966

	Obliquity		144.19519642900048

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4114067954350546
		Eccentricity	0.1
		Inclination		1.1452714187023878
		AscendingNode	14.290905521021617
		ArgOfPericen	75.84027864266699
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 15.1"
{
	ParentBody	"Aeolus A 15"
	Class		"Asteroid"
	Mass		4.80330189651662e-10
	Radius		6.054929957349084

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.7098367051553454e-06
		Eccentricity	0.0037904110668060408
		Inclination		15.885914928192747
		AscendingNode	47.161524894167016
		ArgOfPericen	325.6983455520945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 16"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.0607997278859186e-07
	Radius		52.48016733995756

	RotationPeriod	5.684574515478558

	Obliquity		84.24323414779501

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4112687961975213
		Eccentricity	0.1
		Inclination		-2.5889001827550104
		AscendingNode	246.48530555941912
		ArgOfPericen	239.57594330509033
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 17"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.892174522868809e-09
	Radius		13.442245190453775

	RotationPeriod	5.298767026556581

	Obliquity		147.7220663018988

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4105128353819872
		Eccentricity	0.1
		Inclination		0.578885719865812
		AscendingNode	58.51073146702005
		ArgOfPericen	77.93703551891736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 18"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.420526696547686e-08
	Radius		27.64850877337414

	RotationPeriod	8.160399497358908

	Obliquity		207.95322334147568

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41314656903020336
		Eccentricity	0.1
		Inclination		3.5872756506895973
		AscendingNode	102.85925645941406
		ArgOfPericen	226.5064756468244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 19"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.204771230894982e-08
	Radius		35.836374453894244

	RotationPeriod	4.326175322823582

	Obliquity		250.09283874684934

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41655549174224293
		Eccentricity	0.1
		Inclination		-3.392467332755855
		AscendingNode	30.54938585484161
		ArgOfPericen	46.83628699070964
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 20"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.070074399310535e-06
	Radius		78.18852340959285

	RotationPeriod	3.665969287848265

	Obliquity		302.08780253058023

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41104187860628605
		Eccentricity	0.1
		Inclination		-0.3713229901478709
		AscendingNode	181.95560886745915
		ArgOfPericen	36.229473655294
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 21"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.709740577158484e-07
	Radius		59.163788599553264

	RotationPeriod	5.633648937493151

	Obliquity		250.3559063375141

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4111270434402829
		Eccentricity	0.1
		Inclination		-0.20371378776287502
		AscendingNode	138.8697150263838
		ArgOfPericen	175.20951841088052
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 22"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41462558244222675
		Eccentricity	0.1
		Inclination		0.010786900160905714
		AscendingNode	28.66030480222261
		ArgOfPericen	303.7788379956572
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 22 A"
{
	ParentBody	"Aeolus A 22"
	Class		"Asteroid"
	Mass		3.6708695308052266e-07
	Radius		54.47152573179728

	Orbit
	{
		Epoch			2457395.5
		Period			0.002860867398994278
		Eccentricity	0.004181736780637227
		Inclination		179.08607104807908
		AscendingNode	9.152561213247319
		ArgOfPericen	86.01484276316329
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 22 B"
{
	ParentBody	"Aeolus A 22"
	Class		"Asteroid"
	Mass		6.81187466626147e-08
	Radius		31.0695840954483

	Orbit
	{
		Epoch			2457395.5
		Period			0.002860867398994278
		Eccentricity	0.004181736780637227
		Inclination		179.08607104807908
		AscendingNode	9.152561213247319
		ArgOfPericen	266.0148427631633
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 23"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.409510786241966
		Eccentricity	0.1
		Inclination		0.06615396461933228
		AscendingNode	186.03488394326806
		ArgOfPericen	278.80903888338423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 23 A"
{
	ParentBody	"Aeolus A 23"
	Class		"Asteroid"
	Mass		1.3308458957397174e-06
	Radius		86.07735283974272

	Orbit
	{
		Epoch			2457395.5
		Period			0.00226129820023153
		Eccentricity	0.005159260906561008
		Inclination		269.2275373576085
		AscendingNode	188.7627461472181
		ArgOfPericen	177.25292571243796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 23 B"
{
	ParentBody	"Aeolus A 23"
	Class		"Asteroid"
	Mass		4.334731800263155e-08
	Radius		27.489513672224195

	Orbit
	{
		Epoch			2457395.5
		Period			0.00226129820023153
		Eccentricity	0.005159260906561008
		Inclination		269.2275373576085
		AscendingNode	188.7627461472181
		ArgOfPericen	357.25292571243796
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 24"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.296222144089243e-07
	Radius		55.43182571094769

	RotationPeriod	4.287597852608619

	Obliquity		64.07593043311242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4097753501195648
		Eccentricity	0.1
		Inclination		1.6749996401350717
		AscendingNode	349.1017162133252
		ArgOfPericen	182.72936717527404
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 25"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.6316627187566903e-07
	Radius		52.76606317863151

	RotationPeriod	6.488647711235497

	Obliquity		233.78916002687873

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4116594345612463
		Eccentricity	0.1
		Inclination		0.7453468451616755
		AscendingNode	357.80146384789356
		ArgOfPericen	22.9592287549171
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 25.1"
{
	ParentBody	"Aeolus A 25"
	Class		"Asteroid"
	Mass		1.3439796989580896e-09
	Radius		9.086755725765718

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.74335319858607e-06
		Eccentricity	0.004312331752681424
		Inclination		38.95059865207391
		AscendingNode	345.39897535095815
		ArgOfPericen	283.00831369519153
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 25.2"
{
	ParentBody	"Aeolus A 25"
	Class		"Asteroid"
	Mass		2.944246236923456e-09
	Radius		11.801466917900086

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.558075804107283e-06
		Eccentricity	0.0037581992150676246
		Inclination		34.36470129320507
		AscendingNode	56.97164324226494
		ArgOfPericen	167.79591964084656
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 26"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40858352010953125
		Eccentricity	0.1
		Inclination		1.1030694247431814
		AscendingNode	128.4011705487091
		ArgOfPericen	173.72891418004565
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 26 A"
{
	ParentBody	"Aeolus A 26"
	Class		"Asteroid"
	Mass		3.8179073658868684e-07
	Radius		57.082726809314835

	Orbit
	{
		Epoch			2457395.5
		Period			0.0020092359013823883
		Eccentricity	0.004064314819803169
		Inclination		225.96391159245678
		AscendingNode	120.80936372901131
		ArgOfPericen	347.41005408815187
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 26 B"
{
	ParentBody	"Aeolus A 26"
	Class		"Asteroid"
	Mass		1.0376926013026024e-07
	Radius		36.9759342087531

	Orbit
	{
		Epoch			2457395.5
		Period			0.0020092359013823883
		Eccentricity	0.004064314819803169
		Inclination		225.96391159245678
		AscendingNode	120.80936372901131
		ArgOfPericen	167.4100540881518
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 27"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.636970235537361e-07
	Radius		64.56365694232996

	RotationPeriod	9.592792974506665

	Obliquity		186.35984710522996

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4106441018823827
		Eccentricity	0.1
		Inclination		2.513972423238419
		AscendingNode	195.90467536410102
		ArgOfPericen	316.52056160059357
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 28"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.281124760078377e-07
	Radius		62.68506871403836

	RotationPeriod	9.778376939448568

	Obliquity		210.15999901791292

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40947764348217114
		Eccentricity	0.1
		Inclination		0.22711600697389794
		AscendingNode	228.7710313876281
		ArgOfPericen	272.5826091137282
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 29"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.3734854236197693e-07
	Radius		56.357603047998104

	RotationPeriod	5.170311967421404

	Obliquity		11.189096409389991

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4106129052668678
		Eccentricity	0.1
		Inclination		-0.6574741466101729
		AscendingNode	17.305007232451977
		ArgOfPericen	139.8068128688823
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 30"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4086613181078534
		Eccentricity	0.1
		Inclination		-3.2904951751887883
		AscendingNode	278.9899420404313
		ArgOfPericen	152.23534204128788
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 30 A"
{
	ParentBody	"Aeolus A 30"
	Class		"Asteroid"
	Mass		3.739263830165072e-08
	Radius		26.94074648870687

	Orbit
	{
		Epoch			2457395.5
		Period			0.0054335744626997015
		Eccentricity	0.006986239851443641
		Inclination		310.12120846103556
		AscendingNode	35.213922687910866
		ArgOfPericen	139.10581741977353
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 30 B"
{
	ParentBody	"Aeolus A 30"
	Class		"Asteroid"
	Mass		5.246643815761496e-09
	Radius		13.999357889182198

	Orbit
	{
		Epoch			2457395.5
		Period			0.0054335744626997015
		Eccentricity	0.006986239851443641
		Inclination		310.12120846103556
		AscendingNode	35.213922687910866
		ArgOfPericen	319.10581741977353
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 31"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.602304614575829e-08
	Radius		34.776543643951356

	RotationPeriod	4.079893281357135

	Obliquity		317.1715615863019

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41040969062836286
		Eccentricity	0.1
		Inclination		0.7045248855162786
		AscendingNode	194.65632313111297
		ArgOfPericen	209.09382274726383
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 32"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.911627107866169e-07
	Radius		60.39177387577391

	RotationPeriod	9.908269003517198

	Obliquity		51.84048219373699

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4142624684610046
		Eccentricity	0.1
		Inclination		1.1615465992280813
		AscendingNode	186.69643229614098
		ArgOfPericen	105.24098261421507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 33"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3677154276802967e-08
	Radius		20.30387925863706

	RotationPeriod	7.804993041225214

	Obliquity		310.0542845873866

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4120995844398575
		Eccentricity	0.1
		Inclination		-0.12051152828830736
		AscendingNode	305.9238389097773
		ArgOfPericen	70.09047857574285
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 34"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.99367620150565e-07
	Radius		79.57668636854854

	RotationPeriod	8.96170086910833

	Obliquity		309.54658825263795

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4076127093315001
		Eccentricity	0.1
		Inclination		-1.124682485430901
		AscendingNode	307.8047461484261
		ArgOfPericen	190.38474810207794
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 35"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5289872714244708e-07
	Radius		44.33954263054042

	RotationPeriod	3.8683399271955174

	Obliquity		22.850143480535266

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40717581094219296
		Eccentricity	0.1
		Inclination		0.45305921138165295
		AscendingNode	178.0874535299867
		ArgOfPericen	291.202470033621
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 36"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.460483597680275e-08
	Radius		34.14594171897217

	RotationPeriod	4.044162908746282

	Obliquity		279.29243690715003

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41364154076884413
		Eccentricity	0.1
		Inclination		-1.0811177576531672
		AscendingNode	167.48872117434354
		ArgOfPericen	166.02367357459968
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 37"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7483808721543636e-07
	Radius		43.758835415058236

	RotationPeriod	7.743184584888225

	Obliquity		244.32179498467252

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.408159605747363
		Eccentricity	0.1
		Inclination		3.213128757337097
		AscendingNode	167.23778746487196
		ArgOfPericen	200.62405383906417
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 38"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.126094761191109e-07
	Radius		59.13597965453413

	RotationPeriod	4.743251987351373

	Obliquity		264.50540193507277

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4125352242964275
		Eccentricity	0.1
		Inclination		0.5883154819228344
		AscendingNode	310.7855498897396
		ArgOfPericen	82.99878684404737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 38.1"
{
	ParentBody	"Aeolus A 38"
	Class		"Asteroid"
	Mass		2.9960249976404058e-09
	Radius		11.451275784258158

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.053567637132519e-06
		Eccentricity	0.00570985746333017
		Inclination		-4.990743620591744
		AscendingNode	172.17137435593523
		ArgOfPericen	41.63953371459508
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 38.2"
{
	ParentBody	"Aeolus A 38"
	Class		"Asteroid"
	Mass		3.006689061943381e-09
	Radius		11.464846269500846

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.118991692302345e-07
		Eccentricity	0.005050225843893116
		Inclination		-38.332286086340964
		AscendingNode	76.53155518394111
		ArgOfPericen	309.54624868884395
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 39"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0039521501810073e-07
	Radius		34.85581426997638

	RotationPeriod	5.6354854840758675

	Obliquity		199.98731365890657

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40191430464135336
		Eccentricity	0.1
		Inclination		-0.43299880819790454
		AscendingNode	223.1783569400038
		ArgOfPericen	24.058821935485007
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 40"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.419953782760211e-08
	Radius		27.393978104118954

	RotationPeriod	7.112788108826977

	Obliquity		342.0467251621044

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4079460226900396
		Eccentricity	0.1
		Inclination		1.4573365778577605
		AscendingNode	347.63042173820116
		ArgOfPericen	84.94178480207528
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 41"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.166430791769492e-07
	Radius		60.18516078661712

	RotationPeriod	4.792905500027144

	Obliquity		304.3088988089584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4092323801480203
		Eccentricity	0.1
		Inclination		-0.9904649142517704
		AscendingNode	45.258815023952856
		ArgOfPericen	278.5390194932863
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 42"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.975205848019831e-07
	Radius		43.92877498712672

	RotationPeriod	5.604821016473202

	Obliquity		275.5306942727155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41298867252319427
		Eccentricity	0.1
		Inclination		-0.0027000122769318
		AscendingNode	179.5123819735797
		ArgOfPericen	188.11365721840812
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 42.1"
{
	ParentBody	"Aeolus A 42"
	Class		"Asteroid"
	Mass		1.476032196660408e-09
	Radius		8.588360158764493

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.422268173785003e-06
		Eccentricity	0.0038192362184490394
		Inclination		17.094878753075314
		AscendingNode	99.8132933671083
		ArgOfPericen	262.78084298156364
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 43"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.054685112222783e-08
	Radius		32.74138359470178

	RotationPeriod	6.243055847198817

	Obliquity		288.73571300028067

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4179715800652831
		Eccentricity	0.1
		Inclination		-0.23451351920451668
		AscendingNode	81.9375370573761
		ArgOfPericen	109.3098142349362
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 44"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.683848777520931e-07
	Radius		53.655828173405986

	RotationPeriod	8.445997921297714

	Obliquity		30.067535087368427

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4071796021775779
		Eccentricity	0.1
		Inclination		-0.4191822225321148
		AscendingNode	282.75412140535735
		ArgOfPericen	153.03896562429162
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 45"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4102585939499168
		Eccentricity	0.1
		Inclination		3.860233296225729
		AscendingNode	202.1612116754571
		ArgOfPericen	200.12738790644386
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 45 A"
{
	ParentBody	"Aeolus A 45"
	Class		"Asteroid"
	Mass		2.0995455435397216e-07
	Radius		46.31701650395787

	Orbit
	{
		Epoch			2457395.5
		Period			0.006103939159417606
		Eccentricity	0.003082595288891951
		Inclination		166.6520027766025
		AscendingNode	266.9493896502043
		ArgOfPericen	345.35424000157906
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 45 B"
{
	ParentBody	"Aeolus A 45"
	Class		"Asteroid"
	Mass		7.824753545237255e-08
	Radius		33.33156453193413

	Orbit
	{
		Epoch			2457395.5
		Period			0.006103939159417606
		Eccentricity	0.003082595288891951
		Inclination		166.6520027766025
		AscendingNode	266.9493896502043
		ArgOfPericen	165.354240001579
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 46"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9694887079660285e-15
	Radius		0.1

	RotationPeriod	6.628497317794995

	Obliquity		160.2122999196661

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4118262699044987
		Eccentricity	0.1
		Inclination		2.505950432804815
		AscendingNode	161.75288042914778
		ArgOfPericen	182.78676643151132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 47"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41125995438784096
		Eccentricity	0.1
		Inclination		-1.3458956657991081
		AscendingNode	115.41616442055992
		ArgOfPericen	242.25682447321668
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 47 A"
{
	ParentBody	"Aeolus A 47"
	Class		"Asteroid"
	Mass		5.230174526374646e-07
	Radius		61.276230770135875

	Orbit
	{
		Epoch			2457395.5
		Period			0.004767787183439992
		Eccentricity	0.004816174782699345
		Inclination		199.24822992476103
		AscendingNode	177.99722885752263
		ArgOfPericen	246.75954988009053
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 47 B"
{
	ParentBody	"Aeolus A 47"
	Class		"Asteroid"
	Mass		4.097141508918115e-08
	Radius		26.218849906844977

	Orbit
	{
		Epoch			2457395.5
		Period			0.004767787183439992
		Eccentricity	0.004816174782699345
		Inclination		199.24822992476103
		AscendingNode	177.99722885752263
		ArgOfPericen	66.7595498800905
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 48"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.457846857274272e-07
	Radius		43.02790827790626

	RotationPeriod	4.678534629931297

	Obliquity		173.90597774581843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4086120782168953
		Eccentricity	0.1
		Inclination		1.2333928397930813
		AscendingNode	291.6168010545804
		ArgOfPericen	31.11278989362529
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 49"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0035198587893663e-06
	Radius		100.0

	RotationPeriod	5.29900822997442

	Obliquity		322.08649870124657

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4090303142896526
		Eccentricity	0.1
		Inclination		0.9190945055484723
		AscendingNode	13.784808502697686
		ArgOfPericen	319.64738834134295
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 50"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.521486803700221e-07
	Radius		59.975226149603344

	RotationPeriod	7.292406883769932

	Obliquity		118.39959218987605

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4095036532312855
		Eccentricity	0.1
		Inclination		-1.6632592005198508
		AscendingNode	310.9056028344738
		ArgOfPericen	32.85923066194594
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 51"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.820042464113213e-07
	Radius		58.70484174903074

	RotationPeriod	6.279750000108802

	Obliquity		219.29020723564102

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40716684849449525
		Eccentricity	0.1
		Inclination		-0.1861001615934317
		AscendingNode	205.17724261348445
		ArgOfPericen	294.3997821438025
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 52"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.783960838619833e-07
	Radius		64.0598489433589

	RotationPeriod	5.260102381594164

	Obliquity		11.51334086642461

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4088608200282173
		Eccentricity	0.1
		Inclination		-1.1345564795166825
		AscendingNode	311.30445198730297
		ArgOfPericen	226.55902623371645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 53"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.631017743881218e-07
	Radius		41.887424421936124

	RotationPeriod	3.5421256483756496

	Obliquity		1.498131058147396

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4128983142018904
		Eccentricity	0.1
		Inclination		0.9525376701237452
		AscendingNode	185.11071791508695
		ArgOfPericen	259.9890062468735
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 53.1"
{
	ParentBody	"Aeolus A 53"
	Class		"Asteroid"
	Mass		2.4738788222272693e-09
	Radius		10.368682343911573

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.056740005532472e-06
		Eccentricity	0.006225465104442933
		Inclination		25.83073554008786
		AscendingNode	25.91402954329016
		ArgOfPericen	4.276800337557822
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 54"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.0666743238351595e-07
	Radius		60.398848918844315

	RotationPeriod	6.85767296942876

	Obliquity		136.09561732175672

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4153897865159215
		Eccentricity	0.1
		Inclination		2.3157748693266997
		AscendingNode	217.1883473956025
		ArgOfPericen	300.0934638514347
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 55"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.11027646767813e-07
	Radius		63.31538668933758

	RotationPeriod	7.266316995647993

	Obliquity		117.80057511563099

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.409999949039515
		Eccentricity	0.1
		Inclination		-1.9840966657926706
		AscendingNode	103.13275905493201
		ArgOfPericen	80.7576268338452
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 55.1"
{
	ParentBody	"Aeolus A 55"
	Class		"Asteroid"
	Mass		2.5117148149188625e-09
	Radius		10.142517188344772

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.556756916611143e-06
		Eccentricity	0.0021715797335830583
		Inclination		-14.5462007237171
		AscendingNode	311.07043346300594
		ArgOfPericen	144.37628057267136
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 55.2"
{
	ParentBody	"Aeolus A 55"
	Class		"Asteroid"
	Mass		1.361459412124951e-10
	Radius		3.8384616816849433

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2795783025295964e-06
		Eccentricity	0.007262086892593129
		Inclination		-4.655171664324128
		AscendingNode	330.18523855556344
		ArgOfPericen	267.65035040582126
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 56"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8336251375253776e-06
	Radius		96.069515872614

	RotationPeriod	9.174717827494364

	Obliquity		74.7615019197698

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4051826249512479
		Eccentricity	0.1
		Inclination		1.8979296724284738
		AscendingNode	19.83570334673694
		ArgOfPericen	90.2094144409705
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 57"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7111889272682687e-07
	Radius		44.47227205324082

	RotationPeriod	6.379342930223183

	Obliquity		93.908188795765

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41114566764819105
		Eccentricity	0.1
		Inclination		1.8757601142929663
		AscendingNode	162.70836774264356
		ArgOfPericen	69.39747992687519
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 58"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.1717648286873854e-08
	Radius		28.280851074989165

	RotationPeriod	7.4746916845650455

	Obliquity		283.50392702794255

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40856100077406626
		Eccentricity	0.1
		Inclination		-1.1540348975202666
		AscendingNode	323.54400201612555
		ArgOfPericen	125.26562835499861
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 59"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.375994363511429e-07
	Radius		53.98351495489856

	RotationPeriod	7.598983618387606

	Obliquity		28.088585105764395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4081026833838819
		Eccentricity	0.1
		Inclination		-0.9316431524048374
		AscendingNode	163.6555021911551
		ArgOfPericen	283.4315854120702
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 60"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3365763590983225e-07
	Radius		45.32623034995849

	RotationPeriod	4.8909069249739625

	Obliquity		49.5937885170154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4062191416366209
		Eccentricity	0.1
		Inclination		-3.0563759616530155
		AscendingNode	167.18314132454137
		ArgOfPericen	19.39719460599897
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 60.1"
{
	ParentBody	"Aeolus A 60"
	Class		"Asteroid"
	Mass		9.036925677008031e-10
	Radius		7.114807905620792

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.368590978554415e-06
		Eccentricity	0.006784713307024222
		Inclination		-17.240067314630288
		AscendingNode	25.654851988932045
		ArgOfPericen	1.4095874057944036
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 61"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.160128303268889e-08
	Radius		27.081089390520873

	RotationPeriod	6.596261174678924

	Obliquity		212.22133612025516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4115766947821803
		Eccentricity	0.1
		Inclination		-0.7458124046794045
		AscendingNode	41.9621694659928
		ArgOfPericen	104.29240025619849
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 62"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4257224146531659e-07
	Radius		43.39858696764007

	RotationPeriod	7.545869250790444

	Obliquity		276.4104689622775

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4096601462145923
		Eccentricity	0.1
		Inclination		0.11798279941697405
		AscendingNode	258.1752283192485
		ArgOfPericen	56.797743218639496
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 62.1"
{
	ParentBody	"Aeolus A 62"
	Class		"Asteroid"
	Mass		4.7632862024882807e-11
	Radius		3.011384119712782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.613868326913034e-06
		Eccentricity	0.0031940594124328413
		Inclination		-0.7717031407285433
		AscendingNode	268.88075694015475
		ArgOfPericen	128.71375250499824
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 63"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3268545450616127e-07
	Radius		51.70319596402338

	RotationPeriod	4.811600846291688

	Obliquity		144.47841347962463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41185881014698156
		Eccentricity	0.1
		Inclination		-1.3565129905848394
		AscendingNode	39.63597450024309
		ArgOfPericen	330.2205399585025
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 63.1"
{
	ParentBody	"Aeolus A 63"
	Class		"Asteroid"
	Mass		1.8530959632504492e-10
	Radius		4.792479685610625

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.7319050559347586e-06
		Eccentricity	0.0033339667387087338
		Inclination		-57.08725202609467
		AscendingNode	358.9054795921349
		ArgOfPericen	178.60150613448144
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 63.2"
{
	ParentBody	"Aeolus A 63"
	Class		"Asteroid"
	Mass		3.0191711101193235e-09
	Radius		12.149457506166254

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.64026102268645e-07
		Eccentricity	0.0027587522248074376
		Inclination		-5.157034602767825
		AscendingNode	307.1583374110504
		ArgOfPericen	82.6290048960681
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 64"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41499633060396673
		Eccentricity	0.1
		Inclination		-0.3258103835235058
		AscendingNode	284.35914385846996
		ArgOfPericen	342.6456588020095
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 64 A"
{
	ParentBody	"Aeolus A 64"
	Class		"Asteroid"
	Mass		2.7421793977232396e-08
	Radius		24.241377245509188

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003713248318730025
		Eccentricity	0.006611338209036414
		Inclination		134.3912501244397
		AscendingNode	303.20030284395364
		ArgOfPericen	156.5794359341323
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 64 B"
{
	ParentBody	"Aeolus A 64"
	Class		"Asteroid"
	Mass		9.082960138971063e-10
	Radius		7.785164704331694

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003713248318730025
		Eccentricity	0.006611338209036414
		Inclination		134.3912501244397
		AscendingNode	303.20030284395364
		ArgOfPericen	336.57943593413233
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 65"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.930799907142762e-07
	Radius		45.3811411253441

	RotationPeriod	6.993691667124844

	Obliquity		294.7787871076963

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4130107558293133
		Eccentricity	0.1
		Inclination		1.2354499405922712
		AscendingNode	277.65983175437873
		ArgOfPericen	224.5449399939448
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 65.1"
{
	ParentBody	"Aeolus A 65"
	Class		"Asteroid"
	Mass		1.298263060276144e-09
	Radius		8.565457328021527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4121576969128189e-06
		Eccentricity	0.0032318000799457128
		Inclination		28.740798101680376
		AscendingNode	167.2488069864282
		ArgOfPericen	35.54219427877178
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 66"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.99657182653364e-08
	Radius		35.555727472845255

	RotationPeriod	8.299444929260051

	Obliquity		31.074572938477715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41195482440174575
		Eccentricity	0.1
		Inclination		-2.6384389507596895
		AscendingNode	272.2928740351845
		ArgOfPericen	125.93643460693086
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 67"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.604407996504239e-07
	Radius		64.14545034391448

	RotationPeriod	6.228404222868708

	Obliquity		72.28791694169168

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4118068531180951
		Eccentricity	0.1
		Inclination		-3.008706474005734
		AscendingNode	52.4814711583266
		ArgOfPericen	287.44626183129634
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 68"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.614248060064196e-08
	Radius		22.923771381725132

	RotationPeriod	2.566979174998632

	Obliquity		268.9243763845436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40760233936954293
		Eccentricity	0.1
		Inclination		-1.1775007177157024
		AscendingNode	320.5274444937124
		ArgOfPericen	197.08934499242125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 69"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.557539541623084e-07
	Radius		42.35178430621213

	RotationPeriod	4.415027486924941

	Obliquity		225.67143771520375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4115598649530412
		Eccentricity	0.1
		Inclination		-1.2992427867508587
		AscendingNode	77.12119678761732
		ArgOfPericen	316.5853620040989
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 70"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.193663966394401e-07
	Radius		59.34049576584492

	RotationPeriod	6.156039649534252

	Obliquity		196.84987493078486

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4116557365362989
		Eccentricity	0.1
		Inclination		1.0774527296122263
		AscendingNode	216.32819517036776
		ArgOfPericen	214.423591623569
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 71"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.994810923698563e-07
	Radius		64.76022041262829

	RotationPeriod	3.8314828008787227

	Obliquity		226.63351045059042

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4061534001717762
		Eccentricity	0.1
		Inclination		1.2655570011062216
		AscendingNode	275.86646334864184
		ArgOfPericen	320.6331679150499
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 72"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8444891664917444e-07
	Radius		43.998156160939956

	RotationPeriod	5.5911803523558765

	Obliquity		337.8964506690498

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4089574394178242
		Eccentricity	0.1
		Inclination		-0.637219861740424
		AscendingNode	67.42945172131353
		ArgOfPericen	82.00816930006536
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 73"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4095818644013259
		Eccentricity	0.1
		Inclination		-0.9573492320723214
		AscendingNode	132.57238228201948
		ArgOfPericen	39.79407619807943
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 73 A"
{
	ParentBody	"Aeolus A 73"
	Class		"Asteroid"
	Mass		3.783994054178239e-07
	Radius		59.215170587159186

	Orbit
	{
		Epoch			2457395.5
		Period			0.008043445438866806
		Eccentricity	0.008765342546211414
		Inclination		237.03489654036716
		AscendingNode	258.3925407176583
		ArgOfPericen	195.4405535478491
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 73 B"
{
	ParentBody	"Aeolus A 73"
	Class		"Asteroid"
	Mass		4.6099661337760294e-08
	Radius		29.354999767526323

	Orbit
	{
		Epoch			2457395.5
		Period			0.008043445438866806
		Eccentricity	0.008765342546211414
		Inclination		237.03489654036716
		AscendingNode	258.3925407176583
		ArgOfPericen	15.440553547849106
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 74"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6005013747682365e-07
	Radius		44.337155022868515

	RotationPeriod	4.642394613967296

	Obliquity		237.02292339424258

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4031190143533988
		Eccentricity	0.1
		Inclination		1.661681026658507
		AscendingNode	316.2197768207373
		ArgOfPericen	286.86869490850563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 74.1"
{
	ParentBody	"Aeolus A 74"
	Class		"Asteroid"
	Mass		8.847290963305147e-10
	Radius		7.839455669261506

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.1785763694869277e-06
		Eccentricity	0.0024016126225875666
		Inclination		-12.6758202526822
		AscendingNode	343.75653319788495
		ArgOfPericen	206.10087170922438
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 75"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0219412481118823e-07
	Radius		36.79871496558916

	RotationPeriod	2.987259195314713

	Obliquity		18.857851171825416

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4079668183068628
		Eccentricity	0.1
		Inclination		3.6563777152985097
		AscendingNode	150.0441070762088
		ArgOfPericen	292.7313478023059
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 76"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.812053760694852e-07
	Radius		66.09921740329547

	RotationPeriod	5.068349285342221

	Obliquity		281.80710665895776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4080484694025285
		Eccentricity	0.1
		Inclination		1.5654911638537703
		AscendingNode	24.36666717168829
		ArgOfPericen	251.85257676157605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 77"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4687522869771806e-07
	Radius		41.6793441463069

	RotationPeriod	4.222879643696566

	Obliquity		233.19736215323115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4101502033817192
		Eccentricity	0.1
		Inclination		0.18115877242488165
		AscendingNode	231.11353137554053
		ArgOfPericen	179.62342009848354
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 78"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.66472564882441e-07
	Radius		64.24478141262858

	RotationPeriod	8.056724442871307

	Obliquity		28.784975181823015

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4070222816497867
		Eccentricity	0.1
		Inclination		0.9152270897131491
		AscendingNode	328.74083480231315
		ArgOfPericen	77.28658146022441
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 79"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3832176874025818e-07
	Radius		53.80840075328698

	RotationPeriod	6.630722176765936

	Obliquity		97.74214342734811

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41500523240353554
		Eccentricity	0.1
		Inclination		-1.7777106938463942
		AscendingNode	238.8457721932407
		ArgOfPericen	200.28664698095062
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 80"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.109823516234393e-06
	Radius		82.3757347851205

	RotationPeriod	6.087037075380622

	Obliquity		13.177224084533684

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4136504394141941
		Eccentricity	0.1
		Inclination		0.31437650773012576
		AscendingNode	203.00123440777855
		ArgOfPericen	18.19516824603548
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 81"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.128861713650558e-08
	Radius		28.112003717434227

	RotationPeriod	9.498587636306791

	Obliquity		241.9657732478756

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41317274622565675
		Eccentricity	0.1
		Inclination		-1.160864886232821
		AscendingNode	148.51813046426216
		ArgOfPericen	241.18493128728508
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 82"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.252344376244157e-07
	Radius		56.329166099929466

	RotationPeriod	4.072877812444723

	Obliquity		91.19141573376622

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41325344530608066
		Eccentricity	0.1
		Inclination		2.781071231296949
		AscendingNode	278.11963986215466
		ArgOfPericen	284.563958278152
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 83"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.372426747369035e-08
	Radius		35.075668795919235

	RotationPeriod	5.8811616908610285

	Obliquity		91.26463403439551

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40951377071225453
		Eccentricity	0.1
		Inclination		3.07182799927914
		AscendingNode	242.31086675008484
		ArgOfPericen	96.92138237649388
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 84"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.4187178983742506e-07
	Radius		62.08855003482836

	RotationPeriod	4.743314487192106

	Obliquity		101.80238636547148

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4079322609047561
		Eccentricity	0.1
		Inclination		2.554855470499597
		AscendingNode	294.0188298963824
		ArgOfPericen	209.8047576496027
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 85"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3831037499857043e-07
	Radius		48.52510023408494

	RotationPeriod	8.17687360488588

	Obliquity		200.37029703156273

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40583121622270224
		Eccentricity	0.1
		Inclination		-0.21347541698787012
		AscendingNode	291.71177355816997
		ArgOfPericen	282.7645120503686
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 86"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.451022701845808e-07
	Radius		60.27533337020368

	RotationPeriod	6.635823951988593

	Obliquity		27.44782777724822

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40525213037902813
		Eccentricity	0.1
		Inclination		0.08257422718925146
		AscendingNode	230.00875371654396
		ArgOfPericen	53.972019357645834
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 87"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.52848304607169e-07
	Radius		63.11624867977234

	RotationPeriod	6.018846448898424

	Obliquity		303.2573443408324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4060517902982016
		Eccentricity	0.1
		Inclination		-0.6478454024059035
		AscendingNode	182.2524430024146
		ArgOfPericen	152.773257393203
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 88"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.979262299058995e-07
	Radius		70.15581777899338

	RotationPeriod	4.3806839032475

	Obliquity		168.77711180466986

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41227416922980614
		Eccentricity	0.1
		Inclination		-0.9228956946081731
		AscendingNode	324.5214133405541
		ArgOfPericen	278.95360249838814
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 88.1"
{
	ParentBody	"Aeolus A 88"
	Class		"Asteroid"
	Mass		4.945767083832401e-09
	Radius		12.887064359418664

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.861157437356426e-06
		Eccentricity	0.0032393331106356366
		Inclination		-5.171828693168025
		AscendingNode	47.3129968281493
		ArgOfPericen	223.93825858586828
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 89"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.334669858999636e-07
	Radius		42.370619202691806

	RotationPeriod	5.209551497247786

	Obliquity		91.08753315449248

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4169093014014874
		Eccentricity	0.1
		Inclination		-2.840949278265907
		AscendingNode	350.67402026581817
		ArgOfPericen	284.0202870536818
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 90"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.10319681280166e-07
	Radius		63.37559087618811

	RotationPeriod	2.3109106309479888

	Obliquity		128.7559785284234

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4070338884166186
		Eccentricity	0.1
		Inclination		-0.31471817525146073
		AscendingNode	346.23722432531395
		ArgOfPericen	110.62616218342464
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 91"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.580063299046212e-09
	Radius		15.785423711825196

	RotationPeriod	3.7083156008923424

	Obliquity		307.9625327838109

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40825168148670365
		Eccentricity	0.1
		Inclination		-0.700516988423314
		AscendingNode	221.86702753310263
		ArgOfPericen	279.0670092469348
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 92"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3906900869794027e-06
	Radius		87.2615640574974

	RotationPeriod	8.232126677774612

	Obliquity		57.77047816290811

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40845080784966936
		Eccentricity	0.1
		Inclination		1.0742242953820678
		AscendingNode	260.99164064039286
		ArgOfPericen	91.46825668815364
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 93"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.913887566139752e-07
	Radius		47.89769380948672

	RotationPeriod	6.366855746720345

	Obliquity		233.5180106461501

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4079016468266239
		Eccentricity	0.1
		Inclination		-2.1576534734387236
		AscendingNode	146.22620957831558
		ArgOfPericen	261.59527875343144
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 94"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.2617440985324214e-07
	Radius		57.93163706210996

	RotationPeriod	3.7202536715403394

	Obliquity		77.60565050139952

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40739839541911527
		Eccentricity	0.1
		Inclination		-0.42417179517405473
		AscendingNode	71.65593966916664
		ArgOfPericen	151.9717015427925
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 95"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.7863168807876727e-07
	Radius		51.4903143481303

	RotationPeriod	6.694478665600467

	Obliquity		36.59935754881452

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41412904161808933
		Eccentricity	0.1
		Inclination		0.008331035947644892
		AscendingNode	122.29945441841662
		ArgOfPericen	294.70822911420004
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 96"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.048011248516274e-07
	Radius		50.96496143027322

	RotationPeriod	5.750220929611411

	Obliquity		15.28428216959302

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4156582199356277
		Eccentricity	0.1
		Inclination		0.17389457554277743
		AscendingNode	208.9841124095894
		ArgOfPericen	53.67346736409713
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 97"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.8951728798402966e-08
	Radius		28.80891345663253

	RotationPeriod	5.636079243778616

	Obliquity		218.00620597095312

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41035856169019186
		Eccentricity	0.1
		Inclination		-0.6831018710335527
		AscendingNode	204.08707628837817
		ArgOfPericen	292.89075620551927
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 98"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7142756917483286e-07
	Radius		44.263232214868694

	RotationPeriod	7.233242184313932

	Obliquity		173.6509236270274

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4019113975230782
		Eccentricity	0.1
		Inclination		0.17301905344947727
		AscendingNode	25.934789102006732
		ArgOfPericen	37.99216238401113
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 99"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.236353328352558e-07
	Radius		69.32327127052315

	RotationPeriod	6.426675606879048

	Obliquity		307.16705600508203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4091208838253394
		Eccentricity	0.1
		Inclination		-0.9997038699743853
		AscendingNode	234.4061780796523
		ArgOfPericen	78.8133132567141
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 100"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4129121125718869
		Eccentricity	0.1
		Inclination		0.6460168129043576
		AscendingNode	203.93617104078834
		ArgOfPericen	151.13789937473712
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 100 A"
{
	ParentBody	"Aeolus A 100"
	Class		"Asteroid"
	Mass		2.249144944717692e-07
	Radius		50.21939123701875

	Orbit
	{
		Epoch			2457395.5
		Period			0.004206306257236702
		Eccentricity	0.005435453708689405
		Inclination		58.49792940311292
		AscendingNode	288.45431306312094
		ArgOfPericen	247.4255277823303
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 100 B"
{
	ParentBody	"Aeolus A 100"
	Class		"Asteroid"
	Mass		4.9367820007767475e-08
	Radius		30.293325113342195

	Orbit
	{
		Epoch			2457395.5
		Period			0.004206306257236702
		Eccentricity	0.005435453708689405
		Inclination		58.49792940311292
		AscendingNode	288.45431306312094
		ArgOfPericen	67.42552778233028
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 101"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8088987015987426e-07
	Radius		55.94197041186302

	RotationPeriod	5.705830288763123

	Obliquity		186.27471985070335

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41113602152172324
		Eccentricity	0.1
		Inclination		0.2319521293630204
		AscendingNode	285.4496749027266
		ArgOfPericen	49.49503893360821
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 102"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8424265105623846e-08
	Radius		26.83278455979664

	RotationPeriod	7.221429451031745

	Obliquity		159.07824792171695

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40482132321329395
		Eccentricity	0.1
		Inclination		-0.15036957268611556
		AscendingNode	1.152375317458385
		ArgOfPericen	233.51301741633412
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 103"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7959305389850306e-07
	Radius		45.24423297375081

	RotationPeriod	7.708293209117709

	Obliquity		197.09879086240903

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4085149882972541
		Eccentricity	0.1
		Inclination		0.5157984042427515
		AscendingNode	125.99188968140017
		ArgOfPericen	192.64466839358198
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 103.1"
{
	ParentBody	"Aeolus A 103"
	Class		"Asteroid"
	Mass		7.562859453539163e-11
	Radius		3.3912676055846402

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.092394873349188e-06
		Eccentricity	0.005597528649821925
		Inclination		-34.48829350029054
		AscendingNode	243.21853800425237
		ArgOfPericen	14.894120764248292
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 104"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.468326695058611e-08
	Radius		18.29193014278803

	RotationPeriod	3.294286964325391

	Obliquity		11.768131083982984

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4101879731196701
		Eccentricity	0.1
		Inclination		-2.073596320385591
		AscendingNode	162.35273568067936
		ArgOfPericen	265.6523427680503
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 105"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.3846641910971183e-08
	Radius		31.5265623486752

	RotationPeriod	6.041255467985997

	Obliquity		57.13828918512015

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4072053234370707
		Eccentricity	0.1
		Inclination		-1.1328571938132712
		AscendingNode	221.05119756316716
		ArgOfPericen	59.59048639075889
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 106"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4124347160211508
		Eccentricity	0.1
		Inclination		2.359940563749325
		AscendingNode	298.3442841097689
		ArgOfPericen	253.7980273254599
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 106 A"
{
	ParentBody	"Aeolus A 106"
	Class		"Asteroid"
	Mass		1.46974417552857e-07
	Radius		39.95743282781233

	Orbit
	{
		Epoch			2457395.5
		Period			0.004590666768570646
		Eccentricity	0.0029361331685539512
		Inclination		214.04576173978637
		AscendingNode	151.41720361054098
		ArgOfPericen	177.94179721953665
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 106 B"
{
	ParentBody	"Aeolus A 106"
	Class		"Asteroid"
	Mass		1.388153758128403e-07
	Radius		39.20392230546387

	Orbit
	{
		Epoch			2457395.5
		Period			0.004590666768570646
		Eccentricity	0.0029361331685539512
		Inclination		214.04576173978637
		AscendingNode	151.41720361054098
		ArgOfPericen	357.9417972195366
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 107"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.402178344173285e-07
	Radius		77.3821050217149

	RotationPeriod	4.717012089668882

	Obliquity		225.3648861819537

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4123879568218894
		Eccentricity	0.1
		Inclination		1.0743326014332217
		AscendingNode	223.64469096854472
		ArgOfPericen	71.40480214810418
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 107.1"
{
	ParentBody	"Aeolus A 107"
	Class		"Asteroid"
	Mass		1.011755801830218e-09
	Radius		7.929691272323833

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.564568874306524e-06
		Eccentricity	0.002964535325157698
		Inclination		-5.87518616946778
		AscendingNode	229.24274859183808
		ArgOfPericen	299.60285147899344
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 108"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41096273690172597
		Eccentricity	0.1
		Inclination		-0.8909966810942762
		AscendingNode	317.7958292223301
		ArgOfPericen	143.88444888615234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 108 A"
{
	ParentBody	"Aeolus A 108"
	Class		"Asteroid"
	Mass		1.1541230331523552e-07
	Radius		38.90508649933452

	Orbit
	{
		Epoch			2457395.5
		Period			0.007429323430588599
		Eccentricity	0.0037912013084102497
		Inclination		157.58840522919087
		AscendingNode	49.913311962745524
		ArgOfPericen	354.1356111096428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 108 B"
{
	ParentBody	"Aeolus A 108"
	Class		"Asteroid"
	Mass		6.5666827348984795e-09
	Radius		14.963655247816316

	Orbit
	{
		Epoch			2457395.5
		Period			0.007429323430588599
		Eccentricity	0.0037912013084102497
		Inclination		157.58840522919087
		AscendingNode	49.913311962745524
		ArgOfPericen	174.1356111096428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 109"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.60360491742532e-07
	Radius		63.20251984127825

	RotationPeriod	4.903323819779405

	Obliquity		250.00616378135962

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4124516100531785
		Eccentricity	0.1
		Inclination		-0.8160880551140689
		AscendingNode	346.3207940487417
		ArgOfPericen	171.57501369876877
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 110"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.626197365927436e-07
	Radius		70.35092450247863

	RotationPeriod	3.471085775847779

	Obliquity		263.7871327957932

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.414146177261001
		Eccentricity	0.1
		Inclination		-2.0192950044831948
		AscendingNode	327.38521258687905
		ArgOfPericen	253.11033464585213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 111"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4434162221300982e-09
	Radius		11.865933533585597

	RotationPeriod	7.375787160966609

	Obliquity		196.57920126928462

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4127470459007602
		Eccentricity	0.1
		Inclination		0.04734410515589348
		AscendingNode	18.52550446765075
		ArgOfPericen	34.43310518650306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 112"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0088277852828908e-07
	Radius		43.40266311108992

	RotationPeriod	7.075375648492541

	Obliquity		302.67021392923476

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4159390932315121
		Eccentricity	0.1
		Inclination		-2.0263831207360643
		AscendingNode	147.30361741466785
		ArgOfPericen	144.23097212889203
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 113"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.497764593258108e-09
	Radius		14.792745760566504

	RotationPeriod	6.230311512115364

	Obliquity		20.52136927569193

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4083126983225531
		Eccentricity	0.1
		Inclination		2.2180615619168815
		AscendingNode	30.610298308316022
		ArgOfPericen	109.53352631114973
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 114"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.062969646283648e-07
	Radius		54.38321426735095

	RotationPeriod	6.493365547852969

	Obliquity		208.12935034858637

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41302512368259964
		Eccentricity	0.1
		Inclination		-1.2585995595383026
		AscendingNode	72.97760260172147
		ArgOfPericen	187.33120057588525
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 114.1"
{
	ParentBody	"Aeolus A 114"
	Class		"Asteroid"
	Mass		2.9405106540115175e-10
	Radius		5.3648579506867735

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.127277486906697e-06
		Eccentricity	0.007323892155625098
		Inclination		23.344117975552408
		AscendingNode	43.831240040981946
		ArgOfPericen	337.4614439398911
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 115"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2819910079327414e-07
	Radius		38.4866961370039

	RotationPeriod	4.218854317488247

	Obliquity		145.08601493269973

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4116991839064161
		Eccentricity	0.1
		Inclination		-1.5837172809769389
		AscendingNode	74.81958556277198
		ArgOfPericen	180.67531084773094
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 116"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4110488856728654
		Eccentricity	0.1
		Inclination		-0.11163879390542901
		AscendingNode	350.9751756750098
		ArgOfPericen	354.99744346879726
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 116 A"
{
	ParentBody	"Aeolus A 116"
	Class		"Asteroid"
	Mass		1.3119296494990325e-07
	Radius		38.58673362531092

	Orbit
	{
		Epoch			2457395.5
		Period			0.004161912845305005
		Eccentricity	0.0033354224669120826
		Inclination		215.15368419408318
		AscendingNode	244.81924972292722
		ArgOfPericen	178.04497379663974
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 116 B"
{
	ParentBody	"Aeolus A 116"
	Class		"Asteroid"
	Mass		5.429306827558623e-08
	Radius		28.755171569735825

	Orbit
	{
		Epoch			2457395.5
		Period			0.004161912845305005
		Eccentricity	0.0033354224669120826
		Inclination		215.15368419408318
		AscendingNode	244.81924972292722
		ArgOfPericen	358.04497379663974
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 117"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3547147638387286e-07
	Radius		39.36520241402824

	RotationPeriod	4.206653875859916

	Obliquity		22.706882000940432

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4129876727246369
		Eccentricity	0.1
		Inclination		3.9773915360532404
		AscendingNode	215.438740725829
		ArgOfPericen	245.8042405702551
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 118"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.903078438608752e-07
	Radius		74.5625672553684

	RotationPeriod	5.288975564820413

	Obliquity		110.00275073919319

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4082688922616149
		Eccentricity	0.1
		Inclination		-2.4602900151408775
		AscendingNode	172.020721113823
		ArgOfPericen	87.2236670878792
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 119"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.221524307608853e-07
	Radius		65.11619680774791

	RotationPeriod	7.428638976635718

	Obliquity		200.77824670693388

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4141642903788943
		Eccentricity	0.1
		Inclination		-3.2671134758975726
		AscendingNode	130.69584515387518
		ArgOfPericen	295.12539600991437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 120"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1578120752516913e-08
	Radius		16.60642811009663

	RotationPeriod	4.4715575925107505

	Obliquity		269.2405287552202

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40943823707269056
		Eccentricity	0.1
		Inclination		4.76941990302775
		AscendingNode	113.22847494276597
		ArgOfPericen	37.725604201284746
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 121"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4114060928050383
		Eccentricity	0.1
		Inclination		0.16622166066574248
		AscendingNode	268.88232504524433
		ArgOfPericen	261.4243714938881
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 121 A"
{
	ParentBody	"Aeolus A 121"
	Class		"Asteroid"
	Mass		3.531671709911191e-07
	Radius		51.721172248118556

	Orbit
	{
		Epoch			2457395.5
		Period			0.008003796157129456
		Eccentricity	0.003980569338003613
		Inclination		89.08200396187522
		AscendingNode	354.7044556848186
		ArgOfPericen	10.502106205484903
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 121 B"
{
	ParentBody	"Aeolus A 121"
	Class		"Asteroid"
	Mass		2.1087940336769142e-07
	Radius		43.553156790996546

	Orbit
	{
		Epoch			2457395.5
		Period			0.008003796157129456
		Eccentricity	0.003980569338003613
		Inclination		89.08200396187522
		AscendingNode	354.7044556848186
		ArgOfPericen	190.5021062054849
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 122"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.450376483320928e-07
	Radius		54.17262571432798

	RotationPeriod	5.6409766289670085

	Obliquity		336.158244823154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4122980032592468
		Eccentricity	0.1
		Inclination		-0.5185716098715994
		AscendingNode	251.14986143180354
		ArgOfPericen	43.12551339841337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 123"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0578838533844145e-06
	Radius		76.31719288174493

	RotationPeriod	4.858389909470058

	Obliquity		111.54129238456778

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41015263838718213
		Eccentricity	0.1
		Inclination		-0.025445122843334837
		AscendingNode	34.290610679918416
		ArgOfPericen	78.00295370374671
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 124"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.974803923822975e-08
	Radius		29.72271802339336

	RotationPeriod	7.7606461659470956

	Obliquity		272.60440039750165

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40962899726602897
		Eccentricity	0.1
		Inclination		0.5929367301884562
		AscendingNode	323.76328138366455
		ArgOfPericen	212.12044884003797
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 125"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1171806046097479e-07
	Radius		38.253663141101626

	RotationPeriod	5.243374421450752

	Obliquity		41.982781687194546

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41133161211224323
		Eccentricity	0.1
		Inclination		3.441807382437871
		AscendingNode	87.20461876384559
		ArgOfPericen	296.91507053979456
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 126"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.043965441057611e-08
	Radius		34.49951494597808

	RotationPeriod	6.001148002652455

	Obliquity		82.75760470737536

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41019247172216994
		Eccentricity	0.1
		Inclination		1.6396746845095513
		AscendingNode	143.2790496459582
		ArgOfPericen	208.6755896792002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 126.1"
{
	ParentBody	"Aeolus A 126"
	Class		"Asteroid"
	Mass		8.728620583937688e-10
	Radius		7.637855932888785

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.911958377697702e-07
		Eccentricity	0.00778079941455345
		Inclination		-31.237487605381595
		AscendingNode	119.86088578444561
		ArgOfPericen	187.1892029511937
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 127"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.047223233651653e-08
	Radius		25.374563878818048

	RotationPeriod	5.829110784717925

	Obliquity		14.243307547656006

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4053482751453288
		Eccentricity	0.1
		Inclination		0.3434194241502851
		AscendingNode	70.25804875987163
		ArgOfPericen	124.98966821222184
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 128"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.936547428496166e-07
	Radius		45.536500151994225

	RotationPeriod	8.304743006963127

	Obliquity		353.6990370303346

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40982729603344453
		Eccentricity	0.1
		Inclination		0.9486662740315115
		AscendingNode	19.486799272785234
		ArgOfPericen	312.73368380643745
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 128.1"
{
	ParentBody	"Aeolus A 128"
	Class		"Asteroid"
	Mass		2.862414941442053e-09
	Radius		11.175349973547654

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.895038527674008e-06
		Eccentricity	0.0037094758062341613
		Inclination		-27.736041477353265
		AscendingNode	351.7827171061105
		ArgOfPericen	229.18980840315024
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 128.2"
{
	ParentBody	"Aeolus A 128"
	Class		"Asteroid"
	Mass		2.7056124690139144e-09
	Radius		10.967445033114455

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.960156876482391e-06
		Eccentricity	0.009234432711042804
		Inclination		-50.77189338880105
		AscendingNode	259.7941800712232
		ArgOfPericen	192.92675557546494
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 128.3"
{
	ParentBody	"Aeolus A 128"
	Class		"Asteroid"
	Mass		5.582699646080338e-11
	Radius		3.0081421631295084

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.428981670313223e-06
		Eccentricity	0.006616923062087929
		Inclination		18.12701034346015
		AscendingNode	67.57834982912998
		ArgOfPericen	33.481861869912315
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 128.4"
{
	ParentBody	"Aeolus A 128"
	Class		"Asteroid"
	Mass		9.212639147227467e-10
	Radius		7.658521855388196

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3792856038489326e-06
		Eccentricity	0.004095497516798637
		Inclination		-28.002140614358872
		AscendingNode	227.0178680920921
		ArgOfPericen	217.60490689111316
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 129"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.197884676246875e-07
	Radius		62.4751811081058

	RotationPeriod	5.6111669996751585

	Obliquity		217.3707321711096

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4109400040599677
		Eccentricity	0.1
		Inclination		3.968639069317291
		AscendingNode	171.806741334544
		ArgOfPericen	107.05689979041664
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 130"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.960387323337143e-07
	Radius		51.76374786402134

	RotationPeriod	6.648347167848517

	Obliquity		180.8402820860345

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4088430428886082
		Eccentricity	0.1
		Inclination		1.3943129120258813
		AscendingNode	26.905733784274624
		ArgOfPericen	286.9152367176689
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 131"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40957602692498096
		Eccentricity	0.1
		Inclination		-1.3560662177616498
		AscendingNode	66.98374905872778
		ArgOfPericen	73.27333140390485
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 131 A"
{
	ParentBody	"Aeolus A 131"
	Class		"Asteroid"
	Mass		1.1837960554877952e-07
	Radius		38.48639398912492

	Orbit
	{
		Epoch			2457395.5
		Period			0.005033663297466848
		Eccentricity	0.0037361469182880646
		Inclination		173.6217356074851
		AscendingNode	38.722713992646526
		ArgOfPericen	105.28194996012807
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 131 B"
{
	ParentBody	"Aeolus A 131"
	Class		"Asteroid"
	Mass		3.094840942263766e-09
	Radius		11.422496574352476

	Orbit
	{
		Epoch			2457395.5
		Period			0.005033663297466848
		Eccentricity	0.0037361469182880646
		Inclination		173.6217356074851
		AscendingNode	38.722713992646526
		ArgOfPericen	285.2819499601281
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 132"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.812416741958239e-08
	Radius		35.91856638798079

	RotationPeriod	5.427380831473013

	Obliquity		282.27469712464534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41225964225824024
		Eccentricity	0.1
		Inclination		1.4700950723965989
		AscendingNode	72.95942202566245
		ArgOfPericen	138.52265349348517
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 133"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.694967314421153e-07
	Radius		66.89368320834632

	RotationPeriod	4.997908763760809

	Obliquity		139.88267811214376

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40694964745290585
		Eccentricity	0.1
		Inclination		-2.544306707165466
		AscendingNode	86.20273223323042
		ArgOfPericen	118.74925226329603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 134"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.810874617024644e-07
	Radius		68.70500124704881

	RotationPeriod	5.571129920309009

	Obliquity		75.57241355429194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4055065492142508
		Eccentricity	0.1
		Inclination		-0.5337068916242244
		AscendingNode	189.18177203880887
		ArgOfPericen	82.08883600693349
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 135"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6230248525909142e-07
	Radius		46.47499208214458

	RotationPeriod	7.045185467008875

	Obliquity		251.4237825902424

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.408832625349607
		Eccentricity	0.1
		Inclination		0.03752965623489888
		AscendingNode	26.76730289492252
		ArgOfPericen	346.2142351693868
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 136"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.228735557054766e-08
	Radius		24.574881288713424

	RotationPeriod	6.227434516424903

	Obliquity		196.50816985208138

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41036064804540984
		Eccentricity	0.1
		Inclination		-1.3264621063823374
		AscendingNode	249.9767403009447
		ArgOfPericen	63.91786385039512
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 137"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.473269313476362e-07
	Radius		71.19289513270944

	RotationPeriod	6.805787946269108

	Obliquity		229.48579207166168

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4059160577661312
		Eccentricity	0.1
		Inclination		-2.327470175954853
		AscendingNode	197.3537281666951
		ArgOfPericen	43.7375470647981
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 138"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3353421343477538e-07
	Radius		50.63602874656163

	RotationPeriod	5.935801729646638

	Obliquity		122.0924481988263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.413199880959911
		Eccentricity	0.1
		Inclination		1.6560599229808495
		AscendingNode	272.0882967140988
		ArgOfPericen	195.29543890679759
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 139"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.073987254514729e-07
	Radius		44.453150233369755

	RotationPeriod	7.1359616577055895

	Obliquity		180.02258848836985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4096180069646466
		Eccentricity	0.1
		Inclination		3.1084015158017824
		AscendingNode	345.2812397298755
		ArgOfPericen	234.01968057504365
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 140"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1126015721011058e-07
	Radius		36.879866436891646

	RotationPeriod	7.717990832376434

	Obliquity		338.5726570309182

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4074586712202628
		Eccentricity	0.1
		Inclination		-0.8570896372542207
		AscendingNode	162.2906931142055
		ArgOfPericen	9.6923919286739
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 141"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.813834865361268e-08
	Radius		28.094869745680338

	RotationPeriod	2.7781382290208025

	Obliquity		282.2681166771938

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40744518845873734
		Eccentricity	0.1
		Inclination		-0.5801102888590388
		AscendingNode	202.09778372199654
		ArgOfPericen	191.2984356470473
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 142"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40869627745045883
		Eccentricity	0.1
		Inclination		0.8723462364086872
		AscendingNode	4.124226157236417
		ArgOfPericen	358.4141704665203
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 142 A"
{
	ParentBody	"Aeolus A 142"
	Class		"Asteroid"
	Mass		1.3394603404844856e-07
	Radius		40.028540427836646

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055370265003452735
		Eccentricity	0.006203446615538015
		Inclination		198.00750638591367
		AscendingNode	36.612372891328576
		ArgOfPericen	190.32371130693295
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 142 B"
{
	ParentBody	"Aeolus A 142"
	Class		"Asteroid"
	Mass		1.0088420464414431e-08
	Radius		16.904442776825178

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055370265003452735
		Eccentricity	0.006203446615538015
		Inclination		198.00750638591367
		AscendingNode	36.612372891328576
		ArgOfPericen	10.323711306932978
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 143"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.6054879816656053e-07
	Radius		47.2142128432825

	RotationPeriod	7.597399794088596

	Obliquity		176.14914326571255

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4156381927579161
		Eccentricity	0.1
		Inclination		-1.8624578380684769
		AscendingNode	258.86956516266287
		ArgOfPericen	279.59152043522005
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 143.1"
{
	ParentBody	"Aeolus A 143"
	Class		"Asteroid"
	Mass		1.6431448914173399e-10
	Radius		4.04888102854994

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5473699388604506e-06
		Eccentricity	0.0034565605943610647
		Inclination		-22.333220721384496
		AscendingNode	266.567693486794
		ArgOfPericen	50.1885563176263
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 144"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.1834908581800565e-08
	Radius		28.83847108869787

	RotationPeriod	6.988708549407565

	Obliquity		259.8221577581248

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4033818355113058
		Eccentricity	0.1
		Inclination		1.2108823503118602
		AscendingNode	26.538882327559328
		ArgOfPericen	16.786642882793178
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 145"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41667617665811885
		Eccentricity	0.1
		Inclination		-1.4528397695767523
		AscendingNode	25.80613341607978
		ArgOfPericen	42.22184796469972
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 145 A"
{
	ParentBody	"Aeolus A 145"
	Class		"Asteroid"
	Mass		6.379522611459678e-07
	Radius		63.55955384833933

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023695754677339927
		Eccentricity	0.004965276861386608
		Inclination		327.3973711229036
		AscendingNode	292.25562276500546
		ArgOfPericen	54.65677316710453
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 145 B"
{
	ParentBody	"Aeolus A 145"
	Class		"Asteroid"
	Mass		2.6972868111322847e-08
	Radius		22.142525625834203

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023695754677339927
		Eccentricity	0.004965276861386608
		Inclination		327.3973711229036
		AscendingNode	292.25562276500546
		ArgOfPericen	234.65677316710452
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 146"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7344870403372794e-07
	Radius		42.67892572685283

	RotationPeriod	4.922280807650868

	Obliquity		259.4202071133756

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40558612842642067
		Eccentricity	0.1
		Inclination		-0.0030103052345030346
		AscendingNode	239.9424969816517
		ArgOfPericen	262.1493457326424
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 146.1"
{
	ParentBody	"Aeolus A 146"
	Class		"Asteroid"
	Mass		2.600310619738109e-09
	Radius		10.523613014784578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.086459382815669e-06
		Eccentricity	0.0060398630218408585
		Inclination		-45.82449383270657
		AscendingNode	315.9579013954132
		ArgOfPericen	285.212791823982
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 147"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41010211898268756
		Eccentricity	0.1
		Inclination		0.6556874775257816
		AscendingNode	198.0391298033143
		ArgOfPericen	89.61107340617055
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 147 A"
{
	ParentBody	"Aeolus A 147"
	Class		"Asteroid"
	Mass		2.6841673340600592e-08
	Radius		23.40614757896524

	Orbit
	{
		Epoch			2457395.5
		Period			0.0020700770516760957
		Eccentricity	0.000962738285640195
		Inclination		157.37075282555284
		AscendingNode	325.8083061208746
		ArgOfPericen	74.15555516543513
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 147 B"
{
	ParentBody	"Aeolus A 147"
	Class		"Asteroid"
	Mass		8.294941925665545e-09
	Radius		15.82454360271517

	Orbit
	{
		Epoch			2457395.5
		Period			0.0020700770516760957
		Eccentricity	0.000962738285640195
		Inclination		157.37075282555284
		AscendingNode	325.8083061208746
		ArgOfPericen	254.15555516543515
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 148"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.410223006450083e-07
	Radius		71.7618863902377

	RotationPeriod	5.669738632403074

	Obliquity		323.7232068215895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4102463098480385
		Eccentricity	0.1
		Inclination		-0.44328382182773807
		AscendingNode	36.85591779545947
		ArgOfPericen	349.545147621239
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 149"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8224006368446974e-07
	Radius		44.041476154697115

	RotationPeriod	5.7252864622001605

	Obliquity		149.44833947400903

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4112613281698526
		Eccentricity	0.1
		Inclination		1.213176337100064
		AscendingNode	356.15886991840904
		ArgOfPericen	326.4891067096777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 149.1"
{
	ParentBody	"Aeolus A 149"
	Class		"Asteroid"
	Mass		2.3603700242809135e-09
	Radius		10.342859162853141

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.71418162661094e-06
		Eccentricity	0.007322289954120402
		Inclination		-16.60463667795857
		AscendingNode	112.88580347965697
		ArgOfPericen	35.412795466377666
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 150"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.979231591013847e-07
	Radius		45.74255861054485

	RotationPeriod	8.538333341095147

	Obliquity		127.07473905141099

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41348746761449945
		Eccentricity	0.1
		Inclination		-0.8908635551064424
		AscendingNode	81.35747643604594
		ArgOfPericen	5.068329798136828
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 151"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40516119097455205
		Eccentricity	0.1
		Inclination		-1.9617673815008285
		AscendingNode	118.68781664857353
		ArgOfPericen	20.477410292871493
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 151 A"
{
	ParentBody	"Aeolus A 151"
	Class		"Asteroid"
	Mass		4.793397841195861e-07
	Radius		66.8844856676211

	Orbit
	{
		Epoch			2457395.5
		Period			0.004742051627437208
		Eccentricity	0.006820717980641841
		Inclination		126.05231978077447
		AscendingNode	85.4917917365868
		ArgOfPericen	32.191303462437915
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 151 B"
{
	ParentBody	"Aeolus A 151"
	Class		"Asteroid"
	Mass		2.741066797419031e-07
	Radius		55.51590698587831

	Orbit
	{
		Epoch			2457395.5
		Period			0.004742051627437208
		Eccentricity	0.006820717980641841
		Inclination		126.05231978077447
		AscendingNode	85.4917917365868
		ArgOfPericen	212.19130346243793
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 152"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.456895722172893e-08
	Radius		38.16452089339187

	RotationPeriod	5.718012504430555

	Obliquity		8.586679526733816

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4129576638114211
		Eccentricity	0.1
		Inclination		-1.4498299638044398
		AscendingNode	75.89072465377667
		ArgOfPericen	97.0619005748822
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 153"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41142145597718915
		Eccentricity	0.1
		Inclination		1.0316410399433023
		AscendingNode	291.762149959719
		ArgOfPericen	122.26687657856932
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 153 A"
{
	ParentBody	"Aeolus A 153"
	Class		"Asteroid"
	Mass		7.726254317446009e-08
	Radius		32.94257732569382

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023826005883260796
		Eccentricity	0.0063726491839773474
		Inclination		178.2808504633211
		AscendingNode	14.901460922238115
		ArgOfPericen	186.9810066491435
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 153 B"
{
	ParentBody	"Aeolus A 153"
	Class		"Asteroid"
	Mass		5.84671266510835e-08
	Radius		30.019617752589763

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023826005883260796
		Eccentricity	0.0063726491839773474
		Inclination		178.2808504633211
		AscendingNode	14.901460922238115
		ArgOfPericen	6.981006649143524
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 154"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4081908332561133
		Eccentricity	0.1
		Inclination		2.219430009546991
		AscendingNode	49.38654363937444
		ArgOfPericen	10.982280080016622
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 154 A"
{
	ParentBody	"Aeolus A 154"
	Class		"Asteroid"
	Mass		1.5977411557497394e-07
	Radius		41.084454961926944

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003775686113373452
		Eccentricity	0.006150334695427321
		Inclination		266.4500033667008
		AscendingNode	4.802933983660016
		ArgOfPericen	238.39267232690352
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 154 B"
{
	ParentBody	"Aeolus A 154"
	Class		"Asteroid"
	Mass		1.0849080522345998e-07
	Radius		36.11101536146997

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003775686113373452
		Eccentricity	0.006150334695427321
		Inclination		266.4500033667008
		AscendingNode	4.802933983660016
		ArgOfPericen	58.392672326903494
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 155"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2723575917809253e-07
	Radius		37.96358448863223

	RotationPeriod	6.526037893766995

	Obliquity		358.4365468729969

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4054209298083154
		Eccentricity	0.1
		Inclination		-1.7325418037834492
		AscendingNode	13.054197775152323
		ArgOfPericen	123.34880012397764
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 156"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9997482049981895e-07
	Radius		42.97561781512013

	RotationPeriod	5.947187351556394

	Obliquity		346.9526101447119

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4133559655271434
		Eccentricity	0.1
		Inclination		1.2000811847140045
		AscendingNode	254.92993746173627
		ArgOfPericen	312.9865742480853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 156.1"
{
	ParentBody	"Aeolus A 156"
	Class		"Asteroid"
	Mass		1.9019008969141114e-09
	Radius		9.105273273636284

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.640789834786408e-06
		Eccentricity	0.0019535527490046763
		Inclination		33.068009095175924
		AscendingNode	130.84429271693068
		ArgOfPericen	42.60632664807825
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 156.2"
{
	ParentBody	"Aeolus A 156"
	Class		"Asteroid"
	Mass		2.569189705142641e-10
	Radius		4.671923770126645

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.57616048851594e-06
		Eccentricity	0.0047562595806788606
		Inclination		28.587620163517432
		AscendingNode	200.4538350612061
		ArgOfPericen	194.81380459174386
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 157"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41589067159904486
		Eccentricity	0.1
		Inclination		1.2751758855702708
		AscendingNode	51.67972672720952
		ArgOfPericen	209.02042521789133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 157 A"
{
	ParentBody	"Aeolus A 157"
	Class		"Asteroid"
	Mass		3.340454688451788e-07
	Radius		55.5849128572059

	Orbit
	{
		Epoch			2457395.5
		Period			0.0027333710678571037
		Eccentricity	0.005797308770428024
		Inclination		81.41468282682247
		AscendingNode	348.47842717815627
		ArgOfPericen	277.7474834901698
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 157 B"
{
	ParentBody	"Aeolus A 157"
	Class		"Asteroid"
	Mass		1.9541997094634365e-07
	Radius		46.48841244927706

	Orbit
	{
		Epoch			2457395.5
		Period			0.0027333710678571037
		Eccentricity	0.005797308770428024
		Inclination		81.41468282682247
		AscendingNode	348.47842717815627
		ArgOfPericen	97.74748349016983
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 158"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4076739222474129
		Eccentricity	0.1
		Inclination		-1.882654436827239
		AscendingNode	108.76084317793728
		ArgOfPericen	255.8575981636739
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 158 A"
{
	ParentBody	"Aeolus A 158"
	Class		"Asteroid"
	Mass		4.393923038302783e-07
	Radius		56.7945664450319

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023125078238539713
		Eccentricity	0.003591110557933658
		Inclination		321.884577776284
		AscendingNode	311.63342325300556
		ArgOfPericen	223.03348072594744
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 158 B"
{
	ParentBody	"Aeolus A 158"
	Class		"Asteroid"
	Mass		1.3018108437075766e-07
	Radius		37.862149699389775

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023125078238539713
		Eccentricity	0.003591110557933658
		Inclination		321.884577776284
		AscendingNode	311.63342325300556
		ArgOfPericen	43.03348072594747
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 159"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3493690822012994e-07
	Radius		39.52076128329828

	RotationPeriod	6.7138909139542315

	Obliquity		125.86296058931626

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41318172252719365
		Eccentricity	0.1
		Inclination		-0.7391598002156193
		AscendingNode	152.44595062444367
		ArgOfPericen	38.25661483746596
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 159.1"
{
	ParentBody	"Aeolus A 159"
	Class		"Asteroid"
	Mass		3.1085475647695606e-10
	Radius		5.2195639438977315

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.77652312140811e-07
		Eccentricity	0.006301093422121281
		Inclination		-13.403679544242161
		AscendingNode	341.8907265798672
		ArgOfPericen	306.9727030598339
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 160"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0489312309222379e-06
	Radius		77.17928243212788

	RotationPeriod	4.188290570810838

	Obliquity		87.19462619099818

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41319958000829926
		Eccentricity	0.1
		Inclination		0.8316942197363452
		AscendingNode	180.03173710185735
		ArgOfPericen	341.1105862151121
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 161"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.068124595353178e-07
	Radius		70.3820403332604

	RotationPeriod	5.353048551284555

	Obliquity		292.98974845809005

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4070576631237143
		Eccentricity	0.1
		Inclination		-1.9251450336093798
		AscendingNode	183.0467562815489
		ArgOfPericen	343.58890628975365
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 161.1"
{
	ParentBody	"Aeolus A 161"
	Class		"Asteroid"
	Mass		4.363642766353772e-09
	Radius		13.585013863334083

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.959351865548244e-07
		Eccentricity	0.00703104222114709
		Inclination		-20.494673053498378
		AscendingNode	172.55195345802002
		ArgOfPericen	284.09986885200726
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 162"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4079897517350192
		Eccentricity	0.1
		Inclination		2.771053778318213
		AscendingNode	46.93612042032141
		ArgOfPericen	333.91678387146015
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 162 A"
{
	ParentBody	"Aeolus A 162"
	Class		"Asteroid"
	Mass		4.0973710176636373e-08
	Radius		26.423828470602604

	Orbit
	{
		Epoch			2457395.5
		Period			0.007249750152343437
		Eccentricity	0.006957464467343779
		Inclination		119.06741567018632
		AscendingNode	54.986626814540344
		ArgOfPericen	126.43733415059785
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 162 B"
{
	ParentBody	"Aeolus A 162"
	Class		"Asteroid"
	Mass		1.937350047024656e-08
	Radius		20.58559117942784

	Orbit
	{
		Epoch			2457395.5
		Period			0.007249750152343437
		Eccentricity	0.006957464467343779
		Inclination		119.06741567018632
		AscendingNode	54.986626814540344
		ArgOfPericen	306.43733415059785
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 163"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41086285641336834
		Eccentricity	0.1
		Inclination		-1.8333985841729514
		AscendingNode	159.3978889180326
		ArgOfPericen	85.02569074287268
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 163 A"
{
	ParentBody	"Aeolus A 163"
	Class		"Asteroid"
	Mass		1.1519972192604441e-06
	Radius		85.43565592898739

	Orbit
	{
		Epoch			2457395.5
		Period			0.0031897095683345693
		Eccentricity	0.0026179607556569306
		Inclination		159.95715237467863
		AscendingNode	95.65471552360891
		ArgOfPericen	67.14983169827579
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 163 B"
{
	ParentBody	"Aeolus A 163"
	Class		"Asteroid"
	Mass		4.7216905978617224e-08
	Radius		29.4569553350393

	Orbit
	{
		Epoch			2457395.5
		Period			0.0031897095683345693
		Eccentricity	0.0026179607556569306
		Inclination		159.95715237467863
		AscendingNode	95.65471552360891
		ArgOfPericen	247.1498316982758
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 164"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4338974925384585e-07
	Radius		41.478483073271676

	RotationPeriod	3.7672920221078248

	Obliquity		30.58760157179516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41243582675045287
		Eccentricity	0.1
		Inclination		1.1839717920284818
		AscendingNode	335.7040370111118
		ArgOfPericen	315.2227080140791
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 165"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.000845083713935e-06
	Radius		71.1822583360688

	RotationPeriod	9.766096716369367

	Obliquity		165.59106510988198

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4131168444184267
		Eccentricity	0.1
		Inclination		-0.7367687874554397
		AscendingNode	186.02394513766853
		ArgOfPericen	324.371873043215
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 166"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.2453115722871443e-07
	Radius		55.5312654559994

	RotationPeriod	4.430786008570239

	Obliquity		126.22045201348895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40987427941223403
		Eccentricity	0.1
		Inclination		0.5986778406563047
		AscendingNode	117.90544174002908
		ArgOfPericen	159.81120488422943
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 167"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4136316891869011
		Eccentricity	0.1
		Inclination		-3.0410119184226407
		AscendingNode	288.7368598627014
		ArgOfPericen	14.921500647578343
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 167 A"
{
	ParentBody	"Aeolus A 167"
	Class		"Asteroid"
	Mass		1.604253490097408e-07
	Radius		42.20344575169697

	Orbit
	{
		Epoch			2457395.5
		Period			0.00031245216566621757
		Eccentricity	0.004530018486641697
		Inclination		307.68551329332826
		AscendingNode	241.88573561702373
		ArgOfPericen	147.00075756172578
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 167 B"
{
	ParentBody	"Aeolus A 167"
	Class		"Asteroid"
	Mass		1.2760153807976838e-08
	Radius		18.149954880601168

	Orbit
	{
		Epoch			2457395.5
		Period			0.00031245216566621757
		Eccentricity	0.004530018486641697
		Inclination		307.68551329332826
		AscendingNode	241.88573561702373
		ArgOfPericen	327.0007575617258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 168"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4056069743970597e-07
	Radius		39.831278748859795

	RotationPeriod	7.572535827907368

	Obliquity		12.558896364421104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40316619291723765
		Eccentricity	0.1
		Inclination		1.8788176181558347
		AscendingNode	276.1798068030144
		ArgOfPericen	138.1692184777207
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 169"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.410215008129279
		Eccentricity	0.1
		Inclination		0.1799853269673367
		AscendingNode	0.8621475865001127
		ArgOfPericen	189.143893095368
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 169 A"
{
	ParentBody	"Aeolus A 169"
	Class		"Asteroid"
	Mass		2.0207891554303169e-07
	Radius		45.93122035093892

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037165037987626484
		Eccentricity	0.004784648882433211
		Inclination		26.118602755440243
		AscendingNode	222.9421782913141
		ArgOfPericen	99.71054605951427
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 169 B"
{
	ParentBody	"Aeolus A 169"
	Class		"Asteroid"
	Mass		1.086197372767612e-08
	Radius		17.33420384890913

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037165037987626484
		Eccentricity	0.004784648882433211
		Inclination		26.118602755440243
		AscendingNode	222.9421782913141
		ArgOfPericen	279.7105460595143
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 170"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.084193558703309e-07
	Radius		50.12961129225972

	RotationPeriod	8.477960476676094

	Obliquity		114.51030514349193

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.402027911354637
		Eccentricity	0.1
		Inclination		-1.7829514735898442
		AscendingNode	214.91787628595742
		ArgOfPericen	88.09202173229274
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 171"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.657383426532202e-07
	Radius		72.16029049296537

	RotationPeriod	6.626969780831526

	Obliquity		5.774202067919774

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41226735308640555
		Eccentricity	0.1
		Inclination		0.5311985458219045
		AscendingNode	116.97540601245495
		ArgOfPericen	2.229399371457399
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 172"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.114277895280408e-08
	Radius		24.847266994382036

	RotationPeriod	6.652102421780618

	Obliquity		328.8002513556489

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41622704809897576
		Eccentricity	0.1
		Inclination		-0.8385699771114556
		AscendingNode	185.7899347291464
		ArgOfPericen	25.1545589436321
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 173"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6244733836627301e-07
	Radius		45.020782381568225

	RotationPeriod	5.73021700830402

	Obliquity		159.6217520301946

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41477343107718684
		Eccentricity	0.1
		Inclination		1.423215977302109
		AscendingNode	139.79470139435315
		ArgOfPericen	26.095389742313632
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 174"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.803689266873383e-07
	Radius		64.10295749245697

	RotationPeriod	4.614454820723263

	Obliquity		308.68933916434844

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4038061545749101
		Eccentricity	0.1
		Inclination		-0.040554251568282386
		AscendingNode	168.73147844863865
		ArgOfPericen	164.49864458459118
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 174.1"
{
	ParentBody	"Aeolus A 174"
	Class		"Asteroid"
	Mass		4.93927944702369e-09
	Radius		13.939299962210487

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.887601158579696e-06
		Eccentricity	0.006209592101566145
		Inclination		7.722686305701653
		AscendingNode	329.3484853150951
		ArgOfPericen	107.9761657697947
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 174.2"
{
	ParentBody	"Aeolus A 174"
	Class		"Asteroid"
	Mass		5.492856009497211e-10
	Radius		6.703256471214152

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.939909596565083e-06
		Eccentricity	0.002516217831529063
		Inclination		10.500705397080546
		AscendingNode	156.70126207282587
		ArgOfPericen	335.58730122130794
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 175"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.046650973920831e-07
	Radius		67.12261207229173

	RotationPeriod	5.672160342133723

	Obliquity		25.204202242837887

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4123821131277747
		Eccentricity	0.1
		Inclination		1.0741765427929504
		AscendingNode	189.6265595817438
		ArgOfPericen	47.381910654792584
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 176"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.3033806026031565e-07
	Radius		60.654173036017575

	RotationPeriod	7.658539328445064

	Obliquity		70.00321730818473

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4109741383963283
		Eccentricity	0.1
		Inclination		-1.51012571146631
		AscendingNode	193.27776785306042
		ArgOfPericen	260.5449951392594
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 177"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.870744152711825e-07
	Radius		72.50107725260267

	RotationPeriod	5.730347890602399

	Obliquity		69.58903304193797

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4090350651212342
		Eccentricity	0.1
		Inclination		1.2739730651562442
		AscendingNode	305.72307752331477
		ArgOfPericen	359.4787845023399
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 178"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41072238407873857
		Eccentricity	0.1
		Inclination		-1.4505353908527676
		AscendingNode	136.57106700306363
		ArgOfPericen	41.35377564188877
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 178 A"
{
	ParentBody	"Aeolus A 178"
	Class		"Asteroid"
	Mass		2.3670228883445267e-07
	Radius		46.73769617135918

	Orbit
	{
		Epoch			2457395.5
		Period			0.003909869813663959
		Eccentricity	0.005301714838929942
		Inclination		278.23897030502746
		AscendingNode	28.82619177706079
		ArgOfPericen	281.12115177627976
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 178 B"
{
	ParentBody	"Aeolus A 178"
	Class		"Asteroid"
	Mass		2.2567727345077262e-07
	Radius		46.000486409846964

	Orbit
	{
		Epoch			2457395.5
		Period			0.003909869813663959
		Eccentricity	0.005301714838929942
		Inclination		278.23897030502746
		AscendingNode	28.82619177706079
		ArgOfPericen	101.12115177627976
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 179"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.28188225750917e-07
	Radius		68.52624495191687

	RotationPeriod	4.962536463380713

	Obliquity		248.903935287516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4125128018236259
		Eccentricity	0.1
		Inclination		1.0911035535254896
		AscendingNode	293.892243941934
		ArgOfPericen	260.6670519578622
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus A 180"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4091345788398626
		Eccentricity	0.1
		Inclination		1.2162219725674372
		AscendingNode	84.36614946315152
		ArgOfPericen	65.06022649267406
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 180 A"
{
	ParentBody	"Aeolus A 180"
	Class		"Asteroid"
	Mass		2.981487204824117e-07
	Radius		56.52292563505448

	Orbit
	{
		Epoch			2457395.5
		Period			0.004102259669484723
		Eccentricity	0.006510542753512186
		Inclination		341.290645362543
		AscendingNode	184.9567077683055
		ArgOfPericen	351.02990760757496
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 180 B"
{
	ParentBody	"Aeolus A 180"
	Class		"Asteroid"
	Mass		3.8553119487324276e-08
	Radius		28.58249641637052

	Orbit
	{
		Epoch			2457395.5
		Period			0.004102259669484723
		Eccentricity	0.006510542753512186
		Inclination		341.290645362543
		AscendingNode	184.9567077683055
		ArgOfPericen	171.02990760757496
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 181"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.997668862651884e-07
	Radius		57.54352622807385

	RotationPeriod	4.619485242201163

	Obliquity		163.28743721978736

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.411161672904936
		Eccentricity	0.1
		Inclination		0.4317551236178858
		AscendingNode	310.60475450421484
		ArgOfPericen	88.12971653739731
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 181.1"
{
	ParentBody	"Aeolus A 181"
	Class		"Asteroid"
	Mass		8.021553513765213e-10
	Radius		7.257945356621083

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8152446084337256e-06
		Eccentricity	0.005772255812442403
		Inclination		-20.544047833567703
		AscendingNode	181.29539603647288
		ArgOfPericen	35.706498505172085
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 182"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.6936950669660947e-07
	Radius		50.68472614705384

	RotationPeriod	5.672908279498863

	Obliquity		137.65669166213686

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41345265199265996
		Eccentricity	0.1
		Inclination		1.4282880105151232
		AscendingNode	310.2161604093448
		ArgOfPericen	80.61388729621056
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 182.1"
{
	ParentBody	"Aeolus A 182"
	Class		"Asteroid"
	Mass		1.516538715799688e-09
	Radius		9.016655176809977

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.088233326004868e-06
		Eccentricity	0.004619919315995027
		Inclination		-17.802105489341407
		AscendingNode	115.75246951811096
		ArgOfPericen	196.8698510294492
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 183"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.204830516861721e-07
	Radius		71.0472840123258

	RotationPeriod	9.566239032167761

	Obliquity		330.2544746438965

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40860542925247756
		Eccentricity	0.1
		Inclination		1.7332702289750521
		AscendingNode	141.53113018932467
		ArgOfPericen	181.9864432221767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 184"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.000061638760277e-07
	Radius		57.95177279413777

	RotationPeriod	7.228868959172655

	Obliquity		344.6640379526309

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.409686637778403
		Eccentricity	0.1
		Inclination		1.3497925457729496
		AscendingNode	269.39282929612176
		ArgOfPericen	330.3427218569261
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 185"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.98202448923839e-07
	Radius		72.29835516716923

	RotationPeriod	5.165340708767832

	Obliquity		58.03312824690371

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40761348213547166
		Eccentricity	0.1
		Inclination		3.5930736279658837
		AscendingNode	207.54021622249684
		ArgOfPericen	25.887304154820537
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 185.1"
{
	ParentBody	"Aeolus A 185"
	Class		"Asteroid"
	Mass		1.3957522102506104e-08
	Radius		18.041519555869183

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.479500178545807e-06
		Eccentricity	0.006150783692419455
		Inclination		-31.869055964405298
		AscendingNode	49.53967569766586
		ArgOfPericen	303.78254324826895
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 186"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.023251413627562e-07
	Radius		66.04200249983829

	RotationPeriod	1.1493199558344713

	Obliquity		123.51432095953899

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40554371678909146
		Eccentricity	0.1
		Inclination		-3.5689579537057545
		AscendingNode	61.34904186794011
		ArgOfPericen	237.89712964227482
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 186.1"
{
	ParentBody	"Aeolus A 186"
	Class		"Asteroid"
	Mass		1.6934565566130325e-09
	Radius		8.855889347749127

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.82465293312079e-06
		Eccentricity	0.003612062353599602
		Inclination		-39.271066957224505
		AscendingNode	263.5117660701589
		ArgOfPericen	141.87568687209776
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 186.2"
{
	ParentBody	"Aeolus A 186"
	Class		"Asteroid"
	Mass		5.6368783114359e-09
	Radius		13.222707205934293

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.7663584707531876e-06
		Eccentricity	0.008598500706261218
		Inclination		-4.741849493756131
		AscendingNode	293.05103046517064
		ArgOfPericen	139.19072839238513
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 186.3"
{
	ParentBody	"Aeolus A 186"
	Class		"Asteroid"
	Mass		9.692284297884986e-10
	Radius		7.352745652786897

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.822885185910227e-06
		Eccentricity	0.00236696142510445
		Inclination		-26.628993146156766
		AscendingNode	215.49761829734902
		ArgOfPericen	344.7910072629704
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 187"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.653512991397156e-07
	Radius		44.882750381745716

	RotationPeriod	4.743620590955656

	Obliquity		87.82963152691968

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40815863392377894
		Eccentricity	0.1
		Inclination		-0.2165768968782327
		AscendingNode	320.83270500196966
		ArgOfPericen	296.6745917497276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 188"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.7790782948305296e-08
	Radius		27.948487021555255

	RotationPeriod	8.76008243384132

	Obliquity		82.65123948232251

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4089931531939763
		Eccentricity	0.1
		Inclination		2.1731201197200503
		AscendingNode	206.76499824448746
		ArgOfPericen	218.21906699721865
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 189"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0482610277758565e-06
	Radius		79.07049471417076

	RotationPeriod	6.744691070681742

	Obliquity		130.4176720416261

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40872837412091056
		Eccentricity	0.1
		Inclination		-2.0662594034883757
		AscendingNode	167.96303444141836
		ArgOfPericen	256.7561529597168
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 190"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.102354277899686e-07
	Radius		64.14329132591247

	RotationPeriod	4.243730559448727

	Obliquity		178.1756661945969

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4042011592065256
		Eccentricity	0.1
		Inclination		1.7896171576643365
		AscendingNode	114.87272443042603
		ArgOfPericen	265.2607062731826
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 191"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3135886450872319e-08
	Radius		17.112105718913732

	RotationPeriod	7.509686400889621

	Obliquity		151.92825676346646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41334084136909865
		Eccentricity	0.1
		Inclination		-1.3880025427918263
		AscendingNode	35.678783095790976
		ArgOfPericen	341.74076678939304
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 191.1"
{
	ParentBody	"Aeolus A 191"
	Class		"Asteroid"
	Mass		1.0998379041199351e-11
	Radius		1.6128471843806143

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8323262742764765e-06
		Eccentricity	0.005916694986900279
		Inclination		3.5847527176287954
		AscendingNode	126.83820484908378
		ArgOfPericen	168.22791549747336
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 192"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1822037916596465e-07
	Radius		38.41748728425989

	RotationPeriod	6.837556298249146

	Obliquity		356.98783427539064

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41033598827824364
		Eccentricity	0.1
		Inclination		1.830203902115238
		AscendingNode	177.36765627649032
		ArgOfPericen	64.01200036519893
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 193"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.85960654340747e-08
	Radius		35.52881142467061

	RotationPeriod	4.568015110344785

	Obliquity		28.110452899946168

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4158200440588742
		Eccentricity	0.1
		Inclination		-0.14285845872065903
		AscendingNode	314.04625274293795
		ArgOfPericen	190.4327809271405
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 194"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.7661270875649774e-07
	Radius		50.80485423020278

	RotationPeriod	7.735864860540898

	Obliquity		180.06960635362304

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40539212169516214
		Eccentricity	0.1
		Inclination		0.3865424049593729
		AscendingNode	276.13280520938747
		ArgOfPericen	168.02322355977677
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 195"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9259095490055225e-07
	Radius		43.882520516394614

	RotationPeriod	8.104546403443294

	Obliquity		204.86801661781524

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40715847028460517
		Eccentricity	0.1
		Inclination		0.2708247767440957
		AscendingNode	34.37887573360891
		ArgOfPericen	340.147157384234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 196"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.143892413071461e-07
	Radius		45.440154536377634

	RotationPeriod	7.558384798924382

	Obliquity		161.6745135863776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4132054786120575
		Eccentricity	0.1
		Inclination		0.33026255381568603
		AscendingNode	279.02966233716046
		ArgOfPericen	265.3875364581333
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 196.1"
{
	ParentBody	"Aeolus A 196"
	Class		"Asteroid"
	Mass		7.229022442750185e-10
	Radius		6.8139455933053155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.185930393549588e-06
		Eccentricity	0.003074265996384693
		Inclination		0.8356233057490945
		AscendingNode	271.3998981065779
		ArgOfPericen	211.15201752574094
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 197"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.285636179472881e-10
	Radius		6.16053452780033

	RotationPeriod	5.946244098324721

	Obliquity		202.68713626463236

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41155026330883676
		Eccentricity	0.1
		Inclination		-0.5541207875610666
		AscendingNode	306.58633423677304
		ArgOfPericen	313.9456094970841
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 198"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3438966254817793e-08
	Radius		19.2339126671284

	RotationPeriod	11.609232702320341

	Obliquity		324.1254981223215

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.41489190170179385
		Eccentricity	0.1
		Inclination		0.9623030967099788
		AscendingNode	83.8927472926022
		ArgOfPericen	276.6366132325519
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 199"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.3899797413869065e-07
	Radius		57.45040984282634

	RotationPeriod	3.735118837639019

	Obliquity		157.7194702257461

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.40737473632939386
		Eccentricity	0.1
		Inclination		3.8179140200132267
		AscendingNode	163.1943339996001
		ArgOfPericen	34.1761414635818
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus A 200"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.002813997305157e-10
	Radius		6.521817391945831

	RotationPeriod	4.44032455574509

	Obliquity		148.3172169924392

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.414171284052854
		Eccentricity	0.1
		Inclination		-0.7839728321331001
		AscendingNode	339.35138350196263
		ArgOfPericen	225.97514644930854
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 200.1"
{
	ParentBody	"Aeolus A 200"
	Class		"Asteroid"
	Mass		3.194839869978488e-13
	Radius		0.5020659894273953

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.81707159246521e-07
		Eccentricity	0.006095580693303848
		Inclination		20.329437817347568
		AscendingNode	232.48460272259499
		ArgOfPericen	240.13239580375438
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 200.2"
{
	ParentBody	"Aeolus A 200"
	Class		"Asteroid"
	Mass		3.7689182265270015e-12
	Radius		1.1429222192038901

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.674699232732162e-08
		Eccentricity	0.0038810095197544525
		Inclination		33.72800599342376
		AscendingNode	37.490349696885886
		ArgOfPericen	354.4586775816057
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 200.3"
{
	ParentBody	"Aeolus A 200"
	Class		"Asteroid"
	Mass		7.000300501535207e-12
	Radius		1.4049148358225227

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.145804978272838e-07
		Eccentricity	0.008415293594171584
		Inclination		-14.98262435073549
		AscendingNode	179.9854906912141
		ArgOfPericen	358.92209295356787
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus A 200.4"
{
	ParentBody	"Aeolus A 200"
	Class		"Asteroid"
	Mass		8.274556811592166e-13
	Radius		0.6894868985377802

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3642289286259416e-07
		Eccentricity	0.002750756350768962
		Inclination		-33.04145925857487
		AscendingNode	331.6707632915019
		ArgOfPericen	273.36456834936433
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Aeolus asteroid belt B ------------------------------------------------------
//------------------------------------------------------------------------------
Asteroid "Aeolus B 1"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3634731030305492e-07
	Radius		46.207246545681336

	RotationPeriod	4.303056381178303

	Obliquity		39.67162341481191

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45550456408415063
		Eccentricity	0.1
		Inclination		1.8764769433569615
		AscendingNode	71.66951239039828
		ArgOfPericen	218.8736059358022
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 2"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.624653788981517e-07
	Radius		57.381920983238736

	RotationPeriod	5.192436070659904

	Obliquity		197.85295747574762

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45453277238226847
		Eccentricity	0.1
		Inclination		-1.3828108672581827
		AscendingNode	264.866767378576
		ArgOfPericen	11.223275120539974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 2.1"
{
	ParentBody	"Aeolus B 2"
	Class		"Asteroid"
	Mass		2.020983984586286e-09
	Radius		9.381442729665014

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.495233438273116e-06
		Eccentricity	0.0024685771413886022
		Inclination		29.380778844209434
		AscendingNode	199.34263167219217
		ArgOfPericen	76.68893049906517
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 3"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.501815297543863e-07
	Radius		68.2056113036596

	RotationPeriod	7.401967192155261

	Obliquity		140.48555599991371

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45604441468054063
		Eccentricity	0.1
		Inclination		0.5137843391701972
		AscendingNode	78.46994849537951
		ArgOfPericen	110.24148150544275
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 3.1"
{
	ParentBody	"Aeolus B 3"
	Class		"Asteroid"
	Mass		3.0428419090627667e-10
	Radius		5.295435624457161

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.4022811096477293e-06
		Eccentricity	0.004706157884975566
		Inclination		-14.407284691108114
		AscendingNode	228.91991652341585
		ArgOfPericen	260.98505909462244
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 3.2"
{
	ParentBody	"Aeolus B 3"
	Class		"Asteroid"
	Mass		1.4713416337139082e-09
	Radius		8.954604405202504

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.944611395376044e-06
		Eccentricity	0.0069875963633889825
		Inclination		68.07311086540687
		AscendingNode	46.30675390064651
		ArgOfPericen	109.32006579497227
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 4"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.8156426255384434e-07
	Radius		53.69457995675856

	RotationPeriod	5.646566739751571

	Obliquity		82.62647082162098

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4544314745122133
		Eccentricity	0.1
		Inclination		-1.2831643480696395
		AscendingNode	122.14508353892833
		ArgOfPericen	307.7822088342178
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 5"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0220952795806126e-07
	Radius		36.56382501985244

	RotationPeriod	3.213969789639806

	Obliquity		101.82455406175268

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4559922638590722
		Eccentricity	0.1
		Inclination		-1.5908007550367562
		AscendingNode	257.410340908132
		ArgOfPericen	284.0392907788297
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 6"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5227065505832914e-07
	Radius		46.587452035411445

	RotationPeriod	8.080604690605599

	Obliquity		148.05792105002894

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45457926667584875
		Eccentricity	0.1
		Inclination		1.0755838789989116
		AscendingNode	162.1375165419467
		ArgOfPericen	281.12813224916215
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 7"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45642931747276677
		Eccentricity	0.1
		Inclination		-2.56679859653173
		AscendingNode	63.46197069730122
		ArgOfPericen	44.86642312763741
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 7 A"
{
	ParentBody	"Aeolus B 7"
	Class		"Asteroid"
	Mass		1.7908429218791616e-08
	Radius		20.19790679934598

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016914346864641129
		Eccentricity	0.0051291137518323605
		Inclination		325.31434223289745
		AscendingNode	124.06488316300059
		ArgOfPericen	157.51753878690883
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 7 B"
{
	ParentBody	"Aeolus B 7"
	Class		"Asteroid"
	Mass		1.6033829415141553e-09
	Radius		9.035793251014471

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016914346864641129
		Eccentricity	0.0051291137518323605
		Inclination		325.31434223289745
		AscendingNode	124.06488316300059
		ArgOfPericen	337.51753878690886
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 8"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.26164441034408e-07
	Radius		76.36800097204048

	RotationPeriod	4.7596771989701026

	Obliquity		240.7912593712723

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.456959058710348
		Eccentricity	0.1
		Inclination		2.212088801053426
		AscendingNode	47.630766575366465
		ArgOfPericen	173.25694309153965
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 8.1"
{
	ParentBody	"Aeolus B 8"
	Class		"Asteroid"
	Mass		1.0862657981115964e-09
	Radius		8.366322951293384

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.800475679698871e-06
		Eccentricity	0.005654261875231014
		Inclination		30.58300545117807
		AscendingNode	38.01743801685292
		ArgOfPericen	196.2024583191521
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 9"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.474500851647565e-07
	Radius		75.30021557903734

	RotationPeriod	3.83070027954724

	Obliquity		238.76875136198433

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4568444347046956
		Eccentricity	0.1
		Inclination		2.114548167626554
		AscendingNode	219.3208871468952
		ArgOfPericen	102.0434389450529
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 9.1"
{
	ParentBody	"Aeolus B 9"
	Class		"Asteroid"
	Mass		1.1907660686213997e-08
	Radius		18.170504849367394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.46870087306919e-06
		Eccentricity	0.004966604040735607
		Inclination		27.6018497599017
		AscendingNode	81.5392858938097
		ArgOfPericen	313.53230035026473
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 10"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.5973959546938816e-07
	Radius		61.41530995183621

	RotationPeriod	7.389354865362878

	Obliquity		186.71237132521978

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45531789987945326
		Eccentricity	0.1
		Inclination		-0.26164935721819654
		AscendingNode	55.727447048693996
		ArgOfPericen	51.7605436844009
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 11"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.263962790850118e-07
	Radius		49.707345948802605

	RotationPeriod	5.384286107415563

	Obliquity		304.338381663571

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4580685303946654
		Eccentricity	0.1
		Inclination		-2.1029127875453786
		AscendingNode	242.8915538996572
		ArgOfPericen	260.7546850113003
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 11.1"
{
	ParentBody	"Aeolus B 11"
	Class		"Asteroid"
	Mass		1.981598801774834e-09
	Radius		10.243995774085187

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.383721693219165e-06
		Eccentricity	0.004547535925541272
		Inclination		-2.810839045043205
		AscendingNode	220.51640694520813
		ArgOfPericen	298.57010961410214
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 12"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.841344562120285e-07
	Radius		56.12258300458848

	RotationPeriod	5.004417073408797

	Obliquity		287.48778653918384

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4524361030341999
		Eccentricity	0.1
		Inclination		-1.275904459339063
		AscendingNode	17.53742482419492
		ArgOfPericen	218.18622866648008
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 13"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1673433427112384e-07
	Radius		37.62763086872091

	RotationPeriod	5.253215005255957

	Obliquity		162.27965353004492

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45559149143485406
		Eccentricity	0.1
		Inclination		-1.2584070633759883
		AscendingNode	126.96023756721678
		ArgOfPericen	166.99862129860705
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 13.1"
{
	ParentBody	"Aeolus B 13"
	Class		"Asteroid"
	Mass		1.1232136226037674e-09
	Radius		8.003159247601298

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2123086497857045e-06
		Eccentricity	0.004806363212222309
		Inclination		-23.436717681442286
		AscendingNode	66.34251593204098
		ArgOfPericen	324.0174063552417
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 14"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4511926482830769
		Eccentricity	0.1
		Inclination		1.1668649563751763
		AscendingNode	59.079772008748954
		ArgOfPericen	116.96656978813556
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 14 A"
{
	ParentBody	"Aeolus B 14"
	Class		"Asteroid"
	Mass		1.1946959453479742e-07
	Radius		37.518279875559074

	Orbit
	{
		Epoch			2457395.5
		Period			0.00047558194765069645
		Eccentricity	0.005284001186081222
		Inclination		238.73469102256868
		AscendingNode	75.33342537645602
		ArgOfPericen	184.87129396459665
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 14 B"
{
	ParentBody	"Aeolus B 14"
	Class		"Asteroid"
	Mass		3.9313150871117724e-08
	Radius		25.902185337771932

	Orbit
	{
		Epoch			2457395.5
		Period			0.00047558194765069645
		Eccentricity	0.005284001186081222
		Inclination		238.73469102256868
		AscendingNode	75.33342537645602
		ArgOfPericen	4.871293964596646
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 15"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45584566802520327
		Eccentricity	0.1
		Inclination		-1.3756407707274403
		AscendingNode	158.84698963270807
		ArgOfPericen	302.17850123054745
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 15 A"
{
	ParentBody	"Aeolus B 15"
	Class		"Asteroid"
	Mass		7.782831274520459e-08
	Radius		31.064588681583157

	Orbit
	{
		Epoch			2457395.5
		Period			0.00757298458523217
		Eccentricity	0.004124155311471403
		Inclination		329.8659008603664
		AscendingNode	128.35792309875637
		ArgOfPericen	68.53171590196895
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 15 B"
{
	ParentBody	"Aeolus B 15"
	Class		"Asteroid"
	Mass		7.529057775543935e-08
	Radius		30.723211629250446

	Orbit
	{
		Epoch			2457395.5
		Period			0.00757298458523217
		Eccentricity	0.004124155311471403
		Inclination		329.8659008603664
		AscendingNode	128.35792309875637
		ArgOfPericen	248.53171590196894
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 16"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4099300675448473e-06
	Radius		85.202357863533

	RotationPeriod	4.473969771233016

	Obliquity		326.5683067960771

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4541005346399008
		Eccentricity	0.1
		Inclination		-2.638258474457787
		AscendingNode	114.92453312110759
		ArgOfPericen	207.9105221835717
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 17"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6583518215538654e-06
	Radius		91.32554944950652

	RotationPeriod	4.520661908831749

	Obliquity		318.9740494228214

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45428906403208047
		Eccentricity	0.1
		Inclination		-0.9222364014559925
		AscendingNode	1.5110623391106603
		ArgOfPericen	181.26932764399314
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 17.1"
{
	ParentBody	"Aeolus B 17"
	Class		"Asteroid"
	Mass		2.598653775896191e-09
	Radius		10.607577420391817

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.2145222753204133e-05
		Eccentricity	0.006471381566151546
		Inclination		3.9626865390789727
		AscendingNode	280.56633660764464
		ArgOfPericen	158.29473019793633
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 18"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9333373100626798e-08
	Radius		20.61916124066414

	RotationPeriod	3.1595820455390298

	Obliquity		70.76949169878388

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45382043955789975
		Eccentricity	0.1
		Inclination		2.9527674485725126
		AscendingNode	46.97155713516201
		ArgOfPericen	79.58804684271496
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 19"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2009122252690894e-07
	Radius		39.25771239518514

	RotationPeriod	4.7935225199255935

	Obliquity		304.741528799426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45376596769333427
		Eccentricity	0.1
		Inclination		-2.4182809334174453
		AscendingNode	65.11031961909276
		ArgOfPericen	175.98150249150606
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 19.1"
{
	ParentBody	"Aeolus B 19"
	Class		"Asteroid"
	Mass		1.2482220694662377e-09
	Radius		8.567455407985745

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.645854930267764e-06
		Eccentricity	0.003193926044930958
		Inclination		48.3074742147162
		AscendingNode	331.0740908222686
		ArgOfPericen	328.9686261645281
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 20"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.077087346933519e-08
	Radius		34.28546900881606

	RotationPeriod	8.169465553012591

	Obliquity		355.5247063294027

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45491456477413283
		Eccentricity	0.1
		Inclination		-0.6052646882208323
		AscendingNode	317.69219815371446
		ArgOfPericen	164.47990998209883
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 21"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.446483418602919e-07
	Radius		41.912086584699196

	RotationPeriod	6.192674063041579

	Obliquity		335.6152031736603

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4520109470972911
		Eccentricity	0.1
		Inclination		0.48717444258413023
		AscendingNode	253.62380822875681
		ArgOfPericen	239.31280636120593
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 22"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8992275640743477e-07
	Radius		43.37861975881236

	RotationPeriod	2.2101304123175844

	Obliquity		132.02622703334254

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4570261980909577
		Eccentricity	0.1
		Inclination		0.48778099489065196
		AscendingNode	345.07037236752143
		ArgOfPericen	55.38957174050142
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 23"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1582390237726793e-07
	Radius		37.57450741422777

	RotationPeriod	1.5520294820312497

	Obliquity		335.5267250013171

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45511660012722954
		Eccentricity	0.1
		Inclination		-1.147454162382566
		AscendingNode	165.5318659842989
		ArgOfPericen	326.85752540033616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 24"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.03317666829636e-08
	Radius		31.971929055541867

	RotationPeriod	5.755128773577072

	Obliquity		247.9653846575245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4554289393601065
		Eccentricity	0.1
		Inclination		-1.8952602408537975
		AscendingNode	123.9975572590526
		ArgOfPericen	136.4959536032211
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 25"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1503932476512846e-07
	Radius		36.506208658861595

	RotationPeriod	6.776614949706004

	Obliquity		53.2924838115374

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4556388009312129
		Eccentricity	0.1
		Inclination		-3.0839846166612324
		AscendingNode	268.28219590734227
		ArgOfPericen	233.43537380213968
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 26"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4560891457417787
		Eccentricity	0.1
		Inclination		-0.10277560510428255
		AscendingNode	60.96488541325846
		ArgOfPericen	54.59841112951168
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 26 A"
{
	ParentBody	"Aeolus B 26"
	Class		"Asteroid"
	Mass		1.743485012996324e-08
	Radius		18.86473160886486

	Orbit
	{
		Epoch			2457395.5
		Period			0.006055959304386017
		Eccentricity	0.001279705413338441
		Inclination		50.5407757181701
		AscendingNode	100.23286708606847
		ArgOfPericen	73.691732914201
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 26 B"
{
	ParentBody	"Aeolus B 26"
	Class		"Asteroid"
	Mass		9.027629482000587e-09
	Radius		15.148482633012936

	Orbit
	{
		Epoch			2457395.5
		Period			0.006055959304386017
		Eccentricity	0.001279705413338441
		Inclination		50.5407757181701
		AscendingNode	100.23286708606847
		ArgOfPericen	253.691732914201
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 27"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4523533689917256
		Eccentricity	0.1
		Inclination		-0.18822941617161518
		AscendingNode	224.87126276758204
		ArgOfPericen	287.0200485396586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 27 A"
{
	ParentBody	"Aeolus B 27"
	Class		"Asteroid"
	Mass		2.795503698302858e-07
	Radius		52.019299084105626

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017159241782985404
		Eccentricity	0.00635314053375175
		Inclination		157.12041958491815
		AscendingNode	261.9282602246273
		ArgOfPericen	169.5884825462832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 27 B"
{
	ParentBody	"Aeolus B 27"
	Class		"Asteroid"
	Mass		1.462813599574872e-07
	Radius		41.91866749067926

	Orbit
	{
		Epoch			2457395.5
		Period			0.0017159241782985404
		Eccentricity	0.00635314053375175
		Inclination		157.12041958491815
		AscendingNode	261.9282602246273
		ArgOfPericen	349.5884825462832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 28"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.894298731153037e-07
	Radius		70.43816759706895

	RotationPeriod	4.086406893361746

	Obliquity		112.23834004466072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4542035693867396
		Eccentricity	0.1
		Inclination		0.2634799613572475
		AscendingNode	19.448100969009424
		ArgOfPericen	68.40919208027128
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 28.1"
{
	ParentBody	"Aeolus B 28"
	Class		"Asteroid"
	Mass		3.3114580885817356e-09
	Radius		11.884596407173069

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5493263578254334e-06
		Eccentricity	0.004094142947938412
		Inclination		-4.125209326595785
		AscendingNode	81.937505237156
		ArgOfPericen	317.3128932208187
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 29"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0065835872445058e-07
	Radius		35.81044433299879

	RotationPeriod	4.5404118776042415

	Obliquity		209.30674360962766

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4555927039670052
		Eccentricity	0.1
		Inclination		1.0377180919242426
		AscendingNode	177.54392580122422
		ArgOfPericen	88.42358613357781
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 30"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4082584678290694e-06
	Radius		85.59548783717833

	RotationPeriod	6.986634299936719

	Obliquity		232.4092672991422

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4556872452215722
		Eccentricity	0.1
		Inclination		-1.6940089890265952
		AscendingNode	45.397451530057864
		ArgOfPericen	352.40229833590644
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 30.1"
{
	ParentBody	"Aeolus B 30"
	Class		"Asteroid"
	Mass		1.1160291437910422e-09
	Radius		7.921034891118571

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.343968132398536e-07
		Eccentricity	0.006809908254356808
		Inclination		-37.466211453441716
		AscendingNode	91.68673916988851
		ArgOfPericen	148.84537171308097
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 31"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.043506454939196e-07
	Radius		58.104939535346944

	RotationPeriod	3.481892787108949

	Obliquity		320.92984252947156

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45696137237216666
		Eccentricity	0.1
		Inclination		-2.64307677294706
		AscendingNode	188.2422667013556
		ArgOfPericen	169.14591167370577
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 32"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3437076217880274e-07
	Radius		45.611309149409934

	RotationPeriod	5.7494162954781

	Obliquity		27.825443189862682

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4504977604013534
		Eccentricity	0.1
		Inclination		-1.1002521354518005
		AscendingNode	183.45257798301557
		ArgOfPericen	234.30911881820268
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 33"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.729768522357751e-08
	Radius		29.378194057807768

	RotationPeriod	6.964581173525116

	Obliquity		287.06737154817273

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45
		Eccentricity	0.1
		Inclination		-2.8119763709240746
		AscendingNode	212.53127260140067
		ArgOfPericen	25.67384742431896
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 33.1"
{
	ParentBody	"Aeolus B 33"
	Class		"Asteroid"
	Mass		9.627651983706871e-11
	Radius		3.492632282641879

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.560234347968449e-07
		Eccentricity	0.0046732098303525925
		Inclination		-7.203232099543411
		AscendingNode	182.16308757689512
		ArgOfPericen	313.11993860634897
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 34"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.6971097729693787e-07
	Radius		65.4764805718866

	RotationPeriod	7.300444068421556

	Obliquity		90.68754812382639

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45667176119595093
		Eccentricity	0.1
		Inclination		0.45362461545109173
		AscendingNode	104.90966834870741
		ArgOfPericen	150.03959761817742
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 35"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.821496190763555e-07
	Radius		57.534862571201415

	RotationPeriod	4.650555724758485

	Obliquity		238.84252063353293

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4544069534625253
		Eccentricity	0.1
		Inclination		-2.126001793094496
		AscendingNode	259.4088552682076
		ArgOfPericen	120.08048867097183
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 36"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.762915536665351e-07
	Radius		51.192224603557165

	RotationPeriod	8.578374333933974

	Obliquity		342.35436239757297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45433395612498595
		Eccentricity	0.1
		Inclination		-1.122721798317151
		AscendingNode	359.8780355006634
		ArgOfPericen	219.72428074258892
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 37"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.970669945562408e-07
	Radius		61.96648898527586

	RotationPeriod	7.437774100301548

	Obliquity		267.67742402852195

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4551930420746268
		Eccentricity	0.1
		Inclination		-0.7377011500630045
		AscendingNode	56.33413564987792
		ArgOfPericen	43.59126811969341
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 38"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.753698127243674e-07
	Radius		56.35010423761058

	RotationPeriod	4.671785846307291

	Obliquity		287.0981823326444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45498549114684655
		Eccentricity	0.1
		Inclination		0.823727513842376
		AscendingNode	258.2647912742766
		ArgOfPericen	280.22349601615235
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 39"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.08389189074059e-08
	Radius		31.452528635744578

	RotationPeriod	4.850314053190962

	Obliquity		164.4724963570843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4562046385726731
		Eccentricity	0.1
		Inclination		1.5280453678443076
		AscendingNode	213.63604072149914
		ArgOfPericen	268.0971030760476
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 40"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.583784497508931e-07
	Radius		48.06426799717818

	RotationPeriod	2.624626780386115

	Obliquity		98.92934830781046

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4541617391930203
		Eccentricity	0.1
		Inclination		-0.2099417777835582
		AscendingNode	22.52897029246164
		ArgOfPericen	211.74926462189092
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 40.1"
{
	ParentBody	"Aeolus B 40"
	Class		"Asteroid"
	Mass		2.4492629286983774e-09
	Radius		10.172211299893874

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.593054089787535e-06
		Eccentricity	0.0036004675567247995
		Inclination		-8.780801562084743
		AscendingNode	129.68528420246432
		ArgOfPericen	86.7829261889805
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 41"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.047354629588439e-08
	Radius		34.106223517122416

	RotationPeriod	3.4743999509043166

	Obliquity		39.68957555777993

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45441502985704124
		Eccentricity	0.1
		Inclination		-1.6030766476479947
		AscendingNode	247.7681669256975
		ArgOfPericen	347.31476932872545
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 42"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0500040230244492e-07
	Radius		46.48316578077889

	RotationPeriod	7.415710768378198

	Obliquity		244.41460868839877

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.454817913432401
		Eccentricity	0.1
		Inclination		1.2306810176028113
		AscendingNode	32.97249691257862
		ArgOfPericen	296.1280473965516
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 43"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.397175673330439e-07
	Radius		46.62504293254246

	RotationPeriod	5.339871656322353

	Obliquity		257.93580545962567

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45419905522420484
		Eccentricity	0.1
		Inclination		2.508327168223709
		AscendingNode	94.2002770194472
		ArgOfPericen	264.07145680688467
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 43.1"
{
	ParentBody	"Aeolus B 43"
	Class		"Asteroid"
	Mass		4.280518555530537e-10
	Radius		5.656547244531792

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8455820315439005e-06
		Eccentricity	0.00072993720339928
		Inclination		17.76229319607675
		AscendingNode	250.79788800678
		ArgOfPericen	202.01267571884736
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 43.2"
{
	ParentBody	"Aeolus B 43"
	Class		"Asteroid"
	Mass		2.3451380058871765e-10
	Radius		4.628519443507072

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.326499351841151e-06
		Eccentricity	0.001176667118090096
		Inclination		5.915761085048082
		AscendingNode	131.02544539147357
		ArgOfPericen	250.41786531708948
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 43.3"
{
	ParentBody	"Aeolus B 43"
	Class		"Asteroid"
	Mass		1.9431431948974365e-09
	Radius		9.366001567094724

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.103348925428361e-06
		Eccentricity	0.005237002307122324
		Inclination		26.61063166397299
		AscendingNode	44.49256004576707
		ArgOfPericen	241.9796530996366
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 44"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.121868175462761e-07
	Radius		69.83687757771001

	RotationPeriod	4.638951273180863

	Obliquity		86.66106509174246

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45558825258939
		Eccentricity	0.1
		Inclination		0.7980103903554624
		AscendingNode	94.29443177496925
		ArgOfPericen	228.03700693894166
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 45"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.012641526374738e-07
	Radius		49.91219535380103

	RotationPeriod	6.941672264352275

	Obliquity		110.67410431152652

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45442432302781477
		Eccentricity	0.1
		Inclination		0.5313311975159438
		AscendingNode	103.24076294608244
		ArgOfPericen	33.39489020584499
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 45.1"
{
	ParentBody	"Aeolus B 45"
	Class		"Asteroid"
	Mass		3.243059977142893e-10
	Radius		5.115355800136324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.692510219751667e-07
		Eccentricity	0.006170757429006581
		Inclination		15.830388173745952
		AscendingNode	199.6713165686195
		ArgOfPericen	175.16623686528368
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 46"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.294007158948028e-07
	Radius		60.93079328086206

	RotationPeriod	8.747118934393344

	Obliquity		73.94467049498667

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45189589293822185
		Eccentricity	0.1
		Inclination		-2.6480765283717713
		AscendingNode	253.57818996215758
		ArgOfPericen	142.64130340731066
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 47"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0014611569577325e-07
	Radius		36.19465012817603

	RotationPeriod	3.1502672172574933

	Obliquity		173.65802545127923

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4572226636131753
		Eccentricity	0.1
		Inclination		1.715777835993346
		AscendingNode	62.76298530758682
		ArgOfPericen	120.31910370217084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 48"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4811023629676707e-07
	Radius		47.34379757692391

	RotationPeriod	6.053575171033127

	Obliquity		152.9279670029725

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4563600774371801
		Eccentricity	0.1
		Inclination		1.6212026499131214
		AscendingNode	323.86588523929487
		ArgOfPericen	61.50275370313386
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 49"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.797594492483109e-07
	Radius		57.25690538852209

	RotationPeriod	4.053143913079491

	Obliquity		179.6508497577019

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45657022419523635
		Eccentricity	0.1
		Inclination		-0.7863521306116636
		AscendingNode	88.46153219793582
		ArgOfPericen	59.48264317487355
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 50"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.6433604590663e-08
	Radius		33.44334019802098

	RotationPeriod	9.1677391732045

	Obliquity		284.4457063185419

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45303546133483413
		Eccentricity	0.1
		Inclination		-1.9677964049394785
		AscendingNode	190.27037897158422
		ArgOfPericen	70.36115840105347
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 51"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.587698967380073e-08
	Radius		37.87245256646192

	RotationPeriod	4.441390950945435

	Obliquity		200.80706159441667

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45502192640921807
		Eccentricity	0.1
		Inclination		1.4419347703865817
		AscendingNode	265.3605700957266
		ArgOfPericen	46.31140548618207
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 52"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.824684822726668e-07
	Radius		73.96413030530837

	RotationPeriod	7.097184564278337

	Obliquity		330.30854527854353

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45522334968159145
		Eccentricity	0.1
		Inclination		1.041703723204692
		AscendingNode	85.123549477008
		ArgOfPericen	289.8077685992811
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 53"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.319536034130834e-08
	Radius		36.45047418175008

	RotationPeriod	6.4137110505515285

	Obliquity		103.42286676461005

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45648647106872975
		Eccentricity	0.1
		Inclination		0.34918380076201955
		AscendingNode	353.3551684641121
		ArgOfPericen	310.48466445676274
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 54"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.168190826815842e-07
	Radius		65.5321585281981

	RotationPeriod	4.48182325033941

	Obliquity		353.21884601230687

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4553034309032503
		Eccentricity	0.1
		Inclination		0.6947875847935503
		AscendingNode	144.32430387814014
		ArgOfPericen	126.65066046866322
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 54.1"
{
	ParentBody	"Aeolus B 54"
	Class		"Asteroid"
	Mass		4.381904142626047e-09
	Radius		12.597648807347003

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.16643898058478e-06
		Eccentricity	0.006360183580678348
		Inclination		-36.99794123299592
		AscendingNode	194.8846618882449
		ArgOfPericen	299.8522450776556
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 55"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.3173107120670366e-07
	Radius		56.03342397231294

	RotationPeriod	7.233364910126106

	Obliquity		53.07154286275035

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4543587891977677
		Eccentricity	0.1
		Inclination		0.6817648233821981
		AscendingNode	128.22686920008337
		ArgOfPericen	67.7278264330924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 55.1"
{
	ParentBody	"Aeolus B 55"
	Class		"Asteroid"
	Mass		4.273454938094738e-09
	Radius		13.135445912289832

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.8050446321217847e-06
		Eccentricity	0.005232307616551831
		Inclination		47.52209765957266
		AscendingNode	304.02887590316374
		ArgOfPericen	97.48887659317151
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 56"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.191726760918889e-08
	Radius		33.92185946469853

	RotationPeriod	4.575486403344435

	Obliquity		329.51038295119133

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4545719522290673
		Eccentricity	0.1
		Inclination		1.28899758981281
		AscendingNode	34.70770679632554
		ArgOfPericen	85.32561786297097
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 56.1"
{
	ParentBody	"Aeolus B 56"
	Class		"Asteroid"
	Mass		1.2658520338801418e-09
	Radius		8.130955731240393

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.1310172004854733e-06
		Eccentricity	0.0036140421226079225
		Inclination		8.922847156970063
		AscendingNode	323.39365681921646
		ArgOfPericen	168.4108024005915
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 57"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.807730349019314e-07
	Radius		57.57995186492049

	RotationPeriod	2.792431238481872

	Obliquity		136.56123556216184

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45556659918335773
		Eccentricity	0.1
		Inclination		-1.1446960261809744
		AscendingNode	253.6715259204297
		ArgOfPericen	148.2880277740125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 58"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2049372161720327e-08
	Radius		18.435544792213488

	RotationPeriod	3.689600226525953

	Obliquity		315.4769164838457

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45571003797257864
		Eccentricity	0.1
		Inclination		-2.6767718496173427
		AscendingNode	123.31059775847035
		ArgOfPericen	174.69350706280593
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 59"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.904689892205427e-07
	Radius		61.213454971096965

	RotationPeriod	6.645295425808784

	Obliquity		340.8250018418395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4526125604837193
		Eccentricity	0.1
		Inclination		0.21773768080848407
		AscendingNode	235.81380084306716
		ArgOfPericen	282.84054351979637
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 60"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.679595735409795e-07
	Radius		63.589573181773915

	RotationPeriod	7.865584526625995

	Obliquity		341.0672327197868

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4561817620015717
		Eccentricity	0.1
		Inclination		-0.28902915629502
		AscendingNode	256.2667127617153
		ArgOfPericen	158.04204244929892
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 61"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.885672067336764e-07
	Radius		61.91275177679696

	RotationPeriod	6.850969572170964

	Obliquity		317.19022633815

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45527404813399097
		Eccentricity	0.1
		Inclination		-3.126927899241879
		AscendingNode	130.23831484189762
		ArgOfPericen	356.35101416771954
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 61.1"
{
	ParentBody	"Aeolus B 61"
	Class		"Asteroid"
	Mass		5.234832528865962e-10
	Radius		5.954093966407145

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.001714975691299e-06
		Eccentricity	0.004487860529697796
		Inclination		-39.55816524029927
		AscendingNode	301.06274914006667
		ArgOfPericen	327.07765136693826
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 62"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.669332851728815e-07
	Radius		68.59520392721828

	RotationPeriod	4.98305837126491

	Obliquity		5.085852972056646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45260657091360507
		Eccentricity	0.1
		Inclination		0.664652557312002
		AscendingNode	24.673287386211236
		ArgOfPericen	80.43512923731278
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 63"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.2580586217757405e-07
	Radius		59.45581951752477

	RotationPeriod	7.335654685545713

	Obliquity		72.59834010981194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45643909827444806
		Eccentricity	0.1
		Inclination		-0.5495309601244921
		AscendingNode	249.05178597294807
		ArgOfPericen	66.92411996242778
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 64"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8624831523915813e-07
	Radius		44.47766263459914

	RotationPeriod	4.189651113699325

	Obliquity		13.806763529870047

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45490404422082614
		Eccentricity	0.1
		Inclination		0.05385142070486924
		AscendingNode	144.31580573582994
		ArgOfPericen	116.03730647722303
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 65"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4563844202383494
		Eccentricity	0.1
		Inclination		-0.3527015560337001
		AscendingNode	65.52070671806416
		ArgOfPericen	6.893139691777659
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 65 A"
{
	ParentBody	"Aeolus B 65"
	Class		"Asteroid"
	Mass		6.701266266957426e-08
	Radius		34.26661191578226

	Orbit
	{
		Epoch			2457395.5
		Period			0.003657467296564142
		Eccentricity	0.006918160187831951
		Inclination		4.6585994456406254
		AscendingNode	54.05104546375478
		ArgOfPericen	159.98024563424042
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 65 B"
{
	ParentBody	"Aeolus B 65"
	Class		"Asteroid"
	Mass		4.3237331021398224e-09
	Radius		13.743747481400016

	Orbit
	{
		Epoch			2457395.5
		Period			0.003657467296564142
		Eccentricity	0.006918160187831951
		Inclination		4.6585994456406254
		AscendingNode	54.05104546375478
		ArgOfPericen	339.9802456342404
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 66"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0222036122139186e-07
	Radius		36.95379903494056

	RotationPeriod	4.0289348901331525

	Obliquity		1.8414376849489944

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4555232040247005
		Eccentricity	0.1
		Inclination		1.4584855863417376
		AscendingNode	79.40306004924865
		ArgOfPericen	103.89351781298814
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 66.1"
{
	ParentBody	"Aeolus B 66"
	Class		"Asteroid"
	Mass		1.4204495062880161e-09
	Radius		8.884272870496112

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.957700864874899e-06
		Eccentricity	0.0045948212090738735
		Inclination		-39.5610585218192
		AscendingNode	153.6737384424844
		ArgOfPericen	20.50241175974928
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 67"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.8183367404578575e-07
	Radius		48.860535145460894

	RotationPeriod	3.810318906938933

	Obliquity		3.112759892224628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45714421807623956
		Eccentricity	0.1
		Inclination		1.3396539108017405
		AscendingNode	74.60115179955561
		ArgOfPericen	299.3953244011074
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 67.1"
{
	ParentBody	"Aeolus B 67"
	Class		"Asteroid"
	Mass		8.328638480045943e-10
	Radius		7.0116236234411025

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.408813394944506e-06
		Eccentricity	0.0037608760291942757
		Inclination		-39.66341803590589
		AscendingNode	107.65771665649496
		ArgOfPericen	32.97517096913924
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 68"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.104689061127456e-08
	Radius		29.940193790459777

	RotationPeriod	5.27976645805642

	Obliquity		16.19276856048218

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4551673384410469
		Eccentricity	0.1
		Inclination		1.3137213670371855
		AscendingNode	276.5932625505433
		ArgOfPericen	206.78870944080407
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 69"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1751949003244262e-08
	Radius		17.874754408855587

	RotationPeriod	9.336496789798316

	Obliquity		350.5921495119984

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4571108774949373
		Eccentricity	0.1
		Inclination		1.567374678507348
		AscendingNode	84.20256501685225
		ArgOfPericen	49.94182984333996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 70"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.748325131944571e-07
	Radius		71.737310880078

	RotationPeriod	6.487022394080202

	Obliquity		104.42584623617276

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45493770654001875
		Eccentricity	0.1
		Inclination		-0.2603548418799106
		AscendingNode	161.4435706732708
		ArgOfPericen	63.017894295621765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 71"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.626311420208472e-08
	Radius		26.731860092340362

	RotationPeriod	4.138531978147251

	Obliquity		165.2188249418175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45186707851840663
		Eccentricity	0.1
		Inclination		-0.009351287452979628
		AscendingNode	356.34818687906164
		ArgOfPericen	323.7799563872674
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 72"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5020336782120875e-07
	Radius		50.422525533416355

	RotationPeriod	6.640670602277782

	Obliquity		146.05472041411255

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45537276059282755
		Eccentricity	0.1
		Inclination		-1.21597095880522
		AscendingNode	318.3952895274545
		ArgOfPericen	135.50093016242928
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 73"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.419475018902028e-07
	Radius		59.87821198826427

	RotationPeriod	6.028835026004674

	Obliquity		141.82875988040405

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4583799760747418
		Eccentricity	0.1
		Inclination		-2.552139131293337
		AscendingNode	280.2311779776836
		ArgOfPericen	77.57838730555666
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 73.1"
{
	ParentBody	"Aeolus B 73"
	Class		"Asteroid"
	Mass		2.87990381183389e-10
	Radius		4.850007514082388

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.634023743670744e-06
		Eccentricity	0.0046681219284712
		Inclination		22.06558696765204
		AscendingNode	267.2537260629465
		ArgOfPericen	336.27408977704994
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 74"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.087784867150222e-07
	Radius		60.807170650313125

	RotationPeriod	3.3360306721084316

	Obliquity		325.7935429006449

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4540677437395851
		Eccentricity	0.1
		Inclination		0.1706366988236176
		AscendingNode	272.43492710176554
		ArgOfPericen	26.690734727366777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 75"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.00674170632165e-07
	Radius		52.53474984396357

	RotationPeriod	4.999148948707166

	Obliquity		112.52641527144392

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4549146667868885
		Eccentricity	0.1
		Inclination		0.5987886187715553
		AscendingNode	258.236220124748
		ArgOfPericen	233.07144322018874
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 76"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4938420592438775e-08
	Radius		18.481595497565518

	RotationPeriod	6.110451905393584

	Obliquity		298.13263879056205

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45464041722362625
		Eccentricity	0.1
		Inclination		0.326317906285673
		AscendingNode	219.52619698185393
		ArgOfPericen	256.0252397838694
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 77"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.30196865302426e-08
	Radius		37.28393662279097

	RotationPeriod	3.502908309867405

	Obliquity		251.4325092607483

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45585003279659564
		Eccentricity	0.1
		Inclination		1.9383958159541748
		AscendingNode	31.954836169027004
		ArgOfPericen	89.07037350920004
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 77.1"
{
	ParentBody	"Aeolus B 77"
	Class		"Asteroid"
	Mass		3.8343447812279677e-10
	Radius		5.97806350754121

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.351376103335917e-06
		Eccentricity	0.0003647779291307456
		Inclination		45.667816649079676
		AscendingNode	307.59336745292575
		ArgOfPericen	52.840536057976294
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 78"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45336152364144683
		Eccentricity	0.1
		Inclination		-0.3028429387455888
		AscendingNode	164.01667842651713
		ArgOfPericen	149.88097340891804
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 78 A"
{
	ParentBody	"Aeolus B 78"
	Class		"Asteroid"
	Mass		1.6659240671888348e-07
	Radius		41.758392943701914

	Orbit
	{
		Epoch			2457395.5
		Period			0.006838093551311752
		Eccentricity	0.003575171832884261
		Inclination		30.25145125490826
		AscendingNode	74.01713846566099
		ArgOfPericen	44.075600408376474
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 78 B"
{
	ParentBody	"Aeolus B 78"
	Class		"Asteroid"
	Mass		1.2655029660170962e-08
	Radius		17.68532716404247

	Orbit
	{
		Epoch			2457395.5
		Period			0.006838093551311752
		Eccentricity	0.003575171832884261
		Inclination		30.25145125490826
		AscendingNode	74.01713846566099
		ArgOfPericen	224.0756004083765
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 79"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.983842167656216e-07
	Radius		76.41767718696158

	RotationPeriod	8.193204054218665

	Obliquity		50.680239163837896

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4566861207549145
		Eccentricity	0.1
		Inclination		-0.024066290535569034
		AscendingNode	157.6790933605734
		ArgOfPericen	46.48607611370129
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 80"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4548299879504088
		Eccentricity	0.1
		Inclination		-2.019686338931765
		AscendingNode	14.606794069787128
		ArgOfPericen	300.5300826000099
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 80 A"
{
	ParentBody	"Aeolus B 80"
	Class		"Asteroid"
	Mass		6.810920710895908e-08
	Radius		32.222351960191425

	Orbit
	{
		Epoch			2457395.5
		Period			0.003429691800580966
		Eccentricity	0.0037532482683008076
		Inclination		289.8112575886444
		AscendingNode	168.62551153537385
		ArgOfPericen	92.5641400770385
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 80 B"
{
	ParentBody	"Aeolus B 80"
	Class		"Asteroid"
	Mass		4.2617802592247794e-08
	Radius		27.560408266531265

	Orbit
	{
		Epoch			2457395.5
		Period			0.003429691800580966
		Eccentricity	0.0037532482683008076
		Inclination		289.8112575886444
		AscendingNode	168.62551153537385
		ArgOfPericen	272.5641400770385
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 81"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.011302116955856e-08
	Radius		32.49977950710896

	RotationPeriod	5.040290132775851

	Obliquity		349.5164541373454

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.457346542171628
		Eccentricity	0.1
		Inclination		-1.357744535139286
		AscendingNode	220.7617615122264
		ArgOfPericen	159.30083398004942
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 82"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3349142054306234e-07
	Radius		40.659319149006706

	RotationPeriod	4.802076210527475

	Obliquity		79.62892779090866

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4561725458212875
		Eccentricity	0.1
		Inclination		-0.12397697445425875
		AscendingNode	291.8299846915956
		ArgOfPericen	247.11456466498663
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 82.1"
{
	ParentBody	"Aeolus B 82"
	Class		"Asteroid"
	Mass		3.563955048952024e-10
	Radius		5.640527527344755

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9108720154905915e-06
		Eccentricity	0.004823603192842679
		Inclination		-36.16943477522894
		AscendingNode	345.14853306102776
		ArgOfPericen	61.76340548959373
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 82.2"
{
	ParentBody	"Aeolus B 82"
	Class		"Asteroid"
	Mass		1.2727581264696128e-10
	Radius		4.001820549437647

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.003658014263687e-06
		Eccentricity	0.00554845075988915
		Inclination		17.72338452627134
		AscendingNode	18.29248533401051
		ArgOfPericen	17.977865720034604
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 83"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.896368746304684e-07
	Radius		50.84782804057285

	RotationPeriod	6.160212935411432

	Obliquity		314.57744278113154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4560009942625573
		Eccentricity	0.1
		Inclination		0.2171402482799853
		AscendingNode	313.82727587392424
		ArgOfPericen	58.126618281143266
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 84"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2089265928317956e-07
	Radius		37.23118891687735

	RotationPeriod	3.0605976193534623

	Obliquity		274.57174729557886

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4578615150259415
		Eccentricity	0.1
		Inclination		-1.513426101736079
		AscendingNode	326.98927562771604
		ArgOfPericen	83.9399779980367
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 85"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.815533373990696e-07
	Radius		70.4540714602162

	RotationPeriod	7.267812089120356

	Obliquity		322.7851127011638

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45390519440808447
		Eccentricity	0.1
		Inclination		-0.8302796860778232
		AscendingNode	214.23840673872922
		ArgOfPericen	100.62839966175642
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 86"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45550521873580363
		Eccentricity	0.1
		Inclination		-0.7409927314363205
		AscendingNode	103.51141727394067
		ArgOfPericen	321.22432653023384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 86 A"
{
	ParentBody	"Aeolus B 86"
	Class		"Asteroid"
	Mass		2.2025624142240396e-07
	Radius		48.99290607830029

	Orbit
	{
		Epoch			2457395.5
		Period			0.0004682876337893984
		Eccentricity	0.0056211576942454215
		Inclination		234.45101120378658
		AscendingNode	57.83148991604294
		ArgOfPericen	171.4646126475585
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 86 B"
{
	ParentBody	"Aeolus B 86"
	Class		"Asteroid"
	Mass		1.9040392103217486e-08
	Radius		21.662858131171117

	Orbit
	{
		Epoch			2457395.5
		Period			0.0004682876337893984
		Eccentricity	0.0056211576942454215
		Inclination		234.45101120378658
		AscendingNode	57.83148991604294
		ArgOfPericen	351.4646126475585
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 87"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.269919915628364e-07
	Radius		64.40474455531096

	RotationPeriod	7.2222547673875415

	Obliquity		117.18300752643945

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45504785338741816
		Eccentricity	0.1
		Inclination		-0.31584212308258314
		AscendingNode	145.755819791701
		ArgOfPericen	180.4974586899599
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 88"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.5276878874328003e-07
	Radius		59.49150684381763

	RotationPeriod	4.8885842417068215

	Obliquity		146.9559741289887

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4532116530380507
		Eccentricity	0.1
		Inclination		2.1014986397072795
		AscendingNode	131.7932520704178
		ArgOfPericen	13.162566208620326
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 89"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4549701219570675
		Eccentricity	0.1
		Inclination		0.03238840276009656
		AscendingNode	266.7466585371458
		ArgOfPericen	144.05302358054954
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 89 A"
{
	ParentBody	"Aeolus B 89"
	Class		"Asteroid"
	Mass		2.76590604903125e-07
	Radius		50.196172109404344

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037504657001617477
		Eccentricity	0.005043960194539773
		Inclination		133.43023405105896
		AscendingNode	183.15494721813744
		ArgOfPericen	225.79610915450453
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 89 B"
{
	ParentBody	"Aeolus B 89"
	Class		"Asteroid"
	Mass		1.2558704549450053e-08
	Radius		17.907697084552936

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037504657001617477
		Eccentricity	0.005043960194539773
		Inclination		133.43023405105896
		AscendingNode	183.15494721813744
		ArgOfPericen	45.79610915450451
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 90"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.795096389001101e-07
	Radius		50.089753045832545

	RotationPeriod	5.370136050857964

	Obliquity		176.9289448924804

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45453712417530706
		Eccentricity	0.1
		Inclination		0.9716460044750003
		AscendingNode	327.85287295988485
		ArgOfPericen	215.65403871525132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 90.1"
{
	ParentBody	"Aeolus B 90"
	Class		"Asteroid"
	Mass		7.16437727745348e-10
	Radius		6.855031320463604

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.8161591495428085e-06
		Eccentricity	0.006350212251942381
		Inclination		-39.45258009897533
		AscendingNode	310.0826948068814
		ArgOfPericen	257.35112402940734
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 91"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.452718728946162e-07
	Radius		66.22525885652672

	RotationPeriod	6.007790002938456

	Obliquity		289.37961475674615

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4551851303180194
		Eccentricity	0.1
		Inclination		2.1947355758853444
		AscendingNode	34.30223102455494
		ArgOfPericen	6.878255823100479
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 92"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.452579425841539
		Eccentricity	0.1
		Inclination		-0.4118628047549229
		AscendingNode	170.54678435618953
		ArgOfPericen	248.25810265654388
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 92 A"
{
	ParentBody	"Aeolus B 92"
	Class		"Asteroid"
	Mass		1.3214798693700606e-07
	Radius		42.44632301747003

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033357971511811615
		Eccentricity	0.005017191776532079
		Inclination		358.6624684163209
		AscendingNode	293.35755838800765
		ArgOfPericen	67.1631728943087
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 92 B"
{
	ParentBody	"Aeolus B 92"
	Class		"Asteroid"
	Mass		2.257579984870937e-08
	Radius		23.552351426662433

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033357971511811615
		Eccentricity	0.005017191776532079
		Inclination		358.6624684163209
		AscendingNode	293.35755838800765
		ArgOfPericen	247.1631728943087
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 93"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.3240371284752063e-07
	Radius		52.66796501614255

	RotationPeriod	6.902971961509771

	Obliquity		79.43899845897381

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4577096739886567
		Eccentricity	0.1
		Inclination		-1.1027362936151421
		AscendingNode	107.24639026674659
		ArgOfPericen	17.236011987608634
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 94"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9980224472632443e-08
	Radius		21.223730376071295

	RotationPeriod	9.062831278651531

	Obliquity		289.49555393415346

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4546423979345853
		Eccentricity	0.1
		Inclination		1.5170393382616418
		AscendingNode	198.49542062498762
		ArgOfPericen	288.7761120160147
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 94.1"
{
	ParentBody	"Aeolus B 94"
	Class		"Asteroid"
	Mass		1.7749937489843258e-10
	Radius		4.395624055004285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6437547950745856e-06
		Eccentricity	0.005022283378661011
		Inclination		15.53226737482693
		AscendingNode	23.865555067523616
		ArgOfPericen	43.10610983330883
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 94.2"
{
	ParentBody	"Aeolus B 94"
	Class		"Asteroid"
	Mass		1.0043604850805159e-11
	Radius		1.6875298799753007

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.8436042580441903e-06
		Eccentricity	0.004286971146809622
		Inclination		1.5736130330829614
		AscendingNode	70.51851119976902
		ArgOfPericen	215.55009286152267
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 95"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4497396913105977e-07
	Radius		47.640717189578304

	RotationPeriod	7.233526092427225

	Obliquity		321.6179848228894

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45332886211945966
		Eccentricity	0.1
		Inclination		-1.461017676305348
		AscendingNode	65.27204340611509
		ArgOfPericen	111.1498202535208
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 96"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7831059749556783e-07
	Radius		44.26525899073898

	RotationPeriod	6.575405491885716

	Obliquity		302.96413288095874

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45604719405700556
		Eccentricity	0.1
		Inclination		1.039125510456874
		AscendingNode	207.9083008888048
		ArgOfPericen	1.3562077936943417
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 97"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.895008919657872e-07
	Radius		60.29236334115539

	RotationPeriod	2.337737597294916

	Obliquity		190.68789201273702

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45447821886885914
		Eccentricity	0.1
		Inclination		-1.6725493654797183
		AscendingNode	320.4098580456591
		ArgOfPericen	187.23550686277895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 98"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.383326623994748e-07
	Radius		61.09491964261107

	RotationPeriod	5.741258627777872

	Obliquity		99.2718622222804

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.455874909736858
		Eccentricity	0.1
		Inclination		-0.15802842844347156
		AscendingNode	202.69910258834201
		ArgOfPericen	33.42129119055331
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 99"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.139020753079465e-09
	Radius		16.68331265849143

	RotationPeriod	5.767971922096148

	Obliquity		150.2026820484863

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45392575978717825
		Eccentricity	0.1
		Inclination		1.7013228391484656
		AscendingNode	57.4179990097732
		ArgOfPericen	257.72365627162037
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 100"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0080204604026676e-06
	Radius		79.54661437944424

	RotationPeriod	8.101344998258249

	Obliquity		235.63990983648694

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45645426504663006
		Eccentricity	0.1
		Inclination		-1.068982527977622
		AscendingNode	59.676783682088086
		ArgOfPericen	116.60598588787776
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 101"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.716558325664248e-07
	Radius		67.2628164719552

	RotationPeriod	4.758978334524862

	Obliquity		128.83709299780853

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4515801165562424
		Eccentricity	0.1
		Inclination		2.9434635120953563
		AscendingNode	223.09570362325812
		ArgOfPericen	298.2649648265294
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 102"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.095799538601988e-07
	Radius		61.954773793366115

	RotationPeriod	3.660289957939811

	Obliquity		246.51445339308174

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4543470588651425
		Eccentricity	0.1
		Inclination		2.335130221946548
		AscendingNode	230.35301449040182
		ArgOfPericen	327.5177279218202
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 103"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.1676309363391847e-07
	Radius		46.8823995436759

	RotationPeriod	5.70253838888682

	Obliquity		182.3622608881229

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45437231878605655
		Eccentricity	0.1
		Inclination		0.01773433015517836
		AscendingNode	353.7973446865142
		ArgOfPericen	269.1686032933045
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 104"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.072562123122257e-08
	Radius		31.8400229834653

	RotationPeriod	7.481270343343573

	Obliquity		150.50197164253245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45409080287843945
		Eccentricity	0.1
		Inclination		1.5055684312014426
		AscendingNode	233.73394221536623
		ArgOfPericen	175.1244134884563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 105"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.509385611225063e-07
	Radius		57.21615675440974

	RotationPeriod	5.347239242501731

	Obliquity		314.0146830488178

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4581304419996405
		Eccentricity	0.1
		Inclination		-0.17638661640592154
		AscendingNode	144.25876291540362
		ArgOfPericen	257.4835741985028
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 106"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2867051901076995e-06
	Radius		79.27078521588045

	RotationPeriod	4.876281023459352

	Obliquity		270.54182397336996

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4573310109762116
		Eccentricity	0.1
		Inclination		1.2589861456250964
		AscendingNode	313.6343662217967
		ArgOfPericen	14.988077657014767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 107"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0421574138718867e-07
	Radius		35.61852547876299

	RotationPeriod	5.853416835164264

	Obliquity		204.7077310924723

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45245401117479606
		Eccentricity	0.1
		Inclination		-0.8474781564454578
		AscendingNode	207.04914292040573
		ArgOfPericen	325.8035357499089
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 107.1"
{
	ParentBody	"Aeolus B 107"
	Class		"Asteroid"
	Mass		6.987397233793547e-10
	Radius		6.7164013536019445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6864928529082687e-06
		Eccentricity	0.00642489508077952
		Inclination		46.735358460265104
		AscendingNode	161.75041508762286
		ArgOfPericen	40.10210399114642
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 107.2"
{
	ParentBody	"Aeolus B 107"
	Class		"Asteroid"
	Mass		1.5566796639316915e-10
	Radius		4.071595070797494

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4099690560174921e-06
		Eccentricity	0.0024118047299897514
		Inclination		33.13452897628625
		AscendingNode	209.99211411010268
		ArgOfPericen	307.30383509197134
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 108"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.437606967512916e-07
	Radius		52.420680653776195

	RotationPeriod	3.735451181502983

	Obliquity		350.3072882292786

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4546374835889722
		Eccentricity	0.1
		Inclination		-1.4782245585017377
		AscendingNode	21.880495755774447
		ArgOfPericen	42.95795319477939
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 109"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.395632718571501e-07
	Radius		64.86903793252205

	RotationPeriod	11.072363137199094

	Obliquity		213.50985084288487

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45346799184373393
		Eccentricity	0.1
		Inclination		-1.130660325839726
		AscendingNode	155.1180076367927
		ArgOfPericen	290.9044435755968
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 110"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5654713120362347e-07
	Radius		45.02748197568914

	RotationPeriod	4.931104434704002

	Obliquity		196.5337715777895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45405022296197767
		Eccentricity	0.1
		Inclination		1.5489485981209203
		AscendingNode	263.8094826498022
		ArgOfPericen	301.2249845524924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 111"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.454532874097801
		Eccentricity	0.1
		Inclination		0.04344485629983129
		AscendingNode	190.26835844220787
		ArgOfPericen	104.87395144366216
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 111 A"
{
	ParentBody	"Aeolus B 111"
	Class		"Asteroid"
	Mass		1.3152327579382617e-07
	Radius		40.30828758239602

	Orbit
	{
		Epoch			2457395.5
		Period			0.007967610665458341
		Eccentricity	0.005319157781417438
		Inclination		127.15672106878246
		AscendingNode	146.92331552923352
		ArgOfPericen	21.98204729885208
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 111 B"
{
	ParentBody	"Aeolus B 111"
	Class		"Asteroid"
	Mass		8.571400409453846e-08
	Radius		34.94706736848362

	Orbit
	{
		Epoch			2457395.5
		Period			0.007967610665458341
		Eccentricity	0.005319157781417438
		Inclination		127.15672106878246
		AscendingNode	146.92331552923352
		ArgOfPericen	201.98204729885208
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 112"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.850382907345859e-07
	Radius		64.72807195274856

	RotationPeriod	6.434916203201949

	Obliquity		291.4164108436729

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45400078023655543
		Eccentricity	0.1
		Inclination		-0.029945186219911154
		AscendingNode	268.116581763321
		ArgOfPericen	126.09302313656343
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 113"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.215205707840079e-06
	Radius		88.88318811557642

	RotationPeriod	6.991568100985667

	Obliquity		165.62692945776678

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45400268921299686
		Eccentricity	0.1
		Inclination		-0.7457071786103591
		AscendingNode	296.2894131365433
		ArgOfPericen	189.90395187013632
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 114"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4572996344752673
		Eccentricity	0.1
		Inclination		1.6428986894240813
		AscendingNode	283.2941880335246
		ArgOfPericen	293.8637910041752
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 114 A"
{
	ParentBody	"Aeolus B 114"
	Class		"Asteroid"
	Mass		9.779594262723256e-08
	Radius		36.407173848201275

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010337187869045627
		Eccentricity	0.003537329877781892
		Inclination		61.066745358742224
		AscendingNode	137.05027863714275
		ArgOfPericen	299.9193552382393
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 114 B"
{
	ParentBody	"Aeolus B 114"
	Class		"Asteroid"
	Mass		3.837172206735058e-09
	Radius		12.371350707685286

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010337187869045627
		Eccentricity	0.003537329877781892
		Inclination		61.066745358742224
		AscendingNode	137.05027863714275
		ArgOfPericen	119.91935523823929
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 115"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4598632330783192e-07
	Radius		40.15560372193728

	RotationPeriod	1.6256218830493987

	Obliquity		177.06706945079497

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4536800312943126
		Eccentricity	0.1
		Inclination		0.9859520873714042
		AscendingNode	166.49765330302614
		ArgOfPericen	277.4122020269083
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 116"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1150389251680242e-07
	Radius		38.749399821883145

	RotationPeriod	6.124226376541306

	Obliquity		315.5902016965998

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4559158012224073
		Eccentricity	0.1
		Inclination		-2.8215408176993266
		AscendingNode	215.75369000132815
		ArgOfPericen	78.3315861422744
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 117"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.767943995491619e-08
	Radius		34.44399579971173

	RotationPeriod	5.798117200291479

	Obliquity		1.7213697484618118

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4546970393410847
		Eccentricity	0.1
		Inclination		0.231653314084026
		AscendingNode	88.79064630496242
		ArgOfPericen	115.75743271481373
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 117.1"
{
	ParentBody	"Aeolus B 117"
	Class		"Asteroid"
	Mass		7.231974057135624e-10
	Radius		6.959316024947013

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.3351483712825486e-07
		Eccentricity	0.003746504087994944
		Inclination		36.85335672464063
		AscendingNode	0.36579892325906194
		ArgOfPericen	59.81198334448255
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 118"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45297532778239186
		Eccentricity	0.1
		Inclination		0.46248049775467587
		AscendingNode	348.0871995178314
		ArgOfPericen	218.60799503880853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 118 A"
{
	ParentBody	"Aeolus B 118"
	Class		"Asteroid"
	Mass		2.2869327404866968e-07
	Radius		45.74922594465563

	Orbit
	{
		Epoch			2457395.5
		Period			0.004146766875965168
		Eccentricity	0.005655335677985505
		Inclination		157.57993225856004
		AscendingNode	142.99518016725173
		ArgOfPericen	253.76849012820472
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 118 B"
{
	ParentBody	"Aeolus B 118"
	Class		"Asteroid"
	Mass		2.077085421477778e-08
	Radius		20.5644645302727

	Orbit
	{
		Epoch			2457395.5
		Period			0.004146766875965168
		Eccentricity	0.005655335677985505
		Inclination		157.57993225856004
		AscendingNode	142.99518016725173
		ArgOfPericen	73.76849012820469
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 119"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45908373184120677
		Eccentricity	0.1
		Inclination		-0.34958929865049637
		AscendingNode	121.01855363462107
		ArgOfPericen	268.9081152187304
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 119 A"
{
	ParentBody	"Aeolus B 119"
	Class		"Asteroid"
	Mass		1.302091446812488e-07
	Radius		42.49091303564121

	Orbit
	{
		Epoch			2457395.5
		Period			0.0043701209215224815
		Eccentricity	0.004780620657221518
		Inclination		216.3628142676584
		AscendingNode	316.3446706437173
		ArgOfPericen	351.82998673393894
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 119 B"
{
	ParentBody	"Aeolus B 119"
	Class		"Asteroid"
	Mass		1.2389950591948966e-08
	Radius		19.398676144968153

	Orbit
	{
		Epoch			2457395.5
		Period			0.0043701209215224815
		Eccentricity	0.004780620657221518
		Inclination		216.3628142676584
		AscendingNode	316.3446706437173
		ArgOfPericen	171.829986733939
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 120"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.67584680016175e-08
	Radius		30.39650195588874

	RotationPeriod	5.042653668147786

	Obliquity		64.43935522583229

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4559115756450727
		Eccentricity	0.1
		Inclination		2.8144250526287413
		AscendingNode	142.27757345109455
		ArgOfPericen	238.22848720370993
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 120.1"
{
	ParentBody	"Aeolus B 120"
	Class		"Asteroid"
	Mass		9.241605682017273e-12
	Radius		1.7705953850530067

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.995146236733713e-06
		Eccentricity	0.004865171313204654
		Inclination		29.905337023332883
		AscendingNode	161.4847907049181
		ArgOfPericen	327.2854606389052
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 120.2"
{
	ParentBody	"Aeolus B 120"
	Class		"Asteroid"
	Mass		6.824634506221542e-11
	Radius		3.4479687079778

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.6251184922821335e-07
		Eccentricity	0.006981406562800463
		Inclination		6.7300484819165725
		AscendingNode	302.0915750851791
		ArgOfPericen	291.0170158046371
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 121"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.2113061022619765e-07
	Radius		45.84934856087212

	RotationPeriod	6.594181457046757

	Obliquity		148.1339242780651

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4535022273290593
		Eccentricity	0.1
		Inclination		-0.1032570870968822
		AscendingNode	308.2696468356709
		ArgOfPericen	80.60199691825264
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 121.1"
{
	ParentBody	"Aeolus B 121"
	Class		"Asteroid"
	Mass		2.035643223599977e-09
	Radius		9.609130746276373

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.5505113436139305e-06
		Eccentricity	0.005693630463441984
		Inclination		-23.954605689379523
		AscendingNode	210.43618481795124
		ArgOfPericen	37.030940134224295
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 122"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.358914900063558e-07
	Radius		52.91156599237948

	RotationPeriod	7.354673516358018

	Obliquity		19.53647980726009

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45469436547796593
		Eccentricity	0.1
		Inclination		0.5053805147138845
		AscendingNode	288.8035495499924
		ArgOfPericen	91.46804830762837
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 122.1"
{
	ParentBody	"Aeolus B 122"
	Class		"Asteroid"
	Mass		3.022178391579892e-09
	Radius		11.00502365356698

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4965773918569947e-06
		Eccentricity	0.0032758615202750536
		Inclination		-29.744953494300628
		AscendingNode	292.0273575971018
		ArgOfPericen	189.19536195127276
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 123"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.877770913247372e-07
	Radius		69.0050768642797

	RotationPeriod	5.069025423829787

	Obliquity		340.72603133961155

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45337481708169536
		Eccentricity	0.1
		Inclination		1.219100067472983
		AscendingNode	208.4795516760348
		ArgOfPericen	29.72565035479351
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 123.1"
{
	ParentBody	"Aeolus B 123"
	Class		"Asteroid"
	Mass		3.3104848640912747e-09
	Radius		12.277427013554373

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.275524511221756e-06
		Eccentricity	0.004239053145956963
		Inclination		25.761971152002804
		AscendingNode	342.0057185046378
		ArgOfPericen	56.277467550860806
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 124"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1539924595520718e-08
	Radius		19.118773497434333

	RotationPeriod	7.715222289971411

	Obliquity		229.83453093296976

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45423505587655294
		Eccentricity	0.1
		Inclination		-0.5718391044165271
		AscendingNode	209.2875925023751
		ArgOfPericen	225.57473031732277
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 125"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.1346951115219675e-07
	Radius		45.58536347456531

	RotationPeriod	5.803451605181035

	Obliquity		359.93363094685543

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45139732193706406
		Eccentricity	0.1
		Inclination		1.3604516907492474
		AscendingNode	178.83219303519192
		ArgOfPericen	198.42403003012186
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 125.1"
{
	ParentBody	"Aeolus B 125"
	Class		"Asteroid"
	Mass		1.3469628721408202e-09
	Radius		8.423618281559353

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.243848487351184e-06
		Eccentricity	0.003999882779963241
		Inclination		31.642319070773347
		AscendingNode	175.13269222066054
		ArgOfPericen	132.10255946521832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 126"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5676335395812213e-07
	Radius		51.251504628793334

	RotationPeriod	6.7095207962746315

	Obliquity		270.6863878167185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45439112114643465
		Eccentricity	0.1
		Inclination		2.186435443795432
		AscendingNode	239.87747566056998
		ArgOfPericen	290.53934396378133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 127"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2231721680899353e-07
	Radius		38.45529350835171

	RotationPeriod	9.896356497185625

	Obliquity		162.6062828630766

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45578031470512365
		Eccentricity	0.1
		Inclination		-0.06224578962780627
		AscendingNode	237.27204772265856
		ArgOfPericen	192.50502887394327
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 128"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.920811815504937e-08
	Radius		28.98091426099497

	RotationPeriod	6.944220207475283

	Obliquity		258.84993055789425

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4562755004491555
		Eccentricity	0.1
		Inclination		-0.19971538534566471
		AscendingNode	89.7178305747546
		ArgOfPericen	168.83527872325894
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 128.1"
{
	ParentBody	"Aeolus B 128"
	Class		"Asteroid"
	Mass		2.2163955049651354e-11
	Radius		2.22151329490428

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.6538301836419347e-06
		Eccentricity	0.0027352746446276948
		Inclination		12.001694418165716
		AscendingNode	208.84932849469902
		ArgOfPericen	215.961782676687
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 129"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45360806992595315
		Eccentricity	0.1
		Inclination		-2.2772667088938707
		AscendingNode	120.52771610387786
		ArgOfPericen	37.96071767054911
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 129 A"
{
	ParentBody	"Aeolus B 129"
	Class		"Asteroid"
	Mass		1.1124517493505228e-07
	Radius		40.29585963796006

	Orbit
	{
		Epoch			2457395.5
		Period			0.007566341618143902
		Eccentricity	0.00670976972242804
		Inclination		244.07113852001598
		AscendingNode	338.23161842294036
		ArgOfPericen	126.96855499735821
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 129 B"
{
	ParentBody	"Aeolus B 129"
	Class		"Asteroid"
	Mass		6.51615635186986e-09
	Radius		15.64938215705378

	Orbit
	{
		Epoch			2457395.5
		Period			0.007566341618143902
		Eccentricity	0.00670976972242804
		Inclination		244.07113852001598
		AscendingNode	338.23161842294036
		ArgOfPericen	306.9685549973582
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 130"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.588124337177659e-07
	Radius		42.96743001849014

	RotationPeriod	5.9844940118200975

	Obliquity		282.7459365888518

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4538658059433312
		Eccentricity	0.1
		Inclination		0.887515303465206
		AscendingNode	221.55140497635858
		ArgOfPericen	64.60707752898603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 130.1"
{
	ParentBody	"Aeolus B 130"
	Class		"Asteroid"
	Mass		2.6594332519485586e-11
	Radius		2.368322873488895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.3434380403165573e-07
		Eccentricity	0.004911731892745337
		Inclination		19.378062201024818
		AscendingNode	299.0696940751264
		ArgOfPericen	324.3242909858655
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 130.2"
{
	ParentBody	"Aeolus B 130"
	Class		"Asteroid"
	Mass		2.2548783065748982e-11
	Radius		2.2415696995455328

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.143102443797964e-06
		Eccentricity	0.00703689717741157
		Inclination		1.577287422149039
		AscendingNode	175.94723656478476
		ArgOfPericen	249.17247222112357
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 131"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0348130988388568e-07
	Radius		37.52250870728816

	RotationPeriod	9.267165623123203

	Obliquity		68.66159713381217

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4563557952505445
		Eccentricity	0.1
		Inclination		-0.27791374844714145
		AscendingNode	272.7910050067103
		ArgOfPericen	228.7697922933515
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 132"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.729111858344103e-07
	Radius		77.66118008038609

	RotationPeriod	7.90697196105539

	Obliquity		242.88665279780054

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4528412192784687
		Eccentricity	0.1
		Inclination		0.6014846924670643
		AscendingNode	298.6643859554246
		ArgOfPericen	306.64124599925776
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 133"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.426652403458045e-07
	Radius		64.36430022926184

	RotationPeriod	9.060409597250585

	Obliquity		154.11800451321344

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4512263389852905
		Eccentricity	0.1
		Inclination		-2.0041114651582
		AscendingNode	276.79715265418486
		ArgOfPericen	316.84063556791966
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 134"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0060638771106708e-07
	Radius		35.19113949927383

	RotationPeriod	7.545377293843414

	Obliquity		9.597656966548605

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45765980298633596
		Eccentricity	0.1
		Inclination		-1.1821446852519244
		AscendingNode	237.5125205589921
		ArgOfPericen	218.41636395384802
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 135"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4502661815902416e-07
	Radius		55.86802842238914

	RotationPeriod	3.40075789899753

	Obliquity		295.5271795920609

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4548983208251166
		Eccentricity	0.1
		Inclination		1.9970053335335822
		AscendingNode	53.69039492625859
		ArgOfPericen	183.95185750077582
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 135.1"
{
	ParentBody	"Aeolus B 135"
	Class		"Asteroid"
	Mass		2.1697407249364434e-09
	Radius		10.312131088089346

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.705792568919347e-06
		Eccentricity	0.003319584553468417
		Inclination		-11.208599808000207
		AscendingNode	290.90956864081915
		ArgOfPericen	41.9921773030285
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 136"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4823756182490405e-07
	Radius		52.51874388319119

	RotationPeriod	4.9531214039560485

	Obliquity		186.01020882314825

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45362073683982695
		Eccentricity	0.1
		Inclination		1.2438538969580855
		AscendingNode	332.4202964684398
		ArgOfPericen	89.53935058614714
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 137"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3523855802426789e-07
	Radius		39.75964594843366

	RotationPeriod	6.411517465201907

	Obliquity		101.27213373107804

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4527774271087284
		Eccentricity	0.1
		Inclination		-0.2817640192216349
		AscendingNode	246.13827006041194
		ArgOfPericen	150.63990876412916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 138"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.752368273414044e-07
	Radius		64.92305759300521

	RotationPeriod	7.985958359541932

	Obliquity		264.88641803333144

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4553082459435524
		Eccentricity	0.1
		Inclination		1.1559290788331582
		AscendingNode	99.57719542412232
		ArgOfPericen	202.87988759404647
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 139"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4559477005518007
		Eccentricity	0.1
		Inclination		0.5466414124405107
		AscendingNode	299.7307117209164
		ArgOfPericen	106.25928149446455
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 139 A"
{
	ParentBody	"Aeolus B 139"
	Class		"Asteroid"
	Mass		2.2642890552149716e-07
	Radius		49.6735010531313

	Orbit
	{
		Epoch			2457395.5
		Period			0.0047996503838348735
		Eccentricity	0.0051380059079751805
		Inclination		323.2737339730914
		AscendingNode	351.15410744121283
		ArgOfPericen	322.81534296254074
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 139 B"
{
	ParentBody	"Aeolus B 139"
	Class		"Asteroid"
	Mass		1.8652364671632902e-08
	Radius		21.613517274219596

	Orbit
	{
		Epoch			2457395.5
		Period			0.0047996503838348735
		Eccentricity	0.0051380059079751805
		Inclination		323.2737339730914
		AscendingNode	351.15410744121283
		ArgOfPericen	142.81534296254074
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 140"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.043812938532257e-07
	Radius		55.28218650209071

	RotationPeriod	8.014967634336134

	Obliquity		74.74959577972967

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4543099583253157
		Eccentricity	0.1
		Inclination		3.704225491236226
		AscendingNode	229.78903693392033
		ArgOfPericen	269.1542423815831
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 141"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.367273483193675e-07
	Radius		64.80392223115909

	RotationPeriod	4.870320816004347

	Obliquity		26.98055150272594

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4564856194870651
		Eccentricity	0.1
		Inclination		1.194465770038501
		AscendingNode	306.0984350093742
		ArgOfPericen	341.4701321340158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 142"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.787695824016951e-07
	Radius		68.75991527966224

	RotationPeriod	7.4578092542533705

	Obliquity		8.42413067032831

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4569771169708966
		Eccentricity	0.1
		Inclination		1.6583766774131337
		AscendingNode	208.15072398469144
		ArgOfPericen	133.77112875591214
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 143"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.5275866349242245e-09
	Radius		12.69895337478723

	RotationPeriod	3.200779626689334

	Obliquity		273.1610252931024

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45288653971027637
		Eccentricity	0.1
		Inclination		-1.0718221513356345
		AscendingNode	294.7099680346224
		ArgOfPericen	25.82347726266134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 144"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.5743882266972604e-07
	Radius		59.568483197820655

	RotationPeriod	5.5579176635682845

	Obliquity		241.78404881725575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4559646153361967
		Eccentricity	0.1
		Inclination		0.32243933498855537
		AscendingNode	172.0656309783917
		ArgOfPericen	114.17839830860758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 145"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7955346582131556e-07
	Radius		44.501146951217635

	RotationPeriod	5.051299180723515

	Obliquity		223.8271794902952

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4557284733882065
		Eccentricity	0.1
		Inclination		3.0141353033195535
		AscendingNode	45.72373924449732
		ArgOfPericen	293.41658606147473
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 146"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.6068177029531118e-08
	Radius		23.808026123037436

	RotationPeriod	5.907699961430561

	Obliquity		23.67371536528262

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.458523020670248
		Eccentricity	0.1
		Inclination		-3.933148426005748
		AscendingNode	41.32202077264245
		ArgOfPericen	328.1259988736906
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 147"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.900594386371002e-08
	Radius		36.20140764892591

	RotationPeriod	6.2634680103980065

	Obliquity		191.18059997197233

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45497068661735385
		Eccentricity	0.1
		Inclination		-0.7121735577277499
		AscendingNode	200.62578433559338
		ArgOfPericen	22.437199974664054
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 147.1"
{
	ParentBody	"Aeolus B 147"
	Class		"Asteroid"
	Mass		3.1806412394536105e-11
	Radius		2.568960045036801

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2664625099472866e-06
		Eccentricity	0.0049706272883692695
		Inclination		8.288127316268634
		AscendingNode	116.75846729802943
		ArgOfPericen	20.73948981972983
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 148"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3978541679668915e-07
	Radius		43.405021600163266

	RotationPeriod	6.6333160024671045

	Obliquity		211.7088216837954

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4546213276435734
		Eccentricity	0.1
		Inclination		0.010108692739327838
		AscendingNode	16.67122366706549
		ArgOfPericen	343.9309649527307
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 149"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.807485205593795e-07
	Radius		61.33002821292817

	RotationPeriod	4.712377299226411

	Obliquity		202.01761845169753

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4569600070755001
		Eccentricity	0.1
		Inclination		3.428790262432408
		AscendingNode	56.79473403332689
		ArgOfPericen	236.8498448684606
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 150"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2209649993006822e-07
	Radius		37.99132900187526

	RotationPeriod	2.113013576533723

	Obliquity		102.18701917487815

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4553360161074217
		Eccentricity	0.1
		Inclination		1.2278111498009525
		AscendingNode	205.4430258361665
		ArgOfPericen	61.45277632500807
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 151"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.852571337727783e-07
	Radius		46.07036883903141

	RotationPeriod	6.283232970918573

	Obliquity		260.3402195172978

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4545813212399169
		Eccentricity	0.1
		Inclination		1.5965365071103643
		AscendingNode	197.1856405578115
		ArgOfPericen	257.10955122118264
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 151.1"
{
	ParentBody	"Aeolus B 151"
	Class		"Asteroid"
	Mass		6.897264115231105e-10
	Radius		7.140396491577828

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.355749017738925e-06
		Eccentricity	0.0031111107611002066
		Inclination		-8.226272590316135
		AscendingNode	329.4117590545188
		ArgOfPericen	346.02805495228284
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 152"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45689675083376513
		Eccentricity	0.1
		Inclination		-0.8621800489641162
		AscendingNode	119.89772871189601
		ArgOfPericen	226.54702061479813
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 152 A"
{
	ParentBody	"Aeolus B 152"
	Class		"Asteroid"
	Mass		5.251051227967634e-07
	Radius		63.747645136723136

	Orbit
	{
		Epoch			2457395.5
		Period			0.001211009261072041
		Eccentricity	0.003974454248763698
		Inclination		154.71757830731875
		AscendingNode	167.9947412540858
		ArgOfPericen	297.2400203926581
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 152 B"
{
	ParentBody	"Aeolus B 152"
	Class		"Asteroid"
	Mass		1.4728670415913555e-08
	Radius		19.368823547032378

	Orbit
	{
		Epoch			2457395.5
		Period			0.001211009261072041
		Eccentricity	0.003974454248763698
		Inclination		154.71757830731875
		AscendingNode	167.9947412540858
		ArgOfPericen	117.2400203926581
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 153"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3547399092352375e-07
	Radius		49.309471427988335

	RotationPeriod	4.886849021334786

	Obliquity		13.050050552077085

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45679327566315003
		Eccentricity	0.1
		Inclination		-1.510618696924454
		AscendingNode	185.88029567754316
		ArgOfPericen	65.02602508280205
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 154"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4533350645853249
		Eccentricity	0.1
		Inclination		-0.7688414396947673
		AscendingNode	49.389377054752195
		ArgOfPericen	127.24379225908396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 154 A"
{
	ParentBody	"Aeolus B 154"
	Class		"Asteroid"
	Mass		7.384898876655171e-07
	Radius		67.2457416155216

	Orbit
	{
		Epoch			2457395.5
		Period			0.007778503482947045
		Eccentricity	0.004276705843143167
		Inclination		203.31716563197892
		AscendingNode	196.50453912072416
		ArgOfPericen	217.00205949298896
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 154 B"
{
	ParentBody	"Aeolus B 154"
	Class		"Asteroid"
	Mass		2.7494231528019657e-07
	Radius		48.37605675560823

	Orbit
	{
		Epoch			2457395.5
		Period			0.007778503482947045
		Eccentricity	0.004276705843143167
		Inclination		203.31716563197892
		AscendingNode	196.50453912072416
		ArgOfPericen	37.00205949298896
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 155"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9036673810450412e-07
	Radius		46.8338291935669

	RotationPeriod	7.927019048850028

	Obliquity		200.91420547877289

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4554566587093197
		Eccentricity	0.1
		Inclination		-0.6461187044146224
		AscendingNode	319.95131605483465
		ArgOfPericen	108.43341411460574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 155.1"
{
	ParentBody	"Aeolus B 155"
	Class		"Asteroid"
	Mass		1.9056313181472232e-09
	Radius		10.09351126606024

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6617955444303886e-06
		Eccentricity	0.006697999272448611
		Inclination		20.08162672180569
		AscendingNode	324.47471013158383
		ArgOfPericen	317.11943770782517
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 155.2"
{
	ParentBody	"Aeolus B 155"
	Class		"Asteroid"
	Mass		7.350066986812526e-11
	Radius		3.4103038653750026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.534372812115136e-06
		Eccentricity	0.0040214114982981535
		Inclination		18.37120077786392
		AscendingNode	249.45350824835825
		ArgOfPericen	220.0437920637117
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 156"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4276674217189584e-07
	Radius		54.00860900392867

	RotationPeriod	9.758900713604492

	Obliquity		325.9897740606364

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45424027578031384
		Eccentricity	0.1
		Inclination		-1.1252855850418795
		AscendingNode	102.93322878604023
		ArgOfPericen	83.22305466101344
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 156.1"
{
	ParentBody	"Aeolus B 156"
	Class		"Asteroid"
	Mass		1.3898899278515925e-09
	Radius		8.61238764237635

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5105473873856246e-06
		Eccentricity	0.004712963436933805
		Inclination		17.962835929169618
		AscendingNode	298.05270647288955
		ArgOfPericen	335.1676660863261
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 157"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45426287473068794
		Eccentricity	0.1
		Inclination		-1.8264675693268189
		AscendingNode	253.9889924813144
		ArgOfPericen	338.5913281637646
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 157 A"
{
	ParentBody	"Aeolus B 157"
	Class		"Asteroid"
	Mass		4.5497204979028175e-08
	Radius		26.80765883633248

	Orbit
	{
		Epoch			2457395.5
		Period			0.007922803574457293
		Eccentricity	0.003904551991184775
		Inclination		246.7583323987854
		AscendingNode	6.305627734424339
		ArgOfPericen	286.16465969917544
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 157 B"
{
	ParentBody	"Aeolus B 157"
	Class		"Asteroid"
	Mass		9.214094269284101e-09
	Radius		15.742783844396843

	Orbit
	{
		Epoch			2457395.5
		Period			0.007922803574457293
		Eccentricity	0.003904551991184775
		Inclination		246.7583323987854
		AscendingNode	6.305627734424339
		ArgOfPericen	106.16465969917544
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 158"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0944310345190501e-07
	Radius		34.532323781765456

	RotationPeriod	5.707588544212139

	Obliquity		234.14884582417687

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4581618651124998
		Eccentricity	0.1
		Inclination		0.4468915553823307
		AscendingNode	144.52872701089655
		ArgOfPericen	47.44457766226381
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 159"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.951099033489088e-07
	Radius		61.380801555298945

	RotationPeriod	5.578155434765649

	Obliquity		28.524568873321066

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4568421119900243
		Eccentricity	0.1
		Inclination		3.095952712832163
		AscendingNode	20.897382136269037
		ArgOfPericen	316.8027851381429
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 160"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.215791093155629e-07
	Radius		53.267123840792976

	RotationPeriod	6.241179450875859

	Obliquity		333.0997659520946

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45494914469550546
		Eccentricity	0.1
		Inclination		-2.7280971358472423
		AscendingNode	323.67610893140244
		ArgOfPericen	40.562994709081806
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 160.1"
{
	ParentBody	"Aeolus B 160"
	Class		"Asteroid"
	Mass		1.898286083737329e-09
	Radius		9.626842346344528

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.862866245290777e-06
		Eccentricity	0.005000502089562844
		Inclination		28.72850303491331
		AscendingNode	288.16424831165676
		ArgOfPericen	344.60199549177196
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 161"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.726502608638011e-07
	Radius		48.62476878468497

	RotationPeriod	4.626496566118793

	Obliquity		59.24864142432287

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45319864420546274
		Eccentricity	0.1
		Inclination		1.0261173558854648
		AscendingNode	238.91728235512232
		ArgOfPericen	238.24067114512172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 162"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.2766015906842523e-07
	Radius		61.25650895727555

	RotationPeriod	8.859590679622531

	Obliquity		318.4825784709557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4546265653249162
		Eccentricity	0.1
		Inclination		-3.4870946294354184
		AscendingNode	257.4246930153859
		ArgOfPericen	186.0419344272077
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 163"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4683531071141464e-07
	Radius		53.21538290740525

	RotationPeriod	4.304912378192456

	Obliquity		318.2014824320732

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4519732567856863
		Eccentricity	0.1
		Inclination		2.782621331126722
		AscendingNode	304.551270125996
		ArgOfPericen	206.6502900762264
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 164"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.2742610106328755e-07
	Radius		51.519219722240834

	RotationPeriod	4.61567449643343

	Obliquity		99.82014349698832

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45534565310760144
		Eccentricity	0.1
		Inclination		0.12938813430885526
		AscendingNode	123.26503737819948
		ArgOfPericen	271.6864695583002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 165"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3376719538095034e-07
	Radius		50.05852116666785

	RotationPeriod	5.416830604973718

	Obliquity		66.56946959573112

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4537142659093373
		Eccentricity	0.1
		Inclination		1.1624675952454007
		AscendingNode	204.93178772815187
		ArgOfPericen	117.495531191015
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 165.1"
{
	ParentBody	"Aeolus B 165"
	Class		"Asteroid"
	Mass		2.1688208248168327e-09
	Radius		10.518602699068516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.966364049021573e-07
		Eccentricity	0.003640980219255896
		Inclination		24.690612005541254
		AscendingNode	83.48810851030645
		ArgOfPericen	40.978133478361194
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 166"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4348109739345882e-07
	Radius		41.81361352157016

	RotationPeriod	8.073479312435119

	Obliquity		235.0136991802598

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45623710438401044
		Eccentricity	0.1
		Inclination		1.5589425128020544
		AscendingNode	276.79963335371275
		ArgOfPericen	295.3344420550801
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 167"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.4384028905283005e-07
	Radius		56.76710776417486

	RotationPeriod	1.90684500829195

	Obliquity		72.53484822170428

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4540264110009122
		Eccentricity	0.1
		Inclination		-0.3355895194317806
		AscendingNode	342.9786890371309
		ArgOfPericen	312.2284114656026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 167.1"
{
	ParentBody	"Aeolus B 167"
	Class		"Asteroid"
	Mass		4.244403143746007e-10
	Radius		5.5927671250048405

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0848570046375815e-06
		Eccentricity	0.005567569936337859
		Inclination		-20.995303192590054
		AscendingNode	308.6311608125121
		ArgOfPericen	99.30548984517215
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 168"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.423866613200304e-07
	Radius		53.59094177846948

	RotationPeriod	7.684412768435754

	Obliquity		215.47721185517423

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45403135481523926
		Eccentricity	0.1
		Inclination		3.1272210834345295
		AscendingNode	177.3465137842304
		ArgOfPericen	91.35798493158458
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 169"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4568840138937094
		Eccentricity	0.1
		Inclination		2.711898969684093
		AscendingNode	185.15924058982884
		ArgOfPericen	196.12194157688484
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 169 A"
{
	ParentBody	"Aeolus B 169"
	Class		"Asteroid"
	Mass		3.178559121571268e-07
	Radius		52.90382951518059

	Orbit
	{
		Epoch			2457395.5
		Period			0.003981465956658591
		Eccentricity	0.0034186154982768797
		Inclination		186.21457972900302
		AscendingNode	242.4825479077316
		ArgOfPericen	347.8989460368498
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 169 B"
{
	ParentBody	"Aeolus B 169"
	Class		"Asteroid"
	Mass		2.720237535577181e-08
	Radius		23.313776132946384

	Orbit
	{
		Epoch			2457395.5
		Period			0.003981465956658591
		Eccentricity	0.0034186154982768797
		Inclination		186.21457972900302
		AscendingNode	242.4825479077316
		ArgOfPericen	167.8989460368498
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 170"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5981065036305137e-06
	Radius		85.19792160326458

	RotationPeriod	5.839789895577607

	Obliquity		328.0067721077699

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4573505327652005
		Eccentricity	0.1
		Inclination		1.905887937971829
		AscendingNode	212.74710896786388
		ArgOfPericen	276.4654418023668
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 171"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.05885103965211e-08
	Radius		25.916436100832772

	RotationPeriod	4.98695294875362

	Obliquity		188.04636128380926

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4540665300607458
		Eccentricity	0.1
		Inclination		-0.36754824766836497
		AscendingNode	181.0877676055479
		ArgOfPericen	105.22978056532199
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 171.1"
{
	ParentBody	"Aeolus B 171"
	Class		"Asteroid"
	Mass		3.1500384828258173e-11
	Radius		2.3816587133173943

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.772804014482062e-06
		Eccentricity	0.006188068721315209
		Inclination		19.371633606044902
		AscendingNode	319.54394806895317
		ArgOfPericen	274.16643352826117
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 172"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.53977306205247e-07
	Radius		50.31155054087569

	RotationPeriod	6.9015528567799915

	Obliquity		154.05772798861287

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4543151097459799
		Eccentricity	0.1
		Inclination		-2.2215425927131105
		AscendingNode	39.76790781941045
		ArgOfPericen	48.67902577274234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 173"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.831087995664899e-07
	Radius		70.75048215468061

	RotationPeriod	7.830963017648319

	Obliquity		74.66061832644746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4548737968878617
		Eccentricity	0.1
		Inclination		-2.819450460055145
		AscendingNode	13.386001326990481
		ArgOfPericen	283.2195475429319
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 173.1"
{
	ParentBody	"Aeolus B 173"
	Class		"Asteroid"
	Mass		2.644393925200332e-09
	Radius		10.614448138616979

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.982299772396456e-06
		Eccentricity	0.007950259923779106
		Inclination		-4.9643472902621415
		AscendingNode	136.10774555281327
		ArgOfPericen	268.5919521671815
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 174"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3077344968240096e-07
	Radius		49.85210406490894

	RotationPeriod	6.809034535412597

	Obliquity		241.9028283277235

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45411307650599536
		Eccentricity	0.1
		Inclination		-0.6752549673986394
		AscendingNode	71.41034700630077
		ArgOfPericen	117.47836137910045
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 175"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4740095137322735e-07
	Radius		50.073408596334744

	RotationPeriod	7.92639879575124

	Obliquity		322.0397229741636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45629877023259263
		Eccentricity	0.1
		Inclination		1.1664586801518388
		AscendingNode	288.4784914233201
		ArgOfPericen	32.89143704959416
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 176"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.43739624168634e-08
	Radius		34.868723392802124

	RotationPeriod	2.609546184878111

	Obliquity		1.9466784042110064

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45357531021774533
		Eccentricity	0.1
		Inclination		2.338288372599632
		AscendingNode	153.56463746703207
		ArgOfPericen	135.01074822792376
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 177"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.522104947710812e-07
	Radius		64.3691598640393

	RotationPeriod	6.8766059394844525

	Obliquity		121.39649798538238

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45369042940547943
		Eccentricity	0.1
		Inclination		0.569151760699838
		AscendingNode	145.640426886368
		ArgOfPericen	188.93372463416497
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 177.1"
{
	ParentBody	"Aeolus B 177"
	Class		"Asteroid"
	Mass		2.614087660824076e-09
	Radius		10.808107886094389

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.283146435923474e-06
		Eccentricity	0.003750641159979672
		Inclination		71.00348147834758
		AscendingNode	310.67522589630056
		ArgOfPericen	37.29612651295676
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 177.2"
{
	ParentBody	"Aeolus B 177"
	Class		"Asteroid"
	Mass		1.9787672673097364e-10
	Radius		4.5720172608409415

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.279370365123894e-06
		Eccentricity	0.0048255534316981345
		Inclination		7.883060479419227
		AscendingNode	273.0588152987297
		ArgOfPericen	132.3769522074445
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 178"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.10837969873533e-08
	Radius		33.03900769600014

	RotationPeriod	8.168167869954884

	Obliquity		72.50891136451905

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4554458716715361
		Eccentricity	0.1
		Inclination		-1.3706733340384143
		AscendingNode	39.31396125916314
		ArgOfPericen	156.76623339790072
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 179"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.592073586079079e-08
	Radius		29.225624830947655

	RotationPeriod	6.22488191080019

	Obliquity		72.14011950545203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45555360328374145
		Eccentricity	0.1
		Inclination		-0.41381351462863536
		AscendingNode	316.26059600790177
		ArgOfPericen	45.34768816017472
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 180"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.1016093537175172e-07
	Radius		47.05673350888356

	RotationPeriod	8.902309997841158

	Obliquity		308.3939598491242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45530675976655105
		Eccentricity	0.1
		Inclination		0.5480581951402822
		AscendingNode	8.834017781726612
		ArgOfPericen	245.06288372931385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 180.1"
{
	ParentBody	"Aeolus B 180"
	Class		"Asteroid"
	Mass		3.466507260611638e-10
	Radius		5.559919249119613

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.6738634011510345e-06
		Eccentricity	0.004914977521965982
		Inclination		29.909323982494374
		AscendingNode	141.04586838440082
		ArgOfPericen	266.0014107450672
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 181"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4563479914532215e-08
	Radius		22.322623776367553

	RotationPeriod	6.676417196500596

	Obliquity		352.9484099811562

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4562218403194187
		Eccentricity	0.1
		Inclination		-0.2956780761669961
		AscendingNode	80.28984814019613
		ArgOfPericen	11.280112974104387
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 182"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.2479882934617073e-07
	Radius		45.66043331558933

	RotationPeriod	6.420550762634375

	Obliquity		6.272933812923269

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4530021592943423
		Eccentricity	0.1
		Inclination		-0.30464141862220473
		AscendingNode	129.3392819500593
		ArgOfPericen	70.78542981123266
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 183"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1419149665495108e-06
	Radius		82.61759854945922

	RotationPeriod	6.59047791699252

	Obliquity		257.18830789897726

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45509109839392897
		Eccentricity	0.1
		Inclination		1.0039311314475652
		AscendingNode	205.28726683461946
		ArgOfPericen	307.0208527410721
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 184"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.714772120978429e-07
	Radius		59.73371313057157

	RotationPeriod	6.003766677895749

	Obliquity		148.7992108013917

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4551591042315226
		Eccentricity	0.1
		Inclination		-1.0440965415763892
		AscendingNode	113.38741442655157
		ArgOfPericen	330.98346840156375
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 185"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.427301546833979e-07
	Radius		72.53636409855267

	RotationPeriod	4.190061008439997

	Obliquity		11.191628451296296

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45528272944402254
		Eccentricity	0.1
		Inclination		1.0716846911283942
		AscendingNode	221.72722923800825
		ArgOfPericen	144.50752482627493
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 186"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2906732234528563e-07
	Radius		39.2292619280979

	RotationPeriod	4.166490148806546

	Obliquity		207.42975436097126

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45486178008177836
		Eccentricity	0.1
		Inclination		-0.4412896021577711
		AscendingNode	47.76816133476953
		ArgOfPericen	93.31101211909791
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 187"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2246889122605966e-07
	Radius		38.20833079991674

	RotationPeriod	5.6896396076848585

	Obliquity		150.77707641487706

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4567114302286338
		Eccentricity	0.1
		Inclination		1.5738840197963304
		AscendingNode	77.18057155786914
		ArgOfPericen	52.922247513492124
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 187.1"
{
	ParentBody	"Aeolus B 187"
	Class		"Asteroid"
	Mass		5.653764806157797e-10
	Radius		6.3620251636739855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.699878991907896e-07
		Eccentricity	0.006161324095653262
		Inclination		31.856561386657482
		AscendingNode	212.46177041208355
		ArgOfPericen	135.0393032316836
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 188"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45350264923934175
		Eccentricity	0.1
		Inclination		-0.19793632491722735
		AscendingNode	312.23160628088795
		ArgOfPericen	129.14240864783096
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 188 A"
{
	ParentBody	"Aeolus B 188"
	Class		"Asteroid"
	Mass		4.7011627978126595e-07
	Radius		60.00083859934492

	Orbit
	{
		Epoch			2457395.5
		Period			0.002857542591514977
		Eccentricity	0.004821113927771657
		Inclination		307.75174822086166
		AscendingNode	237.4922247300935
		ArgOfPericen	33.67288519832777
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 188 B"
{
	ParentBody	"Aeolus B 188"
	Class		"Asteroid"
	Mass		2.012347445233998e-08
	Radius		20.988909694156217

	Orbit
	{
		Epoch			2457395.5
		Period			0.002857542591514977
		Eccentricity	0.004821113927771657
		Inclination		307.75174822086166
		AscendingNode	237.4922247300935
		ArgOfPericen	213.67288519832778
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 189"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.66956020325335e-07
	Radius		49.87853887484735

	RotationPeriod	3.221095908635552

	Obliquity		95.78194167973913

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45442345234395704
		Eccentricity	0.1
		Inclination		-0.25146782319654304
		AscendingNode	148.8832239587148
		ArgOfPericen	359.9448222394249
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 190"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.6465891233702934e-07
	Radius		57.811848061868005

	RotationPeriod	8.26367577445139

	Obliquity		349.1030914015209

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4565771857889622
		Eccentricity	0.1
		Inclination		0.38081405275943786
		AscendingNode	269.75534141339944
		ArgOfPericen	180.19586342615958
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 191"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.78692120452615e-07
	Radius		60.53188059471572

	RotationPeriod	3.951894808269401

	Obliquity		307.91904376563673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4529878233634194
		Eccentricity	0.1
		Inclination		1.275027711583466
		AscendingNode	295.3035072532221
		ArgOfPericen	315.3073371145299
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 192"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45760283312133626
		Eccentricity	0.1
		Inclination		0.9758804031307208
		AscendingNode	297.0082182456252
		ArgOfPericen	317.29990833873325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 192 A"
{
	ParentBody	"Aeolus B 192"
	Class		"Asteroid"
	Mass		7.382071285264296e-07
	Radius		68.9381727358589

	Orbit
	{
		Epoch			2457395.5
		Period			0.0048859734669396415
		Eccentricity	0.006317336615900967
		Inclination		315.9562707886093
		AscendingNode	193.51578914797724
		ArgOfPericen	112.82318118450564
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 192 B"
{
	ParentBody	"Aeolus B 192"
	Class		"Asteroid"
	Mass		5.443313816177002e-07
	Radius		62.280890558514706

	Orbit
	{
		Epoch			2457395.5
		Period			0.0048859734669396415
		Eccentricity	0.006317336615900967
		Inclination		315.9562707886093
		AscendingNode	193.51578914797724
		ArgOfPericen	292.82318118450564
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 193"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4553721769725541
		Eccentricity	0.1
		Inclination		0.16374470062506785
		AscendingNode	243.36731993040948
		ArgOfPericen	77.56486568806861
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 193 A"
{
	ParentBody	"Aeolus B 193"
	Class		"Asteroid"
	Mass		2.853489858455925e-07
	Radius		49.839197378345325

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008555897691062328
		Eccentricity	0.004976510055013791
		Inclination		134.88802503754846
		AscendingNode	329.9673074408766
		ArgOfPericen	26.10564506205113
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 193 B"
{
	ParentBody	"Aeolus B 193"
	Class		"Asteroid"
	Mass		2.527388821392318e-07
	Radius		47.86333420581126

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008555897691062328
		Eccentricity	0.004976510055013791
		Inclination		134.88802503754846
		AscendingNode	329.9673074408766
		ArgOfPericen	206.10564506205114
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 194"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5083325866790035e-08
	Radius		23.14956638147664

	RotationPeriod	4.369453966433517

	Obliquity		0.46572087061053313

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4546077943696595
		Eccentricity	0.1
		Inclination		-0.746043474608409
		AscendingNode	76.8752996401759
		ArgOfPericen	262.72092007962306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 195"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.698609434948662e-07
	Radius		57.02004559476042

	RotationPeriod	7.996609513971975

	Obliquity		31.630472753780023

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45724112005211204
		Eccentricity	0.1
		Inclination		0.015265126163189565
		AscendingNode	322.49554236237043
		ArgOfPericen	244.08106850932717
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 195.1"
{
	ParentBody	"Aeolus B 195"
	Class		"Asteroid"
	Mass		1.2594712329897817e-10
	Radius		3.6764940059391185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.275111329221984e-06
		Eccentricity	0.004706529383431033
		Inclination		-63.60119629368957
		AscendingNode	24.99667872288734
		ArgOfPericen	83.04961630109658
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 196"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.45395394573651615
		Eccentricity	0.1
		Inclination		-0.8811102896913374
		AscendingNode	232.29255135672915
		ArgOfPericen	130.40519123153172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 196 A"
{
	ParentBody	"Aeolus B 196"
	Class		"Asteroid"
	Mass		2.867872924868121e-07
	Radius		52.52440818303607

	Orbit
	{
		Epoch			2457395.5
		Period			0.004356891102606658
		Eccentricity	0.005086009008861785
		Inclination		87.55563122503078
		AscendingNode	304.0421581726647
		ArgOfPericen	31.81849719508072
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 196 B"
{
	ParentBody	"Aeolus B 196"
	Class		"Asteroid"
	Mass		2.3253215556687446e-07
	Radius		48.97813067437482

	Orbit
	{
		Epoch			2457395.5
		Period			0.004356891102606658
		Eccentricity	0.005086009008861785
		Inclination		87.55563122503078
		AscendingNode	304.0421581726647
		ArgOfPericen	211.8184971950807
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 197"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.053486531428863e-07
	Radius		69.33408961764209

	RotationPeriod	6.235591265162975

	Obliquity		129.7119053589676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4552353833250208
		Eccentricity	0.1
		Inclination		-0.04991716715234632
		AscendingNode	231.2467922616987
		ArgOfPericen	272.2260990230549
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 198"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4531992680113226
		Eccentricity	0.1
		Inclination		-2.0275463912057456
		AscendingNode	115.81837966212977
		ArgOfPericen	149.588841298454
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 198 A"
{
	ParentBody	"Aeolus B 198"
	Class		"Asteroid"
	Mass		1.62811907994119e-07
	Radius		41.51128248210996

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008617973456518727
		Eccentricity	0.007986094550827896
		Inclination		110.43286399914024
		AscendingNode	26.73805050414705
		ArgOfPericen	195.81885884640326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 198 B"
{
	ParentBody	"Aeolus B 198"
	Class		"Asteroid"
	Mass		1.3370445008758347e-08
	Radius		18.04344180068584

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008617973456518727
		Eccentricity	0.007986094550827896
		Inclination		110.43286399914024
		AscendingNode	26.73805050414705
		ArgOfPericen	15.81885884640326
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 199"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8710026293058115e-07
	Radius		43.37298720160397

	RotationPeriod	6.4756901978037495

	Obliquity		38.64092047894904

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4562943327638176
		Eccentricity	0.1
		Inclination		1.5375257007844016
		AscendingNode	276.8498808905562
		ArgOfPericen	284.50876443927615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus B 200"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.4547740884231139
		Eccentricity	0.1
		Inclination		-0.19079084727197704
		AscendingNode	294.07443593330413
		ArgOfPericen	297.21008700676913
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus B 200 A"
{
	ParentBody	"Aeolus B 200"
	Class		"Asteroid"
	Mass		5.430072149531907e-07
	Radius		61.78434584137599

	Orbit
	{
		Epoch			2457395.5
		Period			0.0031659222419768433
		Eccentricity	0.0064851132858428735
		Inclination		337.2726936438304
		AscendingNode	328.8381897841248
		ArgOfPericen	143.22026835066166
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus B 200 B"
{
	ParentBody	"Aeolus B 200"
	Class		"Asteroid"
	Mass		9.216993023441046e-09
	Radius		15.878385404200205

	Orbit
	{
		Epoch			2457395.5
		Period			0.0031659222419768433
		Eccentricity	0.0064851132858428735
		Inclination		337.2726936438304
		AscendingNode	328.8381897841248
		ArgOfPericen	323.2202683506616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Aeolus asteroid belt C ------------------------------------------------------
//------------------------------------------------------------------------------
Asteroid "Aeolus C 1"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.794982160865368e-07
	Radius		67.33007687137109

	RotationPeriod	7.300728260940661

	Obliquity		175.81548980725913

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5110854305610482
		Eccentricity	0.1
		Inclination		1.8594271942893519
		AscendingNode	289.16471898453545
		ArgOfPericen	301.7247181361612
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 2"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.750609053591994e-08
	Radius		27.60120594525991

	RotationPeriod	5.228739218580477

	Obliquity		111.41690610650664

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5048263799070782
		Eccentricity	0.1
		Inclination		-0.14147961868433087
		AscendingNode	345.8875696295874
		ArgOfPericen	64.20312034739159
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 2.1"
{
	ParentBody	"Aeolus C 2"
	Class		"Asteroid"
	Mass		1.598158916781738e-11
	Radius		2.076988598173381

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3150708293812668e-06
		Eccentricity	0.003732243323053549
		Inclination		-7.153330068546099
		AscendingNode	6.638381185892812
		ArgOfPericen	1.8341511366554153
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 3"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.1075095517938e-08
	Radius		34.81456665991857

	RotationPeriod	5.712131000709502

	Obliquity		350.73997249508136

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5133523842928374
		Eccentricity	0.1
		Inclination		0.2787570565076449
		AscendingNode	137.69556896438215
		ArgOfPericen	85.66609984537327
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 3.1"
{
	ParentBody	"Aeolus C 3"
	Class		"Asteroid"
	Mass		6.625023098301696e-10
	Radius		6.745646536749097

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6026968496538825e-06
		Eccentricity	0.0048557593392962355
		Inclination		-48.32635297653903
		AscendingNode	73.96365157127295
		ArgOfPericen	41.97604162688607
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 4"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.964916343652e-08
	Radius		30.565316833456485

	RotationPeriod	4.081251182859421

	Obliquity		90.42113877072467

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5154909128849758
		Eccentricity	0.1
		Inclination		-0.3699342007245186
		AscendingNode	281.303977465822
		ArgOfPericen	45.24632319818267
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 5"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.174678478306406e-07
	Radius		76.7266919049836

	RotationPeriod	8.902048649881557

	Obliquity		139.50816917406718

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5119858358789884
		Eccentricity	0.1
		Inclination		-0.5076778479739255
		AscendingNode	176.3313308692844
		ArgOfPericen	200.50077310354882
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 6"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.5229157962748714e-07
	Radius		59.04272200575643

	RotationPeriod	2.6311928729476923

	Obliquity		337.8799145806302

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5117190593231113
		Eccentricity	0.1
		Inclination		-0.06888816415251005
		AscendingNode	138.00845547406198
		ArgOfPericen	315.6541273059223
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 7"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5111279072619198
		Eccentricity	0.1
		Inclination		-2.270101492146375
		AscendingNode	307.84409777213244
		ArgOfPericen	299.3875218533482
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 7 A"
{
	ParentBody	"Aeolus C 7"
	Class		"Asteroid"
	Mass		1.9870267655304691e-07
	Radius		45.6660578791513

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011596932885001578
		Eccentricity	0.006276773815215844
		Inclination		12.76086079851261
		AscendingNode	246.78128115029273
		ArgOfPericen	198.291507911091
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 7 B"
{
	ParentBody	"Aeolus C 7"
	Class		"Asteroid"
	Mass		5.0645211817907154e-09
	Radius		13.439148340186964

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011596932885001578
		Eccentricity	0.006276773815215844
		Inclination		12.76086079851261
		AscendingNode	246.78128115029273
		ArgOfPericen	18.291507911091003
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 8"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5658016928984654e-07
	Radius		41.71046868391128

	RotationPeriod	8.319299602695137

	Obliquity		24.71484455742499

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5121353062931945
		Eccentricity	0.1
		Inclination		-1.4726693650712661
		AscendingNode	351.35204387319897
		ArgOfPericen	243.71540448825903
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 9"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.0518325328490136e-07
	Radius		54.70947561651286

	RotationPeriod	1.015193797781337

	Obliquity		344.446008566704

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5117053068087534
		Eccentricity	0.1
		Inclination		-1.690029567551262
		AscendingNode	48.26074551679963
		ArgOfPericen	122.78201924135273
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 9.1"
{
	ParentBody	"Aeolus C 9"
	Class		"Asteroid"
	Mass		3.5908627212174007e-10
	Radius		5.255067803406843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1873009367862333e-06
		Eccentricity	0.008836944441365702
		Inclination		-45.50674726134233
		AscendingNode	136.87613895351328
		ArgOfPericen	291.7685773841422
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 10"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5171139069209599
		Eccentricity	0.1
		Inclination		-0.2907689560080598
		AscendingNode	12.44287708077918
		ArgOfPericen	279.32969581151974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 10 A"
{
	ParentBody	"Aeolus C 10"
	Class		"Asteroid"
	Mass		3.7589609434421994e-07
	Radius		53.55523260811268

	Orbit
	{
		Epoch			2457395.5
		Period			0.006182260483072359
		Eccentricity	0.006447146349853442
		Inclination		186.64651472284288
		AscendingNode	343.2191121326443
		ArgOfPericen	36.203102225848546
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 10 B"
{
	ParentBody	"Aeolus C 10"
	Class		"Asteroid"
	Mass		1.7755988861041392e-07
	Radius		41.70879025104702

	Orbit
	{
		Epoch			2457395.5
		Period			0.006182260483072359
		Eccentricity	0.006447146349853442
		Inclination		186.64651472284288
		AscendingNode	343.2191121326443
		ArgOfPericen	216.20310222584854
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 11"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4334286632553655e-07
	Radius		47.2502784037351

	RotationPeriod	1.6801991168483408

	Obliquity		106.44144776585203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.510083937868753
		Eccentricity	0.1
		Inclination		-0.7612607463617805
		AscendingNode	12.35383872121659
		ArgOfPericen	254.79403672193337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 12"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.149821776654179e-08
	Radius		31.454788176486012

	RotationPeriod	5.619067747219387

	Obliquity		89.95222308705783

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5127260005592696
		Eccentricity	0.1
		Inclination		-1.050181258907334
		AscendingNode	183.8522425908569
		ArgOfPericen	225.7975128957239
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 12.1"
{
	ParentBody	"Aeolus C 12"
	Class		"Asteroid"
	Mass		2.2317320182780989e-10
	Radius		4.596942175882184

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.5724366955374799e-06
		Eccentricity	0.003377024227727802
		Inclination		-8.888031779084962
		AscendingNode	258.8761268635103
		ArgOfPericen	324.1582308606822
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 13"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5089285275644412
		Eccentricity	0.1
		Inclination		-1.2351483772288974
		AscendingNode	166.4094833311502
		ArgOfPericen	111.70103583060788
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 13 A"
{
	ParentBody	"Aeolus C 13"
	Class		"Asteroid"
	Mass		7.374647565259441e-07
	Radius		74.35157911833039

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005375299087154936
		Eccentricity	0.004996806289857337
		Inclination		42.019534592815674
		AscendingNode	165.05506582199015
		ArgOfPericen	140.40422471985374
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 13 B"
{
	ParentBody	"Aeolus C 13"
	Class		"Asteroid"
	Mass		1.9830741805854823e-07
	Radius		47.99059045909979

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005375299087154936
		Eccentricity	0.004996806289857337
		Inclination		42.019534592815674
		AscendingNode	165.05506582199015
		ArgOfPericen	320.40422471985374
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 14"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.878676255662467e-07
	Radius		60.89750464172768

	RotationPeriod	6.36904140156726

	Obliquity		78.04397441572355

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5118303306096244
		Eccentricity	0.1
		Inclination		1.927815743592362
		AscendingNode	47.717805824032155
		ArgOfPericen	264.7122607767019
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 14.1"
{
	ParentBody	"Aeolus C 14"
	Class		"Asteroid"
	Mass		1.0214388041562883e-10
	Radius		3.616065441366449

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.60950907637261e-06
		Eccentricity	0.0054035190346188805
		Inclination		-28.525739109520483
		AscendingNode	225.7805745095007
		ArgOfPericen	145.4248999641945
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 14.2"
{
	ParentBody	"Aeolus C 14"
	Class		"Asteroid"
	Mass		7.470886041179176e-09
	Radius		15.122474745431049

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.912128285379161e-06
		Eccentricity	0.0029533613903956475
		Inclination		5.603032485725646
		AscendingNode	183.5204722794371
		ArgOfPericen	22.04949387119974
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 15"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.716069781216049e-07
	Radius		50.85377738653138

	RotationPeriod	6.557064231004897

	Obliquity		3.515646693309029

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5159574155398639
		Eccentricity	0.1
		Inclination		2.1369517316655235
		AscendingNode	236.89038707608017
		ArgOfPericen	35.46854005675198
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 16"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.501585693259067e-07
	Radius		44.02393119530544

	RotationPeriod	4.345543312208019

	Obliquity		21.93972394880175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5116153083210339
		Eccentricity	0.1
		Inclination		0.17344325427026586
		AscendingNode	312.02970018404267
		ArgOfPericen	110.15931318009687
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 16.1"
{
	ParentBody	"Aeolus C 16"
	Class		"Asteroid"
	Mass		1.0082271893532566e-10
	Radius		3.855004732022227

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.287087541202757e-07
		Eccentricity	0.006742852052615833
		Inclination		36.9938127871364
		AscendingNode	263.21819672178754
		ArgOfPericen	236.7171877200457
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 17"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0786328861240575e-07
	Radius		44.297067116332485

	RotationPeriod	7.840606814248746

	Obliquity		285.8947246674498

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5124053549141399
		Eccentricity	0.1
		Inclination		-0.5927503997752703
		AscendingNode	322.69336948618235
		ArgOfPericen	205.91559386151732
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 18"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1811737594350597e-07
	Radius		40.035981859171166

	RotationPeriod	5.187810567376361

	Obliquity		323.020151061576

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5060302191950958
		Eccentricity	0.1
		Inclination		-0.7836540623438503
		AscendingNode	59.86605175327697
		ArgOfPericen	3.1329880592604242
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 19"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8719603215496783e-07
	Radius		52.835116889317966

	RotationPeriod	7.816415264263187

	Obliquity		340.16459353818124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5085240630296304
		Eccentricity	0.1
		Inclination		2.343930614501367
		AscendingNode	113.23248567508539
		ArgOfPericen	28.05872044979854
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 20"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5105163004659319
		Eccentricity	0.1
		Inclination		-0.042558873986234355
		AscendingNode	81.25134121159002
		ArgOfPericen	172.27598689306737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 20 A"
{
	ParentBody	"Aeolus C 20"
	Class		"Asteroid"
	Mass		6.295484887304608e-09
	Radius		15.615905450654964

	Orbit
	{
		Epoch			2457395.5
		Period			0.001908192169634656
		Eccentricity	0.005133344172570657
		Inclination		104.54415544413432
		AscendingNode	203.92055342568926
		ArgOfPericen	217.14814564922307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 20 B"
{
	ParentBody	"Aeolus C 20"
	Class		"Asteroid"
	Mass		2.0577796287005676e-09
	Radius		10.756980881698968

	Orbit
	{
		Epoch			2457395.5
		Period			0.001908192169634656
		Eccentricity	0.005133344172570657
		Inclination		104.54415544413432
		AscendingNode	203.92055342568926
		ArgOfPericen	37.14814564922307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 21"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.19243506979836e-07
	Radius		61.21286734890725

	RotationPeriod	4.830528637233878

	Obliquity		53.101124572758785

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5114471492427788
		Eccentricity	0.1
		Inclination		-2.0676672639013964
		AscendingNode	101.97406426951622
		ArgOfPericen	130.6268374118213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 22"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8941411329554476e-07
	Radius		57.440241949632195

	RotationPeriod	6.607445983550434

	Obliquity		122.37553017915596

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5114046260735778
		Eccentricity	0.1
		Inclination		0.41232542632525077
		AscendingNode	200.2054904504233
		ArgOfPericen	246.31090707658507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 22.1"
{
	ParentBody	"Aeolus C 22"
	Class		"Asteroid"
	Mass		3.2610968245527344e-09
	Radius		11.664521536715734

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4340014690472964e-06
		Eccentricity	0.007656116410090218
		Inclination		28.91384479752841
		AscendingNode	184.58711220856657
		ArgOfPericen	357.5546864209145
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 23"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5093865832348744
		Eccentricity	0.1
		Inclination		0.032580337197475495
		AscendingNode	221.9260123313638
		ArgOfPericen	236.5361382970856
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 23 A"
{
	ParentBody	"Aeolus C 23"
	Class		"Asteroid"
	Mass		1.860175771162864e-07
	Radius		46.25186285693993

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021658989419645154
		Eccentricity	0.005566663524917326
		Inclination		259.9305590088857
		AscendingNode	45.99132646597915
		ArgOfPericen	300.64928958575763
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 23 B"
{
	ParentBody	"Aeolus C 23"
	Class		"Asteroid"
	Mass		7.526946002791536e-08
	Radius		34.20982361121031

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021658989419645154
		Eccentricity	0.005566663524917326
		Inclination		259.9305590088857
		AscendingNode	45.99132646597915
		ArgOfPericen	120.64928958575763
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 24"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5136733371674644
		Eccentricity	0.1
		Inclination		1.5191127392199633
		AscendingNode	183.01824722154834
		ArgOfPericen	281.83989264205076
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 24 A"
{
	ParentBody	"Aeolus C 24"
	Class		"Asteroid"
	Mass		2.4916706808990573e-08
	Radius		22.243003543925074

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010402096446455987
		Eccentricity	0.005061609923142803
		Inclination		87.32157168899474
		AscendingNode	29.021601609110284
		ArgOfPericen	267.1684148948483
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 24 B"
{
	ParentBody	"Aeolus C 24"
	Class		"Asteroid"
	Mass		1.776975053716758e-08
	Radius		19.872705381226744

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010402096446455987
		Eccentricity	0.005061609923142803
		Inclination		87.32157168899474
		AscendingNode	29.021601609110284
		ArgOfPericen	87.1684148948483
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 25"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.34842724424442e-09
	Radius		16.42786212686763

	RotationPeriod	7.145447443630246

	Obliquity		249.38471383569987

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5188961614276838
		Eccentricity	0.1
		Inclination		1.5274020207332148
		AscendingNode	304.38987026344097
		ArgOfPericen	292.5210421775288
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 26"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5919891869032136e-06
	Radius		96.10873742214385

	RotationPeriod	4.6971647721570315

	Obliquity		320.75613426799896

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5143195472799557
		Eccentricity	0.1
		Inclination		-0.10675684807796647
		AscendingNode	155.3164303245396
		ArgOfPericen	301.22955204789656
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 26.1"
{
	ParentBody	"Aeolus C 26"
	Class		"Asteroid"
	Mass		1.9158345743803977e-09
	Radius		10.22277580204354

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.668322291093035e-06
		Eccentricity	0.0025303145532963776
		Inclination		24.476455295976923
		AscendingNode	170.69005639410673
		ArgOfPericen	338.3383273759694
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 27"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.674461622008821e-07
	Radius		65.18190527536345

	RotationPeriod	5.817340242521057

	Obliquity		172.8854852901967

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5097725837307006
		Eccentricity	0.1
		Inclination		-0.5655181750516147
		AscendingNode	63.89332755797845
		ArgOfPericen	232.79586815929576
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 28"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7186082874988403e-07
	Radius		46.17824395950669

	RotationPeriod	8.107066602100474

	Obliquity		232.84196681435947

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5102598122868126
		Eccentricity	0.1
		Inclination		-1.9683243586699428
		AscendingNode	229.69324089402596
		ArgOfPericen	302.7153437325453
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 29"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.602897293276596e-07
	Radius		67.48362800278505

	RotationPeriod	5.696458734777839

	Obliquity		192.55377677278668

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5082795695627103
		Eccentricity	0.1
		Inclination		-2.1933605809947836
		AscendingNode	192.8359140961466
		ArgOfPericen	345.689558899067
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 30"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5034225807844942
		Eccentricity	0.1
		Inclination		-0.35594770569203515
		AscendingNode	319.77120771725794
		ArgOfPericen	207.82626533924693
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 30 A"
{
	ParentBody	"Aeolus C 30"
	Class		"Asteroid"
	Mass		2.0814055272824153e-07
	Radius		47.94617845049041

	Orbit
	{
		Epoch			2457395.5
		Period			0.007278329250029303
		Eccentricity	0.0058991868057084364
		Inclination		328.49826430186306
		AscendingNode	87.42561495405276
		ArgOfPericen	314.3928983949983
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 30 B"
{
	ParentBody	"Aeolus C 30"
	Class		"Asteroid"
	Mass		1.152823337584534e-07
	Radius		39.375191849927134

	Orbit
	{
		Epoch			2457395.5
		Period			0.007278329250029303
		Eccentricity	0.0058991868057084364
		Inclination		328.49826430186306
		AscendingNode	87.42561495405276
		ArgOfPericen	134.39289839499833
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 31"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4369402850646744e-06
	Radius		85.00590291420272

	RotationPeriod	3.2550769161690023

	Obliquity		155.9567535547057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5109305466789278
		Eccentricity	0.1
		Inclination		1.1602305627402234
		AscendingNode	324.2470207034395
		ArgOfPericen	33.85138323783621
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 32"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5878190435775195e-07
	Radius		49.564668215281145

	RotationPeriod	8.381631541237883

	Obliquity		165.8220300744136

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5103151581862426
		Eccentricity	0.1
		Inclination		0.6015744120440285
		AscendingNode	231.0444632448509
		ArgOfPericen	193.90615126821598
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 33"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.627011148457908e-07
	Radius		66.79770117200677

	RotationPeriod	7.2799953277230935

	Obliquity		350.98285610112293

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5129674563610508
		Eccentricity	0.1
		Inclination		-1.21803222880219
		AscendingNode	267.75955160445756
		ArgOfPericen	321.693056569504
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 34"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5072619022321663
		Eccentricity	0.1
		Inclination		0.24687511655133065
		AscendingNode	293.85248909803
		ArgOfPericen	251.34879267489563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 34 A"
{
	ParentBody	"Aeolus C 34"
	Class		"Asteroid"
	Mass		1.8309071511119103e-07
	Radius		46.7908919046425

	Orbit
	{
		Epoch			2457395.5
		Period			0.006499751895474703
		Eccentricity	0.002303229100718771
		Inclination		306.4498029331736
		AscendingNode	238.07507592584258
		ArgOfPericen	155.21726556633104
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 34 B"
{
	ParentBody	"Aeolus C 34"
	Class		"Asteroid"
	Mass		3.394311068773774e-08
	Radius		26.680241932625986

	Orbit
	{
		Epoch			2457395.5
		Period			0.006499751895474703
		Eccentricity	0.002303229100718771
		Inclination		306.4498029331736
		AscendingNode	238.07507592584258
		ArgOfPericen	335.21726556633104
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 35"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.757878745502627e-07
	Radius		47.602943024028804

	RotationPeriod	8.484910342384872

	Obliquity		153.67268278392027

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5108241772153242
		Eccentricity	0.1
		Inclination		0.8930454004684054
		AscendingNode	77.64065673447385
		ArgOfPericen	297.68094259385725
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 36"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0968220929668016e-06
	Radius		79.28210224779608

	RotationPeriod	3.788606865920352

	Obliquity		128.06868627853424

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5118237288127482
		Eccentricity	0.1
		Inclination		-0.5344494762832923
		AscendingNode	114.41187147758626
		ArgOfPericen	255.69422072018654
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 36.1"
{
	ParentBody	"Aeolus C 36"
	Class		"Asteroid"
	Mass		5.812504353853305e-09
	Radius		13.822423379191115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.5598336208867464e-06
		Eccentricity	0.0048693330650757104
		Inclination		-52.21287706276243
		AscendingNode	86.73304648265734
		ArgOfPericen	205.07201198809602
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 37"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3464329668711e-07
	Radius		47.84104417851262

	RotationPeriod	4.452226213103495

	Obliquity		322.0611302447241

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5067184178399164
		Eccentricity	0.1
		Inclination		0.7206432870005723
		AscendingNode	38.158030361341744
		ArgOfPericen	283.0204665226157
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 37.1"
{
	ParentBody	"Aeolus C 37"
	Class		"Asteroid"
	Mass		1.0417461775336266e-10
	Radius		3.6496557717717266

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.773288749760069e-06
		Eccentricity	0.004355152460423522
		Inclination		-58.92321005572681
		AscendingNode	257.2198743067901
		ArgOfPericen	230.0988120088186
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 37.2"
{
	ParentBody	"Aeolus C 37"
	Class		"Asteroid"
	Mass		5.947163615670347e-10
	Radius		6.522807496713596

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.1546433806677987e-07
		Eccentricity	0.00417276032128328
		Inclination		21.470348723146778
		AscendingNode	261.20863820067234
		ArgOfPericen	11.445177516769562
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 38"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5118536511765608
		Eccentricity	0.1
		Inclination		-4.895548318807351
		AscendingNode	136.24065156946165
		ArgOfPericen	205.68537878917158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 38 A"
{
	ParentBody	"Aeolus C 38"
	Class		"Asteroid"
	Mass		1.2588828400454663e-07
	Radius		36.95815943442452

	Orbit
	{
		Epoch			2457395.5
		Period			0.00645817617936074
		Eccentricity	0.00602969259735465
		Inclination		218.9603482296356
		AscendingNode	221.24480726885517
		ArgOfPericen	64.79801658208223
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 38 B"
{
	ParentBody	"Aeolus C 38"
	Class		"Asteroid"
	Mass		4.871751923173792e-09
	Radius		12.500967281456248

	Orbit
	{
		Epoch			2457395.5
		Period			0.00645817617936074
		Eccentricity	0.00602969259735465
		Inclination		218.9603482296356
		AscendingNode	221.24480726885517
		ArgOfPericen	244.79801658208223
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 39"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8607127410898486e-07
	Radius		43.199689288488536

	RotationPeriod	6.07118045264371

	Obliquity		207.19318003565883

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5095980794255939
		Eccentricity	0.1
		Inclination		-2.109209464844169
		AscendingNode	205.33535058286773
		ArgOfPericen	81.25602277330151
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 39.1"
{
	ParentBody	"Aeolus C 39"
	Class		"Asteroid"
	Mass		5.2682052128867903e-11
	Radius		2.836667332366087

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.849536074743293e-06
		Eccentricity	0.0052514505550843105
		Inclination		36.33711645896154
		AscendingNode	52.08393698741122
		ArgOfPericen	175.25029766147088
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 39.2"
{
	ParentBody	"Aeolus C 39"
	Class		"Asteroid"
	Mass		9.93514184733518e-10
	Radius		7.550554906884699

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.139881791609751e-06
		Eccentricity	0.002717988187266734
		Inclination		25.958221525984396
		AscendingNode	307.59281292643175
		ArgOfPericen	269.7459021758787
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 40"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.556459083886549e-07
	Radius		71.54087157048941

	RotationPeriod	7.747035179199964

	Obliquity		278.97693594716276

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5115577071035634
		Eccentricity	0.1
		Inclination		2.8760846654856937
		AscendingNode	306.12336192097547
		ArgOfPericen	351.0769125350455
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 40.1"
{
	ParentBody	"Aeolus C 40"
	Class		"Asteroid"
	Mass		2.965967559141225e-10
	Radius		5.2380573280068745

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.156011213301103e-06
		Eccentricity	0.0036913529788736776
		Inclination		26.416463128821658
		AscendingNode	74.27942224892016
		ArgOfPericen	316.4288640404222
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 41"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.041944874318597e-08
	Radius		26.341375023150977

	RotationPeriod	3.9141349094924163

	Obliquity		252.46955656625008

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5079182131153795
		Eccentricity	0.1
		Inclination		0.5472626577959048
		AscendingNode	195.98524689343998
		ArgOfPericen	176.47399760974648
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 42"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.100061441643612e-08
	Radius		25.920502845951304

	RotationPeriod	5.06574489830232

	Obliquity		47.220411666407635

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5127122917726327
		Eccentricity	0.1
		Inclination		0.8932383896352455
		AscendingNode	292.9896634049758
		ArgOfPericen	33.88435334122264
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 43"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5111902637005877
		Eccentricity	0.1
		Inclination		-1.1262551298310102
		AscendingNode	4.363575342217194
		ArgOfPericen	191.97142136898876
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 43 A"
{
	ParentBody	"Aeolus C 43"
	Class		"Asteroid"
	Mass		1.9842224767148935e-06
	Radius		92.18170845452178

	Orbit
	{
		Epoch			2457395.5
		Period			0.004630041773974889
		Eccentricity	0.005345647096634128
		Inclination		256.2945858470419
		AscendingNode	308.44256326305504
		ArgOfPericen	69.45871430359375
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 43 B"
{
	ParentBody	"Aeolus C 43"
	Class		"Asteroid"
	Mass		3.6279006869413706e-07
	Radius		52.31984248945418

	Orbit
	{
		Epoch			2457395.5
		Period			0.004630041773974889
		Eccentricity	0.005345647096634128
		Inclination		256.2945858470419
		AscendingNode	308.44256326305504
		ArgOfPericen	249.45871430359375
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 44"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5119729872432882
		Eccentricity	0.1
		Inclination		0.10976488733044895
		AscendingNode	187.48932915829948
		ArgOfPericen	131.99431592625334
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 44 A"
{
	ParentBody	"Aeolus C 44"
	Class		"Asteroid"
	Mass		3.95085285899625e-08
	Radius		26.912141060557115

	Orbit
	{
		Epoch			2457395.5
		Period			0.002813534579120826
		Eccentricity	0.005300923501975249
		Inclination		210.85742582656277
		AscendingNode	224.92672411579653
		ArgOfPericen	202.78184411752687
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 44 B"
{
	ParentBody	"Aeolus C 44"
	Class		"Asteroid"
	Mass		6.21429997305442e-09
	Radius		14.527204040819546

	Orbit
	{
		Epoch			2457395.5
		Period			0.002813534579120826
		Eccentricity	0.005300923501975249
		Inclination		210.85742582656277
		AscendingNode	224.92672411579653
		ArgOfPericen	22.781844117526873
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 45"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.054003159128325e-07
	Radius		55.47094870775023

	RotationPeriod	5.066274815581782

	Obliquity		83.10969363416137

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5093231961700636
		Eccentricity	0.1
		Inclination		0.14935037771413934
		AscendingNode	191.41097858328473
		ArgOfPericen	177.7402995164838
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 46"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0765980363892992e-07
	Radius		47.49959089345744

	RotationPeriod	3.828756475442494

	Obliquity		302.5460601742429

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5065270652371041
		Eccentricity	0.1
		Inclination		-2.946701354801753
		AscendingNode	255.2701967438492
		ArgOfPericen	91.65514719246467
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 47"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5044787496393229
		Eccentricity	0.1
		Inclination		1.6472448481117845
		AscendingNode	169.50102464045688
		ArgOfPericen	253.5648717867607
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 47 A"
{
	ParentBody	"Aeolus C 47"
	Class		"Asteroid"
	Mass		3.217254645364992e-07
	Radius		55.92784891655454

	Orbit
	{
		Epoch			2457395.5
		Period			0.005087298131132268
		Eccentricity	0.004993124482699486
		Inclination		63.44277652004894
		AscendingNode	139.03221379407728
		ArgOfPericen	283.15249154036616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 47 B"
{
	ParentBody	"Aeolus C 47"
	Class		"Asteroid"
	Mass		5.197875807970032e-09
	Radius		14.138660620959278

	Orbit
	{
		Epoch			2457395.5
		Period			0.005087298131132268
		Eccentricity	0.004993124482699486
		Inclination		63.44277652004894
		AscendingNode	139.03221379407728
		ArgOfPericen	103.15249154036616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 48"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.8789728924912616e-08
	Radius		28.945206569436632

	RotationPeriod	3.583209297558469

	Obliquity		117.64672762819667

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5084588943353673
		Eccentricity	0.1
		Inclination		-1.1095518117898973
		AscendingNode	130.91059655714136
		ArgOfPericen	271.41262701852884
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 48.1"
{
	ParentBody	"Aeolus C 48"
	Class		"Asteroid"
	Mass		1.8780762954179817e-10
	Radius		4.2629860463433955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9766707795320254e-06
		Eccentricity	0.002868011551794386
		Inclination		-33.08644670631777
		AscendingNode	345.2285266088331
		ArgOfPericen	163.57077736071915
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 48.2"
{
	ParentBody	"Aeolus C 48"
	Class		"Asteroid"
	Mass		4.1371679459322947e-10
	Radius		5.546817594312781

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.877621765084742e-06
		Eccentricity	0.002776596915472996
		Inclination		-9.983768216569574
		AscendingNode	112.47880079898714
		ArgOfPericen	15.881556942196244
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 49"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5163691586367466
		Eccentricity	0.1
		Inclination		1.9962009329562969
		AscendingNode	54.60242099382108
		ArgOfPericen	194.35761042051078
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 49 A"
{
	ParentBody	"Aeolus C 49"
	Class		"Asteroid"
	Mass		3.685070636917987e-08
	Radius		24.029819115500207

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016958840421668786
		Eccentricity	0.007377934308840457
		Inclination		281.2367237728625
		AscendingNode	33.31463789091471
		ArgOfPericen	190.04419213390148
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 49 B"
{
	ParentBody	"Aeolus C 49"
	Class		"Asteroid"
	Mass		3.167111902852716e-08
	Radius		22.846676492400658

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016958840421668786
		Eccentricity	0.007377934308840457
		Inclination		281.2367237728625
		AscendingNode	33.31463789091471
		ArgOfPericen	10.044192133901447
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 50"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1945558117894105e-07
	Radius		37.25949182607366

	RotationPeriod	5.08144470340673

	Obliquity		303.371590186851

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5111389913609475
		Eccentricity	0.1
		Inclination		-2.694841258451091
		AscendingNode	100.81062255494787
		ArgOfPericen	235.29042849534355
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 51"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.012541547162929e-09
	Radius		12.614106746373167

	RotationPeriod	6.074300446767533

	Obliquity		359.3086247519387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5122532694297582
		Eccentricity	0.1
		Inclination		-0.4451570269211813
		AscendingNode	128.04911763144776
		ArgOfPericen	337.94678416357095
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 52"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.267029627689119e-07
	Radius		57.264362861309664

	RotationPeriod	6.429269458759893

	Obliquity		7.562470893043138

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5102093783538866
		Eccentricity	0.1
		Inclination		1.6078616533025496
		AscendingNode	190.92611935980668
		ArgOfPericen	251.5319959180535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 53"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.420901278879656e-08
	Radius		33.23773005248167

	RotationPeriod	7.528370489122074

	Obliquity		291.95767838680604

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5058111761676958
		Eccentricity	0.1
		Inclination		0.03062671102907117
		AscendingNode	58.966926783996556
		ArgOfPericen	192.96110727692692
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 53.1"
{
	ParentBody	"Aeolus C 53"
	Class		"Asteroid"
	Mass		9.448622673991898e-10
	Radius		7.441057598894812

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.50686637751622e-06
		Eccentricity	0.0044953868731414225
		Inclination		90
		AscendingNode	109.2224651014748
		ArgOfPericen	121.02348864863043
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 53.2"
{
	ParentBody	"Aeolus C 53"
	Class		"Asteroid"
	Mass		7.404918471034421e-10
	Radius		6.860439277592115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.8014112420303293e-06
		Eccentricity	0.004652135829960757
		Inclination		23.227037912638018
		AscendingNode	256.06828379854943
		ArgOfPericen	141.00953022411852
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 54"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5092222653139454
		Eccentricity	0.1
		Inclination		-1.327864907236378
		AscendingNode	10.881687252047252
		ArgOfPericen	329.9749338579411
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 54 A"
{
	ParentBody	"Aeolus C 54"
	Class		"Asteroid"
	Mass		6.62343555350144e-07
	Radius		64.61994801246443

	Orbit
	{
		Epoch			2457395.5
		Period			0.007387741389573353
		Eccentricity	0.00402189317738989
		Inclination		68.77742565301928
		AscendingNode	200.0691028111227
		ArgOfPericen	114.62574487388846
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 54 B"
{
	ParentBody	"Aeolus C 54"
	Class		"Asteroid"
	Mass		5.425815720144492e-07
	Radius		60.463578325473975

	Orbit
	{
		Epoch			2457395.5
		Period			0.007387741389573353
		Eccentricity	0.00402189317738989
		Inclination		68.77742565301928
		AscendingNode	200.0691028111227
		ArgOfPericen	294.6257448738885
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 55"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.6354497952333374e-07
	Radius		60.95816006940784

	RotationPeriod	7.401615147585471

	Obliquity		57.17558493655546

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5081962352526989
		Eccentricity	0.1
		Inclination		0.8062470245638217
		AscendingNode	242.09859907623684
		ArgOfPericen	311.3836884968185
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 56"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.502363046665204e-08
	Radius		37.51673157242942

	RotationPeriod	3.982379596969956

	Obliquity		12.334694977790704

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5085917413509998
		Eccentricity	0.1
		Inclination		3.7449527138597793
		AscendingNode	357.70581882471083
		ArgOfPericen	152.76268957093592
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 57"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.928659352162912e-08
	Radius		24.991404810383155

	RotationPeriod	7.329847411314065

	Obliquity		152.65338422395553

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5097777182056148
		Eccentricity	0.1
		Inclination		-0.015638129932448747
		AscendingNode	145.20472821376876
		ArgOfPericen	162.9965026707104
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 58"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.352404474215767e-07
	Radius		54.37075408141118

	RotationPeriod	6.186446880521911

	Obliquity		94.70924354306115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5091542552472307
		Eccentricity	0.1
		Inclination		-0.3784860255770152
		AscendingNode	327.19873467387225
		ArgOfPericen	250.77565912195817
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 58.1"
{
	ParentBody	"Aeolus C 58"
	Class		"Asteroid"
	Mass		3.063583686099828e-10
	Radius		5.276222908756646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.755879916638472e-06
		Eccentricity	0.008131613284142334
		Inclination		-31.287733318822625
		AscendingNode	172.9830574536781
		ArgOfPericen	147.51648984220566
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 59"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8667989216542834e-07
	Radius		57.687097302402776

	RotationPeriod	7.1251259061552865

	Obliquity		256.23393980658193

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5107479757305389
		Eccentricity	0.1
		Inclination		-0.11858498425951529
		AscendingNode	53.20019012251022
		ArgOfPericen	350.2703437500318
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 60"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.972070544246796e-07
	Radius		59.89008314002524

	RotationPeriod	7.457081694498266

	Obliquity		82.31241553494237

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5098560911612863
		Eccentricity	0.1
		Inclination		2.901585446719452
		AscendingNode	281.0958541867026
		ArgOfPericen	157.90433347089632
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 60.1"
{
	ParentBody	"Aeolus C 60"
	Class		"Asteroid"
	Mass		3.112281286024713e-09
	Radius		11.895303998736377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5959644722401015e-06
		Eccentricity	0.0023498518874426316
		Inclination		15.44200951863916
		AscendingNode	244.20503482343716
		ArgOfPericen	13.758903234574337
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 61"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.1434254574106335e-07
	Radius		46.352533311692106

	RotationPeriod	5.660771252703452

	Obliquity		67.14829370495596

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5116703227319502
		Eccentricity	0.1
		Inclination		0.8535652262755539
		AscendingNode	226.34884405502189
		ArgOfPericen	158.7689926962253
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 62"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.325862806655645e-07
	Radius		41.41784811792033

	RotationPeriod	8.370304666144023

	Obliquity		358.68867862928175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5082113369765349
		Eccentricity	0.1
		Inclination		3.61435315258492
		AscendingNode	293.8979521885606
		ArgOfPericen	194.2360707717682
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 62.1"
{
	ParentBody	"Aeolus C 62"
	Class		"Asteroid"
	Mass		1.2947949080138922e-09
	Radius		8.8529564842403

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6864717511421324e-06
		Eccentricity	0.004558849230587254
		Inclination		-7.413895736110306
		AscendingNode	273.2762412300605
		ArgOfPericen	30.703523432713755
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 63"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4619063332616648e-07
	Radius		39.821088081077576

	RotationPeriod	8.02773337597284

	Obliquity		338.7178366145572

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5119433002884225
		Eccentricity	0.1
		Inclination		0.29985905612317865
		AscendingNode	272.33996314011245
		ArgOfPericen	25.609370421517564
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 64"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.003363781235792e-08
	Radius		26.134662631409313

	RotationPeriod	5.77160695973489

	Obliquity		205.98563723040297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5085125605549384
		Eccentricity	0.1
		Inclination		2.863310064934414
		AscendingNode	288.67228879248245
		ArgOfPericen	246.68509430554602
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 65"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.6231233699417445e-07
	Radius		61.1069877426556

	RotationPeriod	3.3878440839562

	Obliquity		345.92535143412107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5107490672742104
		Eccentricity	0.1
		Inclination		-0.3766279395697465
		AscendingNode	1.4513584263296897
		ArgOfPericen	92.46032093468747
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 66"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5091834364609816
		Eccentricity	0.1
		Inclination		0.34001834004878556
		AscendingNode	129.3080074918013
		ArgOfPericen	74.52203958845492
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 66 A"
{
	ParentBody	"Aeolus C 66"
	Class		"Asteroid"
	Mass		8.962698696545378e-08
	Radius		35.97793772807948

	Orbit
	{
		Epoch			2457395.5
		Period			0.004080326514863101
		Eccentricity	0.008548571014611277
		Inclination		188.96647847052535
		AscendingNode	277.0927089741885
		ArgOfPericen	8.38948403441799
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 66 B"
{
	ParentBody	"Aeolus C 66"
	Class		"Asteroid"
	Mass		7.458487599823673e-09
	Radius		15.707494784295811

	Orbit
	{
		Epoch			2457395.5
		Period			0.004080326514863101
		Eccentricity	0.008548571014611277
		Inclination		188.96647847052535
		AscendingNode	277.0927089741885
		ArgOfPericen	188.389484034418
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 67"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5032668564563387
		Eccentricity	0.1
		Inclination		-3.725793031576232
		AscendingNode	55.28099773842304
		ArgOfPericen	20.934168343597396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 67 A"
{
	ParentBody	"Aeolus C 67"
	Class		"Asteroid"
	Mass		5.838185565192799e-07
	Radius		62.45171630750547

	Orbit
	{
		Epoch			2457395.5
		Period			0.005919292103793545
		Eccentricity	0.0034645307364534767
		Inclination		94.56613472161789
		AscendingNode	159.58307721726405
		ArgOfPericen	175.72983779928975
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 67 B"
{
	ParentBody	"Aeolus C 67"
	Class		"Asteroid"
	Mass		1.793830614458129e-08
	Radius		19.56045219452645

	Orbit
	{
		Epoch			2457395.5
		Period			0.005919292103793545
		Eccentricity	0.0034645307364534767
		Inclination		94.56613472161789
		AscendingNode	159.58307721726405
		ArgOfPericen	355.7298377992897
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 68"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.925346887619992e-07
	Radius		75.81146649725781

	RotationPeriod	5.300320315613295

	Obliquity		232.82262137201917

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5136566673896678
		Eccentricity	0.1
		Inclination		-1.3062281981441708
		AscendingNode	215.45719348340782
		ArgOfPericen	331.1206732971388
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 69"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5016674106725643e-07
	Radius		53.37579833186718

	RotationPeriod	4.540334957757931

	Obliquity		311.3203361600233

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5101124022502899
		Eccentricity	0.1
		Inclination		-1.5021128072885723
		AscendingNode	68.93937714063492
		ArgOfPericen	324.750963137708
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 70"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.90377733410979e-07
	Radius		56.82744770746153

	RotationPeriod	4.923563825584997

	Obliquity		172.52315299700777

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5120893530878633
		Eccentricity	0.1
		Inclination		2.239872352293116
		AscendingNode	62.850727507588566
		ArgOfPericen	183.30646998970002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 71"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.087417503653959e-07
	Radius		45.644158923307344

	RotationPeriod	7.639617220448772

	Obliquity		305.6577211730596

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.509661867236008
		Eccentricity	0.1
		Inclination		-0.8782677468697224
		AscendingNode	100.70783662435463
		ArgOfPericen	81.46025440168061
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 72"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5105116754124013
		Eccentricity	0.1
		Inclination		-1.0680218607229806
		AscendingNode	7.882305653259021
		ArgOfPericen	66.20919322809146
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 72 A"
{
	ParentBody	"Aeolus C 72"
	Class		"Asteroid"
	Mass		9.032691952580132e-07
	Radius		75.72002036245237

	Orbit
	{
		Epoch			2457395.5
		Period			0.001172321898067093
		Eccentricity	0.0050850086424077965
		Inclination		203.92603313512168
		AscendingNode	163.06688029503377
		ArgOfPericen	23.285751798634013
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 72 B"
{
	ParentBody	"Aeolus C 72"
	Class		"Asteroid"
	Mass		6.978901947317989e-07
	Radius		69.48120703514812

	Orbit
	{
		Epoch			2457395.5
		Period			0.001172321898067093
		Eccentricity	0.0050850086424077965
		Inclination		203.92603313512168
		AscendingNode	163.06688029503377
		ArgOfPericen	203.285751798634
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 73"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6643127000001344e-07
	Radius		39.019328410696374

	RotationPeriod	10.137474291364132

	Obliquity		88.80460199301336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5069595846549124
		Eccentricity	0.1
		Inclination		-2.0884787250028434
		AscendingNode	150.6149512617338
		ArgOfPericen	46.91215525086194
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 74"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5069070429592935
		Eccentricity	0.1
		Inclination		1.746829568396298
		AscendingNode	134.96785519936614
		ArgOfPericen	299.9744896708036
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 74 A"
{
	ParentBody	"Aeolus C 74"
	Class		"Asteroid"
	Mass		4.494750834281225e-08
	Radius		27.80952246297261

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022270034708341173
		Eccentricity	0.005163287356846496
		Inclination		358.7643781368535
		AscendingNode	170.48826455486645
		ArgOfPericen	300.9312136165357
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 74 B"
{
	ParentBody	"Aeolus C 74"
	Class		"Asteroid"
	Mass		1.9566176309731727e-08
	Radius		21.076264733094582

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022270034708341173
		Eccentricity	0.005163287356846496
		Inclination		358.7643781368535
		AscendingNode	170.48826455486645
		ArgOfPericen	120.93121361653567
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 75"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.481539413390704e-08
	Radius		26.51649166793404

	RotationPeriod	8.671925386367116

	Obliquity		312.40800870834533

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5142725364308147
		Eccentricity	0.1
		Inclination		4.139286693660279
		AscendingNode	114.02868124360934
		ArgOfPericen	18.249341836501635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 76"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.80845727752012e-07
	Radius		60.600169885548176

	RotationPeriod	4.5292517911822845

	Obliquity		50.36517900599464

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.511463419606292
		Eccentricity	0.1
		Inclination		-0.5188586446457418
		AscendingNode	25.898376137577724
		ArgOfPericen	139.79456261713779
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 77"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.5854902873299363e-07
	Radius		52.18841802525037

	RotationPeriod	7.354223900504396

	Obliquity		143.86017260765234

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5190838071362169
		Eccentricity	0.1
		Inclination		-2.2086404571054397
		AscendingNode	126.33247813843174
		ArgOfPericen	202.24268320003833
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 78"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0829478069237802e-07
	Radius		47.76958383746058

	RotationPeriod	8.338042543302198

	Obliquity		51.71432487098321

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5081784595695229
		Eccentricity	0.1
		Inclination		0.9772698864903511
		AscendingNode	50.47144020447958
		ArgOfPericen	206.1222478276803
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 79"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.312383970124076e-07
	Radius		62.99226998581518

	RotationPeriod	5.6524873220889065

	Obliquity		47.158050579013164

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5092503145195729
		Eccentricity	0.1
		Inclination		2.3632526476251567
		AscendingNode	320.9584074864079
		ArgOfPericen	214.12748115599572
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 80"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.429347250685372e-07
	Radius		50.3718259282896

	RotationPeriod	9.785602792413245

	Obliquity		330.83620745946126

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5105561371685124
		Eccentricity	0.1
		Inclination		-1.6122937195336027
		AscendingNode	184.31599927882533
		ArgOfPericen	312.1390353388932
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 81"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.730891883446002e-07
	Radius		61.54998068000942

	RotationPeriod	6.179645136699126

	Obliquity		199.51325116380823

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5090688758674768
		Eccentricity	0.1
		Inclination		-0.7222942035254342
		AscendingNode	159.65206473941748
		ArgOfPericen	12.08164166321405
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 82"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.299624445612113e-07
	Radius		47.928107465921826

	RotationPeriod	5.892523951292897

	Obliquity		194.31098362484587

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5133979191150487
		Eccentricity	0.1
		Inclination		-1.461601121782829
		AscendingNode	11.879041758087073
		ArgOfPericen	45.28236957919454
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 83"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5126260633630321
		Eccentricity	0.1
		Inclination		-0.17200077241235218
		AscendingNode	23.575948936426485
		ArgOfPericen	356.22957335735657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 83 A"
{
	ParentBody	"Aeolus C 83"
	Class		"Asteroid"
	Mass		4.0299364846207e-07
	Radius		56.86918687664149

	Orbit
	{
		Epoch			2457395.5
		Period			0.0027582057068585427
		Eccentricity	0.005217162063608358
		Inclination		147.05574270033358
		AscendingNode	277.57184106742017
		ArgOfPericen	234.8645439151006
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 83 B"
{
	ParentBody	"Aeolus C 83"
	Class		"Asteroid"
	Mass		4.883560994418945e-08
	Radius		28.14209925039097

	Orbit
	{
		Epoch			2457395.5
		Period			0.0027582057068585427
		Eccentricity	0.005217162063608358
		Inclination		147.05574270033358
		AscendingNode	277.57184106742017
		ArgOfPericen	54.864543915100626
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 84"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5095789679400093
		Eccentricity	0.1
		Inclination		1.0973324656751722
		AscendingNode	160.7261858226156
		ArgOfPericen	322.9432202542026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 84 A"
{
	ParentBody	"Aeolus C 84"
	Class		"Asteroid"
	Mass		4.537039398920908e-07
	Radius		55.43839466385564

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008410283347884573
		Eccentricity	0.006724065613400169
		Inclination		349.82605263048845
		AscendingNode	228.3865648957364
		ArgOfPericen	158.0947427480148
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 84 B"
{
	ParentBody	"Aeolus C 84"
	Class		"Asteroid"
	Mass		2.319194743120775e-07
	Radius		44.32671372706878

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008410283347884573
		Eccentricity	0.006724065613400169
		Inclination		349.82605263048845
		AscendingNode	228.3865648957364
		ArgOfPericen	338.0947427480148
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 85"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.901503688151026e-08
	Radius		31.716438355716686

	RotationPeriod	2.9959134118003075

	Obliquity		206.41099551160735

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5106887996910648
		Eccentricity	0.1
		Inclination		2.286795474397442
		AscendingNode	319.1957689389169
		ArgOfPericen	75.51797910529577
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 86"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5087618571508774
		Eccentricity	0.1
		Inclination		0.27940604656809476
		AscendingNode	223.7716905037046
		ArgOfPericen	257.4622008339167
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 86 A"
{
	ParentBody	"Aeolus C 86"
	Class		"Asteroid"
	Mass		2.602399722786081e-07
	Radius		51.93132562821579

	Orbit
	{
		Epoch			2457395.5
		Period			0.00404891389563702
		Eccentricity	0.006965694645281682
		Inclination		7.072996765355222
		AscendingNode	183.08772815720985
		ArgOfPericen	6.786331321000447
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 86 B"
{
	ParentBody	"Aeolus C 86"
	Class		"Asteroid"
	Mass		8.532241520703838e-08
	Radius		35.80902153367243

	Orbit
	{
		Epoch			2457395.5
		Period			0.00404891389563702
		Eccentricity	0.006965694645281682
		Inclination		7.072996765355222
		AscendingNode	183.08772815720985
		ArgOfPericen	186.78633132100046
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 87"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.722071847130257e-07
	Radius		40.977004681827886

	RotationPeriod	6.082467460450481

	Obliquity		287.43500923458396

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5111873135126664
		Eccentricity	0.1
		Inclination		0.7068189240659575
		AscendingNode	249.73140557487156
		ArgOfPericen	124.33387363437846
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 87.1"
{
	ParentBody	"Aeolus C 87"
	Class		"Asteroid"
	Mass		1.1650090999594611e-09
	Radius		7.749961760694342

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.037830995868111e-06
		Eccentricity	0.006536322720617706
		Inclination		29.15331412773531
		AscendingNode	328.25911759276045
		ArgOfPericen	350.8400729237492
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 87.2"
{
	ParentBody	"Aeolus C 87"
	Class		"Asteroid"
	Mass		6.31853922867815e-11
	Radius		2.9335625255170794

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6590252936532927e-06
		Eccentricity	0.007348507271358124
		Inclination		-7.609019598333368
		AscendingNode	315.30722650205894
		ArgOfPericen	220.87588288612753
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 87.3"
{
	ParentBody	"Aeolus C 87"
	Class		"Asteroid"
	Mass		2.1041842092506627e-10
	Radius		4.380775922129852

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2902787248111723e-06
		Eccentricity	0.006520542261146906
		Inclination		46.691445273520685
		AscendingNode	63.36638555012592
		ArgOfPericen	81.38409089054583
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 88"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0452683296475367e-07
	Radius		37.382062765244484

	RotationPeriod	5.842703722463266

	Obliquity		2.876518532884047

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5163664247735633
		Eccentricity	0.1
		Inclination		4.460242269762911
		AscendingNode	234.4357749440125
		ArgOfPericen	177.14686815100353
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 89"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5096861246678595
		Eccentricity	0.1
		Inclination		1.9587966103020624
		AscendingNode	63.67706936719237
		ArgOfPericen	54.864219742412736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 89 A"
{
	ParentBody	"Aeolus C 89"
	Class		"Asteroid"
	Mass		9.464704188513837e-08
	Radius		34.531365623811226

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013448459960377576
		Eccentricity	0.00557201185613283
		Inclination		108.08479260332042
		AscendingNode	253.73529296567347
		ArgOfPericen	63.43603222490434
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 89 B"
{
	ParentBody	"Aeolus C 89"
	Class		"Asteroid"
	Mass		5.605723442534848e-08
	Radius		28.99937434883573

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013448459960377576
		Eccentricity	0.00557201185613283
		Inclination		108.08479260332042
		AscendingNode	253.73529296567347
		ArgOfPericen	243.43603222490435
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 90"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.514571970975223
		Eccentricity	0.1
		Inclination		-4.019295443352053
		AscendingNode	34.632222663035314
		ArgOfPericen	23.033784027718404
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 90 A"
{
	ParentBody	"Aeolus C 90"
	Class		"Asteroid"
	Mass		9.172491904921512e-08
	Radius		35.188624643719606

	Orbit
	{
		Epoch			2457395.5
		Period			0.003410102558824502
		Eccentricity	0.0072561500839307316
		Inclination		26.531457178079943
		AscendingNode	16.298256996702015
		ArgOfPericen	3.0102082315590106
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 90 B"
{
	ParentBody	"Aeolus C 90"
	Class		"Asteroid"
	Mass		4.2419660962579705e-08
	Radius		27.21211167910981

	Orbit
	{
		Epoch			2457395.5
		Period			0.003410102558824502
		Eccentricity	0.0072561500839307316
		Inclination		26.531457178079943
		AscendingNode	16.298256996702015
		ArgOfPericen	183.010208231559
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 91"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5108938495137656
		Eccentricity	0.1
		Inclination		-0.671595947682178
		AscendingNode	202.15692176402814
		ArgOfPericen	22.551243681886884
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 91 A"
{
	ParentBody	"Aeolus C 91"
	Class		"Asteroid"
	Mass		3.8158003480804764e-07
	Radius		53.712158534836696

	Orbit
	{
		Epoch			2457395.5
		Period			0.001118264678136193
		Eccentricity	0.0050959235048545345
		Inclination		156.44397328198548
		AscendingNode	92.72256950256632
		ArgOfPericen	46.478189357570756
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 91 B"
{
	ParentBody	"Aeolus C 91"
	Class		"Asteroid"
	Mass		2.8798525988189465e-08
	Radius		22.698690915888214

	Orbit
	{
		Epoch			2457395.5
		Period			0.001118264678136193
		Eccentricity	0.0050959235048545345
		Inclination		156.44397328198548
		AscendingNode	92.72256950256632
		ArgOfPericen	226.47818935757076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 92"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7444861239069445e-07
	Radius		47.154810249244555

	RotationPeriod	6.890183400078349

	Obliquity		312.67184868893867

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5109097595903395
		Eccentricity	0.1
		Inclination		0.11408495604465746
		AscendingNode	284.35276452437984
		ArgOfPericen	140.55098494634188
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 93"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.7639974981070994e-08
	Radius		29.73638286363566

	RotationPeriod	7.091059962372818

	Obliquity		49.99111807914854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5166456033180835
		Eccentricity	0.1
		Inclination		0.3145855886717382
		AscendingNode	96.91226593018803
		ArgOfPericen	258.3504800051154
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 94"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.90841312323634e-07
	Radius		73.67797902431761

	RotationPeriod	7.590843581648081

	Obliquity		100.86084355842516

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5028778201493491
		Eccentricity	0.1
		Inclination		-0.6261888825608503
		AscendingNode	352.55686041498075
		ArgOfPericen	66.35617800757271
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 94.1"
{
	ParentBody	"Aeolus C 94"
	Class		"Asteroid"
	Mass		1.2846533661239548e-10
	Radius		3.7290509958417095

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.935978607537608e-06
		Eccentricity	0.005692569122535929
		Inclination		17.445479377332994
		AscendingNode	136.8731631858063
		ArgOfPericen	27.223802691847595
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 95"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1435736515689895e-07
	Radius		35.28435782660457

	RotationPeriod	6.9304751809443665

	Obliquity		186.51512629562916

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5110821870705099
		Eccentricity	0.1
		Inclination		0.02568133226786953
		AscendingNode	55.635845119954865
		ArgOfPericen	290.7504474894579
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 95.1"
{
	ParentBody	"Aeolus C 95"
	Class		"Asteroid"
	Mass		1.0753811613154054e-09
	Radius		7.447576603679288

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6938295640385715e-06
		Eccentricity	0
		Inclination		-13.807776750943479
		AscendingNode	238.89297413931857
		ArgOfPericen	194.30644917606222
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 96"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.1831628933986396e-07
	Radius		58.67249134709128

	RotationPeriod	2.59785200581588

	Obliquity		0.991358503873645

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5142233963383683
		Eccentricity	0.1
		Inclination		1.0159696285549673
		AscendingNode	335.8620565950143
		ArgOfPericen	3.642223033138956
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 97"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.722852042524928e-07
	Radius		42.49257427765476

	RotationPeriod	6.999470867878761

	Obliquity		350.5661973004608

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5159523786634399
		Eccentricity	0.1
		Inclination		-0.3549062881059018
		AscendingNode	289.9468794878155
		ArgOfPericen	136.9288440459414
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 97.1"
{
	ParentBody	"Aeolus C 97"
	Class		"Asteroid"
	Mass		3.355395440351619e-11
	Radius		2.463078678978291

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4544603396886755e-06
		Eccentricity	0.006327666205531784
		Inclination		43.24308133125642
		AscendingNode	37.919239413805954
		ArgOfPericen	334.01221025338884
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 98"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.629968043008066e-07
	Radius		80.11524395797991

	RotationPeriod	4.79256610012721

	Obliquity		112.51797062747539

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5098106411731368
		Eccentricity	0.1
		Inclination		2.9662766618052223
		AscendingNode	169.19753400410715
		ArgOfPericen	52.51258930956132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 99"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.447152662908439e-07
	Radius		60.13614613129387

	RotationPeriod	3.7339535352883617

	Obliquity		155.72549887413544

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5116611904769294
		Eccentricity	0.1
		Inclination		0.7930177313459607
		AscendingNode	324.2738337707554
		ArgOfPericen	117.38478237950817
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 100"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2927961277812922e-07
	Radius		40.55919949528861

	RotationPeriod	4.804070608416411

	Obliquity		264.0262495360422

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5061259445877757
		Eccentricity	0.1
		Inclination		-0.5276924653288564
		AscendingNode	207.83133513795283
		ArgOfPericen	266.84251615524516
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 101"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.550459832567696e-07
	Radius		42.80227769704584

	RotationPeriod	5.1024042366891935

	Obliquity		206.7922647546007

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5114919296396404
		Eccentricity	0.1
		Inclination		0.43732684535722166
		AscendingNode	180.28300368536955
		ArgOfPericen	136.66127155995946
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 102"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5063381569773053
		Eccentricity	0.1
		Inclination		2.6304094361203707
		AscendingNode	10.71501611862169
		ArgOfPericen	176.26482191806087
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 102 A"
{
	ParentBody	"Aeolus C 102"
	Class		"Asteroid"
	Mass		6.948800637808903e-08
	Radius		29.763219272790796

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018538940550512863
		Eccentricity	0.007565995249907092
		Inclination		306.7716064528298
		AscendingNode	310.0229881917665
		ArgOfPericen	344.77424661812256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 102 B"
{
	ParentBody	"Aeolus C 102"
	Class		"Asteroid"
	Mass		2.1648451262919736e-08
	Radius		20.176797285543593

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018538940550512863
		Eccentricity	0.007565995249907092
		Inclination		306.7716064528298
		AscendingNode	310.0229881917665
		ArgOfPericen	164.77424661812256
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 103"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.84517427031685e-08
	Radius		35.38909657951447

	RotationPeriod	4.963629835601688

	Obliquity		152.48960041689338

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5130676556703959
		Eccentricity	0.1
		Inclination		-1.404431887835212
		AscendingNode	300.272043450839
		ArgOfPericen	104.11910384212558
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 103.1"
{
	ParentBody	"Aeolus C 103"
	Class		"Asteroid"
	Mass		9.0507778441637e-10
	Radius		7.682973107748696

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.4403635694849564e-06
		Eccentricity	0.004168695046994284
		Inclination		-21.640987566510756
		AscendingNode	214.43184034430033
		ArgOfPericen	124.44006531796968
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 104"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5093472936067365
		Eccentricity	0.1
		Inclination		-1.89815693776602
		AscendingNode	187.873937048214
		ArgOfPericen	39.17581515573112
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 104 A"
{
	ParentBody	"Aeolus C 104"
	Class		"Asteroid"
	Mass		4.356934921924021e-07
	Radius		56.66884249080271

	Orbit
	{
		Epoch			2457395.5
		Period			0.004651908065777162
		Eccentricity	0.005496044242442547
		Inclination		164.99426549065876
		AscendingNode	124.10328833253564
		ArgOfPericen	132.25477184420893
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 104 B"
{
	ParentBody	"Aeolus C 104"
	Class		"Asteroid"
	Mass		4.029713428517502e-07
	Radius		55.21308812954718

	Orbit
	{
		Epoch			2457395.5
		Period			0.004651908065777162
		Eccentricity	0.005496044242442547
		Inclination		164.99426549065876
		AscendingNode	124.10328833253564
		ArgOfPericen	312.2547718442089
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 105"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5133368237732187
		Eccentricity	0.1
		Inclination		-1.7412877533251292
		AscendingNode	131.91894728558322
		ArgOfPericen	115.18845685573046
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 105 A"
{
	ParentBody	"Aeolus C 105"
	Class		"Asteroid"
	Mass		4.171385319031731e-08
	Radius		27.216337849249047

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015244620980014877
		Eccentricity	0.006539899305659101
		Inclination		127.48945474967164
		AscendingNode	47.940389826642964
		ArgOfPericen	346.3900697122821
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 105 B"
{
	ParentBody	"Aeolus C 105"
	Class		"Asteroid"
	Mass		1.384906843294755e-08
	Radius		18.845591442197804

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015244620980014877
		Eccentricity	0.006539899305659101
		Inclination		127.48945474967164
		AscendingNode	47.940389826642964
		ArgOfPericen	166.39006971228218
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 106"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.502362792538748
		Eccentricity	0.1
		Inclination		1.458794267304621
		AscendingNode	4.059557641245073
		ArgOfPericen	308.9783864244615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 106 A"
{
	ParentBody	"Aeolus C 106"
	Class		"Asteroid"
	Mass		2.463158492103898e-07
	Radius		47.46948367212848

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006834552051674804
		Eccentricity	0.0036282478178822127
		Inclination		353.62771695966586
		AscendingNode	284.1537060529357
		ArgOfPericen	70.48221812270386
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 106 B"
{
	ParentBody	"Aeolus C 106"
	Class		"Asteroid"
	Mass		7.175013514693787e-09
	Radius		14.605775800044674

	Orbit
	{
		Epoch			2457395.5
		Period			0.0006834552051674804
		Eccentricity	0.0036282478178822127
		Inclination		353.62771695966586
		AscendingNode	284.1537060529357
		ArgOfPericen	250.48221812270384
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 107"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5719757022930165e-06
	Radius		84.27405373662342

	RotationPeriod	6.844301509985839

	Obliquity		151.3719397090641

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5126884880183792
		Eccentricity	0.1
		Inclination		-0.4002202281506363
		AscendingNode	122.27019940991464
		ArgOfPericen	305.0023405180271
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 108"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.260538801537409e-07
	Radius		53.03666716750083

	RotationPeriod	10.977612518273604

	Obliquity		211.76156851420535

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5099715917480654
		Eccentricity	0.1
		Inclination		0.6818981687757397
		AscendingNode	97.80517469798014
		ArgOfPericen	355.1482192887254
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 109"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.6280183821307684e-07
	Radius		61.665241408134

	RotationPeriod	8.24397156082378

	Obliquity		174.92514272918135

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5122597290661495
		Eccentricity	0.1
		Inclination		-1.0370612802547006
		AscendingNode	197.01977715185922
		ArgOfPericen	137.50897508886808
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 110"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5127162822615351
		Eccentricity	0.1
		Inclination		-1.125300878044946
		AscendingNode	90.98549929940951
		ArgOfPericen	351.0824615467815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 110 A"
{
	ParentBody	"Aeolus C 110"
	Class		"Asteroid"
	Mass		1.6601326540036301e-07
	Radius		45.37369891139883

	Orbit
	{
		Epoch			2457395.5
		Period			0.007479914557335358
		Eccentricity	0.00565097946287324
		Inclination		61.504572102134155
		AscendingNode	250.67966607414425
		ArgOfPericen	112.69206967512825
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 110 B"
{
	ParentBody	"Aeolus C 110"
	Class		"Asteroid"
	Mass		1.3136091099831376e-08
	Radius		19.479537356083682

	Orbit
	{
		Epoch			2457395.5
		Period			0.007479914557335358
		Eccentricity	0.00565097946287324
		Inclination		61.504572102134155
		AscendingNode	250.67966607414425
		ArgOfPericen	292.69206967512827
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 111"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5154300534292916
		Eccentricity	0.1
		Inclination		-1.9630753884539487
		AscendingNode	210.38569783362055
		ArgOfPericen	322.3613605415988
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 111 A"
{
	ParentBody	"Aeolus C 111"
	Class		"Asteroid"
	Mass		6.482639022332012e-07
	Radius		68.12335558067805

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033583971038959755
		Eccentricity	0.0014208091901741532
		Inclination		83.29870200852457
		AscendingNode	270.63554485806935
		ArgOfPericen	296.4767049675044
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 111 B"
{
	ParentBody	"Aeolus C 111"
	Class		"Asteroid"
	Mass		3.425195750858968e-07
	Radius		55.07323037397304

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033583971038959755
		Eccentricity	0.0014208091901741532
		Inclination		83.29870200852457
		AscendingNode	270.63554485806935
		ArgOfPericen	116.47670496750442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 112"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.2231832397881015e-07
	Radius		53.44627356232584

	RotationPeriod	2.55512453104262

	Obliquity		358.81577241468966

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5106957913101394
		Eccentricity	0.1
		Inclination		-2.021843398073195
		AscendingNode	237.02024857426454
		ArgOfPericen	134.8437008083386
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 113"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8766211688085788e-07
	Radius		44.12260038062836

	RotationPeriod	4.875228189975468

	Obliquity		30.638005535825673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5102796445269893
		Eccentricity	0.1
		Inclination		-0.7076343668696138
		AscendingNode	79.89511855782926
		ArgOfPericen	273.372171402326
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 114"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2575084865618978e-07
	Radius		40.047176291221405

	RotationPeriod	5.3851499869961845

	Obliquity		207.03136827533916

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5084719712061033
		Eccentricity	0.1
		Inclination		-0.7869285496200483
		AscendingNode	311.2329443008252
		ArgOfPericen	134.67905395317774
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 115"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5096022797581243
		Eccentricity	0.1
		Inclination		-1.0435629846827519
		AscendingNode	125.03309873295454
		ArgOfPericen	60.90121255440517
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 115 A"
{
	ParentBody	"Aeolus C 115"
	Class		"Asteroid"
	Mass		3.619307728022129e-08
	Radius		25.819891370892655

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037041045483354627
		Eccentricity	0.007778670438293618
		Inclination		57.80518442615123
		AscendingNode	6.67290026474086
		ArgOfPericen	2.5337254776002016
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 115 B"
{
	ParentBody	"Aeolus C 115"
	Class		"Asteroid"
	Mass		1.8976204656407497e-08
	Radius		20.820078337065212

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037041045483354627
		Eccentricity	0.007778670438293618
		Inclination		57.80518442615123
		AscendingNode	6.67290026474086
		ArgOfPericen	182.5337254776002
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 116"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.9258937035409365e-07
	Radius		55.05339723029775

	RotationPeriod	5.977594327406406

	Obliquity		177.84004105295466

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.509232814843457
		Eccentricity	0.1
		Inclination		1.2070001365964371
		AscendingNode	113.39320826404754
		ArgOfPericen	129.89519825167002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 117"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.63751108769544e-08
	Radius		29.68542678289577

	RotationPeriod	8.244861770062629

	Obliquity		265.5426621877012

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5051335810509986
		Eccentricity	0.1
		Inclination		0.9383539802097346
		AscendingNode	161.26143529657293
		ArgOfPericen	113.39332364908398
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 118"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.00678857003365e-08
	Radius		30.201683109823882

	RotationPeriod	5.734258952413819

	Obliquity		320.7808514441344

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5090561340137602
		Eccentricity	0.1
		Inclination		3.1646266077083203
		AscendingNode	229.5512197333681
		ArgOfPericen	238.72720667545153
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 119"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.365678326619643e-08
	Radius		34.36260902512364

	RotationPeriod	5.0558108804924435

	Obliquity		42.07283532073554

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5135940200438982
		Eccentricity	0.1
		Inclination		2.1302747644581244
		AscendingNode	214.0041953367874
		ArgOfPericen	110.46246789175694
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 119.1"
{
	ParentBody	"Aeolus C 119"
	Class		"Asteroid"
	Mass		3.0209370878914487e-10
	Radius		5.077153322371146

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.9366128552024417e-06
		Eccentricity	0.003940005888903933
		Inclination		26.617913259936493
		AscendingNode	252.03578541651171
		ArgOfPericen	48.39167337343752
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 120"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.044188937717473e-08
	Radius		29.165041445830404

	RotationPeriod	6.494071516324976

	Obliquity		271.1888521308749

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5087939197446956
		Eccentricity	0.1
		Inclination		-1.4647934364477602
		AscendingNode	359.9177313583287
		ArgOfPericen	313.58460434213396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 121"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.660631924618015e-08
	Radius		19.254285183229793

	RotationPeriod	6.689064947361742

	Obliquity		271.77032271343137

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5135636840495945
		Eccentricity	0.1
		Inclination		0.6901455675721204
		AscendingNode	110.2728872469447
		ArgOfPericen	124.82193243851346
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 122"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.159960978737309e-08
	Radius		30.807809397618858

	RotationPeriod	3.303916338479112

	Obliquity		97.3413751395661

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5120636097968659
		Eccentricity	0.1
		Inclination		-1.2043234912678866
		AscendingNode	348.9738749265466
		ArgOfPericen	252.2177821335749
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 123"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.71075707787942e-07
	Radius		70.63074233911506

	RotationPeriod	7.326502546664441

	Obliquity		330.98736664382534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.504806011864176
		Eccentricity	0.1
		Inclination		0.8048077399842464
		AscendingNode	29.295775055106084
		ArgOfPericen	254.53164119475778
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 124"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2854679085289629e-08
	Radius		18.253550910092883

	RotationPeriod	3.7084866952442046

	Obliquity		265.5176093849039

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5033942321138914
		Eccentricity	0.1
		Inclination		1.1502866862371879
		AscendingNode	296.98753837991
		ArgOfPericen	327.37341359594996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 125"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.488148933592502e-07
	Radius		53.171975144062536

	RotationPeriod	4.730246629313944

	Obliquity		357.4578755895213

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5089790583235255
		Eccentricity	0.1
		Inclination		1.0874864684881234
		AscendingNode	45.748244541227095
		ArgOfPericen	176.7567276042916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 126"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.683428772512223e-07
	Radius		74.25632230046446

	RotationPeriod	8.85330800424142

	Obliquity		145.25959235130452

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5104186810291704
		Eccentricity	0.1
		Inclination		-0.4646401838726349
		AscendingNode	355.7466092479049
		ArgOfPericen	236.97690149726344
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 126.1"
{
	ParentBody	"Aeolus C 126"
	Class		"Asteroid"
	Mass		7.221193741615112e-09
	Radius		15.044324290500942

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.129157197317662e-06
		Eccentricity	0.001756022975928047
		Inclination		-2.124393979688369
		AscendingNode	55.716044522841635
		ArgOfPericen	58.84189622291299
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 127"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.5041200086570185e-07
	Radius		54.776343346459306

	RotationPeriod	8.470326003313136

	Obliquity		180.48185741156107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5137960748770064
		Eccentricity	0.1
		Inclination		-0.39272102851168017
		AscendingNode	248.06565516050998
		ArgOfPericen	107.31439929014574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 128"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.7816924295927007e-07
	Radius		52.05967566128186

	RotationPeriod	5.597788292262883

	Obliquity		176.0341400787944

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5080671018563035
		Eccentricity	0.1
		Inclination		-1.2880376591475171
		AscendingNode	76.34122539662889
		ArgOfPericen	158.28246299351102
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 128.1"
{
	ParentBody	"Aeolus C 128"
	Class		"Asteroid"
	Mass		1.5805386763406331e-09
	Radius		9.289666671890313

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2245192624738483e-06
		Eccentricity	0.0050492451656237065
		Inclination		-11.94078763870883
		AscendingNode	59.36487413082175
		ArgOfPericen	214.7101453676005
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 129"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.303277193475884e-07
	Radius		61.9483038596429

	RotationPeriod	7.989908969606212

	Obliquity		305.67287706932615

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5165890177618035
		Eccentricity	0.1
		Inclination		-1.8695350040825243
		AscendingNode	124.52070692510222
		ArgOfPericen	190.98331349011627
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 130"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0184453485537053e-07
	Radius		38.08995542310332

	RotationPeriod	7.915430809543206

	Obliquity		159.68866426014128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5111015237906206
		Eccentricity	0.1
		Inclination		2.739407672454406
		AscendingNode	55.49155700494407
		ArgOfPericen	90.16001345869476
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 130.1"
{
	ParentBody	"Aeolus C 130"
	Class		"Asteroid"
	Mass		1.4117175300690472e-09
	Radius		9.14984682952641

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.6293496693576225e-06
		Eccentricity	0.0061654109769623405
		Inclination		18.803162505172285
		AscendingNode	255.6269985132483
		ArgOfPericen	69.03310823316784
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 131"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.191200992123653e-07
	Radius		40.10103459024253

	RotationPeriod	6.237006874297498

	Obliquity		355.9992700635582

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5101969965608619
		Eccentricity	0.1
		Inclination		1.0307867474676817
		AscendingNode	199.84684367478565
		ArgOfPericen	177.30385393747133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 132"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5167974594045895
		Eccentricity	0.1
		Inclination		-1.1682602045192385
		AscendingNode	26.3193153057141
		ArgOfPericen	243.51317582418838
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 132 A"
{
	ParentBody	"Aeolus C 132"
	Class		"Asteroid"
	Mass		3.8428911069897806e-07
	Radius		58.35250542728973

	Orbit
	{
		Epoch			2457395.5
		Period			0.004211539886428405
		Eccentricity	0.003870238851534436
		Inclination		250.80398969639097
		AscendingNode	119.42794236899753
		ArgOfPericen	357.41799417184444
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 132 B"
{
	ParentBody	"Aeolus C 132"
	Class		"Asteroid"
	Mass		3.581867060482372e-07
	Radius		57.00023365578047

	Orbit
	{
		Epoch			2457395.5
		Period			0.004211539886428405
		Eccentricity	0.003870238851534436
		Inclination		250.80398969639097
		AscendingNode	119.42794236899753
		ArgOfPericen	177.41799417184438
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 133"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.9533282232576585e-07
	Radius		57.99130212853816

	RotationPeriod	7.528538081211111

	Obliquity		160.03564544548507

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5121437412819594
		Eccentricity	0.1
		Inclination		0.5252959281078866
		AscendingNode	19.597961771186018
		ArgOfPericen	119.84993527920986
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 134"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.357910153072361e-07
	Radius		75.453225535994

	RotationPeriod	6.011518357817357

	Obliquity		26.411399587502288

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5087629567400538
		Eccentricity	0.1
		Inclination		-0.757637021645331
		AscendingNode	231.45493708487714
		ArgOfPericen	214.2722058240641
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 135"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5111795362845114
		Eccentricity	0.1
		Inclination		-1.2173377797125715
		AscendingNode	214.5374517206579
		ArgOfPericen	256.76067112210427
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 135 A"
{
	ParentBody	"Aeolus C 135"
	Class		"Asteroid"
	Mass		1.3752092640332014e-07
	Radius		39.37014113711608

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030463198184061116
		Eccentricity	0.0029206572698721356
		Inclination		137.43935874271537
		AscendingNode	228.09338902339482
		ArgOfPericen	8.56000065766153
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 135 B"
{
	ParentBody	"Aeolus C 135"
	Class		"Asteroid"
	Mass		6.626748125439101e-08
	Radius		30.865799439359872

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030463198184061116
		Eccentricity	0.0029206572698721356
		Inclination		137.43935874271537
		AscendingNode	228.09338902339482
		ArgOfPericen	188.56000065766153
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 136"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0796589539049938e-07
	Radius		45.165712394322924

	RotationPeriod	6.088451050840678

	Obliquity		66.60587910172094

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5101941891715092
		Eccentricity	0.1
		Inclination		-0.7128941515476669
		AscendingNode	180.13798554397886
		ArgOfPericen	304.60896656011516
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 137"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.909462716526596e-07
	Radius		74.27352474551235

	RotationPeriod	5.924265881957598

	Obliquity		321.0312834623645

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5100812027889424
		Eccentricity	0.1
		Inclination		-3.3376258501046014
		AscendingNode	61.18550681234672
		ArgOfPericen	250.79180698117997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 138"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9535826291976295e-07
	Radius		44.303332667275235

	RotationPeriod	5.142215624321234

	Obliquity		353.78233217717946

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5067599107140343
		Eccentricity	0.1
		Inclination		0.6950039221019757
		AscendingNode	45.022565207565854
		ArgOfPericen	142.57116272974224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 139"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7527998510891374e-07
	Radius		44.62860096676231

	RotationPeriod	8.661084450318215

	Obliquity		140.77535947803173

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5080194086175938
		Eccentricity	0.1
		Inclination		-2.7556135237480386
		AscendingNode	59.71981552143185
		ArgOfPericen	261.98467345119883
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 140"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.9916250640018185e-07
	Radius		56.6272394299145

	RotationPeriod	5.007275427446341

	Obliquity		167.83185566178128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5115738610326906
		Eccentricity	0.1
		Inclination		0.7160864638532787
		AscendingNode	335.077160520106
		ArgOfPericen	327.91750194494887
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 141"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1223274157519864e-06
	Radius		78.1161005042756

	RotationPeriod	5.491324666015686

	Obliquity		248.19670604808005

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5155581627535338
		Eccentricity	0.1
		Inclination		1.664379168630404
		AscendingNode	294.9128185090358
		ArgOfPericen	129.46440144507005
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 142"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.119926965492166e-09
	Radius		15.337058505052873

	RotationPeriod	5.19979937862367

	Obliquity		115.41516723061727

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5035583309241716
		Eccentricity	0.1
		Inclination		-0.11488118964801552
		AscendingNode	272.9897235153353
		ArgOfPericen	45.57739338098741
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 143"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5095515728037634
		Eccentricity	0.1
		Inclination		-3.1641963456675506
		AscendingNode	57.562900825380375
		ArgOfPericen	221.01198106786268
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 143 A"
{
	ParentBody	"Aeolus C 143"
	Class		"Asteroid"
	Mass		2.522893542358317e-07
	Radius		46.21455480295221

	Orbit
	{
		Epoch			2457395.5
		Period			0.004513995646189529
		Eccentricity	0.0073425143472035485
		Inclination		287.9138110773348
		AscendingNode	178.16776089636778
		ArgOfPericen	265.62671371411375
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 143 B"
{
	ParentBody	"Aeolus C 143"
	Class		"Asteroid"
	Mass		1.7831015635265094e-07
	Radius		41.165919989780186

	Orbit
	{
		Epoch			2457395.5
		Period			0.004513995646189529
		Eccentricity	0.0073425143472035485
		Inclination		287.9138110773348
		AscendingNode	178.16776089636778
		ArgOfPericen	85.62671371411375
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 144"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.865819261081791e-07
	Radius		46.1338882157734

	RotationPeriod	3.3752160041060306

	Obliquity		308.34622450229375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5132229715680239
		Eccentricity	0.1
		Inclination		1.125071513975716
		AscendingNode	39.96845551975624
		ArgOfPericen	315.6421935360192
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 145"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.201705458708831e-07
	Radius		68.7353718924131

	RotationPeriod	7.188359238075848

	Obliquity		108.47553332190304

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5042763748263641
		Eccentricity	0.1
		Inclination		1.6700603663038627
		AscendingNode	188.59999353298963
		ArgOfPericen	88.01722101078938
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 145.1"
{
	ParentBody	"Aeolus C 145"
	Class		"Asteroid"
	Mass		3.5721215415644885e-10
	Radius		5.718980957548666

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.891441423602304e-06
		Eccentricity	0.0048429799147543
		Inclination		-3.4838696264027655
		AscendingNode	124.65500427593838
		ArgOfPericen	338.4204809770219
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 145.2"
{
	ParentBody	"Aeolus C 145"
	Class		"Asteroid"
	Mass		8.425805251499778e-09
	Radius		16.40137960467909

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.735413772909362e-06
		Eccentricity	0.0038765658484376147
		Inclination		-49.37711843314312
		AscendingNode	115.52292675340124
		ArgOfPericen	106.57135745980237
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 145.3"
{
	ParentBody	"Aeolus C 145"
	Class		"Asteroid"
	Mass		2.9619695633918843e-09
	Radius		11.575420374141085

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.753219998464066e-06
		Eccentricity	0.004321368214497795
		Inclination		3.935061785185261
		AscendingNode	49.40394200744108
		ArgOfPericen	273.35305342912716
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 146"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3744613049778823e-07
	Radius		50.471788116110396

	RotationPeriod	5.25053191981971

	Obliquity		117.03470671465257

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5118274285038455
		Eccentricity	0.1
		Inclination		-0.5991240820873509
		AscendingNode	345.4802895409237
		ArgOfPericen	33.716243107539796
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 146.1"
{
	ParentBody	"Aeolus C 146"
	Class		"Asteroid"
	Mass		2.5510334462187365e-09
	Radius		11.13693563986094

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4531248949530656e-06
		Eccentricity	0.00432545330256135
		Inclination		30.216106589585095
		AscendingNode	212.76185869299482
		ArgOfPericen	263.3921667750236
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 147"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.175144979773638e-07
	Radius		52.45708856307013

	RotationPeriod	4.9444108163331535

	Obliquity		190.38466744887756

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.50832476320133
		Eccentricity	0.1
		Inclination		0.9171213697129155
		AscendingNode	150.36212760277482
		ArgOfPericen	93.11864745578886
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 148"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.139266777156926e-07
	Radius		35.97815205713694

	RotationPeriod	3.3524813228252928

	Obliquity		297.1326668127649

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5095327092821436
		Eccentricity	0.1
		Inclination		0.7965673984145509
		AscendingNode	56.62901992556916
		ArgOfPericen	105.3919888735709
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 149"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5130485764710239
		Eccentricity	0.1
		Inclination		-0.6478608195383767
		AscendingNode	101.66930700381523
		ArgOfPericen	255.9044422141475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 149 A"
{
	ParentBody	"Aeolus C 149"
	Class		"Asteroid"
	Mass		1.391135157035764e-06
	Radius		86.27727332506883

	Orbit
	{
		Epoch			2457395.5
		Period			0.005168835934556106
		Eccentricity	0.002871006237029358
		Inclination		352.48032445778875
		AscendingNode	207.80155435254414
		ArgOfPericen	178.39228775851072
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 149 B"
{
	ParentBody	"Aeolus C 149"
	Class		"Asteroid"
	Mass		1.1276664721171901e-06
	Radius		80.44521041426383

	Orbit
	{
		Epoch			2457395.5
		Period			0.005168835934556106
		Eccentricity	0.002871006237029358
		Inclination		352.48032445778875
		AscendingNode	207.80155435254414
		ArgOfPericen	358.39228775851075
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 150"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7513582659074044e-07
	Radius		45.81352683007419

	RotationPeriod	4.888281583715752

	Obliquity		260.4932999567353

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5106660952390681
		Eccentricity	0.1
		Inclination		-1.4179612631964145
		AscendingNode	255.38361375733328
		ArgOfPericen	43.96274347277346
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 150.1"
{
	ParentBody	"Aeolus C 150"
	Class		"Asteroid"
	Mass		1.4279023535599787e-09
	Radius		9.220792104678683

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.497727221970975e-06
		Eccentricity	0.005515810560116731
		Inclination		23.17729610379757
		AscendingNode	78.82976621067907
		ArgOfPericen	211.8778631354281
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 151"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.537504013387783e-07
	Radius		43.05463770328574

	RotationPeriod	6.488359940072513

	Obliquity		344.5977700886937

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5005055715260399
		Eccentricity	0.1
		Inclination		2.453613793635603
		AscendingNode	335.8295281789485
		ArgOfPericen	47.02295656463344
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 151.1"
{
	ParentBody	"Aeolus C 151"
	Class		"Asteroid"
	Mass		2.446101723995905e-11
	Radius		2.3329531867147173

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.5957814460379765e-06
		Eccentricity	0.007002832303323821
		Inclination		18.35660530078844
		AscendingNode	328.6985451230292
		ArgOfPericen	322.4859913174209
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 151.2"
{
	ParentBody	"Aeolus C 151"
	Class		"Asteroid"
	Mass		1.8944146157986907e-09
	Radius		9.944269026671117

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.471678179642518e-06
		Eccentricity	0.007666212386853832
		Inclination		25.718311322769306
		AscendingNode	59.72847295498917
		ArgOfPericen	340.23093796407545
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 152"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.9578621414269673e-07
	Radius		57.8147302823255

	RotationPeriod	5.889323618612761

	Obliquity		342.7858912896938

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.514791945451952
		Eccentricity	0.1
		Inclination		0.20146610987242924
		AscendingNode	287.51776785686604
		ArgOfPericen	182.36344364420106
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 153"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.467678188023809e-07
	Radius		75.43772464811904

	RotationPeriod	5.332187900814997

	Obliquity		179.9405524096039

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5160782275255061
		Eccentricity	0.1
		Inclination		-3.4535171656054287
		AscendingNode	116.34242464823572
		ArgOfPericen	50.83434102014306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 154"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5036549762869577e-07
	Radius		40.466654238943036

	RotationPeriod	9.395005888191452

	Obliquity		353.837329710255

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5106432081200636
		Eccentricity	0.1
		Inclination		1.7211425739823205
		AscendingNode	311.79627578163127
		ArgOfPericen	91.63755314011172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 155"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.88272544524751e-08
	Radius		35.75630691157249

	RotationPeriod	8.848558874760325

	Obliquity		171.0107747234833

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5132896008889309
		Eccentricity	0.1
		Inclination		1.1555386007067918
		AscendingNode	341.6306516958056
		ArgOfPericen	53.500322763334786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 155.1"
{
	ParentBody	"Aeolus C 155"
	Class		"Asteroid"
	Mass		6.050008750325926e-11
	Radius		3.036074427799665

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.9455996288213515e-06
		Eccentricity	0.0043487747157301224
		Inclination		6.76031625939517
		AscendingNode	151.33976018788437
		ArgOfPericen	270.89081130675123
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 155.2"
{
	ParentBody	"Aeolus C 155"
	Class		"Asteroid"
	Mass		1.0774155483408848e-09
	Radius		7.928447579940367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.100071026257392e-06
		Eccentricity	0.0025363213120804355
		Inclination		-8.720966212211877
		AscendingNode	33.131698060986395
		ArgOfPericen	311.10405313289783
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 156"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5086622321529536
		Eccentricity	0.1
		Inclination		-0.403258529709873
		AscendingNode	19.828722657344446
		ArgOfPericen	130.75691748496166
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 156 A"
{
	ParentBody	"Aeolus C 156"
	Class		"Asteroid"
	Mass		5.051685592853457e-07
	Radius		62.885998713462314

	Orbit
	{
		Epoch			2457395.5
		Period			0.004910639513845665
		Eccentricity	0.0022732298570771765
		Inclination		200.2736644083076
		AscendingNode	131.423341972318
		ArgOfPericen	154.70112783082322
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 156 B"
{
	ParentBody	"Aeolus C 156"
	Class		"Asteroid"
	Mass		3.316828319113772e-07
	Radius		54.657469660629296

	Orbit
	{
		Epoch			2457395.5
		Period			0.004910639513845665
		Eccentricity	0.0022732298570771765
		Inclination		200.2736644083076
		AscendingNode	131.423341972318
		ArgOfPericen	334.7011278308232
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 157"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.382120267490279e-07
	Radius		61.15477757432842

	RotationPeriod	9.20229986267082

	Obliquity		145.8609987009661

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.513511976488223
		Eccentricity	0.1
		Inclination		1.9097345889045818
		AscendingNode	327.4437667455534
		ArgOfPericen	123.29343863039628
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 157.1"
{
	ParentBody	"Aeolus C 157"
	Class		"Asteroid"
	Mass		6.3087673868283125e-09
	Radius		13.891871681472297

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.358446845871056e-06
		Eccentricity	0.0038504309748468206
		Inclination		-52.35291902552834
		AscendingNode	47.91341554245602
		ArgOfPericen	228.92073409636512
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 158"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4070478224816785e-07
	Radius		55.832029158045195

	RotationPeriod	7.065926656070703

	Obliquity		196.90624538492523

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5094310544031829
		Eccentricity	0.1
		Inclination		0.4971611003807173
		AscendingNode	349.524875043848
		ArgOfPericen	85.62581715864506
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 159"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.855174660324198e-07
	Radius		55.663811721315234

	RotationPeriod	7.2550075700694805

	Obliquity		132.58233058447735

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5124371475391832
		Eccentricity	0.1
		Inclination		-0.6395117094353074
		AscendingNode	294.3508723936623
		ArgOfPericen	140.26549236742258
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 159.1"
{
	ParentBody	"Aeolus C 159"
	Class		"Asteroid"
	Mass		1.9374968267252825e-10
	Radius		4.425597599085763

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.0857386423712986e-06
		Eccentricity	0.00660594551585932
		Inclination		46.87855578279742
		AscendingNode	211.0434937747156
		ArgOfPericen	235.79986128414583
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 160"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.411802977573361e-07
	Radius		72.12424608891756

	RotationPeriod	8.6490944650163

	Obliquity		79.49860643363749

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.511681192834586
		Eccentricity	0.1
		Inclination		-0.5044758773963178
		AscendingNode	334.24320081737153
		ArgOfPericen	118.82339705434507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 160.1"
{
	ParentBody	"Aeolus C 160"
	Class		"Asteroid"
	Mass		1.8021676038623599e-09
	Radius		9.698510878280182

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.999899510112966e-06
		Eccentricity	0.0060155936369916865
		Inclination		23.654920883377713
		AscendingNode	308.6460960347679
		ArgOfPericen	307.5639517150345
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 161"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.038228376583339e-06
	Radius		79.72445228785692

	RotationPeriod	5.6984736846753625

	Obliquity		234.47449256193536

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5110023629121587
		Eccentricity	0.1
		Inclination		0.5018141921759913
		AscendingNode	32.95466728502334
		ArgOfPericen	116.19607755827731
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 161.1"
{
	ParentBody	"Aeolus C 161"
	Class		"Asteroid"
	Mass		3.657906154925544e-09
	Radius		12.131228018790791

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.31332211054903e-06
		Eccentricity	0.005855425090326911
		Inclination		-39.46880808239512
		AscendingNode	140.24849805911197
		ArgOfPericen	243.6008869880105
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 162"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.194754766962522e-07
	Radius		37.568255848422965

	RotationPeriod	10.10773768044413

	Obliquity		338.08044865249923

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5104689251542243
		Eccentricity	0.1
		Inclination		0.9536831900411429
		AscendingNode	71.95552212150744
		ArgOfPericen	299.4079763979608
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 163"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.388017336655025e-07
	Radius		49.08350237507699

	RotationPeriod	11.504469395117372

	Obliquity		212.78448627559646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.510529072513177
		Eccentricity	0.1
		Inclination		1.103428866047182
		AscendingNode	267.09688707349073
		ArgOfPericen	21.02764035942287
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 164"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5101992393300353
		Eccentricity	0.1
		Inclination		-0.923803156919149
		AscendingNode	71.98248610486279
		ArgOfPericen	215.88851727317083
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 164 A"
{
	ParentBody	"Aeolus C 164"
	Class		"Asteroid"
	Mass		2.533026221264872e-07
	Radius		49.00686662445474

	Orbit
	{
		Epoch			2457395.5
		Period			0.005398338313424054
		Eccentricity	0.004833092528017029
		Inclination		272.6924875309113
		AscendingNode	353.1692262936336
		ArgOfPericen	273.41472321309004
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 164 B"
{
	ParentBody	"Aeolus C 164"
	Class		"Asteroid"
	Mass		1.4090985471568488e-07
	Radius		40.30486735777612

	Orbit
	{
		Epoch			2457395.5
		Period			0.005398338313424054
		Eccentricity	0.004833092528017029
		Inclination		272.6924875309113
		AscendingNode	353.1692262936336
		ArgOfPericen	93.41472321309004
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 165"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.719839738971057e-09
	Radius		16.491958774268618

	RotationPeriod	7.070672749105899

	Obliquity		180.45129895816007

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5125877743241976
		Eccentricity	0.1
		Inclination		1.5614644165040938
		AscendingNode	262.9276918514392
		ArgOfPericen	106.50701499806786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 166"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.495636696806025e-07
	Radius		63.57285491860138

	RotationPeriod	1.9865401314563407

	Obliquity		270.9579957978962

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5150146035500728
		Eccentricity	0.1
		Inclination		-1.4764570450125096
		AscendingNode	22.629464283782546
		ArgOfPericen	81.61295273272133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 167"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.555869269870286e-07
	Radius		50.54596724107459

	RotationPeriod	10.755166004787428

	Obliquity		65.57153377878453

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5105781881354298
		Eccentricity	0.1
		Inclination		0.7265111635001343
		AscendingNode	79.89971428308182
		ArgOfPericen	150.15966311620033
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 168"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.909805348447521e-08
	Radius		33.23011895494677

	RotationPeriod	5.421349387307856

	Obliquity		212.60312697458144

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5068333543453519
		Eccentricity	0.1
		Inclination		-0.46700206347086365
		AscendingNode	102.44198861392394
		ArgOfPericen	300.11531101283543
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 168.1"
{
	ParentBody	"Aeolus C 168"
	Class		"Asteroid"
	Mass		1.965670516520112e-10
	Radius		4.325929111577588

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.158318797390943e-07
		Eccentricity	0.005974668449542304
		Inclination		32.90476140654879
		AscendingNode	208.37135741591732
		ArgOfPericen	263.6324821939051
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 168.2"
{
	ParentBody	"Aeolus C 168"
	Class		"Asteroid"
	Mass		5.169518302674863e-11
	Radius		2.771569986267786

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.4146724793167048e-06
		Eccentricity	0.006962754603434708
		Inclination		-1.914235004884227
		AscendingNode	258.7943451357336
		ArgOfPericen	356.9024401494722
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 169"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.8210807132374877e-07
	Radius		50.15951037888735

	RotationPeriod	3.0496545847669396

	Obliquity		147.91248123671423

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5079391825648275
		Eccentricity	0.1
		Inclination		-0.6819360815712148
		AscendingNode	24.241786270762994
		ArgOfPericen	313.84597455798996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 170"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.506946725989023
		Eccentricity	0.1
		Inclination		-1.2326291000035048
		AscendingNode	121.67241871752383
		ArgOfPericen	176.36229827267795
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 170 A"
{
	ParentBody	"Aeolus C 170"
	Class		"Asteroid"
	Mass		1.3065604837680707e-07
	Radius		41.446141535552414

	Orbit
	{
		Epoch			2457395.5
		Period			0.006379483446808468
		Eccentricity	0.0031451794393383566
		Inclination		135.73709240526716
		AscendingNode	16.800619283366135
		ArgOfPericen	190.5768173204613
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 170 B"
{
	ParentBody	"Aeolus C 170"
	Class		"Asteroid"
	Mass		9.323736985648686e-09
	Radius		17.191123913328845

	Orbit
	{
		Epoch			2457395.5
		Period			0.006379483446808468
		Eccentricity	0.0031451794393383566
		Inclination		135.73709240526716
		AscendingNode	16.800619283366135
		ArgOfPericen	10.57681732046126
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 171"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5059235299909152
		Eccentricity	0.1
		Inclination		-0.431372254036812
		AscendingNode	283.2986703193858
		ArgOfPericen	180.5203177583086
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 171 A"
{
	ParentBody	"Aeolus C 171"
	Class		"Asteroid"
	Mass		9.47757778858037e-07
	Radius		76.2964690574839

	Orbit
	{
		Epoch			2457395.5
		Period			0.005318348732751575
		Eccentricity	0.006860656307303529
		Inclination		158.51085004488158
		AscendingNode	315.97412887416516
		ArgOfPericen	356.5138656022829
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 171 B"
{
	ParentBody	"Aeolus C 171"
	Class		"Asteroid"
	Mass		2.9606053827132843e-07
	Radius		51.76848972117669

	Orbit
	{
		Epoch			2457395.5
		Period			0.005318348732751575
		Eccentricity	0.006860656307303529
		Inclination		158.51085004488158
		AscendingNode	315.97412887416516
		ArgOfPericen	176.51386560228298
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 172"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.434679890414336e-07
	Radius		65.36177877491036

	RotationPeriod	4.668743433942487

	Obliquity		341.5584387214185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5060857561732031
		Eccentricity	0.1
		Inclination		-0.8045908811336164
		AscendingNode	356.91081835684787
		ArgOfPericen	57.04298907998199
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 173"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5070907192978384
		Eccentricity	0.1
		Inclination		0.14150136410770967
		AscendingNode	66.41145298111265
		ArgOfPericen	195.20403913908137
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 173 A"
{
	ParentBody	"Aeolus C 173"
	Class		"Asteroid"
	Mass		7.705947500391226e-07
	Radius		73.2133715935773

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010077775645102103
		Eccentricity	0.007659151081117692
		Inclination		64.97892418746785
		AscendingNode	21.088305884870934
		ArgOfPericen	87.00248643748371
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 173 B"
{
	ParentBody	"Aeolus C 173"
	Class		"Asteroid"
	Mass		4.0927666836183173e-07
	Radius		59.29081059066676

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010077775645102103
		Eccentricity	0.007659151081117692
		Inclination		64.97892418746785
		AscendingNode	21.088305884870934
		ArgOfPericen	267.0024864374837
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 174"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6493832485169846e-07
	Radius		43.785952475009324

	RotationPeriod	6.661599176657353

	Obliquity		142.92491098896983

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5123150911279127
		Eccentricity	0.1
		Inclination		-0.7595339831998285
		AscendingNode	36.3219395960957
		ArgOfPericen	27.131700290081888
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 174.1"
{
	ParentBody	"Aeolus C 174"
	Class		"Asteroid"
	Mass		1.0392804389862362e-09
	Radius		8.087330519987646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.037615540904988e-06
		Eccentricity	0.004446842356724135
		Inclination		-17.563454500741315
		AscendingNode	110.61422906241563
		ArgOfPericen	177.14982641458752
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 175"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.172539389461699e-07
	Radius		63.89785882345227

	RotationPeriod	6.624551969494158

	Obliquity		51.71580721039819

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5099118004793125
		Eccentricity	0.1
		Inclination		-2.120300389590289
		AscendingNode	156.00879600343694
		ArgOfPericen	136.90848774446468
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 176"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.583424231683974e-07
	Radius		67.78205851384368

	RotationPeriod	8.659980054152527

	Obliquity		31.64164023596202

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5129855980670034
		Eccentricity	0.1
		Inclination		0.020631898003863135
		AscendingNode	135.79441565850976
		ArgOfPericen	351.7793997817321
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 177"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.335659408592815e-07
	Radius		56.641034331519755

	RotationPeriod	3.079429006105546

	Obliquity		52.66724364274741

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5074920869639318
		Eccentricity	0.1
		Inclination		-1.1612042848337567
		AscendingNode	333.6013349075919
		ArgOfPericen	278.0143620515184
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 178"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.511925730163699e-07
	Radius		55.07026193115222

	RotationPeriod	9.227922273586287

	Obliquity		4.793136978695851

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.507813093996901
		Eccentricity	0.1
		Inclination		1.5649280953964526
		AscendingNode	151.5859139647037
		ArgOfPericen	216.2380585462191
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 179"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.908386156550312e-07
	Radius		61.86975275522849

	RotationPeriod	7.1460796047921455

	Obliquity		132.06231258088718

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5109583180211504
		Eccentricity	0.1
		Inclination		0.8095492471519812
		AscendingNode	226.46813950429348
		ArgOfPericen	269.80319055163403
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 180"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3581780069717099e-06
	Radius		85.5034058897196

	RotationPeriod	5.8042902876305735

	Obliquity		30.919268682249527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.51053794419254
		Eccentricity	0.1
		Inclination		-3.471180510936973
		AscendingNode	243.82751360921472
		ArgOfPericen	73.83937762783388
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 181"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.324512852494614e-07
	Radius		67.05145601834053

	RotationPeriod	9.01581779334814

	Obliquity		332.2583810338553

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5095724468609963
		Eccentricity	0.1
		Inclination		-1.9198861054461045
		AscendingNode	73.73763742794064
		ArgOfPericen	28.3428100374975
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 182"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.574035125767156e-07
	Radius		54.8810917919618

	RotationPeriod	4.978027692915256

	Obliquity		301.8866729474063

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5090487480657963
		Eccentricity	0.1
		Inclination		3.3888315260543043
		AscendingNode	44.468370240004724
		ArgOfPericen	337.422708188569
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 183"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.140097361432849e-08
	Radius		31.568166489732405

	RotationPeriod	7.1082397447226215

	Obliquity		28.870518326212796

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5025105707629609
		Eccentricity	0.1
		Inclination		1.7655023435322534
		AscendingNode	34.830245629222965
		ArgOfPericen	216.0588514916901
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 184"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5138907222514165
		Eccentricity	0.1
		Inclination		0.23208617243434473
		AscendingNode	294.69777111357286
		ArgOfPericen	335.7146423466546
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 184 A"
{
	ParentBody	"Aeolus C 184"
	Class		"Asteroid"
	Mass		2.9260034136229433e-08
	Radius		24.826664523139566

	Orbit
	{
		Epoch			2457395.5
		Period			0.003849197847577551
		Eccentricity	0.008621720107134084
		Inclination		316.0468911738885
		AscendingNode	79.95094132129358
		ArgOfPericen	216.18645602786307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 184 B"
{
	ParentBody	"Aeolus C 184"
	Class		"Asteroid"
	Mass		7.931229661835603e-10
	Radius		7.457734901514322

	Orbit
	{
		Epoch			2457395.5
		Period			0.003849197847577551
		Eccentricity	0.008621720107134084
		Inclination		316.0468911738885
		AscendingNode	79.95094132129358
		ArgOfPericen	36.18645602786307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 185"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7920689788753546e-07
	Radius		42.76774434749632

	RotationPeriod	6.753894956049767

	Obliquity		326.63623382532006

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5107270263283197
		Eccentricity	0.1
		Inclination		-0.2749734436695567
		AscendingNode	85.08667180258715
		ArgOfPericen	177.0116335575333
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 186"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.748214825895604e-07
	Radius		53.522970790982235

	RotationPeriod	4.090291232420813

	Obliquity		223.23690037227877

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5095436609807695
		Eccentricity	0.1
		Inclination		-1.0144297135319706
		AscendingNode	315.53744275933917
		ArgOfPericen	113.69060978082571
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 187"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5183048824513482
		Eccentricity	0.1
		Inclination		0.9681156412042823
		AscendingNode	63.4222474339071
		ArgOfPericen	119.71032847215535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 187 A"
{
	ParentBody	"Aeolus C 187"
	Class		"Asteroid"
	Mass		1.166529526763738e-08
	Radius		17.995962598964418

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009967008449454572
		Eccentricity	0.0018998370000354397
		Inclination		356.40722552276065
		AscendingNode	334.98771538599794
		ArgOfPericen	60.14948925558157
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 187 B"
{
	ParentBody	"Aeolus C 187"
	Class		"Asteroid"
	Mass		5.8289324671283665e-09
	Radius		14.280371680901826

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009967008449454572
		Eccentricity	0.0018998370000354397
		Inclination		356.40722552276065
		AscendingNode	334.98771538599794
		ArgOfPericen	240.14948925558156
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 188"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.854052295960446e-07
	Radius		62.02787532448553

	RotationPeriod	8.87224425092407

	Obliquity		332.6153657055343

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.509896508535722
		Eccentricity	0.1
		Inclination		0.22847279856549704
		AscendingNode	158.129342830532
		ArgOfPericen	245.1305646354427
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 189"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.817385446721932e-07
	Radius		41.83877786126361

	RotationPeriod	3.653943668940174

	Obliquity		332.809284984729

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5060859391470598
		Eccentricity	0.1
		Inclination		2.421849697988526
		AscendingNode	329.57034006395014
		ArgOfPericen	115.44210391231825
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "Aeolus C 190"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5050132380905302
		Eccentricity	0.1
		Inclination		-0.8902561226364494
		AscendingNode	54.48489378055195
		ArgOfPericen	222.5853279447978
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 190 A"
{
	ParentBody	"Aeolus C 190"
	Class		"Asteroid"
	Mass		3.106786870503402e-07
	Radius		52.68642808519587

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033284333184140126
		Eccentricity	0.0032321759124243725
		Inclination		278.1268154718803
		AscendingNode	141.59460276835702
		ArgOfPericen	327.1773131898717
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 190 B"
{
	ParentBody	"Aeolus C 190"
	Class		"Asteroid"
	Mass		7.989332704793326e-08
	Radius		33.50413718579652

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033284333184140126
		Eccentricity	0.0032321759124243725
		Inclination		278.1268154718803
		AscendingNode	141.59460276835702
		ArgOfPericen	147.1773131898717
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 191"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3989994112873097e-06
	Radius		82.79791823713919

	RotationPeriod	4.117778128470393

	Obliquity		256.27228178304904

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5101593469269194
		Eccentricity	0.1
		Inclination		0.022932653052650374
		AscendingNode	276.5412234984054
		ArgOfPericen	16.140187981434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 192"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.494211423189912e-07
	Radius		39.40482412551899

	RotationPeriod	7.1824467232161435

	Obliquity		12.55268719375216

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.515478086481234
		Eccentricity	0.1
		Inclination		-1.3515541883864766
		AscendingNode	34.74795498315673
		ArgOfPericen	99.95038666550785
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 193"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.78050999507459e-08
	Radius		32.08416246674054

	RotationPeriod	2.1646574568566868

	Obliquity		320.5076863341323

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5031768484149278
		Eccentricity	0.1
		Inclination		4.072099935974166
		AscendingNode	56.31318725242905
		ArgOfPericen	116.75413619641031
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 193.1"
{
	ParentBody	"Aeolus C 193"
	Class		"Asteroid"
	Mass		5.173958420730121e-11
	Radius		2.9318667716774924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0235275680055304e-06
		Eccentricity	0.00344254583389421
		Inclination		-5.08913924926623
		AscendingNode	307.3996047670504
		ArgOfPericen	160.7279375918084
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 193.2"
{
	ParentBody	"Aeolus C 193"
	Class		"Asteroid"
	Mass		9.485114983808195e-11
	Radius		3.5882617860360577

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.194435802465201e-06
		Eccentricity	0.0033125663095853073
		Inclination		-1.3205791660241941
		AscendingNode	319.0206289951287
		ArgOfPericen	309.3753800609171
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 193.3"
{
	ParentBody	"Aeolus C 193"
	Class		"Asteroid"
	Mass		8.260198331937502e-10
	Radius		7.38244259070026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.4772778849527988e-06
		Eccentricity	0.007471921741132408
		Inclination		-2.0857557693950795
		AscendingNode	168.48172712099048
		ArgOfPericen	28.941346788280242
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 193.4"
{
	ParentBody	"Aeolus C 193"
	Class		"Asteroid"
	Mass		3.255165456318648e-10
	Radius		5.412454719301567

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0402712468105401e-06
		Eccentricity	0.005812922752105926
		Inclination		-7.139868865907186
		AscendingNode	150.21402578662847
		ArgOfPericen	224.14460115180214
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 194"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.28522358659987e-07
	Radius		40.82824072734575

	RotationPeriod	5.137918900232154

	Obliquity		54.61836985430133

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5130751369833935
		Eccentricity	0.1
		Inclination		-0.6288249147100544
		AscendingNode	202.73268090915244
		ArgOfPericen	106.55333744936682
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 195"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7915020586407952e-08
	Radius		20.159991056343355

	RotationPeriod	3.358372165459507

	Obliquity		210.14840600796748

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5094055973721908
		Eccentricity	0.1
		Inclination		0.3790521255132129
		AscendingNode	66.22772070334393
		ArgOfPericen	206.49863178716396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 196"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.260958907316003e-07
	Radius		46.33181059873028

	RotationPeriod	7.037249368316746

	Obliquity		235.1042832647324

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5047580122007581
		Eccentricity	0.1
		Inclination		3.794478592947341
		AscendingNode	322.7777179713045
		ArgOfPericen	204.43488061064647
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 197"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.390564302967734e-08
	Radius		32.95225450805752

	RotationPeriod	4.868779013459266

	Obliquity		295.77718844725865

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5098134714631032
		Eccentricity	0.1
		Inclination		-2.7901740482382174
		AscendingNode	320.90785111175717
		ArgOfPericen	89.97507507762279
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 197.1"
{
	ParentBody	"Aeolus C 197"
	Class		"Asteroid"
	Mass		3.844735842642403e-10
	Radius		5.993229368395175

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.2622283435792466e-06
		Eccentricity	0.0020800802410950478
		Inclination		-7.842180572300055
		AscendingNode	154.3600088965844
		ArgOfPericen	355.40909723083735
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Asteroid "Aeolus C 197.2"
{
	ParentBody	"Aeolus C 197"
	Class		"Asteroid"
	Mass		1.0295889383257082e-10
	Radius		3.863017594507144

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.009161655286586e-06
		Eccentricity	0.006124910301292523
		Inclination		-11.774031396929399
		AscendingNode	300.6075277359851
		ArgOfPericen	76.72710665365136
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 198"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.6168613758964613e-07
	Radius		48.10849250255119

	RotationPeriod	5.3365087874512

	Obliquity		160.3744492370593

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5096556416834314
		Eccentricity	0.1
		Inclination		2.0173545812058014
		AscendingNode	330.8139513106259
		ArgOfPericen	48.24136748033205
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 199"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1105733805073111e-06
	Radius		78.3305799567849

	RotationPeriod	3.8010717253000794

	Obliquity		324.03501983891545

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5112814603702103
		Eccentricity	0.1
		Inclination		3.8698220334930578
		AscendingNode	180.04050960090143
		ArgOfPericen	133.32204815994683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Asteroid "Aeolus C 200"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.3235659215344e-07
	Radius		65.33694083097467

	RotationPeriod	4.889840474843899

	Obliquity		257.31022145910265

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.5112791985461544
		Eccentricity	0.1
		Inclination		-1.6540825641550008
		AscendingNode	70.03406410731027
		ArgOfPericen	197.58419252550635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Helios Alpha comets ---------------------------------------------------------
//------------------------------------------------------------------------------
Comet "HeliosA 1"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.582502707099885e-09
	Radius		15.984543839272655

	RotationPeriod	3.6058737719848897

	Obliquity		316.3903701585885

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.836794668543229
		Eccentricity	0.4090637139530842
		Inclination		-20.592166037935648
		AscendingNode	74.39751342974526
		ArgOfPericen	320.5424717916798
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 2"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.581057861413654e-09
	Radius		13.461448626457463

	RotationPeriod	5.9749458718075745

	Obliquity		101.74320324099283

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.223040653851427
		Eccentricity	0.3478358174662348
		Inclination		15.021542888658539
		AscendingNode	218.7244992958369
		ArgOfPericen	270.1214747492549
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 3"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5403373057830905e-08
	Radius		20.811500315807802

	RotationPeriod	8.144295105493374

	Obliquity		242.29862482145364

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.386832912653432
		Eccentricity	0.5084950290073421
		Inclination		-76.56398302932053
		AscendingNode	160.1284403097451
		ArgOfPericen	187.6094776482998
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 4"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.0510520267154987e-09
	Radius		10.217352476601379

	RotationPeriod	5.369007362435706

	Obliquity		194.6060021898578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.131017095603767
		Eccentricity	0.610148730383874
		Inclination		-7.313108443452664
		AscendingNode	272.1502013578334
		ArgOfPericen	1.4574692266974898
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 5"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.191521891783689e-09
	Radius		14.936527440023816

	RotationPeriod	3.322331285381417

	Obliquity		134.61629656420584

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.052335142472341
		Eccentricity	0.735800710515571
		Inclination		-29.78832268208326
		AscendingNode	298.63263052945973
		ArgOfPericen	295.1330847196033
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 6"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.274740400473995e-09
	Radius		17.53026992035378

	RotationPeriod	7.516184995116401

	Obliquity		38.389370420142214

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.988889302850955
		Eccentricity	0.5992848515761713
		Inclination		-124.02302995796768
		AscendingNode	146.64165418298072
		ArgOfPericen	28.546721888549577
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 7"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.641180973004499
		Eccentricity	0.5082777016859649
		Inclination		68.16775965855993
		AscendingNode	221.60132102548815
		ArgOfPericen	295.20385236919367
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 7 A"
{
	ParentBody	"HeliosA 7"
	Class		"Asteroid"
	Mass		3.6326999081315416e-09
	Radius		11.760181684578088

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018590592318786206
		Eccentricity	0.006015231335870706
		Inclination		54.307739822297364
		AscendingNode	230.2731965632239
		ArgOfPericen	250.3559575846875
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 7 B"
{
	ParentBody	"HeliosA 7"
	Class		"Asteroid"
	Mass		2.5753480154968516e-09
	Radius		10.486152401782318

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018590592318786206
		Eccentricity	0.006015231335870706
		Inclination		54.307739822297364
		AscendingNode	230.2731965632239
		ArgOfPericen	70.35595758468753
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 8"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.175955255429812e-10
	Radius		7.202984701282614

	RotationPeriod	6.388020379566941

	Obliquity		19.080389230762837

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.680676210968569
		Eccentricity	0.5671609257911674
		Inclination		43.07827631436414
		AscendingNode	47.76470316692589
		ArgOfPericen	3.756509443679068
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 9"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.877586347921375
		Eccentricity	0.5934613358025089
		Inclination		-65.97663673062893
		AscendingNode	280.2703609625913
		ArgOfPericen	120.602992960078
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 9 A"
{
	ParentBody	"HeliosA 9"
	Class		"Asteroid"
	Mass		1.6469591612986194e-09
	Radius		9.659104168373549

	Orbit
	{
		Epoch			2457395.5
		Period			0.005415628343362918
		Eccentricity	0.0047022657248331975
		Inclination		206.14069585105048
		AscendingNode	294.60569013267383
		ArgOfPericen	249.97061957358986
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 9 B"
{
	ParentBody	"HeliosA 9"
	Class		"Asteroid"
	Mass		8.117840343281195e-10
	Radius		7.6299684384551805

	Orbit
	{
		Epoch			2457395.5
		Period			0.005415628343362918
		Eccentricity	0.0047022657248331975
		Inclination		206.14069585105048
		AscendingNode	294.60569013267383
		ArgOfPericen	69.97061957358983
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 10"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.6517566253408972e-09
	Radius		12.107756127762796

	RotationPeriod	5.95704417464041

	Obliquity		217.79774484947896

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.03392558586893
		Eccentricity	0.7360006636992966
		Inclination		-6.098550246793905
		AscendingNode	223.82070645944341
		ArgOfPericen	151.2783319708575
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 11"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7469118230547945e-09
	Radius		9.66043644156518

	RotationPeriod	5.0245438154036774

	Obliquity		310.88976099284486

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.735127088402978
		Eccentricity	0.6376002284234117
		Inclination		-60.85748881517048
		AscendingNode	267.66080876430107
		ArgOfPericen	104.46575140847224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 12"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.225917933558036e-09
	Radius		10.346166308283095

	RotationPeriod	4.470959778183692

	Obliquity		71.72500181662275

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.755204050855479
		Eccentricity	0.28778893117012794
		Inclination		122.61947624979194
		AscendingNode	13.541841725196523
		ArgOfPericen	179.5823289329025
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 13"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.698369160425476e-09
	Radius		12.903857999087618

	RotationPeriod	5.75999507969993

	Obliquity		132.91714945840545

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.488526592281788
		Eccentricity	0.6963283783804988
		Inclination		84.6338570416073
		AscendingNode	279.91126436324623
		ArgOfPericen	213.1058332368126
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 14"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.394731916682957
		Eccentricity	0.5955686902702185
		Inclination		-40.74068643725477
		AscendingNode	162.55009843459754
		ArgOfPericen	111.34166990983293
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 14 A"
{
	ParentBody	"HeliosA 14"
	Class		"Asteroid"
	Mass		1.0823192374606085e-08
	Radius		19.31879148679823

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013181787848421784
		Eccentricity	0.0035058159792242544
		Inclination		131.85346501079653
		AscendingNode	57.171679627796635
		ArgOfPericen	277.980656061768
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 14 B"
{
	ParentBody	"HeliosA 14"
	Class		"Asteroid"
	Mass		2.0553225736573857e-09
	Radius		11.104222614760312

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013181787848421784
		Eccentricity	0.0035058159792242544
		Inclination		131.85346501079653
		AscendingNode	57.171679627796635
		ArgOfPericen	97.980656061768
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 15"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0403537242627019e-08
	Radius		15.90871672873846

	RotationPeriod	4.05145635412749

	Obliquity		77.48301409069067

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.949089846874244
		Eccentricity	0.5517554907203002
		Inclination		-47.662158981695704
		AscendingNode	135.2539773463501
		ArgOfPericen	341.63480800770765
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 16"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.672051881853827
		Eccentricity	0.6996993536530542
		Inclination		-147.04960116254782
		AscendingNode	134.44329548367426
		ArgOfPericen	323.3112022759168
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 16 A"
{
	ParentBody	"HeliosA 16"
	Class		"Asteroid"
	Mass		7.219161493445384e-09
	Radius		14.782001362241623

	Orbit
	{
		Epoch			2457395.5
		Period			0.0036921995183736567
		Eccentricity	0.006030888801502288
		Inclination		114.15310666257001
		AscendingNode	145.89817693085845
		ArgOfPericen	129.55474243807814
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 16 B"
{
	ParentBody	"HeliosA 16"
	Class		"Asteroid"
	Mass		5.467889994501449e-10
	Radius		6.25428366816062

	Orbit
	{
		Epoch			2457395.5
		Period			0.0036921995183736567
		Eccentricity	0.006030888801502288
		Inclination		114.15310666257001
		AscendingNode	145.89817693085845
		ArgOfPericen	309.55474243807816
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 17"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.4408166731832e-09
	Radius		12.805001783804705

	RotationPeriod	5.549330747307383

	Obliquity		334.24535732371646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.1632180755961175
		Eccentricity	0.6852557733901663
		Inclination		27.31312065520968
		AscendingNode	201.29011142800778
		ArgOfPericen	335.0443478338148
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 18"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2610580201028995e-09
	Radius		7.99745270371471

	RotationPeriod	5.901845879418008

	Obliquity		169.8496730664921

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.915961920151892
		Eccentricity	0.38803156834718
		Inclination		63.24871644197189
		AscendingNode	244.65572663852038
		ArgOfPericen	122.01824759729084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 19"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.46968480402978e-09
	Radius		9.100054164022843

	RotationPeriod	5.576380076442048

	Obliquity		319.99419692698257

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.705988641371682
		Eccentricity	0.7428063681360868
		Inclination		43.72602026313798
		AscendingNode	107.85535213820359
		ArgOfPericen	29.614276350216034
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 20"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.627824246350677
		Eccentricity	0.6000357479114109
		Inclination		-83.43419864266279
		AscendingNode	131.22866680066085
		ArgOfPericen	354.418109589013
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 20 A"
{
	ParentBody	"HeliosA 20"
	Class		"Asteroid"
	Mass		9.185272474310797e-10
	Radius		7.992959187913043

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005407225477008274
		Eccentricity	0.006702058598346102
		Inclination		341.34383579919074
		AscendingNode	133.36419280177498
		ArgOfPericen	131.22356488331832
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 20 B"
{
	ParentBody	"HeliosA 20"
	Class		"Asteroid"
	Mass		1.316067028365971e-10
	Radius		4.18250289703471

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005407225477008274
		Eccentricity	0.006702058598346102
		Inclination		341.34383579919074
		AscendingNode	133.36419280177498
		ArgOfPericen	311.2235648833183
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 21"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.4668941920290824e-09
	Radius		12.409752812995908

	RotationPeriod	4.0441453860270045

	Obliquity		111.92775489512489

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.130638801930886
		Eccentricity	0.7441391525523551
		Inclination		-27.40144964162017
		AscendingNode	357.82093068526734
		ArgOfPericen	71.21291682444279
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 22"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0698272878514761e-08
	Radius		17.547032573028268

	RotationPeriod	4.109429347880592

	Obliquity		66.85892435038242

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.455717556528507
		Eccentricity	0.3655422628964914
		Inclination		-106.0866964919779
		AscendingNode	6.552000984226698
		ArgOfPericen	130.7579295848408
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 23"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2231951905779643e-08
	Radius		18.912194638641363

	RotationPeriod	7.617564478628282

	Obliquity		74.53443427519396

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.813300382432676
		Eccentricity	0.4415743844331581
		Inclination		6.282829608042134
		AscendingNode	117.31003937034508
		ArgOfPericen	234.69733436148294
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 24"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.244219235024035e-09
	Radius		14.490909354974216

	RotationPeriod	7.282252278317147

	Obliquity		298.62476483555537

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.3787990325989092
		Eccentricity	0.6254642371566359
		Inclination		-5.44390898577398
		AscendingNode	83.70760246624367
		ArgOfPericen	91.57645555703611
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 25"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.5533462205619747e-09
	Radius		11.03430609368364

	RotationPeriod	10.548695099091217

	Obliquity		90.29873649605369

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.78011247808398
		Eccentricity	0.5380590667340306
		Inclination		29.182343927717756
		AscendingNode	219.44196859230084
		ArgOfPericen	153.81847804403125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 26"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.743172065540517
		Eccentricity	0.221675992428488
		Inclination		19.112062920825352
		AscendingNode	116.93050924112815
		ArgOfPericen	67.53615327524098
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 26 A"
{
	ParentBody	"HeliosA 26"
	Class		"Asteroid"
	Mass		4.029792611417648e-09
	Radius		12.821261817388256

	Orbit
	{
		Epoch			2457395.5
		Period			0.006662500981342608
		Eccentricity	0.004188261665091663
		Inclination		22.106213620061656
		AscendingNode	294.38586198207605
		ArgOfPericen	139.80117740412794
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 26 B"
{
	ParentBody	"HeliosA 26"
	Class		"Asteroid"
	Mass		8.320941303138856e-10
	Radius		7.578106240834232

	Orbit
	{
		Epoch			2457395.5
		Period			0.006662500981342608
		Eccentricity	0.004188261665091663
		Inclination		22.106213620061656
		AscendingNode	294.38586198207605
		ArgOfPericen	319.80117740412794
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 27"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.588519810483182e-09
	Radius		13.691667254965306

	RotationPeriod	4.83561030022549

	Obliquity		40.72051856144756

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.16624169528472
		Eccentricity	0.47865250303142426
		Inclination		67.22066590835784
		AscendingNode	315.9946231336507
		ArgOfPericen	78.22962303502683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 28"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.793393240119352
		Eccentricity	0.45582840996492574
		Inclination		-22.755168319940935
		AscendingNode	14.055634557314525
		ArgOfPericen	205.8272002476111
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 28 A"
{
	ParentBody	"HeliosA 28"
	Class		"Asteroid"
	Mass		7.667545299940534e-09
	Radius		15.078550399007662

	Orbit
	{
		Epoch			2457395.5
		Period			0.002997229015342229
		Eccentricity	0.0045327415623590914
		Inclination		201.37277344849522
		AscendingNode	28.731641525467122
		ArgOfPericen	302.35394099078565
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 28 B"
{
	ParentBody	"HeliosA 28"
	Class		"Asteroid"
	Mass		6.685642582941163e-09
	Radius		14.405285174336955

	Orbit
	{
		Epoch			2457395.5
		Period			0.002997229015342229
		Eccentricity	0.0045327415623590914
		Inclination		201.37277344849522
		AscendingNode	28.731641525467122
		ArgOfPericen	122.35394099078565
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 29"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.726167710104832e-09
	Radius		11.615725453675807

	RotationPeriod	5.487260137183986

	Obliquity		160.34197678226138

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.400581609208386
		Eccentricity	0.6483952185420022
		Inclination		-43.9330316192344
		AscendingNode	18.83069960893632
		ArgOfPericen	272.22175228940256
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 30"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.183684674397391e-13
	Radius		0.7078555531892832

	RotationPeriod	8.966755719347919

	Obliquity		189.0233985363528

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.683647491290884
		Eccentricity	0.5187228704555968
		Inclination		-3.9509550586042597
		AscendingNode	240.23387806948972
		ArgOfPericen	171.22125197147952
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 31"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.134395800837718e-09
	Radius		14.14549064516098

	RotationPeriod	5.6989745661647815

	Obliquity		276.4012223543861

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.720517185000112
		Eccentricity	0.6188088593228671
		Inclination		29.652431726463007
		AscendingNode	239.91166443659694
		ArgOfPericen	165.59287761738958
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 32"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.6042481155714635e-09
	Radius		10.404336186967827

	RotationPeriod	5.82158258343108

	Obliquity		94.01944795428993

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.535877084219187
		Eccentricity	0.5144355308117493
		Inclination		50.3616334197181
		AscendingNode	78.34236683016485
		ArgOfPericen	186.87361318346484
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 33"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.980368138161946e-09
	Radius		12.970052910926022

	RotationPeriod	4.61061712323701

	Obliquity		224.52998725069594

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.26663020382574
		Eccentricity	0.47486502166464983
		Inclination		-31.371929440064
		AscendingNode	86.41256969850932
		ArgOfPericen	2.8374014351641907
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 34"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.708099638001008e-09
	Radius		12.652123430904874

	RotationPeriod	4.406576161779456

	Obliquity		296.6808832641494

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.845424407403272
		Eccentricity	0.579851746122901
		Inclination		-41.3864764569538
		AscendingNode	338.99406718290106
		ArgOfPericen	357.3158256411541
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 35"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.755385370725571e-09
	Radius		15.490233877088354

	RotationPeriod	3.6728171106036953

	Obliquity		343.12642508457105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.572918984350745
		Eccentricity	0.6127659436125604
		Inclination		146.3730345542957
		AscendingNode	111.17738621671086
		ArgOfPericen	183.8419183330369
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 36"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.471517524555808e-09
	Radius		11.892194094106678

	RotationPeriod	7.431522948449409

	Obliquity		8.95092636031194

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.475840761090577
		Eccentricity	0.45248231379262066
		Inclination		57.93225063869366
		AscendingNode	225.21124448255634
		ArgOfPericen	101.55813103252294
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 37"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.045814598583919e-09
	Radius		13.560767791354355

	RotationPeriod	6.06922008077771

	Obliquity		51.42872885188759

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.895968181336999
		Eccentricity	0.5169151435301266
		Inclination		-33.257247854708744
		AscendingNode	109.74415217807955
		ArgOfPericen	182.43831914816457
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 38"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3161274679687357e-08
	Radius		18.97971670130933

	RotationPeriod	6.838153909170781

	Obliquity		88.6631590981975

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.289333329536428
		Eccentricity	0.6597549932212001
		Inclination		-123.23954596195341
		AscendingNode	323.5683774662256
		ArgOfPericen	95.99921894574794
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 39"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.649539484047816e-09
	Radius		14.427469922867648

	RotationPeriod	7.908338115798614

	Obliquity		335.52814724804205

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.316095449885433
		Eccentricity	0.2947645717426939
		Inclination		-64.53385643105808
		AscendingNode	357.79072438272476
		ArgOfPericen	15.206886708008277
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 40"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0397994557240559e-08
	Radius		17.40499211231763

	RotationPeriod	7.1311331109211915

	Obliquity		170.5449706266768

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.791459815429516
		Eccentricity	0.6364144318457375
		Inclination		121.10962321048743
		AscendingNode	67.47701400411148
		ArgOfPericen	270.12789017970783
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 41"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4501914302277924e-08
	Radius		18.985321895963978

	RotationPeriod	7.04050096227861

	Obliquity		241.87478307116314

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.434942630327363
		Eccentricity	0.32844490551470745
		Inclination		-42.29548532556139
		AscendingNode	76.64686607511291
		ArgOfPericen	352.7436302713004
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 42"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.685125394648788
		Eccentricity	0.15930094772465164
		Inclination		29.55363284774115
		AscendingNode	180.28950042711585
		ArgOfPericen	343.47060197893865
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 42 A"
{
	ParentBody	"HeliosA 42"
	Class		"Asteroid"
	Mass		6.976992242368806e-09
	Radius		14.931731895796851

	Orbit
	{
		Epoch			2457395.5
		Period			0.001156560477432685
		Eccentricity	0.005639147056803284
		Inclination		25.498234414904104
		AscendingNode	140.03664230062486
		ArgOfPericen	276.9612749965888
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 42 B"
{
	ParentBody	"HeliosA 42"
	Class		"Asteroid"
	Mass		5.6652625082479435e-09
	Radius		13.930310053767442

	Orbit
	{
		Epoch			2457395.5
		Period			0.001156560477432685
		Eccentricity	0.005639147056803284
		Inclination		25.498234414904104
		AscendingNode	140.03664230062486
		ArgOfPericen	96.96127499658883
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 43"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.6987776948045464e-09
	Radius		12.38679490887764

	RotationPeriod	5.886877546740113

	Obliquity		6.507951946985502

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.730739500699409
		Eccentricity	0.5209957332531162
		Inclination		71.22511405716622
		AscendingNode	349.9917575294948
		ArgOfPericen	353.9400444537122
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 44"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7520878137292285e-09
	Radius		10.479489171642447

	RotationPeriod	8.75041419766287

	Obliquity		23.867093989523607

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.036433810171975
		Eccentricity	0.7915212413416377
		Inclination		-16.132672305731372
		AscendingNode	21.20058308566215
		ArgOfPericen	176.51850496672282
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 45"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.133739577832337
		Eccentricity	0.3258089822709443
		Inclination		12.420471939932456
		AscendingNode	104.70076692508418
		ArgOfPericen	158.61528934642394
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 45 A"
{
	ParentBody	"HeliosA 45"
	Class		"Asteroid"
	Mass		1.581906957419024e-08
	Radius		18.913300039204806

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003442047065541772
		Eccentricity	0.00507223837914945
		Inclination		317.7792490845169
		AscendingNode	320.962523370345
		ArgOfPericen	319.0758407338651
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 45 B"
{
	ParentBody	"HeliosA 45"
	Class		"Asteroid"
	Mass		1.6909100444050894e-09
	Radius		8.975951587188641

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003442047065541772
		Eccentricity	0.00507223837914945
		Inclination		317.7792490845169
		AscendingNode	320.962523370345
		ArgOfPericen	139.0758407338651
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 46"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.6823544490939205e-09
	Radius		11.202504730892512

	RotationPeriod	6.396999323358468

	Obliquity		52.93648280526636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.0791251335401
		Eccentricity	0.60538306475544
		Inclination		31.562755967673095
		AscendingNode	238.97452639451535
		ArgOfPericen	216.4196699747185
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 47"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.250111690886988e-09
	Radius		14.226579696678654

	RotationPeriod	6.6984921514165015

	Obliquity		292.6453370349656

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.507673554470578
		Eccentricity	0.468352768822367
		Inclination		91.20509992965181
		AscendingNode	240.42437120854902
		ArgOfPericen	46.136702958199535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 48"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.444177120706274e-09
	Radius		8.374312716706914

	RotationPeriod	6.526604521010454

	Obliquity		53.084691993233676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.159681439018017
		Eccentricity	0.6967495425003337
		Inclination		35.09557594900211
		AscendingNode	331.9360191451441
		ArgOfPericen	10.693971574356116
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 49"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.56571575387279e-09
	Radius		14.886390563489291

	RotationPeriod	6.576732905411257

	Obliquity		318.8250251737345

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.685523799772692
		Eccentricity	0.41862843813729095
		Inclination		-17.728225814711685
		AscendingNode	88.11466174527737
		ArgOfPericen	31.83058376428976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 50"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.415221841739022e-09
	Radius		13.828693432784657

	RotationPeriod	4.027275543027729

	Obliquity		83.17849768054849

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.965586203345196
		Eccentricity	0.40990717608730676
		Inclination		-33.55276937018287
		AscendingNode	118.4859123364577
		ArgOfPericen	211.17766053333045
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 51"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8228709328751898e-09
	Radius		9.343727759567088

	RotationPeriod	8.76500377908735

	Obliquity		359.78424319059826

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.273292057748165
		Eccentricity	0.5172675408550407
		Inclination		126.03815440803064
		AscendingNode	22.49399511608377
		ArgOfPericen	75.81610280564932
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 52"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3655844611452388e-09
	Radius		8.749256829247201

	RotationPeriod	5.5047309345938995

	Obliquity		59.53389380389354

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.521502364126043
		Eccentricity	0.4236386920104578
		Inclination		-37.96282836409917
		AscendingNode	186.51092909847256
		ArgOfPericen	164.7610534215228
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 53"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.402978310531487e-09
	Radius		16.813803823590327

	RotationPeriod	6.16757421150406

	Obliquity		269.4705227542458

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.296877778977695
		Eccentricity	0.39435085248512725
		Inclination		-52.62255308095257
		AscendingNode	259.45245349477284
		ArgOfPericen	224.6051031744856
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 54"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.898304549177797e-09
	Radius		11.230175366299262

	RotationPeriod	3.6984288174312008

	Obliquity		191.11587802569994

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.712920476209312
		Eccentricity	0.2807689277902148
		Inclination		-8.011600521439814
		AscendingNode	124.33768397203207
		ArgOfPericen	47.65889819894225
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 55"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.2835035008447447e-09
	Radius		10.605535426314367

	RotationPeriod	7.031745392570384

	Obliquity		333.12989281575625

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.422624325343432
		Eccentricity	0.26364747663166305
		Inclination		65.45089394748972
		AscendingNode	252.27773744536088
		ArgOfPericen	220.26177753273058
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 56"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.736048256087517e-09
	Radius		12.548323633128746

	RotationPeriod	5.616287797637245

	Obliquity		36.791403664523266

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.319323920061379
		Eccentricity	0.9733876262148503
		Inclination		9.468729489104991
		AscendingNode	245.3427348400797
		ArgOfPericen	64.66315829290754
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 57"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.950256317576712e-09
	Radius		16.228787360648226

	RotationPeriod	8.719358565839165

	Obliquity		182.3042371291234

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.848019429910593
		Eccentricity	0.3631547025030918
		Inclination		-18.146242667753285
		AscendingNode	13.084427903518723
		ArgOfPericen	133.1603338810308
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 58"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.6816245478329815e-09
	Radius		13.829894415949706

	RotationPeriod	8.19067478281531

	Obliquity		33.07423386202547

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.148789147868683
		Eccentricity	0.6690460402744249
		Inclination		-13.832638813212773
		AscendingNode	39.15337065497865
		ArgOfPericen	180.96613876937036
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 59"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.267376360634207e-09
	Radius		11.831708433649247

	RotationPeriod	7.341244071155858

	Obliquity		137.87145556064024

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.226791290764554
		Eccentricity	0.22004331980026337
		Inclination		36.019335574404124
		AscendingNode	170.417268380163
		ArgOfPericen	271.0398945175287
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 60"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.5862745789929005e-09
	Radius		14.816545272859814

	RotationPeriod	3.600076407381303

	Obliquity		20.473250220921692

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.318507816883326
		Eccentricity	0.6489221983317977
		Inclination		55.467042554165225
		AscendingNode	218.39153741692934
		ArgOfPericen	79.26800157866982
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 61"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.1748291364617146e-09
	Radius		10.875384539111957

	RotationPeriod	8.528615286044854

	Obliquity		158.7012296950147

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.508929517509138
		Eccentricity	0.7037677939965183
		Inclination		-29.832528804814416
		AscendingNode	140.8614663198972
		ArgOfPericen	240.70266017900298
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 62"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.5220007008331994e-09
	Radius		11.309658543009753

	RotationPeriod	7.545810730976233

	Obliquity		248.21201346391834

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.806247380649367
		Eccentricity	0.2862994662707662
		Inclination		-16.346881776380403
		AscendingNode	259.53272965362055
		ArgOfPericen	294.7414261167775
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 63"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.012371990708406
		Eccentricity	0.12349925942280071
		Inclination		-101.57016878090548
		AscendingNode	222.39678617806985
		ArgOfPericen	240.71269183085033
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 63 A"
{
	ParentBody	"HeliosA 63"
	Class		"Asteroid"
	Mass		7.001242932049609e-09
	Radius		15.271976258043033

	Orbit
	{
		Epoch			2457395.5
		Period			0.003779360298044496
		Eccentricity	0.001227836458754784
		Inclination		71.8432573927169
		AscendingNode	18.52312613242519
		ArgOfPericen	168.98413564230384
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 63 B"
{
	ParentBody	"HeliosA 63"
	Class		"Asteroid"
	Mass		3.62207044427836e-09
	Radius		12.259962881596266

	Orbit
	{
		Epoch			2457395.5
		Period			0.003779360298044496
		Eccentricity	0.001227836458754784
		Inclination		71.8432573927169
		AscendingNode	18.52312613242519
		ArgOfPericen	348.98413564230384
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 64"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.151550950691139e-09
	Radius		12.590828621244986

	RotationPeriod	4.1024396126517395

	Obliquity		317.6640381246322

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.17195730560516
		Eccentricity	0.5170160386324479
		Inclination		54.87159291936513
		AscendingNode	287.4904018724832
		ArgOfPericen	120.69711138141643
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 65"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.016739572361262e-09
	Radius		12.073794294999667

	RotationPeriod	5.333391807786143

	Obliquity		4.434205785544996

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.693769932738956
		Eccentricity	0.6514661516319947
		Inclination		97.55630573236337
		AscendingNode	145.25770485947396
		ArgOfPericen	157.20172934782275
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 66"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.6520660543893937e-09
	Radius		10.390410463451683

	RotationPeriod	6.715890312925749

	Obliquity		354.6871554318841

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.776909232597571
		Eccentricity	0.27436178148214724
		Inclination		47.047919327025674
		AscendingNode	146.60848554407934
		ArgOfPericen	52.605550434004954
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 67"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0743175083759078e-08
	Radius		16.12955755186255

	RotationPeriod	3.9679953949528075

	Obliquity		164.9319042610996

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.96101666314309
		Eccentricity	0.37847846269707314
		Inclination		45.185200769980675
		AscendingNode	159.26555619268163
		ArgOfPericen	150.1754810546717
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 68"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.109800093430416e-08
	Radius		18.25689347940275

	RotationPeriod	7.0426882913736195

	Obliquity		358.84546782920046

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.813267840827539
		Eccentricity	0.7574686230257794
		Inclination		86.62836379323895
		AscendingNode	178.31506310854027
		ArgOfPericen	174.33470625120756
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 69"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7739800956432492e-09
	Radius		10.689985980504892

	RotationPeriod	4.706148048521094

	Obliquity		176.76487348985762

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.927131919783417
		Eccentricity	0.39246121064370815
		Inclination		8.01427796664325
		AscendingNode	49.42660075066979
		ArgOfPericen	94.43675224165665
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 70"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.330617750676476e-08
	Radius		19.930944122860087

	RotationPeriod	6.440769454432415

	Obliquity		299.1653454804628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.798023699145181
		Eccentricity	0.20790902048269222
		Inclination		73.85173704076439
		AscendingNode	87.53429282346083
		ArgOfPericen	291.22428407844797
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 71"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.72936775161231e-09
	Radius		15.506549883437263

	RotationPeriod	5.65982495509606

	Obliquity		28.490385525938166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.258468298069781
		Eccentricity	0.24187616549872493
		Inclination		-12.028291342842198
		AscendingNode	43.72254964352444
		ArgOfPericen	169.33881705012868
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 72"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.2477172161910244e-09
	Radius		10.99543934252503

	RotationPeriod	2.921546655443216

	Obliquity		99.06379077796477

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.686395379052968
		Eccentricity	0.5972594079402626
		Inclination		2.521136027992734
		AscendingNode	150.10638474218538
		ArgOfPericen	43.89588174414685
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 73"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.601615743960132e-09
	Radius		16.105823504187114

	RotationPeriod	5.647655350420176

	Obliquity		135.27913500444734

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.552286272660496
		Eccentricity	0.43138376813021045
		Inclination		-33.16170244885781
		AscendingNode	63.20995145963447
		ArgOfPericen	207.93674070689985
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 74"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.619546557634628e-10
	Radius		7.180346088482446

	RotationPeriod	3.3230233476971778

	Obliquity		48.18969558906569

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.722824295647007
		Eccentricity	0.5085435013991129
		Inclination		-40.17600361827532
		AscendingNode	232.705632796371
		ArgOfPericen	26.007847212902348
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 75"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.7095428469807395e-09
	Radius		14.382001621917455

	RotationPeriod	6.704997952337218

	Obliquity		221.39067440476728

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.248505300315841
		Eccentricity	0.3049857986342604
		Inclination		-55.39261197553686
		AscendingNode	188.9309949189511
		ArgOfPericen	27.93237019243884
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 76"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.1634791913691405e-09
	Radius		13.823917296141412

	RotationPeriod	5.979338740238055

	Obliquity		161.6176955106915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.120851222114132
		Eccentricity	0.5680571897164678
		Inclination		-108.91849976137013
		AscendingNode	353.24040118861353
		ArgOfPericen	219.29646234932994
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 77"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.857336362668731
		Eccentricity	0.3850785865405074
		Inclination		-28.167732328688412
		AscendingNode	331.8808103243051
		ArgOfPericen	325.65643580559777
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 77 A"
{
	ParentBody	"HeliosA 77"
	Class		"Asteroid"
	Mass		1.9526971319480314e-09
	Radius		10.169049257702476

	Orbit
	{
		Epoch			2457395.5
		Period			0.006268495400206512
		Eccentricity	0.005087178939310648
		Inclination		72.70611332650724
		AscendingNode	251.58955113182148
		ArgOfPericen	127.81824346670666
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 77 B"
{
	ParentBody	"HeliosA 77"
	Class		"Asteroid"
	Mass		1.5570195276062274e-09
	Radius		9.429747735998948

	Orbit
	{
		Epoch			2457395.5
		Period			0.006268495400206512
		Eccentricity	0.005087178939310648
		Inclination		72.70611332650724
		AscendingNode	251.58955113182148
		ArgOfPericen	307.8182434667067
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 78"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.244404109756875
		Eccentricity	0.5596649642888577
		Inclination		-15.55388413895633
		AscendingNode	267.30746017875424
		ArgOfPericen	16.635908333347285
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 78 A"
{
	ParentBody	"HeliosA 78"
	Class		"Asteroid"
	Mass		5.899699042734522e-09
	Radius		14.514810234790055

	Orbit
	{
		Epoch			2457395.5
		Period			0.006726304480178832
		Eccentricity	0.007157680999533197
		Inclination		128.1516185399416
		AscendingNode	265.2195192022979
		ArgOfPericen	337.70318337561713
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 78 B"
{
	ParentBody	"HeliosA 78"
	Class		"Asteroid"
	Mass		2.474233167776255e-10
	Radius		5.042914648970289

	Orbit
	{
		Epoch			2457395.5
		Period			0.006726304480178832
		Eccentricity	0.007157680999533197
		Inclination		128.1516185399416
		AscendingNode	265.2195192022979
		ArgOfPericen	157.70318337561707
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 79"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.268194425643966
		Eccentricity	0.2519682184276275
		Inclination		19.573101287411653
		AscendingNode	333.09587398226193
		ArgOfPericen	107.82702133282127
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 79 A"
{
	ParentBody	"HeliosA 79"
	Class		"Asteroid"
	Mass		2.1796360028165125e-09
	Radius		10.64453587510478

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007700899567366705
		Eccentricity	0.00473562133965566
		Inclination		167.49005199119915
		AscendingNode	100.59387755570124
		ArgOfPericen	197.19404923105313
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 79 B"
{
	ParentBody	"HeliosA 79"
	Class		"Asteroid"
	Mass		1.1175777851587733e-09
	Radius		8.519706998431866

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007700899567366705
		Eccentricity	0.00473562133965566
		Inclination		167.49005199119915
		AscendingNode	100.59387755570124
		ArgOfPericen	17.1940492310531
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 80"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.195208545584721e-10
	Radius		3.9509869253449246

	RotationPeriod	9.391406813163908

	Obliquity		127.40502122373026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.6192008987886037
		Eccentricity	0.46416057128460647
		Inclination		92.75465178367212
		AscendingNode	348.1307471980343
		ArgOfPericen	42.925462481949694
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 81"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0882640301865714e-08
	Radius		17.02131521668481

	RotationPeriod	6.9576781961863805

	Obliquity		198.2882134150934

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.107377695908546
		Eccentricity	0.4792879401437575
		Inclination		-106.59119103607662
		AscendingNode	58.615016687826106
		ArgOfPericen	98.30687562184102
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 82"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.7153026353056864e-09
	Radius		9.714591954757939

	RotationPeriod	9.361453623238818

	Obliquity		232.22296000561312

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.995942956537725
		Eccentricity	0.45331330477103265
		Inclination		33.74383263895204
		AscendingNode	190.62120165641096
		ArgOfPericen	270.92660803881466
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 83"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1518845672607282e-09
	Radius		7.8586003848766355

	RotationPeriod	5.8178476059405915

	Obliquity		282.3061655677907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.110381897205146
		Eccentricity	0.5861296352875235
		Inclination		10.139299794185723
		AscendingNode	206.2829772453731
		ArgOfPericen	82.22848526926182
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 84"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.892731843955536e-09
	Radius		12.553281706281243

	RotationPeriod	6.69324975209484

	Obliquity		322.09330854025865

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.7334753359705
		Eccentricity	0.7601839342045754
		Inclination		15.054166217883667
		AscendingNode	358.8095323260565
		ArgOfPericen	209.55830531768308
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 85"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.041314489256066e-09
	Radius		12.912070365746644

	RotationPeriod	5.409852521270943

	Obliquity		309.87084422506535

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.468323784243001
		Eccentricity	0.635703087276812
		Inclination		-21.482201855247098
		AscendingNode	73.99680710369742
		ArgOfPericen	123.88620404694647
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 86"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.077785325824165e-09
	Radius		8.513933684786831

	RotationPeriod	6.660816298927237

	Obliquity		321.2369850509725

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.662320574847593
		Eccentricity	0.4828086089096829
		Inclination		80.08550330281155
		AscendingNode	244.45593291724802
		ArgOfPericen	162.70593821062164
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 87"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.104541176314749
		Eccentricity	0.6781581910691816
		Inclination		111.80757870462537
		AscendingNode	329.57295654272934
		ArgOfPericen	337.839863366666
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 87 A"
{
	ParentBody	"HeliosA 87"
	Class		"Asteroid"
	Mass		2.180201927840733e-08
	Radius		20.99888720326527

	Orbit
	{
		Epoch			2457395.5
		Period			0.0077303323096026616
		Eccentricity	0.004641366271202086
		Inclination		131.32378910970536
		AscendingNode	69.43104588587995
		ArgOfPericen	3.1937096304244372
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 87 B"
{
	ParentBody	"HeliosA 87"
	Class		"Asteroid"
	Mass		6.605477611100247e-10
	Radius		6.546343389707764

	Orbit
	{
		Epoch			2457395.5
		Period			0.0077303323096026616
		Eccentricity	0.004641366271202086
		Inclination		131.32378910970536
		AscendingNode	69.43104588587995
		ArgOfPericen	183.19370963042445
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 88"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.73920810944173
		Eccentricity	0.5784624553218527
		Inclination		3.5731300922177502
		AscendingNode	25.88017069264066
		ArgOfPericen	280.93239825160595
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 88 A"
{
	ParentBody	"HeliosA 88"
	Class		"Asteroid"
	Mass		3.458278132929537e-09
	Radius		11.876444806768948

	Orbit
	{
		Epoch			2457395.5
		Period			0.003461040274032146
		Eccentricity	0.004622198549977994
		Inclination		52.233228017399746
		AscendingNode	134.8214682081223
		ArgOfPericen	217.3390973142545
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 88 B"
{
	ParentBody	"HeliosA 88"
	Class		"Asteroid"
	Mass		2.5412808339963832e-09
	Radius		10.717266634087599

	Orbit
	{
		Epoch			2457395.5
		Period			0.003461040274032146
		Eccentricity	0.004622198549977994
		Inclination		52.233228017399746
		AscendingNode	134.8214682081223
		ArgOfPericen	37.3390973142545
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 89"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0424958794475526e-08
	Radius		16.926807392510106

	RotationPeriod	4.103922815998233

	Obliquity		266.4030280700026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.319750737470294
		Eccentricity	0.6675295264000223
		Inclination		53.21229915999814
		AscendingNode	1.3589421671655089
		ArgOfPericen	216.623149027971
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 90"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.088291594668606
		Eccentricity	0.22737066160447694
		Inclination		23.650158831048152
		AscendingNode	284.05615842100406
		ArgOfPericen	281.9688264818929
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 90 A"
{
	ParentBody	"HeliosA 90"
	Class		"Asteroid"
	Mass		1.4277475904115226e-08
	Radius		19.19731522291169

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037481820441272245
		Eccentricity	0.005151988495682632
		Inclination		72.65745465035745
		AscendingNode	29.679026603121134
		ArgOfPericen	251.87949959424026
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 90 B"
{
	ParentBody	"HeliosA 90"
	Class		"Asteroid"
	Mass		6.5557145353465195e-09
	Radius		14.810283170236158

	Orbit
	{
		Epoch			2457395.5
		Period			0.0037481820441272245
		Eccentricity	0.005151988495682632
		Inclination		72.65745465035745
		AscendingNode	29.679026603121134
		ArgOfPericen	71.87949959424026
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 91"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.935321472377533e-09
	Radius		9.981230863992034

	RotationPeriod	8.293064856114558

	Obliquity		250.92405436347673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.54466284258678
		Eccentricity	0.2323019753221202
		Inclination		-46.573207545395405
		AscendingNode	244.84633915921427
		ArgOfPericen	9.307848771116532
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 92"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.546408438401135
		Eccentricity	0.47133575030091585
		Inclination		110.25914872754693
		AscendingNode	170.66326203436012
		ArgOfPericen	159.1468095489684
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 92 A"
{
	ParentBody	"HeliosA 92"
	Class		"Asteroid"
	Mass		1.1800758415489189e-09
	Radius		8.551046849052614

	Orbit
	{
		Epoch			2457395.5
		Period			0.0064127941568267385
		Eccentricity	0.005997621171349294
		Inclination		150.75459798944718
		AscendingNode	351.90324868396004
		ArgOfPericen	354.3347819312078
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 92 B"
{
	ParentBody	"HeliosA 92"
	Class		"Asteroid"
	Mass		7.916452200912839e-11
	Radius		3.474504223415533

	Orbit
	{
		Epoch			2457395.5
		Period			0.0064127941568267385
		Eccentricity	0.005997621171349294
		Inclination		150.75459798944718
		AscendingNode	351.90324868396004
		ArgOfPericen	174.33478193120777
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 93"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.252259087849502e-10
	Radius		8.079332294491284

	RotationPeriod	5.219300030214224

	Obliquity		180.42173501039582

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.85686213636751
		Eccentricity	0.3105585036369391
		Inclination		-0.725472681216942
		AscendingNode	9.831610098665685
		ArgOfPericen	306.8415597598798
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 94"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3142218740500055e-10
	Radius		3.7375373685356443

	RotationPeriod	4.53206826158673

	Obliquity		289.7468023460347

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.80522940285018
		Eccentricity	0.4171120389016074
		Inclination		-4.436126801577524
		AscendingNode	107.34304157565927
		ArgOfPericen	305.2046519316594
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 95"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.356871851204489e-09
	Radius		13.553518271151772

	RotationPeriod	5.073328714041838

	Obliquity		325.75650233407697

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.053509254556616
		Eccentricity	0.47113031312175013
		Inclination		96.01980024190281
		AscendingNode	229.76549493551406
		ArgOfPericen	161.4394583742688
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 96"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3361106178755116e-09
	Radius		8.843902589038002

	RotationPeriod	7.4537810901792705

	Obliquity		339.11691681052775

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.624614498193814
		Eccentricity	0.6283469698343103
		Inclination		103.16943146550221
		AscendingNode	122.28602294819295
		ArgOfPericen	193.70753338684645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 97"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6168598469030013e-09
	Radius		9.200234016085474

	RotationPeriod	4.543143406835811

	Obliquity		114.55227519876104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.237744371116115
		Eccentricity	0.6773119463622808
		Inclination		63.757763053362105
		AscendingNode	234.75484378324785
		ArgOfPericen	105.36754587749664
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 98"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.4164809681624375e-09
	Radius		11.937395913060614

	RotationPeriod	0.8923734435575783

	Obliquity		111.17000509846065

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.54602709367395
		Eccentricity	0.2642731678658622
		Inclination		-20.746339106990405
		AscendingNode	213.1055637443675
		ArgOfPericen	61.437387062244824
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 99"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.50137748950955
		Eccentricity	0.7377522510807164
		Inclination		-50.08869621281752
		AscendingNode	7.4014331604441574
		ArgOfPericen	107.85074544825548
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 99 A"
{
	ParentBody	"HeliosA 99"
	Class		"Asteroid"
	Mass		1.4808563211755279e-08
	Radius		18.79505343729884

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013152406876153907
		Eccentricity	0.005254585322472626
		Inclination		186.56648185027257
		AscendingNode	82.88281598810269
		ArgOfPericen	3.4942065704513725
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 99 B"
{
	ParentBody	"HeliosA 99"
	Class		"Asteroid"
	Mass		1.0262606852027797e-08
	Radius		16.63253659381021

	Orbit
	{
		Epoch			2457395.5
		Period			0.0013152406876153907
		Eccentricity	0.005254585322472626
		Inclination		186.56648185027257
		AscendingNode	82.88281598810269
		ArgOfPericen	183.49420657045138
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 100"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.947202176312957e-09
	Radius		14.72906124404972

	RotationPeriod	8.75999638869381

	Obliquity		301.1091718204786

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.606718243029245
		Eccentricity	0.5397986512126971
		Inclination		101.41654614170272
		AscendingNode	241.20665160367554
		ArgOfPericen	352.54651045190263
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 101"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1228562190590286e-08
	Radius		17.02582895909904

	RotationPeriod	2.5866703591823192

	Obliquity		272.38041053172844

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.50523850865037
		Eccentricity	0.5957924661963118
		Inclination		-1.6515781849046345
		AscendingNode	164.95921837021848
		ArgOfPericen	222.18046028428955
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 102"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2161582402583804e-08
	Radius		17.864619601158502

	RotationPeriod	5.533952567302247

	Obliquity		316.73873985552234

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.048086700802711
		Eccentricity	0.44986546954304535
		Inclination		1.341210316060007
		AscendingNode	18.02458742769534
		ArgOfPericen	214.96702182838027
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 103"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.727260006811573e-09
	Radius		15.12929737822931

	RotationPeriod	7.144799958247518

	Obliquity		70.33654722219619

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.879050723553892
		Eccentricity	0.6524064059942929
		Inclination		-47.907491262407305
		AscendingNode	317.75102407440835
		ArgOfPericen	263.6002412216037
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 104"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.995065172712059e-09
	Radius		11.96908388177623

	RotationPeriod	8.800790182520593

	Obliquity		68.93224306145551

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.81339160185008
		Eccentricity	0.2823083966445215
		Inclination		-26.009146574258935
		AscendingNode	115.33056671734916
		ArgOfPericen	54.719268613702965
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 105"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.734409432613364e-09
	Radius		14.797381163972119

	RotationPeriod	6.574340897022542

	Obliquity		40.575959306026284

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.04636817792545
		Eccentricity	0.4485278016548573
		Inclination		-74.56319468571382
		AscendingNode	315.01364859669513
		ArgOfPericen	9.439608913004385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 106"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.259938639424867e-09
	Radius		13.231526147992

	RotationPeriod	4.284394361674695

	Obliquity		159.7552178095583

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.916660645655032
		Eccentricity	0.45948807652486695
		Inclination		-7.43875547547002
		AscendingNode	241.30032632415154
		ArgOfPericen	172.95117448094132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 107"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4000580238061447e-09
	Radius		9.266725635237565

	RotationPeriod	5.8452608273328845

	Obliquity		73.64598421234436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.47716827981992
		Eccentricity	0.40801189218441863
		Inclination		45.73835014432997
		AscendingNode	222.57625005637618
		ArgOfPericen	102.09242678421904
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 108"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.73003521841529e-09
	Radius		12.93734205810767

	RotationPeriod	5.864453956661269

	Obliquity		185.5544251430693

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.12947572737101
		Eccentricity	0.4579706992863901
		Inclination		62.70275285975817
		AscendingNode	37.050034882281736
		ArgOfPericen	261.33835841822685
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 109"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.780145696536666
		Eccentricity	0.5565381843482894
		Inclination		90.55183755354967
		AscendingNode	218.82575823012988
		ArgOfPericen	263.8994403610046
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 109 A"
{
	ParentBody	"HeliosA 109"
	Class		"Asteroid"
	Mass		6.2053594200420366e-09
	Radius		14.227456643552454

	Orbit
	{
		Epoch			2457395.5
		Period			0.003913486271048786
		Eccentricity	0.003636151384282774
		Inclination		293.1327375199076
		AscendingNode	30.47432228763774
		ArgOfPericen	322.6369569089672
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 109 B"
{
	ParentBody	"HeliosA 109"
	Class		"Asteroid"
	Mass		3.46780447759426e-10
	Radius		5.439468816906635

	Orbit
	{
		Epoch			2457395.5
		Period			0.003913486271048786
		Eccentricity	0.003636151384282774
		Inclination		293.1327375199076
		AscendingNode	30.47432228763774
		ArgOfPericen	142.6369569089672
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 110"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.622484834340035
		Eccentricity	0.7872020247909242
		Inclination		-50.92213847578979
		AscendingNode	281.8166887524222
		ArgOfPericen	25.054238636750704
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 110 A"
{
	ParentBody	"HeliosA 110"
	Class		"Asteroid"
	Mass		1.1477776232677393e-08
	Radius		17.416849105976944

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030015716107115393
		Eccentricity	0.0026534647117445907
		Inclination		168.45242789984002
		AscendingNode	230.95804202324675
		ArgOfPericen	293.0302939002734
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 110 B"
{
	ParentBody	"HeliosA 110"
	Class		"Asteroid"
	Mass		7.47176858281492e-09
	Radius		15.094711219642937

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030015716107115393
		Eccentricity	0.0026534647117445907
		Inclination		168.45242789984002
		AscendingNode	230.95804202324675
		ArgOfPericen	113.03029390027342
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 111"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.651011161237019e-09
	Radius		10.514575864878164

	RotationPeriod	7.976653148796643

	Obliquity		264.08537069163646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.835468041158293
		Eccentricity	0.5475396720338931
		Inclination		-63.92350750337615
		AscendingNode	192.5581515071092
		ArgOfPericen	61.232168578613056
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 112"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.062625350144554
		Eccentricity	0.49119840540155
		Inclination		13.768479349376815
		AscendingNode	127.23114212267137
		ArgOfPericen	75.70071383585284
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 112 A"
{
	ParentBody	"HeliosA 112"
	Class		"Asteroid"
	Mass		6.830169501280634e-09
	Radius		14.796899565695966

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066751880303354315
		Eccentricity	0.0039370155032278625
		Inclination		179.56856700964317
		AscendingNode	64.54307816480105
		ArgOfPericen	218.0307421611467
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 112 B"
{
	ParentBody	"HeliosA 112"
	Class		"Asteroid"
	Mass		2.8356300631162056e-09
	Radius		11.038500700680453

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066751880303354315
		Eccentricity	0.0039370155032278625
		Inclination		179.56856700964317
		AscendingNode	64.54307816480105
		ArgOfPericen	38.03074216114669
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 113"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.753020243067473
		Eccentricity	0.957873845070558
		Inclination		34.82749988825611
		AscendingNode	4.599535506522079
		ArgOfPericen	151.2095887757909
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 113 A"
{
	ParentBody	"HeliosA 113"
	Class		"Asteroid"
	Mass		2.7699475997698117e-10
	Radius		5.3663258998752

	Orbit
	{
		Epoch			2457395.5
		Period			0.003225614539510577
		Eccentricity	0.005891927031864637
		Inclination		334.71153836916596
		AscendingNode	213.05303493556744
		ArgOfPericen	248.04067625548922
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 113 B"
{
	ParentBody	"HeliosA 113"
	Class		"Asteroid"
	Mass		2.302957826842226e-10
	Radius		5.046014814977621

	Orbit
	{
		Epoch			2457395.5
		Period			0.003225614539510577
		Eccentricity	0.005891927031864637
		Inclination		334.71153836916596
		AscendingNode	213.05303493556744
		ArgOfPericen	68.04067625548919
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 114"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.701975313811426e-09
	Radius		15.313390339952887

	RotationPeriod	5.892645265749378

	Obliquity		219.29228341104985

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.217472195093555
		Eccentricity	0.43696951745048884
		Inclination		-21.92315371210002
		AscendingNode	92.59809081284544
		ArgOfPericen	359.57886901889134
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 115"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.758422850522018e-10
	Radius		7.312225672022832

	RotationPeriod	7.4645110730192465

	Obliquity		58.01189749204579

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.871212743531128
		Eccentricity	0.35980874188552536
		Inclination		-74.13321189144317
		AscendingNode	97.91941166087172
		ArgOfPericen	315.7891279312427
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 116"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.91037170734726e-10
	Radius		6.716370630537648

	RotationPeriod	5.597689518087037

	Obliquity		275.8236701119245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.993417092697964
		Eccentricity	0.7409351451944709
		Inclination		7.116000924044924
		AscendingNode	290.2319776333966
		ArgOfPericen	75.6276291447529
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 117"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.771059951977693e-09
	Radius		16.211077613543004

	RotationPeriod	7.461020012106996

	Obliquity		196.1075905784616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.1436269914113915
		Eccentricity	0.45348827882669335
		Inclination		26.977649496127164
		AscendingNode	313.4005156839143
		ArgOfPericen	165.47231641133632
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 118"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.021736545406365e-09
	Radius		13.335199691454363

	RotationPeriod	5.730060270831057

	Obliquity		206.36619163035618

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.705394360260788
		Eccentricity	0.5044417919930598
		Inclination		-28.769072236291652
		AscendingNode	312.0228226269395
		ArgOfPericen	223.66848410951076
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 119"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.453134948644345e-10
	Radius		5.3731990798211715

	RotationPeriod	8.307387531131518

	Obliquity		220.2449940961751

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.649645322743892
		Eccentricity	0.32734323903704987
		Inclination		58.353093694763885
		AscendingNode	50.40768565583192
		ArgOfPericen	130.21299185607106
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 120"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.129432560185548e-08
	Radius		18.177546152501122

	RotationPeriod	4.718696276334336

	Obliquity		323.0347968990488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.016901517430082
		Eccentricity	0.6312501127214737
		Inclination		-55.266588128286116
		AscendingNode	125.69233052573863
		ArgOfPericen	3.1398327042030916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 121"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.867335614651356
		Eccentricity	0.43859719997142727
		Inclination		80.2848433822531
		AscendingNode	221.82975185906457
		ArgOfPericen	326.45602261956424
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 121 A"
{
	ParentBody	"HeliosA 121"
	Class		"Asteroid"
	Mass		2.1851511256699342e-08
	Radius		22.83120376456019

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016331955555088464
		Eccentricity	0.005435626233004657
		Inclination		66.71587819458318
		AscendingNode	147.92447147801036
		ArgOfPericen	167.16306643053719
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 121 B"
{
	ParentBody	"HeliosA 121"
	Class		"Asteroid"
	Mass		1.0032868721676054e-08
	Radius		17.61340658983559

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016331955555088464
		Eccentricity	0.005435626233004657
		Inclination		66.71587819458318
		AscendingNode	147.92447147801036
		ArgOfPericen	347.1630664305372
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 122"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.638574323224223
		Eccentricity	0.7712692573287813
		Inclination		26.21111344662526
		AscendingNode	166.49415978479547
		ArgOfPericen	318.22265560029535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 122 A"
{
	ParentBody	"HeliosA 122"
	Class		"Asteroid"
	Mass		1.3222136623024398e-09
	Radius		8.062915636425718

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011954424298070505
		Eccentricity	0.0034691689017440396
		Inclination		124.14033850948269
		AscendingNode	185.31031603804055
		ArgOfPericen	349.6266070508338
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 122 B"
{
	ParentBody	"HeliosA 122"
	Class		"Asteroid"
	Mass		9.071343205847468e-10
	Radius		7.1112962021785675

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011954424298070505
		Eccentricity	0.0034691689017440396
		Inclination		124.14033850948269
		AscendingNode	185.31031603804055
		ArgOfPericen	169.62660705083385
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 123"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.015494615408201e-10
	Radius		6.659410210248958

	RotationPeriod	7.188059761191554

	Obliquity		71.05048549274369

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	2.1377700433056965
		Eccentricity	0.3422569250680439
		Inclination		47.46536861066697
		AscendingNode	229.34417680514716
		ArgOfPericen	279.3179427325703
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 124"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.195086983034138
		Eccentricity	0.6551617998317284
		Inclination		0.9415261208653698
		AscendingNode	96.76865738477623
		ArgOfPericen	285.37821742700675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 124 A"
{
	ParentBody	"HeliosA 124"
	Class		"Asteroid"
	Mass		8.864504273762052e-11
	Radius		3.3987675573903413

	Orbit
	{
		Epoch			2457395.5
		Period			0.00691209163018533
		Eccentricity	0.005682027066112426
		Inclination		139.2582253291041
		AscendingNode	171.69318200996048
		ArgOfPericen	211.3961577276271
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 124 B"
{
	ParentBody	"HeliosA 124"
	Class		"Asteroid"
	Mass		6.009347076941597e-12
	Radius		1.3858378187499474

	Orbit
	{
		Epoch			2457395.5
		Period			0.00691209163018533
		Eccentricity	0.005682027066112426
		Inclination		139.2582253291041
		AscendingNode	171.69318200996048
		ArgOfPericen	31.3961577276271
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 125"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.065079454589982e-09
	Radius		16.428493275864255

	RotationPeriod	3.821170202042903

	Obliquity		230.6329217056487

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.802971208635944
		Eccentricity	0.42136960730969636
		Inclination		-41.93777467763534
		AscendingNode	119.26000446883835
		ArgOfPericen	57.876725570158015
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 126"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.868062022029767e-09
	Radius		9.962671618442217

	RotationPeriod	3.9823396915412803

	Obliquity		331.69704805638406

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.761787476105244
		Eccentricity	0.6037892689437714
		Inclination		-122.27091058128121
		AscendingNode	82.5001900821275
		ArgOfPericen	267.2839435731202
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 127"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.967255829639318e-10
	Radius		4.983358276816985

	RotationPeriod	5.108318873936435

	Obliquity		287.39615830543823

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.594082747797817
		Eccentricity	0.6153890670166947
		Inclination		-52.070404985504936
		AscendingNode	162.95811919970944
		ArgOfPericen	312.6775778631724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 128"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.001018014939427e-09
	Radius		9.822838112268242

	RotationPeriod	5.317589488186766

	Obliquity		24.101023129606208

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.0140172198944
		Eccentricity	0.3057471318826164
		Inclination		-14.166071924568927
		AscendingNode	302.3551283919627
		ArgOfPericen	252.35268586667164
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 129"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.377632859307647
		Eccentricity	0.5017534831025953
		Inclination		101.8602363641351
		AscendingNode	214.3500505578533
		ArgOfPericen	91.26658364303364
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 129 A"
{
	ParentBody	"HeliosA 129"
	Class		"Asteroid"
	Mass		8.919610260000899e-09
	Radius		16.26168726829097

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024171031492557886
		Eccentricity	0.004889249856629135
		Inclination		204.51599679196642
		AscendingNode	109.68075080980073
		ArgOfPericen	67.56164566489778
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 129 B"
{
	ParentBody	"HeliosA 129"
	Class		"Asteroid"
	Mass		5.473712214499809e-09
	Radius		13.81903230479294

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024171031492557886
		Eccentricity	0.004889249856629135
		Inclination		204.51599679196642
		AscendingNode	109.68075080980073
		ArgOfPericen	247.56164566489778
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 130"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3117966459374812e-09
	Radius		9.210085609744882

	RotationPeriod	4.4765926152554325

	Obliquity		42.65169527214481

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.3146163673239482
		Eccentricity	0.33577563946635736
		Inclination		11.514827808088581
		AscendingNode	258.91886854560835
		ArgOfPericen	232.13410823682148
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 131"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.7637074457775484e-09
	Radius		11.080481106313632

	RotationPeriod	3.886662006429567

	Obliquity		256.31324212079585

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.563852393250325
		Eccentricity	0.43870132767958087
		Inclination		-113.73167572344741
		AscendingNode	78.80430413247308
		ArgOfPericen	20.76501363764132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 132"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.220126066572756e-12
	Radius		0.8488886862603007

	RotationPeriod	6.871628451170595

	Obliquity		26.480071928259285

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.105232694838966
		Eccentricity	0.6685614310382844
		Inclination		-46.50212742380211
		AscendingNode	110.08432971829419
		ArgOfPericen	302.8187100488239
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 133"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1227291654066017e-09
	Radius		8.441177940563437

	RotationPeriod	4.5897242195031085

	Obliquity		82.95432623243855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.180875638697758
		Eccentricity	0.5849313803693494
		Inclination		26.273539973068978
		AscendingNode	232.63836760130417
		ArgOfPericen	287.46836516906797
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 134"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.118507307220407e-09
	Radius		15.399068438137965

	RotationPeriod	7.012807520736078

	Obliquity		166.21883685220786

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.920051904117898
		Eccentricity	0.23687052229042938
		Inclination		47.12032616533204
		AscendingNode	104.7924435582543
		ArgOfPericen	251.15971708115686
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 135"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.116282184881914e-09
	Radius		8.188859880991025

	RotationPeriod	4.002485902734298

	Obliquity		202.12754354534877

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.968863744924334
		Eccentricity	0.21242750878504363
		Inclination		87.56488182262942
		AscendingNode	332.1259972734626
		ArgOfPericen	25.00502092489452
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 136"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.865920103110579e-09
	Radius		12.674520998092593

	RotationPeriod	2.2213843989419106

	Obliquity		156.75548363286663

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.466896168905684
		Eccentricity	0.301477798106906
		Inclination		-99.23709409137687
		AscendingNode	197.48072461262407
		ArgOfPericen	195.9645856207191
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 137"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.20647402793961
		Eccentricity	0.49735974353266216
		Inclination		110.23890515925243
		AscendingNode	219.65697413224834
		ArgOfPericen	143.04970743924213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 137 A"
{
	ParentBody	"HeliosA 137"
	Class		"Asteroid"
	Mass		3.138012416277843e-09
	Radius		11.308978547990879

	Orbit
	{
		Epoch			2457395.5
		Period			0.005557842230087209
		Eccentricity	0.006342696145245432
		Inclination		250.83827763648196
		AscendingNode	107.2952750156897
		ArgOfPericen	106.52413641421762
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 137 B"
{
	ParentBody	"HeliosA 137"
	Class		"Asteroid"
	Mass		2.650746313749335e-09
	Radius		10.69041463033315

	Orbit
	{
		Epoch			2457395.5
		Period			0.005557842230087209
		Eccentricity	0.006342696145245432
		Inclination		250.83827763648196
		AscendingNode	107.2952750156897
		ArgOfPericen	286.52413641421765
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 138"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1970248352157078e-08
	Radius		17.168401263824943

	RotationPeriod	4.853559812779476

	Obliquity		186.053441340427

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.924693974388713
		Eccentricity	0.8582387537090098
		Inclination		72.7682374693289
		AscendingNode	281.40161342395294
		ArgOfPericen	2.9961460512632065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 139"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		7.271478129657332e-09
	Radius		15.292808401852717

	RotationPeriod	6.2134026422996085

	Obliquity		316.8041668472104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.862564381644878
		Eccentricity	0.821578409986393
		Inclination		-75.88052909843367
		AscendingNode	36.78161319295193
		ArgOfPericen	148.8562993266269
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 140"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.225219698911088e-09
	Radius		8.623052846287404

	RotationPeriod	3.496962501336058

	Obliquity		278.79628298738754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.083967256646773
		Eccentricity	0.7247931708096369
		Inclination		-119.11401303179831
		AscendingNode	256.47732702301255
		ArgOfPericen	184.80399253406236
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 141"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.573766565469957e-09
	Radius		10.410521485258734

	RotationPeriod	6.09995582680342

	Obliquity		216.67566318857843

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.151417205665595
		Eccentricity	0.6175038180825746
		Inclination		27.55768721467169
		AscendingNode	295.1422117671617
		ArgOfPericen	59.24619888671482
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 142"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.560796892185696e-09
	Radius		13.57624472378292

	RotationPeriod	11.116156043220421

	Obliquity		323.6819808160169

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.065720653330692
		Eccentricity	0.6754145430413977
		Inclination		-0.23564873118737725
		AscendingNode	100.70996695790696
		ArgOfPericen	220.4818981153512
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 143"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.979894561731035e-09
	Radius		12.792837292334823

	RotationPeriod	5.292776956904351

	Obliquity		219.73705717002412

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.968528239190555
		Eccentricity	0.22960844873206498
		Inclination		-41.27692701849123
		AscendingNode	327.12438269248145
		ArgOfPericen	319.40861764329895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 144"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.579562799394027e-09
	Radius		13.92574015565557

	RotationPeriod	7.105130207879883

	Obliquity		138.66165056714956

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.612327515413947
		Eccentricity	0.19920063159904544
		Inclination		-11.427659523393087
		AscendingNode	93.71039166393676
		ArgOfPericen	260.4909938374903
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 145"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4300170658156688e-09
	Radius		9.074853735649938

	RotationPeriod	7.05751367411803

	Obliquity		6.20785965068833

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.230642336356938
		Eccentricity	0.21103570134526706
		Inclination		104.17185425284099
		AscendingNode	313.8879330612054
		ArgOfPericen	341.1293590170736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 146"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0415576005479702e-08
	Radius		16.942922953515108

	RotationPeriod	8.771849890533012

	Obliquity		67.25762994418847

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.276625126005754
		Eccentricity	0.43920858654348405
		Inclination		73.08472975511887
		AscendingNode	232.67454622105814
		ArgOfPericen	332.4126648408316
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 147"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.976411691079719
		Eccentricity	0.5290102177866313
		Inclination		71.19627424369573
		AscendingNode	139.49579969629949
		ArgOfPericen	194.80816426649673
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 147 A"
{
	ParentBody	"HeliosA 147"
	Class		"Asteroid"
	Mass		2.901569726095304e-10
	Radius		5.156145920468206

	Orbit
	{
		Epoch			2457395.5
		Period			0.004926597484507215
		Eccentricity	0.007364324833519853
		Inclination		92.37950097627419
		AscendingNode	294.0671669151471
		ArgOfPericen	275.23000866276374
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 147 B"
{
	ParentBody	"HeliosA 147"
	Class		"Asteroid"
	Mass		1.3132029849893293e-10
	Radius		3.958750666405784

	Orbit
	{
		Epoch			2457395.5
		Period			0.004926597484507215
		Eccentricity	0.007364324833519853
		Inclination		92.37950097627419
		AscendingNode	294.0671669151471
		ArgOfPericen	95.23000866276374
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 148"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.3131485137686507e-08
	Radius		18.88580621081578

	RotationPeriod	8.015671519673583

	Obliquity		71.14337638318699

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.7997348861982
		Eccentricity	0.4302576940602752
		Inclination		13.752196823560359
		AscendingNode	316.89887465617187
		ArgOfPericen	237.9708757931337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 149"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.585138722152923
		Eccentricity	0.6000917606455267
		Inclination		46.477616548910426
		AscendingNode	167.15820283142557
		ArgOfPericen	6.260385445286691
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 149 A"
{
	ParentBody	"HeliosA 149"
	Class		"Asteroid"
	Mass		1.2359087961695478e-08
	Radius		17.93150918002354

	Orbit
	{
		Epoch			2457395.5
		Period			0.006177965306165658
		Eccentricity	0.003266716743000786
		Inclination		239.2981823515476
		AscendingNode	239.3208641840193
		ArgOfPericen	13.45434986288955
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 149 B"
{
	ParentBody	"HeliosA 149"
	Class		"Asteroid"
	Mass		7.9629034007016e-09
	Radius		15.487400083940813

	Orbit
	{
		Epoch			2457395.5
		Period			0.006177965306165658
		Eccentricity	0.003266716743000786
		Inclination		239.2981823515476
		AscendingNode	239.3208641840193
		ArgOfPericen	193.45434986288956
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 150"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.234799120545602e-09
	Radius		11.532052654010231

	RotationPeriod	8.520389790874663

	Obliquity		255.2937319883661

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.7265749123178953
		Eccentricity	0.21512715030115165
		Inclination		-16.333391841679187
		AscendingNode	255.8399812383403
		ArgOfPericen	146.64269174192387
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 151"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6845276514436608e-09
	Radius		9.530961888072909

	RotationPeriod	4.804442453538405

	Obliquity		78.17738735864192

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.86036437810001
		Eccentricity	0.46025021898562274
		Inclination		76.32162779152863
		AscendingNode	229.07323012320015
		ArgOfPericen	278.36014620978995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 152"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.1523423119254368e-08
	Radius		18.010847534409642

	RotationPeriod	8.495735484452428

	Obliquity		116.36248404766224

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.28045981468733
		Eccentricity	0.5629347192615701
		Inclination		17.52068001692291
		AscendingNode	89.97838332747338
		ArgOfPericen	31.9916378898889
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 153"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.8629945004926378e-08
	Radius		19.895301327522382

	RotationPeriod	3.7424119041231694

	Obliquity		184.17373027131782

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.843851948086915
		Eccentricity	0.6529829069622517
		Inclination		-74.40723857908394
		AscendingNode	125.77831353093751
		ArgOfPericen	316.4695805379713
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 154"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.251660899076833e-09
	Radius		16.44003552789895

	RotationPeriod	8.449099311421982

	Obliquity		230.6749080227695

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.710485388382541
		Eccentricity	0.1991157540178336
		Inclination		42.364124513768886
		AscendingNode	282.5789922699832
		ArgOfPericen	41.350180190304265
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 155"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.433538017028975e-09
	Radius		8.72423394844685

	RotationPeriod	3.810710794361555

	Obliquity		116.71989927466284

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.25811783369536
		Eccentricity	0.4389287484519308
		Inclination		-38.54600429116171
		AscendingNode	184.30992237482513
		ArgOfPericen	55.17015680315498
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 156"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.0104393926752636e-09
	Radius		11.061224527809081

	RotationPeriod	6.81562227551102

	Obliquity		250.6433285093116

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.266326859593587
		Eccentricity	0.6172539983543318
		Inclination		-26.96282889869764
		AscendingNode	74.73360941338223
		ArgOfPericen	42.087836211774686
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 157"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2554044771204012e-08
	Radius		17.617322209843966

	RotationPeriod	5.091340203618445

	Obliquity		5.905376787400356

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.830570417045415
		Eccentricity	0.2806100030637984
		Inclination		-87.26994965062651
		AscendingNode	136.57925247048794
		ArgOfPericen	294.18490355174356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 158"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2023651390809278e-09
	Radius		8.040657985342866

	RotationPeriod	5.863635287608345

	Obliquity		92.78934418230762

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.990497734247338
		Eccentricity	0.2805504676287811
		Inclination		31.97610775192443
		AscendingNode	292.1989755528733
		ArgOfPericen	283.56907572742284
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 159"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4620860619217195e-11
	Radius		1.9464681812642937

	RotationPeriod	2.6202040266964994

	Obliquity		205.65803978592788

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.151621459498228
		Eccentricity	0.10298759786727424
		Inclination		14.786861513064803
		AscendingNode	98.51030715814312
		ArgOfPericen	351.5959103677786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 160"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.395269978083852e-09
	Radius		13.252452418558397

	RotationPeriod	6.91213351419742

	Obliquity		351.76184407204767

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.600651603778834
		Eccentricity	0.4032057960415597
		Inclination		-5.2791916419429405
		AscendingNode	157.62532594756084
		ArgOfPericen	237.01313428875204
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 161"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.0411246772029142e-09
	Radius		7.97494372034575

	RotationPeriod	7.428302401683695

	Obliquity		227.73008266498363

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.653726195210723
		Eccentricity	0.4062153016897896
		Inclination		15.627066555641761
		AscendingNode	111.79300048342411
		ArgOfPericen	272.4144920628841
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 162"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.707200330078891e-09
	Radius		16.336426060109737

	RotationPeriod	7.571991189464465

	Obliquity		226.53195660871924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.212831477665098
		Eccentricity	0.43224926062731495
		Inclination		111.48116846767431
		AscendingNode	228.3236888507798
		ArgOfPericen	96.7096987623851
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 163"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.3741043119459782e-09
	Radius		10.097478351263662

	RotationPeriod	3.4694535895773857

	Obliquity		350.6559126398487

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.259659025383344
		Eccentricity	0.36665592742284436
		Inclination		85.36890983057452
		AscendingNode	142.97036860768475
		ArgOfPericen	266.3838874147732
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 164"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.608385951865123e-11
	Radius		3.0607436419926994

	RotationPeriod	4.5060147647515745

	Obliquity		85.50548915409672

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.702793668462725
		Eccentricity	0.4670181784458685
		Inclination		44.50722101281952
		AscendingNode	298.9094506474292
		ArgOfPericen	333.5217643368821
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 165"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.460992343491725
		Eccentricity	0.4805012301517061
		Inclination		-4.856706881973737
		AscendingNode	319.40544457731266
		ArgOfPericen	337.88960165442984
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 165 A"
{
	ParentBody	"HeliosA 165"
	Class		"Asteroid"
	Mass		5.74399026570705e-09
	Radius		14.32868287129949

	Orbit
	{
		Epoch			2457395.5
		Period			0.005893813309553256
		Eccentricity	0.0029402935985450244
		Inclination		29.950173240082204
		AscendingNode	189.67181427266166
		ArgOfPericen	28.483020686960852
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 165 B"
{
	ParentBody	"HeliosA 165"
	Class		"Asteroid"
	Mass		9.917368541005506e-10
	Radius		7.978731611316584

	Orbit
	{
		Epoch			2457395.5
		Period			0.005893813309553256
		Eccentricity	0.0029402935985450244
		Inclination		29.950173240082204
		AscendingNode	189.67181427266166
		ArgOfPericen	208.48302068696086
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 166"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.894854606218658
		Eccentricity	0.5899944762832239
		Inclination		-8.331436602961722
		AscendingNode	37.581898077306
		ArgOfPericen	352.11579603243257
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 166 A"
{
	ParentBody	"HeliosA 166"
	Class		"Asteroid"
	Mass		4.756600860317745e-09
	Radius		13.100735467503519

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023226832010431963
		Eccentricity	0.007290513947109195
		Inclination		24.727318520342465
		AscendingNode	281.4726316212349
		ArgOfPericen	74.54416032830218
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 166 B"
{
	ParentBody	"HeliosA 166"
	Class		"Asteroid"
	Mass		2.3816132242851458e-09
	Radius		10.402886297633131

	Orbit
	{
		Epoch			2457395.5
		Period			0.0023226832010431963
		Eccentricity	0.007290513947109195
		Inclination		24.727318520342465
		AscendingNode	281.4726316212349
		ArgOfPericen	254.54416032830218
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 167"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.588728862304687e-09
	Radius		15.724166871375477

	RotationPeriod	6.5923889023921936

	Obliquity		231.56212593548335

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.863333840189991
		Eccentricity	0.478963205591908
		Inclination		78.04482364881213
		AscendingNode	102.68668522772825
		ArgOfPericen	175.3401868812475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 168"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.2571216342922482e-09
	Radius		8.545568857859362

	RotationPeriod	3.191035936092161

	Obliquity		107.83580656134717

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.374105393445044
		Eccentricity	0.39218560965628324
		Inclination		-16.87254585164579
		AscendingNode	222.7067642599881
		ArgOfPericen	138.07240167154092
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 169"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.897674623263003e-09
	Radius		14.405646772343935

	RotationPeriod	7.274716712278062

	Obliquity		221.83514245234133

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.310942357417034
		Eccentricity	0.5872266174798002
		Inclination		10.339685704155306
		AscendingNode	46.62294134371881
		ArgOfPericen	246.3543815301009
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 170"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.8922252438479958e-09
	Radius		11.407064826531805

	RotationPeriod	6.104979816989007

	Obliquity		39.33578157653355

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.0082220531935
		Eccentricity	0.5512243435170172
		Inclination		4.244740089621836
		AscendingNode	73.58646266468843
		ArgOfPericen	172.22036349971077
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 171"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.823959274945432e-09
	Radius		15.433819677204728

	RotationPeriod	6.53895647571502

	Obliquity		179.46575749401927

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.839786746482467
		Eccentricity	0.5304926156773987
		Inclination		67.97395267667571
		AscendingNode	85.14523571286148
		ArgOfPericen	30.144826008104992
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 172"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.079709504843011
		Eccentricity	0.6520269178287962
		Inclination		-48.685503056628754
		AscendingNode	313.14095827220643
		ArgOfPericen	212.1038563221333
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 172 A"
{
	ParentBody	"HeliosA 172"
	Class		"Asteroid"
	Mass		3.8770939973379756e-09
	Radius		13.190454275635538

	Orbit
	{
		Epoch			2457395.5
		Period			0.001570053898424503
		Eccentricity	0.006206042695397264
		Inclination		185.04549324354034
		AscendingNode	266.75248555195265
		ArgOfPericen	104.28667458000736
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 172 B"
{
	ParentBody	"HeliosA 172"
	Class		"Asteroid"
	Mass		3.7081061922190424e-09
	Radius		12.99595993095987

	Orbit
	{
		Epoch			2457395.5
		Period			0.001570053898424503
		Eccentricity	0.006206042695397264
		Inclination		185.04549324354034
		AscendingNode	266.75248555195265
		ArgOfPericen	284.28667458000734
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 173"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6060502893296273e-08
	Radius		19.7642925444652

	RotationPeriod	2.5908610427907948

	Obliquity		342.5291111001413

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.333262750668702
		Eccentricity	0.42495233302840774
		Inclination		-26.360780730795106
		AscendingNode	289.2118986001407
		ArgOfPericen	189.18013878443116
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 174"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5819020658179884e-09
	Radius		8.927361402327096

	RotationPeriod	6.067762793084747

	Obliquity		136.588731108108

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.519911396523643
		Eccentricity	0.4333038275547051
		Inclination		62.72614695034348
		AscendingNode	14.72951137907058
		ArgOfPericen	147.65605526241967
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 175"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5877979121206756e-09
	Radius		8.568369273438824

	RotationPeriod	4.0927445373808675

	Obliquity		54.33192214608671

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.130063381544858
		Eccentricity	0.6822511945587298
		Inclination		-52.92609331462852
		AscendingNode	110.70894199159873
		ArgOfPericen	72.79286825595966
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 176"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.77491690025674e-09
	Radius		11.869072125283635

	RotationPeriod	7.330531762626713

	Obliquity		320.77127657680876

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.406250645277396
		Eccentricity	0.3539621105431511
		Inclination		125.5051720628819
		AscendingNode	103.72179124955767
		ArgOfPericen	346.5770028020443
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 177"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.0809579340707566e-09
	Radius		10.52728856418622

	RotationPeriod	2.907188215970972

	Obliquity		160.70293581992684

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.905213840591927
		Eccentricity	0.203708493428722
		Inclination		14.87746125575759
		AscendingNode	357.5799141553179
		ArgOfPericen	206.41592564174675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 178"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.9845418893411235e-09
	Radius		13.611146616128469

	RotationPeriod	7.150585867186424

	Obliquity		69.0991535101157

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.70603660917089
		Eccentricity	0.6761958590988587
		Inclination		33.15660603700253
		AscendingNode	176.27617845509528
		ArgOfPericen	300.3374294537781
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 179"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.352308403242888e-10
	Radius		6.355637290123101

	RotationPeriod	5.39901884492269

	Obliquity		165.7968984377812

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.78238865436391
		Eccentricity	0.19920949132247923
		Inclination		10.079757168072526
		AscendingNode	303.1234977980789
		ArgOfPericen	83.81376995031447
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 180"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.049221058515423
		Eccentricity	0.584236004974444
		Inclination		-107.1032172000216
		AscendingNode	223.30624102045758
		ArgOfPericen	45.16176441220083
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 180 A"
{
	ParentBody	"HeliosA 180"
	Class		"Asteroid"
	Mass		1.3697861982039945e-08
	Radius		19.52629299009654

	Orbit
	{
		Epoch			2457395.5
		Period			0.008077389571884716
		Eccentricity	0.006566818113413672
		Inclination		211.13149475157834
		AscendingNode	82.08025580147563
		ArgOfPericen	314.7030721409978
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 180 B"
{
	ParentBody	"HeliosA 180"
	Class		"Asteroid"
	Mass		1.246841025877739e-09
	Radius		8.783600353219942

	Orbit
	{
		Epoch			2457395.5
		Period			0.008077389571884716
		Eccentricity	0.006566818113413672
		Inclination		211.13149475157834
		AscendingNode	82.08025580147563
		ArgOfPericen	134.7030721409978
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 181"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.4825932466860218e-09
	Radius		8.835437915884201

	RotationPeriod	7.631942377153616

	Obliquity		111.75631102821734

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.45024180820798
		Eccentricity	0.39069513783153653
		Inclination		-17.786482602656722
		AscendingNode	271.87302919270064
		ArgOfPericen	119.43271059877031
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 182"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.6004922234354146e-09
	Radius		9.017768026199636

	RotationPeriod	10.88241233312193

	Obliquity		60.71982195191955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.491820433639823
		Eccentricity	0.40625283885239516
		Inclination		-49.54696969713513
		AscendingNode	341.25035830077366
		ArgOfPericen	103.94594018147507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 183"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.934426672207696e-10
	Radius		5.951271011805806

	RotationPeriod	9.378513691898219

	Obliquity		231.89793873788184

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.369464828065622
		Eccentricity	0.45639234197858825
		Inclination		-11.512733924609325
		AscendingNode	6.782909272348001
		ArgOfPericen	141.168517306053
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 184"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.420642556829439e-09
	Radius		11.033356838975937

	RotationPeriod	4.022624665810001

	Obliquity		216.35279730348708

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.512117197332895
		Eccentricity	0.2020939468508473
		Inclination		5.671367831307883
		AscendingNode	55.41561012202655
		ArgOfPericen	37.789504791695926
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 185"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		2.619768132503111e-09
	Radius		10.886669224241015

	RotationPeriod	8.08238692886921

	Obliquity		85.95876041409807

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.04789599442291
		Eccentricity	0.5356603236605937
		Inclination		-37.96464799026332
		AscendingNode	14.580652674233413
		ArgOfPericen	279.87783413226623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 186"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.268566740577483e-08
	Radius		17.874535581577625

	RotationPeriod	5.668066897048523

	Obliquity		287.24041992215666

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.879701207525697
		Eccentricity	0.6349169801985636
		Inclination		39.43444746523944
		AscendingNode	185.76769348553591
		ArgOfPericen	230.52852440430755
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 187"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		6.615053561806938e-09
	Radius		14.343690600619238

	RotationPeriod	7.338403023568889

	Obliquity		22.29027255394124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.996855857212218
		Eccentricity	0.5939203591645387
		Inclination		87.2854459676275
		AscendingNode	358.5582717676744
		ArgOfPericen	51.369783673661324
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 188"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.6871257973935946e-09
	Radius		12.240906944666364

	RotationPeriod	3.79447834657166

	Obliquity		94.31710619280673

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.30481628329445
		Eccentricity	0.46452830517672805
		Inclination		25.360757552325712
		AscendingNode	113.07445203908533
		ArgOfPericen	154.54709456870535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 189"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		8.593910125605571e-10
	Radius		7.4809163738536

	RotationPeriod	6.81205639809312

	Obliquity		242.17086832864464

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.984946082727049
		Eccentricity	0.5496914219100874
		Inclination		-6.675104088435043
		AscendingNode	12.720101168749615
		ArgOfPericen	53.61252689840085
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 190"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.384926710536444
		Eccentricity	0.5297901509454719
		Inclination		-25.321269821358158
		AscendingNode	310.67672537108524
		ArgOfPericen	125.50831152431935
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 190 A"
{
	ParentBody	"HeliosA 190"
	Class		"Asteroid"
	Mass		1.1543867968279701e-08
	Radius		17.66021730806686

	Orbit
	{
		Epoch			2457395.5
		Period			0.0068138091159270055
		Eccentricity	0.005537263102912199
		Inclination		198.37241616655348
		AscendingNode	220.1964071634299
		ArgOfPericen	266.0185048207135
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 190 B"
{
	ParentBody	"HeliosA 190"
	Class		"Asteroid"
	Mass		9.072727942507566e-10
	Radius		7.564697320523009

	Orbit
	{
		Epoch			2457395.5
		Period			0.0068138091159270055
		Eccentricity	0.005537263102912199
		Inclination		198.37241616655348
		AscendingNode	220.1964071634299
		ArgOfPericen	86.01850482071347
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 191"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.5872667568982523e-09
	Radius		9.478808486101574

	RotationPeriod	7.660840397065473

	Obliquity		342.30620595765174

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.394192144940904
		Eccentricity	0.4853326226534774
		Inclination		33.19637482930479
		AscendingNode	80.53332540219168
		ArgOfPericen	42.82836282507538
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 192"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		4.1235279588399794e-09
	Radius		12.77083922681202

	RotationPeriod	6.1359053396348875

	Obliquity		137.50633678672466

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.209738141798924
		Eccentricity	0.8162612668286606
		Inclination		60.65826526897446
		AscendingNode	183.944602430787
		ArgOfPericen	150.7824803402377
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 193"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.059883437932276
		Eccentricity	0.6034969821753988
		Inclination		63.90019593218044
		AscendingNode	117.99987444449594
		ArgOfPericen	13.590899773247411
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 193 A"
{
	ParentBody	"HeliosA 193"
	Class		"Asteroid"
	Mass		2.1385075062396464e-10
	Radius		4.493922992982913

	Orbit
	{
		Epoch			2457395.5
		Period			0.0071895548192095265
		Eccentricity	0.007088296871380239
		Inclination		216.78973398528083
		AscendingNode	332.55026055816893
		ArgOfPericen	150.41189015727508
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 193 B"
{
	ParentBody	"HeliosA 193"
	Class		"Asteroid"
	Mass		9.35716213075492e-12
	Radius		1.5835681246642512

	Orbit
	{
		Epoch			2457395.5
		Period			0.0071895548192095265
		Eccentricity	0.007088296871380239
		Inclination		216.78973398528083
		AscendingNode	332.55026055816893
		ArgOfPericen	330.4118901572751
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 194"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		1.610647755123115e-09
	Radius		8.425541992255223

	RotationPeriod	8.109716054001566

	Obliquity		141.2693799812559

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.09819227988251
		Eccentricity	0.4814134022476034
		Inclination		-33.983510248718986
		AscendingNode	2.0777374607259835
		ArgOfPericen	357.5272680937917
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 195"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.2043010164751842e-09
	Radius		12.126401664220085

	RotationPeriod	5.650972100304285

	Obliquity		82.1129715464537

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.212327331639544
		Eccentricity	0.4552063873060276
		Inclination		88.00430303537767
		AscendingNode	206.6804311976388
		ArgOfPericen	207.26518074891516
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 196"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		5.738487751450469e-09
	Radius		14.222439928441782

	RotationPeriod	1.1490863669900993

	Obliquity		320.6387620721191

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.801955977440002
		Eccentricity	0.6229275645511223
		Inclination		-63.12377864470062
		AscendingNode	303.9666684598639
		ArgOfPericen	152.41238323075828
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 197"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.1096763950989414
		Eccentricity	0.4456846903943731
		Inclination		-0.04827687723730043
		AscendingNode	239.36968497571763
		ArgOfPericen	102.85936271929056
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 197 A"
{
	ParentBody	"HeliosA 197"
	Class		"Asteroid"
	Mass		7.511490704886263e-09
	Radius		14.5782330772108

	Orbit
	{
		Epoch			2457395.5
		Period			0.004206801804982357
		Eccentricity	0.0011753319460681448
		Inclination		72.76954167000963
		AscendingNode	156.4876940179506
		ArgOfPericen	228.60756702230873
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 197 B"
{
	ParentBody	"HeliosA 197"
	Class		"Asteroid"
	Mass		6.3647973748634356e-09
	Radius		13.795084726874645

	Orbit
	{
		Epoch			2457395.5
		Period			0.004206801804982357
		Eccentricity	0.0011753319460681448
		Inclination		72.76954167000963
		AscendingNode	156.4876940179506
		ArgOfPericen	48.60756702230873
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 198"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		9.88070834762285e-09
	Radius		17.2509388846864

	RotationPeriod	4.789670715573564

	Obliquity		235.4772374850578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.001725804044069
		Eccentricity	0.7143270941912225
		Inclination		-11.415584768149799
		AscendingNode	110.61141853792185
		ArgOfPericen	249.569116845624
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 199"
{
	ParentBody	"Helios ALF"
	Class		"Asteroid"
	Mass		3.1153280204548733e-09
	Radius		11.493130294168507

	RotationPeriod	8.132644972845565

	Obliquity		298.14123809068377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.914426440529603
		Eccentricity	0.5972362688251617
		Inclination		-50.30472740467292
		AscendingNode	174.4702752142336
		ArgOfPericen	123.43906724241872
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosA 200"
{
	ParentBody	"Helios ALF"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.46426408843626
		Eccentricity	0.45906389904699574
		Inclination		75.24883628757206
		AscendingNode	12.074348203566903
		ArgOfPericen	288.2500899054268
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosA 200 A"
{
	ParentBody	"HeliosA 200"
	Class		"Asteroid"
	Mass		1.1379183391451265e-08
	Radius		17.880539797816198

	Orbit
	{
		Epoch			2457395.5
		Period			0.004921560674468232
		Eccentricity	0.005645423300007637
		Inclination		52.94553560633865
		AscendingNode	284.7752939487165
		ArgOfPericen	106.62402557136055
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosA 200 B"
{
	ParentBody	"HeliosA 200"
	Class		"Asteroid"
	Mass		9.95752049101319e-09
	Radius		17.102541895641036

	Orbit
	{
		Epoch			2457395.5
		Period			0.004921560674468232
		Eccentricity	0.005645423300007637
		Inclination		52.94553560633865
		AscendingNode	284.7752939487165
		ArgOfPericen	286.62402557136056
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Helios Beta comets ---------------------------------------------------------
//------------------------------------------------------------------------------
Barycenter "HeliosB 1"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.540965789111748
		Eccentricity	0.5673539455935428
		Inclination		-6.199366622535966
		AscendingNode	104.07924931182681
		ArgOfPericen	167.26001464435973
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 1 A"
{
	ParentBody	"HeliosB 1"
	Class		"Asteroid"
	Mass		1.0457620609562013e-08
	Radius		17.070970156632207

	Orbit
	{
		Epoch			2457395.5
		Period			0.0034543302014686315
		Eccentricity	0.005378827203550117
		Inclination		278.9470314026547
		AscendingNode	290.8759838442287
		ArgOfPericen	354.3008262227444
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 1 B"
{
	ParentBody	"HeliosB 1"
	Class		"Asteroid"
	Mass		3.6541544797362537e-10
	Radius		5.5809681429562215

	Orbit
	{
		Epoch			2457395.5
		Period			0.0034543302014686315
		Eccentricity	0.005378827203550117
		Inclination		278.9470314026547
		AscendingNode	290.8759838442287
		ArgOfPericen	174.30082622274438
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 2"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.042559845120327e-09
	Radius		10.707538931588047

	RotationPeriod	5.657556175730669

	Obliquity		0.9594680986512882

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.042890796886783
		Eccentricity	0.562159623038029
		Inclination		47.82746681605301
		AscendingNode	88.29107620989315
		ArgOfPericen	332.7462692681758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 3"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.126765171471761e-09
	Radius		15.286244070767784

	RotationPeriod	9.748896840400203

	Obliquity		285.9962589466395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.048758068807993
		Eccentricity	0.3292714069175975
		Inclination		-96.83654825364877
		AscendingNode	197.43612412160138
		ArgOfPericen	207.88208944180997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 4"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.260738363622897e-09
	Radius		12.239213411806759

	RotationPeriod	6.423164352267169

	Obliquity		182.26254824054848

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.289674228602259
		Eccentricity	0.5069908828107086
		Inclination		60.74701303060449
		AscendingNode	187.5081135765117
		ArgOfPericen	74.88846267740215
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 5"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.769467774517889e-09
	Radius		16.5698085440512

	RotationPeriod	5.10501841665635

	Obliquity		115.83669943682764

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.482643070893311
		Eccentricity	0.4316035092781716
		Inclination		29.78781153497601
		AscendingNode	312.8279364695903
		ArgOfPericen	66.46814927785631
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 6"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.6425729424827884e-10
	Radius		4.393900626023184

	RotationPeriod	4.212599201481167

	Obliquity		80.88536091636159

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.72977595924183
		Eccentricity	0.7019104648355584
		Inclination		-39.55059099302399
		AscendingNode	261.915744793988
		ArgOfPericen	270.2593810717468
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 7"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.007959771899279e-10
	Radius		6.230881516550641

	RotationPeriod	6.123085424471547

	Obliquity		25.628896477636395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.069497189259106
		Eccentricity	0.7803146960493902
		Inclination		17.265457819215147
		AscendingNode	143.1139497847773
		ArgOfPericen	253.9879762249349
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 8"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2480196916277283e-09
	Radius		8.205996456525845

	RotationPeriod	4.520937758862529

	Obliquity		77.68411092648608

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.585622046397575
		Eccentricity	0.5279710237077525
		Inclination		59.299168586403106
		AscendingNode	209.17806385400746
		ArgOfPericen	25.847554138591878
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 9"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.172585387137321e-09
	Radius		14.890333489072528

	RotationPeriod	7.062244386296765

	Obliquity		235.36319703033348

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.042492962648735
		Eccentricity	0.474571437167877
		Inclination		-53.07162059367277
		AscendingNode	26.237552593733234
		ArgOfPericen	37.48652020291971
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 10"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.882576779550277
		Eccentricity	0.44618799448909
		Inclination		14.261222274847283
		AscendingNode	285.6200046400418
		ArgOfPericen	262.58571212754816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 10 A"
{
	ParentBody	"HeliosB 10"
	Class		"Asteroid"
	Mass		3.5254477750064026e-09
	Radius		13.442067173110207

	Orbit
	{
		Epoch			2457395.5
		Period			0.004357055185102526
		Eccentricity	0.0062586670791845
		Inclination		318.2030332380238
		AscendingNode	315.45482039712823
		ArgOfPericen	143.49633451137115
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 10 B"
{
	ParentBody	"HeliosB 10"
	Class		"Asteroid"
	Mass		6.14971778308136e-10
	Radius		7.510687540224947

	Orbit
	{
		Epoch			2457395.5
		Period			0.004357055185102526
		Eccentricity	0.0062586670791845
		Inclination		318.2030332380238
		AscendingNode	315.45482039712823
		ArgOfPericen	323.4963345113712
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 11"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.192711785243059
		Eccentricity	0.5036541953561873
		Inclination		68.39306657127159
		AscendingNode	92.86702987306498
		ArgOfPericen	94.27849354425187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 11 A"
{
	ParentBody	"HeliosB 11"
	Class		"Asteroid"
	Mass		5.809249293872068e-09
	Radius		13.440443297228779

	Orbit
	{
		Epoch			2457395.5
		Period			0.006979515667481889
		Eccentricity	0.004377110606484208
		Inclination		269.9319415885472
		AscendingNode	303.6628554411109
		ArgOfPericen	194.167789728074
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 11 B"
{
	ParentBody	"HeliosB 11"
	Class		"Asteroid"
	Mass		4.5486516793900004e-10
	Radius		5.749999613127768

	Orbit
	{
		Epoch			2457395.5
		Period			0.006979515667481889
		Eccentricity	0.004377110606484208
		Inclination		269.9319415885472
		AscendingNode	303.6628554411109
		ArgOfPericen	14.167789728074013
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 12"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.744369787427874e-09
	Radius		14.552693031064607

	RotationPeriod	8.724499308275659

	Obliquity		301.8426854697106

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.689887009899335
		Eccentricity	0.40204713350264176
		Inclination		114.05169393963806
		AscendingNode	278.32169752114777
		ArgOfPericen	74.51073080127506
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 13"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7642254650319688e-10
	Radius		4.242541272346504

	RotationPeriod	5.978029414148006

	Obliquity		113.406489665354

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.419341760872202
		Eccentricity	0.46934445339709385
		Inclination		74.97982343758282
		AscendingNode	24.087386839619583
		ArgOfPericen	236.99372469214137
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 14"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.766390606505807
		Eccentricity	0.23686296445860322
		Inclination		-6.664554517699837
		AscendingNode	171.54990538037873
		ArgOfPericen	338.9779554077621
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 14 A"
{
	ParentBody	"HeliosB 14"
	Class		"Asteroid"
	Mass		4.286887611890158e-09
	Radius		12.982068077764898

	Orbit
	{
		Epoch			2457395.5
		Period			0.004633977635794284
		Eccentricity	0.0045764632161551634
		Inclination		241.0901609291198
		AscendingNode	109.15682820781484
		ArgOfPericen	298.975371968111
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 14 B"
{
	ParentBody	"HeliosB 14"
	Class		"Asteroid"
	Mass		3.5355877711827764e-09
	Radius		12.174479161027653

	Orbit
	{
		Epoch			2457395.5
		Period			0.004633977635794284
		Eccentricity	0.0045764632161551634
		Inclination		241.0901609291198
		AscendingNode	109.15682820781484
		ArgOfPericen	118.975371968111
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 15"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.104137646429056e-09
	Radius		11.696204619416827

	RotationPeriod	7.911098723332171

	Obliquity		51.423844528350884

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.210854371156078
		Eccentricity	0.7155402055260096
		Inclination		-68.08368533904984
		AscendingNode	251.37016610914813
		ArgOfPericen	149.90888634834945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 16"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.0264923524320624e-10
	Radius		4.97860424078387

	RotationPeriod	2.3227497834773834

	Obliquity		128.6356705135119

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.346434146945732
		Eccentricity	0.5969850098003046
		Inclination		-19.514427979538784
		AscendingNode	87.56793758687334
		ArgOfPericen	109.77091647830966
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 17"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.320357481983673e-09
	Radius		12.10964141462798

	RotationPeriod	6.747271255348447

	Obliquity		171.83983501673737

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.467151477328381
		Eccentricity	0.5037991536264247
		Inclination		-41.466495848334525
		AscendingNode	157.4004726905396
		ArgOfPericen	201.8852051980059
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 18"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.948585622990958
		Eccentricity	0.6558401098415125
		Inclination		39.28479866722126
		AscendingNode	281.17312047057294
		ArgOfPericen	63.776381990540386
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 18 A"
{
	ParentBody	"HeliosB 18"
	Class		"Asteroid"
	Mass		2.0816044652402474e-08
	Radius		21.44561410463627

	Orbit
	{
		Epoch			2457395.5
		Period			0.0035663449280958757
		Eccentricity	0.00574208389822954
		Inclination		99.01749729786121
		AscendingNode	113.52244824701745
		ArgOfPericen	99.2465362842864
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 18 B"
{
	ParentBody	"HeliosB 18"
	Class		"Asteroid"
	Mass		3.129449274649798e-09
	Radius		11.403243255375731

	Orbit
	{
		Epoch			2457395.5
		Period			0.0035663449280958757
		Eccentricity	0.00574208389822954
		Inclination		99.01749729786121
		AscendingNode	113.52244824701745
		ArgOfPericen	279.24653628428644
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 19"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.617804370729729e-10
	Radius		6.417121700290148

	RotationPeriod	9.139971378517215

	Obliquity		129.48507784803394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.46188013331255
		Eccentricity	0.5757999149097333
		Inclination		-5.862342643219472
		AscendingNode	210.6176396487874
		ArgOfPericen	276.13146401161475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 20"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.128636618570987
		Eccentricity	0.5905473740494631
		Inclination		-128.04822865250054
		AscendingNode	241.18690210621313
		ArgOfPericen	255.6941849119616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 20 A"
{
	ParentBody	"HeliosB 20"
	Class		"Asteroid"
	Mass		1.2174153997486416e-08
	Radius		18.65743887192937

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019992010796240018
		Eccentricity	0.007141401754729047
		Inclination		259.96877532557255
		AscendingNode	78.95904535967499
		ArgOfPericen	272.58858783074396
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 20 B"
{
	ParentBody	"HeliosB 20"
	Class		"Asteroid"
	Mass		9.739641037334959e-09
	Radius		17.320220395328786

	Orbit
	{
		Epoch			2457395.5
		Period			0.0019992010796240018
		Eccentricity	0.007141401754729047
		Inclination		259.96877532557255
		AscendingNode	78.95904535967499
		ArgOfPericen	92.58858783074396
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 21"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.314188493773998e-09
	Radius		15.561788806577129

	RotationPeriod	7.443734921862184

	Obliquity		242.56628701059302

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.895183405543472
		Eccentricity	0.3530724739292863
		Inclination		-52.216620291693374
		AscendingNode	18.001235970735372
		ArgOfPericen	166.43824859658625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 22"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2993177006469728e-09
	Radius		8.289252080037233

	RotationPeriod	4.235328255128624

	Obliquity		28.489006497658117

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.862748755791918
		Eccentricity	0.4255033734072319
		Inclination		16.721471495727243
		AscendingNode	15.703930268504704
		ArgOfPericen	250.67239351881736
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 23"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4481751553313804e-09
	Radius		9.20096866383166

	RotationPeriod	7.118314516670054

	Obliquity		296.38138631151185

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.295289931105298
		Eccentricity	0.06499306811584316
		Inclination		15.089998200993763
		AscendingNode	296.9804976636787
		ArgOfPericen	336.0541198165454
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 24"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.271661079397109e-09
	Radius		10.351292972612843

	RotationPeriod	5.1518650461942626

	Obliquity		138.150760936492

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.297337192361786
		Eccentricity	0.06786710056246731
		Inclination		1.8883795491178088
		AscendingNode	266.8077579403246
		ArgOfPericen	77.5672802876244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 25"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.446472207958736e-09
	Radius		11.574449064037951

	RotationPeriod	2.0606467276277867

	Obliquity		63.82711018982854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.51302001471764
		Eccentricity	0.33622144585147673
		Inclination		21.610462107379107
		AscendingNode	147.42644844346628
		ArgOfPericen	64.7200273032924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 26"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.692596263042629e-09
	Radius		9.083001586636408

	RotationPeriod	7.096847445522183

	Obliquity		353.69625568869526

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.252446505271212
		Eccentricity	0.6515018793760443
		Inclination		-27.263903510939016
		AscendingNode	49.77815356375812
		ArgOfPericen	178.342503495834
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 27"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.066461459972005e-09
	Radius		9.867840736431132

	RotationPeriod	6.968279381993889

	Obliquity		258.01721168602904

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.02081182156504
		Eccentricity	0.7305358167168498
		Inclination		38.85858166962644
		AscendingNode	31.29035822949018
		ArgOfPericen	280.3649310037297
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 28"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.7792502929463126e-08
	Radius		24.237351592604682

	RotationPeriod	4.946023289477536

	Obliquity		208.8949497156088

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.340169795983607
		Eccentricity	0.4618954172486748
		Inclination		1.4875703002041327
		AscendingNode	244.60804212097156
		ArgOfPericen	171.1232386854344
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 29"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.972979762769515e-09
	Radius		12.394112811815033

	RotationPeriod	5.932419048463745

	Obliquity		290.227284463958

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.4132082137549
		Eccentricity	0.33020222077400746
		Inclination		-5.282612894663683
		AscendingNode	258.369063288867
		ArgOfPericen	212.39134668826793
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 30"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.513419193859012e-09
	Radius		12.931497853114909

	RotationPeriod	8.398665283970498

	Obliquity		310.58399197487694

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.852633084371984
		Eccentricity	0.6349564372752118
		Inclination		-43.8011688268769
		AscendingNode	123.11346629535747
		ArgOfPericen	253.3284603919093
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 31"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.485674222128944
		Eccentricity	0.5591030898415953
		Inclination		-106.88707197230801
		AscendingNode	150.7060387624422
		ArgOfPericen	195.87673322923766
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 31 A"
{
	ParentBody	"HeliosB 31"
	Class		"Asteroid"
	Mass		9.748800335899114e-09
	Radius		16.921868805062402

	Orbit
	{
		Epoch			2457395.5
		Period			0.0047414609961924925
		Eccentricity	0.004204292382530961
		Inclination		6.964850880715585
		AscendingNode	67.10949179895667
		ArgOfPericen	285.1216802306753
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 31 B"
{
	ParentBody	"HeliosB 31"
	Class		"Asteroid"
	Mass		1.9914430207948045e-09
	Radius		9.965992592398406

	Orbit
	{
		Epoch			2457395.5
		Period			0.0047414609961924925
		Eccentricity	0.004204292382530961
		Inclination		6.964850880715585
		AscendingNode	67.10949179895667
		ArgOfPericen	105.12168023067528
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 32"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.88717325753987e-09
	Radius		14.242597211655532

	RotationPeriod	3.0262104476195133

	Obliquity		137.56629955155083

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.236823008329717
		Eccentricity	0.647698683943986
		Inclination		-63.05249939587084
		AscendingNode	158.59887848322066
		ArgOfPericen	142.336974376805
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 33"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.48514262923333e-08
	Radius		18.59113193891038

	RotationPeriod	3.2912667499389605

	Obliquity		104.3354929448594

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.956267098325817
		Eccentricity	0.3067849778689005
		Inclination		40.961530328420345
		AscendingNode	136.2537836795395
		ArgOfPericen	138.15950983666704
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 34"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.803441053337836e-10
	Radius		7.845987649515067

	RotationPeriod	7.104423712463852

	Obliquity		112.36748756652504

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.246357894113597
		Eccentricity	0.4971468523464469
		Inclination		-56.77791412726127
		AscendingNode	327.5109345839231
		ArgOfPericen	311.83699384402627
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 35"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.8994833874299532e-08
	Radius		20.635041728220017

	RotationPeriod	6.237881298020344

	Obliquity		345.09188670419246

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.162506477967809
		Eccentricity	0.6265806921011817
		Inclination		-60.23020055025344
		AscendingNode	211.538662363336
		ArgOfPericen	276.10614179461436
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 36"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.440818916463812e-09
	Radius		15.52151655374003

	RotationPeriod	5.315134123838803

	Obliquity		97.73188836452655

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.69407025789985
		Eccentricity	0.35315744996464704
		Inclination		-84.64869240390699
		AscendingNode	222.7610510443601
		ArgOfPericen	121.67905709633041
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 37"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.5694052123340046e-09
	Radius		12.201270590528924

	RotationPeriod	9.717398721090882

	Obliquity		185.34987829285956

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.38661674805051
		Eccentricity	0.6135961755453929
		Inclination		23.499448099106026
		AscendingNode	296.13689121179243
		ArgOfPericen	210.39255540639294
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 38"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.468766923626227e-09
	Radius		16.42645384430997

	RotationPeriod	5.730430240830403

	Obliquity		131.555975897437

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.397437335112725
		Eccentricity	0.5441255572463062
		Inclination		37.87511665264411
		AscendingNode	80.4816817126657
		ArgOfPericen	53.05056519751437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 39"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.976577659533889e-09
	Radius		14.696560377186124

	RotationPeriod	5.540398742684267

	Obliquity		331.4116424157488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.920814474056314
		Eccentricity	0.4459085303314854
		Inclination		-5.614455215083933
		AscendingNode	252.28851082611445
		ArgOfPericen	160.79074635084385
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 40"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.289836764040413e-09
	Radius		13.348153405348945

	RotationPeriod	3.4901612958268777

	Obliquity		62.04603374244836

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.144015588081007
		Eccentricity	0.6970163169017219
		Inclination		27.779663063916622
		AscendingNode	70.77791554822828
		ArgOfPericen	336.41766645073415
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 41"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2112835741467416e-08
	Radius		18.370445872759134

	RotationPeriod	6.493688234585561

	Obliquity		56.65412896692259

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.941792895055922
		Eccentricity	0.9948604797975941
		Inclination		59.269025214939376
		AscendingNode	164.4624975655154
		ArgOfPericen	108.61745489099273
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 42"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.683837538639688e-08
	Radius		20.107596919684834

	RotationPeriod	10.419239088200879

	Obliquity		194.41481028734114

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.880589540331826
		Eccentricity	0.7158864935786056
		Inclination		146.27426584187828
		AscendingNode	311.91834484583325
		ArgOfPericen	95.73655588484696
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 43"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.124036652076537
		Eccentricity	0.25668007873950005
		Inclination		28.340341047224832
		AscendingNode	2.4830512649450087
		ArgOfPericen	135.66136179877356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 43 A"
{
	ParentBody	"HeliosB 43"
	Class		"Asteroid"
	Mass		4.3354327591296756e-11
	Radius		2.796483336454278

	Orbit
	{
		Epoch			2457395.5
		Period			0.001403203332739903
		Eccentricity	0.005439999302771492
		Inclination		205.08835710756117
		AscendingNode	213.56563882673782
		ArgOfPericen	87.0016341426467
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 43 B"
{
	ParentBody	"HeliosB 43"
	Class		"Asteroid"
	Mass		7.832234299437609e-13
	Radius		0.7337756702687174

	Orbit
	{
		Epoch			2457395.5
		Period			0.001403203332739903
		Eccentricity	0.005439999302771492
		Inclination		205.08835710756117
		AscendingNode	213.56563882673782
		ArgOfPericen	267.0016341426467
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 44"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.954538276040218e-09
	Radius		15.261856042474447

	RotationPeriod	6.1958137534412225

	Obliquity		78.92610317526241

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.078290358382144
		Eccentricity	0.6705420015708332
		Inclination		-36.23093281113088
		AscendingNode	278.2428544215602
		ArgOfPericen	262.4937638597875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 45"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2729106685104033e-08
	Radius		17.604502169214296

	RotationPeriod	6.054782671999484

	Obliquity		256.77121246529725

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.910322113651798
		Eccentricity	0.41223683868567634
		Inclination		74.50772223530922
		AscendingNode	147.25313196820127
		ArgOfPericen	200.64266655954998
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 46"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.057635834752881e-09
	Radius		12.495092990111868

	RotationPeriod	3.151512015859923

	Obliquity		189.10228739707287

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.23757662449887
		Eccentricity	0.5385604395435092
		Inclination		-101.18454832860999
		AscendingNode	145.11998359767904
		ArgOfPericen	143.32749188158
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 47"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0676537238905557e-08
	Radius		17.56095285273153

	RotationPeriod	5.717735883093693

	Obliquity		133.27481178378184

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.444836619197098
		Eccentricity	0.5972007338726968
		Inclination		15.127154916699501
		AscendingNode	299.30038289616397
		ArgOfPericen	353.6529063426457
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 48"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.991307749829348e-09
	Radius		11.174107474910308

	RotationPeriod	5.071882339833246

	Obliquity		227.9377177149685

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.873798191531547
		Eccentricity	0.3976082020384333
		Inclination		67.51291114436934
		AscendingNode	349.14960933709455
		ArgOfPericen	326.81111330948534
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 49"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.930279875178172e-09
	Radius		12.262227063185199

	RotationPeriod	3.9762304218577187

	Obliquity		47.447743479538296

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.1679401992752148
		Eccentricity	0.3701928576607786
		Inclination		99.60280384130718
		AscendingNode	88.69030131535196
		ArgOfPericen	194.5593552072427
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 50"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.27720107616323e-09
	Radius		13.99571168566562

	RotationPeriod	5.564697789110429

	Obliquity		100.4014958872317

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.778336415362656
		Eccentricity	0.4090464347810584
		Inclination		91.37128539282989
		AscendingNode	180.71230593717775
		ArgOfPericen	118.65451761546768
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 51"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.6477048701998696e-09
	Radius		13.156899019885657

	RotationPeriod	4.210227955611696

	Obliquity		244.94212818944078

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.541472412572645
		Eccentricity	0.5470607410681968
		Inclination		23.8512588476245
		AscendingNode	59.42218796897558
		ArgOfPericen	54.397240119375276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 52"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.328947309044327
		Eccentricity	0.2811161078979469
		Inclination		21.26121753719377
		AscendingNode	155.6249808507744
		ArgOfPericen	195.40472393772362
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 52 A"
{
	ParentBody	"HeliosB 52"
	Class		"Asteroid"
	Mass		2.4509868256995047e-09
	Radius		10.529985833286055

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009376414258140267
		Eccentricity	0.003159542601979424
		Inclination		241.11127106924008
		AscendingNode	224.5706748033609
		ArgOfPericen	246.74253967190643
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 52 B"
{
	ParentBody	"HeliosB 52"
	Class		"Asteroid"
	Mass		9.028001303367885e-11
	Radius		3.5035743026953376

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009376414258140267
		Eccentricity	0.003159542601979424
		Inclination		241.11127106924008
		AscendingNode	224.5706748033609
		ArgOfPericen	66.74253967190646
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 53"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.4648511521323154e-09
	Radius		14.367592888635246

	RotationPeriod	3.979641960909585

	Obliquity		148.18743710945554

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.030177826803445
		Eccentricity	0.5470431072103459
		Inclination		3.0997812212542124
		AscendingNode	194.7661397656068
		ArgOfPericen	87.60135417087466
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 54"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.510957256123314e-09
	Radius		15.391766664698052

	RotationPeriod	3.6188373733492205

	Obliquity		349.79846542889953

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.60727246279069
		Eccentricity	0.4349648855167644
		Inclination		41.06788164224902
		AscendingNode	64.22973737412312
		ArgOfPericen	214.62608098321815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 55"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.289794717813095e-09
	Radius		12.93061306358099

	RotationPeriod	6.169447494403139

	Obliquity		1.0325112805499437

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.139779680269474
		Eccentricity	0.6078965844311038
		Inclination		-52.694983046628856
		AscendingNode	306.37357072624246
		ArgOfPericen	56.738277933069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 56"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.687264428380934e-09
	Radius		9.340199081628493

	RotationPeriod	5.543770842211328

	Obliquity		244.09269815294735

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.651492712923439
		Eccentricity	0.4955058316266503
		Inclination		158.6596421790538
		AscendingNode	21.83006001451117
		ArgOfPericen	10.909215707141833
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 57"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.893567589154541e-09
	Radius		15.749593755514423

	RotationPeriod	6.477693837797576

	Obliquity		126.46269543673566

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.234199788752813
		Eccentricity	0.503651988466558
		Inclination		-31.551950059800866
		AscendingNode	294.0039195337644
		ArgOfPericen	16.15580490885049
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 58"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.375510718141092e-09
	Radius		12.716005797589398

	RotationPeriod	8.03214394000721

	Obliquity		122.1849850780902

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.5192445169881506
		Eccentricity	0.37349771019151207
		Inclination		-2.2825462836200914
		AscendingNode	282.7268894568551
		ArgOfPericen	307.9502413746184
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 59"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.42090841199982
		Eccentricity	0.5874632896186336
		Inclination		-15.112379732757743
		AscendingNode	35.42473863387624
		ArgOfPericen	238.60224654005788
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 59 A"
{
	ParentBody	"HeliosB 59"
	Class		"Asteroid"
	Mass		2.6517495478162944e-09
	Radius		10.992081530244743

	Orbit
	{
		Epoch			2457395.5
		Period			0.001954860196018446
		Eccentricity	0.0034308201044665936
		Inclination		186.17384470341213
		AscendingNode	267.0585570362994
		ArgOfPericen	233.25291440750658
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 59 B"
{
	ParentBody	"HeliosB 59"
	Class		"Asteroid"
	Mass		1.5540255006328233e-10
	Radius		4.269612751263043

	Orbit
	{
		Epoch			2457395.5
		Period			0.001954860196018446
		Eccentricity	0.0034308201044665936
		Inclination		186.17384470341213
		AscendingNode	267.0585570362994
		ArgOfPericen	53.25291440750658
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 60"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7601748948031012e-08
	Radius		20.825178113800376

	RotationPeriod	7.1787039927307

	Obliquity		325.16902518113363

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.22346276932298
		Eccentricity	0.6972147220033968
		Inclination		89.25161322254988
		AscendingNode	278.52951025866724
		ArgOfPericen	343.44524037596875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 61"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.8694959927496877e-09
	Radius		9.391907220798494

	RotationPeriod	0.8534895784467702

	Obliquity		130.26459677641697

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.279546140289705
		Eccentricity	0.6405227035903177
		Inclination		-1.077014606391964
		AscendingNode	322.09133940869236
		ArgOfPericen	77.88389125489532
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 62"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.4673817407458792e-09
	Radius		10.619056656506896

	RotationPeriod	1.403403006158693

	Obliquity		175.9822280920053

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.14255077568486
		Eccentricity	0.6695426204347301
		Inclination		100.39793223193732
		AscendingNode	51.17013749443465
		ArgOfPericen	45.09988143770815
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 63"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1200830226736067e-08
	Radius		17.759033234764527

	RotationPeriod	6.864181049215725

	Obliquity		254.65806204878388

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.345270682313345
		Eccentricity	0.2833786453700531
		Inclination		-77.42664207074625
		AscendingNode	265.3912440410466
		ArgOfPericen	315.4890547945793
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 64"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.982664817001535
		Eccentricity	0.5229364372719693
		Inclination		37.92877181265779
		AscendingNode	36.63204297471492
		ArgOfPericen	36.55648528248359
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 64 A"
{
	ParentBody	"HeliosB 64"
	Class		"Asteroid"
	Mass		4.271545066042258e-09
	Radius		12.291921974422117

	Orbit
	{
		Epoch			2457395.5
		Period			0.008005956136681279
		Eccentricity	0.006705695463806163
		Inclination		199.6013030874596
		AscendingNode	123.06424598126813
		ArgOfPericen	335.29617443150954
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 64 B"
{
	ParentBody	"HeliosB 64"
	Class		"Asteroid"
	Mass		2.50169612694052e-09
	Radius		10.284179526508574

	Orbit
	{
		Epoch			2457395.5
		Period			0.008005956136681279
		Eccentricity	0.006705695463806163
		Inclination		199.6013030874596
		AscendingNode	123.06424598126813
		ArgOfPericen	155.2961744315096
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 65"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4156227257474518e-08
	Radius		18.6898542652874

	RotationPeriod	7.538882264499613

	Obliquity		278.42394497538515

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.94612781340451
		Eccentricity	0.5288140515103465
		Inclination		48.58528574673487
		AscendingNode	314.3735576530371
		ArgOfPericen	265.3137583527485
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 66"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.966482482088284e-09
	Radius		12.952078669886886

	RotationPeriod	3.776303777288614

	Obliquity		238.33786205346638

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.021635725396576
		Eccentricity	0.2632200280045247
		Inclination		78.44457797759748
		AscendingNode	199.43767617979486
		ArgOfPericen	192.56390493611073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 67"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.1295040803182574e-09
	Radius		14.641461458630731

	RotationPeriod	5.105093974206318

	Obliquity		115.61703314198199

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.233198402543131
		Eccentricity	0.7339006300437194
		Inclination		-52.805836210674414
		AscendingNode	167.30252427111122
		ArgOfPericen	130.1786331367381
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 68"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.382202855245066e-09
	Radius		13.289132274043862

	RotationPeriod	3.1170497081249704

	Obliquity		207.8182852800327

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.594965980304993
		Eccentricity	0.24414681577984304
		Inclination		-60.67009804463881
		AscendingNode	158.13366332626546
		ArgOfPericen	309.2336106182996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 69"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.9217725926320725e-10
	Radius		6.24658912580798

	RotationPeriod	5.287979500197842

	Obliquity		81.56492522448544

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.974056976127233
		Eccentricity	0.43173245811132654
		Inclination		-5.918690602029583
		AscendingNode	78.9771954133549
		ArgOfPericen	206.1961721353622
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 70"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.591511898398429e-09
	Radius		14.798051142045548

	RotationPeriod	4.987454835623257

	Obliquity		341.12055489357834

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.149797097482474
		Eccentricity	0.5529714345677208
		Inclination		-7.973451327488357
		AscendingNode	353.5970801287825
		ArgOfPericen	63.34909912530663
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 71"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.2196746272902942e-09
	Radius		10.234966340991596

	RotationPeriod	7.079547720255166

	Obliquity		3.616912970531523

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.564846618804555
		Eccentricity	0.5011234194922588
		Inclination		49.82807275563766
		AscendingNode	50.152443148015266
		ArgOfPericen	121.6986425182868
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 72"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.7542218232812603e-09
	Radius		10.893231257185978

	RotationPeriod	8.00967220665896

	Obliquity		211.94880986541128

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.12319196266542
		Eccentricity	0.5586155146478963
		Inclination		69.72421014369499
		AscendingNode	115.45995508207123
		ArgOfPericen	67.87124982832621
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 73"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0916666960593012e-08
	Radius		17.32313672450063

	RotationPeriod	10.642535489509406

	Obliquity		33.26206271002973

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.889711378489981
		Eccentricity	0.5972317351784687
		Inclination		-38.451871707025376
		AscendingNode	260.6237358651097
		ArgOfPericen	5.6808141456958605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 74"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1654103143363132e-08
	Radius		16.597888333652207

	RotationPeriod	7.689124358640434

	Obliquity		12.106995200598023

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.779081380877973
		Eccentricity	0.6592671497900368
		Inclination		-143.97240979461577
		AscendingNode	157.75072481932983
		ArgOfPericen	318.6158114848605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 75"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.6012188562457068e-09
	Radius		12.676881412472001

	RotationPeriod	8.646199322168531

	Obliquity		195.77698966083858

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.340521305803872
		Eccentricity	0.2511451124494094
		Inclination		25.83739099391683
		AscendingNode	112.01035971277412
		ArgOfPericen	155.2547494149923
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 76"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.075662064582405
		Eccentricity	0.6384073224615139
		Inclination		-139.65402997221338
		AscendingNode	71.51388790782181
		ArgOfPericen	132.4134623328781
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 76 A"
{
	ParentBody	"HeliosB 76"
	Class		"Asteroid"
	Mass		5.519551041434447e-10
	Radius		6.250224267150615

	Orbit
	{
		Epoch			2457395.5
		Period			0.0002845106048937796
		Eccentricity	0.003970604551390067
		Inclination		17.45593371633705
		AscendingNode	93.07869065937011
		ArgOfPericen	194.36836255557228
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 76 B"
{
	ParentBody	"HeliosB 76"
	Class		"Asteroid"
	Mass		3.4848186358722256e-10
	Radius		5.361929214378976

	Orbit
	{
		Epoch			2457395.5
		Period			0.0002845106048937796
		Eccentricity	0.003970604551390067
		Inclination		17.45593371633705
		AscendingNode	93.07869065937011
		ArgOfPericen	14.368362555572276
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 77"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.442690725083962e-09
	Radius		11.464616818320298

	RotationPeriod	2.944627824302388

	Obliquity		7.640163168768508

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.232531763019836
		Eccentricity	0.49073788372652144
		Inclination		40.83621169787797
		AscendingNode	26.65282548162464
		ArgOfPericen	210.85041451022292
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 78"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.175888236019081e-09
	Radius		12.673255700640548

	RotationPeriod	4.8499777572572125

	Obliquity		224.69514666607776

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.004740833281814
		Eccentricity	0.4120417651846942
		Inclination		-124.70585879483694
		AscendingNode	342.02063932711
		ArgOfPericen	26.84451572432037
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 79"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.439434811880737e-10
	Radius		7.5983757096767395

	RotationPeriod	4.903361791314534

	Obliquity		195.76062356846583

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.27368586197643
		Eccentricity	0.3293474182535929
		Inclination		-1.8237840898647033
		AscendingNode	91.16569820840513
		ArgOfPericen	235.53413919953724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 80"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.809818842441449e-09
	Radius		14.38362548242569

	RotationPeriod	3.1869995422870403

	Obliquity		201.7626345070025

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.34692808770976
		Eccentricity	0.3140162541225544
		Inclination		-2.694572966237821
		AscendingNode	105.04378875764762
		ArgOfPericen	205.05940548347309
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 81"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.53122165502769e-09
	Radius		13.543334863143624

	RotationPeriod	6.603609165405869

	Obliquity		137.72769706758984

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	3.1454390630747504
		Eccentricity	0.8737892246498693
		Inclination		62.62460284399021
		AscendingNode	343.76833801407537
		ArgOfPericen	294.4596758058697
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 82"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.299825701343309
		Eccentricity	0.414506863929773
		Inclination		44.351737877565085
		AscendingNode	247.3302094798169
		ArgOfPericen	211.12270606666885
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 82 A"
{
	ParentBody	"HeliosB 82"
	Class		"Asteroid"
	Mass		2.8357343919250153e-10
	Radius		5.152929950009037

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025080997684245785
		Eccentricity	0.0041414613184483215
		Inclination		131.001661452144
		AscendingNode	114.99902519675071
		ArgOfPericen	33.36038633448097
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 82 B"
{
	ParentBody	"HeliosB 82"
	Class		"Asteroid"
	Mass		2.5633068642443798e-11
	Radius		2.3125932587152183

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025080997684245785
		Eccentricity	0.0041414613184483215
		Inclination		131.001661452144
		AscendingNode	114.99902519675071
		ArgOfPericen	213.36038633448098
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 83"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.80043390027887e-09
	Radius		15.471138005002155

	RotationPeriod	2.5153026648322165

	Obliquity		346.60862023995145

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.470059010017374
		Eccentricity	0.3977592978410647
		Inclination		46.30606348495251
		AscendingNode	208.075057347296
		ArgOfPericen	285.2868476485498
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 84"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.1682461222928832e-09
	Radius		11.871245170549956

	RotationPeriod	4.402853264209835

	Obliquity		75.0019943887578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.491343613771505
		Eccentricity	0.7234803956366163
		Inclination		48.731637258758674
		AscendingNode	210.566577426629
		ArgOfPericen	38.035315536369325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 85"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.6380472491718275e-09
	Radius		13.159744699214686

	RotationPeriod	8.498685904809022

	Obliquity		27.022121190284537

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.726963678460702
		Eccentricity	0.4679930594637242
		Inclination		-36.341664506423804
		AscendingNode	342.7633528833533
		ArgOfPericen	26.97099386528354
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 86"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7921647068709524e-09
	Radius		9.960414457461471

	RotationPeriod	9.223499990116675

	Obliquity		99.44761113713628

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.923671445637732
		Eccentricity	0.585526483778228
		Inclination		9.300586958772344
		AscendingNode	265.8126596415371
		ArgOfPericen	29.08410301965961
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 87"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.1006722427343725e-09
	Radius		13.65176703117275

	RotationPeriod	4.948562969960528

	Obliquity		274.29176120340486

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.72562415072702
		Eccentricity	0.27921230301748046
		Inclination		78.90726243390843
		AscendingNode	197.11337594795788
		ArgOfPericen	153.03290996462795
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 88"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.718735017914277
		Eccentricity	0.6452439764337112
		Inclination		92.51514678789435
		AscendingNode	160.50329858637616
		ArgOfPericen	323.47682999028314
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 88 A"
{
	ParentBody	"HeliosB 88"
	Class		"Asteroid"
	Mass		1.4160783826825965e-09
	Radius		8.722539661580416

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010743301218727901
		Eccentricity	0.003001467407200622
		Inclination		276.89639776698556
		AscendingNode	67.68702752042472
		ArgOfPericen	348.9006774105679
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 88 B"
{
	ParentBody	"HeliosB 88"
	Class		"Asteroid"
	Mass		8.781686370872194e-11
	Radius		3.4525488284540278

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010743301218727901
		Eccentricity	0.003001467407200622
		Inclination		276.89639776698556
		AscendingNode	67.68702752042472
		ArgOfPericen	168.90067741056782
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 89"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.197383426168822e-09
	Radius		12.915359491399391

	RotationPeriod	4.030241525918882

	Obliquity		224.66001489152615

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.71369080410751
		Eccentricity	0.3143599003095786
		Inclination		107.43960808258456
		AscendingNode	201.54674561111403
		ArgOfPericen	164.21900346345174
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 90"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.245018828168526
		Eccentricity	0.6403861060412483
		Inclination		-23.45344273861549
		AscendingNode	202.68635388675605
		ArgOfPericen	160.56002216701245
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 90 A"
{
	ParentBody	"HeliosB 90"
	Class		"Asteroid"
	Mass		5.673383689923636e-09
	Radius		13.184917923947337

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033946021526660894
		Eccentricity	0.005053617584205857
		Inclination		66.55614393354654
		AscendingNode	336.56561420041146
		ArgOfPericen	266.4086777244451
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 90 B"
{
	ParentBody	"HeliosB 90"
	Class		"Asteroid"
	Mass		7.843381595734057e-10
	Radius		6.817594402991979

	Orbit
	{
		Epoch			2457395.5
		Period			0.0033946021526660894
		Eccentricity	0.005053617584205857
		Inclination		66.55614393354654
		AscendingNode	336.56561420041146
		ArgOfPericen	86.40867772444511
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 91"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.550360875716831
		Eccentricity	0.5751280545640203
		Inclination		-10.873530653001172
		AscendingNode	128.41509694776707
		ArgOfPericen	357.44525825066626
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 91 A"
{
	ParentBody	"HeliosB 91"
	Class		"Asteroid"
	Mass		4.734630997925193e-09
	Radius		12.730490388734918

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010799979439452833
		Eccentricity	0.0027160661384315744
		Inclination		196.50873162248635
		AscendingNode	294.8095667467906
		ArgOfPericen	305.0012342079352
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 91 B"
{
	ParentBody	"HeliosB 91"
	Class		"Asteroid"
	Mass		1.8231851633346458e-09
	Radius		9.261756247515155

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010799979439452833
		Eccentricity	0.0027160661384315744
		Inclination		196.50873162248635
		AscendingNode	294.8095667467906
		ArgOfPericen	125.00123420793523
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 92"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.373122978860321e-09
	Radius		16.32774418852972

	RotationPeriod	3.9226878420202773

	Obliquity		192.3732648389239

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.984674978564448
		Eccentricity	0.5691169340333005
		Inclination		-67.30935747659379
		AscendingNode	272.5678106032683
		ArgOfPericen	203.92103397702707
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 93"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.184333335248501
		Eccentricity	0.5593782080871249
		Inclination		27.1941872521799
		AscendingNode	262.8161491358608
		ArgOfPericen	125.88410838447155
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 93 A"
{
	ParentBody	"HeliosB 93"
	Class		"Asteroid"
	Mass		6.219316920503751e-09
	Radius		14.995677035748763

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003370437475351076
		Eccentricity	0.007624863774166438
		Inclination		18.068300557126488
		AscendingNode	162.15173755810275
		ArgOfPericen	157.27057385763862
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 93 B"
{
	ParentBody	"HeliosB 93"
	Class		"Asteroid"
	Mass		2.553884788892786e-09
	Radius		11.145997711597326

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003370437475351076
		Eccentricity	0.007624863774166438
		Inclination		18.068300557126488
		AscendingNode	162.15173755810275
		ArgOfPericen	337.2705738576386
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 94"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.2211165705785564e-08
	Radius		25.0

	RotationPeriod	7.157032526074498

	Obliquity		113.24243596909466

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.50563688084891
		Eccentricity	0.5968595541671385
		Inclination		9.400285797860432
		AscendingNode	174.7930399220418
		ArgOfPericen	146.57940859523129
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 95"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.269354214307479e-09
	Radius		12.496468836972408

	RotationPeriod	6.155604263101896

	Obliquity		50.61100878667038

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.1917368993775
		Eccentricity	0.050380657543761476
		Inclination		-180.0
		AscendingNode	85.05039223721214
		ArgOfPericen	67.29220000973065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 96"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3074679559370392e-09
	Radius		8.542588104064262

	RotationPeriod	2.8586487513706365

	Obliquity		181.50098143908463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.851347097084453
		Eccentricity	0.313310325605353
		Inclination		32.45015231551003
		AscendingNode	340.7335426500118
		ArgOfPericen	94.63879744664297
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 97"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.572054177985843
		Eccentricity	0.35996231396774003
		Inclination		-4.017161014880862
		AscendingNode	180.58557898600736
		ArgOfPericen	87.39359797738112
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 97 A"
{
	ParentBody	"HeliosB 97"
	Class		"Asteroid"
	Mass		2.867101142322525e-09
	Radius		10.277649117308167

	Orbit
	{
		Epoch			2457395.5
		Period			0.002689188359217557
		Eccentricity	0.0038564228263013025
		Inclination		331.1867597172457
		AscendingNode	61.71147696817696
		ArgOfPericen	131.67525977308935
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 97 B"
{
	ParentBody	"HeliosB 97"
	Class		"Asteroid"
	Mass		1.3624568270430653e-09
	Radius		8.020233858122195

	Orbit
	{
		Epoch			2457395.5
		Period			0.002689188359217557
		Eccentricity	0.0038564228263013025
		Inclination		331.1867597172457
		AscendingNode	61.71147696817696
		ArgOfPericen	311.67525977308935
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 98"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.957290097630244e-09
	Radius		13.38201234983077

	RotationPeriod	4.351921639052302

	Obliquity		55.609567578898236

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.803010664307921
		Eccentricity	0.6380844145297224
		Inclination		-10.793446717201306
		AscendingNode	159.94533805458084
		ArgOfPericen	46.01981721372605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 99"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.4220435631695203e-08
	Radius		18.188290599131342

	RotationPeriod	0.3890249153628842

	Obliquity		250.8760954689336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.810571197918916
		Eccentricity	0.9821672102926691
		Inclination		-38.397615544105996
		AscendingNode	44.49277736460608
		ArgOfPericen	304.60756578124125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 100"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7119437834315498e-08
	Radius		19.232601591486965

	RotationPeriod	7.674304392489504

	Obliquity		351.73934369973995

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.533069772206792
		Eccentricity	0.40665248946165583
		Inclination		-82.31935754637401
		AscendingNode	57.20540765160337
		ArgOfPericen	4.197451250857238
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 101"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.242309712200763
		Eccentricity	0.5925502760725716
		Inclination		12.758715672087963
		AscendingNode	210.26626682164795
		ArgOfPericen	112.88022738677901
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 101 A"
{
	ParentBody	"HeliosB 101"
	Class		"Asteroid"
	Mass		4.9755141997402835e-09
	Radius		13.09823351926999

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028080871540820114
		Eccentricity	0.004301256154148755
		Inclination		106.90010740839111
		AscendingNode	204.02387610213435
		ArgOfPericen	160.10649042291635
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 101 B"
{
	ParentBody	"HeliosB 101"
	Class		"Asteroid"
	Mass		3.2329731555368486e-10
	Radius		5.2658373234780385

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028080871540820114
		Eccentricity	0.004301256154148755
		Inclination		106.90010740839111
		AscendingNode	204.02387610213435
		ArgOfPericen	340.10649042291635
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 102"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.99274690555557e-09
	Radius		13.535331047691793

	RotationPeriod	6.883873032558394

	Obliquity		354.60800162014453

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.188206201892728
		Eccentricity	0.6205677113706092
		Inclination		-3.817847857774383
		AscendingNode	280.79153247128716
		ArgOfPericen	47.03916242889602
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 103"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.731711762402176
		Eccentricity	0.6261694892049832
		Inclination		5.076034548020138
		AscendingNode	20.12816450462621
		ArgOfPericen	88.37344448721993
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 103 A"
{
	ParentBody	"HeliosB 103"
	Class		"Asteroid"
	Mass		4.506038885750885e-09
	Radius		13.00212883002631

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005657468433945832
		Eccentricity	0.004273833888956662
		Inclination		214.0801923565216
		AscendingNode	57.036116530964435
		ArgOfPericen	271.9528498900691
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 103 B"
{
	ParentBody	"HeliosB 103"
	Class		"Asteroid"
	Mass		1.508370272799895e-09
	Radius		9.027873700548259

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005657468433945832
		Eccentricity	0.004273833888956662
		Inclination		214.0801923565216
		AscendingNode	57.036116530964435
		ArgOfPericen	91.9528498900691
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 104"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.9960364584080643e-09
	Radius		11.290889889069549

	RotationPeriod	6.723755471842036

	Obliquity		110.6194478163876

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.076783172586474
		Eccentricity	0.5886530762421756
		Inclination		-31.43470976105511
		AscendingNode	99.4296374909841
		ArgOfPericen	320.63055232060236
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 105"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.5970080651802892e-09
	Radius		9.191749221639352

	RotationPeriod	8.264793674748354

	Obliquity		189.43770547435676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.674887894521127
		Eccentricity	0.3874621633445969
		Inclination		-37.584268006397146
		AscendingNode	150.17654907904333
		ArgOfPericen	229.52197469013447
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 106"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.71457931122991e-09
	Radius		15.094092279208526

	RotationPeriod	4.366164404702439

	Obliquity		144.06790751532154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.976230723871616
		Eccentricity	0.4674201781813113
		Inclination		100.81481160321631
		AscendingNode	296.571494308345
		ArgOfPericen	253.18333444297397
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 107"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.58004108648057e-09
	Radius		14.468875128820539

	RotationPeriod	5.383748284593259

	Obliquity		265.5983015752553

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.741785151665127
		Eccentricity	0.7716613728282606
		Inclination		-1.0021773273235928
		AscendingNode	343.54247836693736
		ArgOfPericen	179.0019719604409
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 108"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2784726231346044e-09
	Radius		8.998178872927902

	RotationPeriod	5.061834655737712

	Obliquity		197.9351671677789

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.788925294393342
		Eccentricity	0.4312006534688241
		Inclination		-78.78838124835298
		AscendingNode	237.00960843725355
		ArgOfPericen	140.48023386216687
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 109"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.1243676441627087e-09
	Radius		10.190772589219034

	RotationPeriod	6.093151221019511

	Obliquity		314.30220453862876

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.578186576799517
		Eccentricity	0.7868180750808599
		Inclination		-13.777693586948535
		AscendingNode	0.5802472035717354
		ArgOfPericen	292.70113684116825
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 110"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.0361358161413147e-08
	Radius		20.803481916824992

	RotationPeriod	4.631105328502921

	Obliquity		324.70346489956955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.320801298475117
		Eccentricity	0.8278364966966972
		Inclination		-7.975603491401651
		AscendingNode	8.224376027580833
		ArgOfPericen	249.72617075411893
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 111"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.855830188283077
		Eccentricity	0.36237524476831606
		Inclination		-34.25539611571656
		AscendingNode	273.02413169010254
		ArgOfPericen	321.45665297369885
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 111 A"
{
	ParentBody	"HeliosB 111"
	Class		"Asteroid"
	Mass		7.388738666234584e-09
	Radius		15.167546258322359

	Orbit
	{
		Epoch			2457395.5
		Period			0.006725172447397787
		Eccentricity	0.007800278582630989
		Inclination		76.21843276930831
		AscendingNode	192.98303179680482
		ArgOfPericen	284.2793647860403
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 111 B"
{
	ParentBody	"HeliosB 111"
	Class		"Asteroid"
	Mass		8.506916657305487e-10
	Radius		7.378746984623658

	Orbit
	{
		Epoch			2457395.5
		Period			0.006725172447397787
		Eccentricity	0.007800278582630989
		Inclination		76.21843276930831
		AscendingNode	192.98303179680482
		ArgOfPericen	104.27936478604028
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 112"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.004592418468148
		Eccentricity	0.665064639056835
		Inclination		-66.74665141546515
		AscendingNode	257.8506040497028
		ArgOfPericen	28.313770150425267
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 112 A"
{
	ParentBody	"HeliosB 112"
	Class		"Asteroid"
	Mass		5.216761291663878e-09
	Radius		13.792652749389065

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055191725476534245
		Eccentricity	0.003524757588443786
		Inclination		166.09047253322873
		AscendingNode	298.62889605528545
		ArgOfPericen	347.4624091582564
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 112 B"
{
	ParentBody	"HeliosB 112"
	Class		"Asteroid"
	Mass		5.1015287038374996e-09
	Radius		13.690340786624732

	Orbit
	{
		Epoch			2457395.5
		Period			0.0055191725476534245
		Eccentricity	0.003524757588443786
		Inclination		166.09047253322873
		AscendingNode	298.62889605528545
		ArgOfPericen	167.46240915825638
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 113"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.3434852836725103e-09
	Radius		11.598320844857914

	RotationPeriod	8.526146701263826

	Obliquity		194.66099416208132

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.189595248988269
		Eccentricity	0.4208258711792966
		Inclination		-54.91244468248516
		AscendingNode	122.57740496073858
		ArgOfPericen	306.16183525109193
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 114"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.221974845281755e-09
	Radius		12.672225611152362

	RotationPeriod	4.474844045114203

	Obliquity		340.53795343689166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.71039784841204
		Eccentricity	0.4465604563319785
		Inclination		-74.46461248914642
		AscendingNode	166.08662943847068
		ArgOfPericen	123.81437274958625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 115"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.52083854829825
		Eccentricity	0.8175968866620177
		Inclination		-82.59499267759168
		AscendingNode	356.05328490253817
		ArgOfPericen	216.24505012103776
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 115 A"
{
	ParentBody	"HeliosB 115"
	Class		"Asteroid"
	Mass		2.1509629501540544e-09
	Radius		10.545431533204296

	Orbit
	{
		Epoch			2457395.5
		Period			0.006731319507076383
		Eccentricity	0.0029427425870775254
		Inclination		308.7100595556004
		AscendingNode	22.447185825453996
		ArgOfPericen	1.6579540744563426
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 115 B"
{
	ParentBody	"HeliosB 115"
	Class		"Asteroid"
	Mass		1.9755327435637806e-09
	Radius		10.250572551840888

	Orbit
	{
		Epoch			2457395.5
		Period			0.006731319507076383
		Eccentricity	0.0029427425870775254
		Inclination		308.7100595556004
		AscendingNode	22.447185825453996
		ArgOfPericen	181.65795407445634
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 116"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.676594894367058e-09
	Radius		9.38177717896647

	RotationPeriod	6.201191444127508

	Obliquity		113.62283021784651

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.523131529959572
		Eccentricity	0.4780813816785019
		Inclination		-98.23162213785683
		AscendingNode	204.25515550165747
		ArgOfPericen	226.8534668211889
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 117"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.910090555218105e-08
	Radius		20.592925154391576

	RotationPeriod	5.773028994532927

	Obliquity		108.15480467820646

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.661107523981888
		Eccentricity	0.5084281658826585
		Inclination		87.50581842304273
		AscendingNode	264.6000110022785
		ArgOfPericen	271.82934850488675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 118"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.383715527828142e-09
	Radius		15.82977052284659

	RotationPeriod	6.718791312936753

	Obliquity		1.7282319954176861

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.476565819512887
		Eccentricity	0.5534068745233971
		Inclination		-99.57033165758521
		AscendingNode	292.06191114669656
		ArgOfPericen	112.07935002164051
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 119"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.307154619769722
		Eccentricity	0.8200939452786136
		Inclination		-86.48895576442219
		AscendingNode	351.78624918822794
		ArgOfPericen	340.4959179181995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 119 A"
{
	ParentBody	"HeliosB 119"
	Class		"Asteroid"
	Mass		6.640343428118624e-10
	Radius		6.730177669027159

	Orbit
	{
		Epoch			2457395.5
		Period			0.0076096649819531285
		Eccentricity	0.006013083296417936
		Inclination		306.2275313275454
		AscendingNode	266.5351991591529
		ArgOfPericen	63.800761178253886
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 119 B"
{
	ParentBody	"HeliosB 119"
	Class		"Asteroid"
	Mass		8.199925361432061e-11
	Radius		3.351451832441792

	Orbit
	{
		Epoch			2457395.5
		Period			0.0076096649819531285
		Eccentricity	0.006013083296417936
		Inclination		306.2275313275454
		AscendingNode	266.5351991591529
		ArgOfPericen	243.80076117825388
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 120"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.037593203489685
		Eccentricity	0.31464059343389683
		Inclination		13.232398877014838
		AscendingNode	83.82648738355772
		ArgOfPericen	272.56694366440047
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 120 A"
{
	ParentBody	"HeliosB 120"
	Class		"Asteroid"
	Mass		7.915403601968362e-11
	Radius		3.304476840040442

	Orbit
	{
		Epoch			2457395.5
		Period			0.00549298596095152
		Eccentricity	0.0013830353703160902
		Inclination		276.37072278022254
		AscendingNode	3.898766890484673
		ArgOfPericen	116.05266537001957
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 120 B"
{
	ParentBody	"HeliosB 120"
	Class		"Asteroid"
	Mass		6.477042557619224e-11
	Radius		3.0907978955039073

	Orbit
	{
		Epoch			2457395.5
		Period			0.00549298596095152
		Eccentricity	0.0013830353703160902
		Inclination		276.37072278022254
		AscendingNode	3.898766890484673
		ArgOfPericen	296.05266537001955
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 121"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7864229546169295e-09
	Radius		9.353833036484852

	RotationPeriod	4.441241172597713

	Obliquity		245.10813137339707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.788996015507657
		Eccentricity	1.0
		Inclination		-72.95664166593323
		AscendingNode	181.49715044489815
		ArgOfPericen	169.37063340164315
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 122"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.6423790125037062e-09
	Radius		10.677132796451426

	RotationPeriod	2.1955405463696636

	Obliquity		12.40000126898346

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.716998323747664
		Eccentricity	0.6557088154539755
		Inclination		61.29366283455934
		AscendingNode	125.46635082257104
		ArgOfPericen	35.911821465893155
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 123"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.55579417736902e-09
	Radius		10.948367565708127

	RotationPeriod	4.579542472984764

	Obliquity		233.2199527152307

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.637063278420325
		Eccentricity	0.6624773075668928
		Inclination		5.577367150164221
		AscendingNode	202.06429950633964
		ArgOfPericen	311.6472731569725
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 124"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.438731469955035e-09
	Radius		13.814070564868208

	RotationPeriod	5.46709392182612

	Obliquity		22.161430778995133

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.213697888031412
		Eccentricity	0.40531832825124403
		Inclination		95.51781732995272
		AscendingNode	157.4923999375633
		ArgOfPericen	243.81286534812858
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 125"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.421288826202884
		Eccentricity	0.4902823035207119
		Inclination		-104.20827777091785
		AscendingNode	92.59606955804347
		ArgOfPericen	54.40166079338505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 125 A"
{
	ParentBody	"HeliosB 125"
	Class		"Asteroid"
	Mass		8.389349055922404e-11
	Radius		3.3841842416914236

	Orbit
	{
		Epoch			2457395.5
		Period			0.005820138058308088
		Eccentricity	0.006304298457812989
		Inclination		18.088964488957252
		AscendingNode	156.82870099316412
		ArgOfPericen	160.13239687566912
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 125 B"
{
	ParentBody	"HeliosB 125"
	Class		"Asteroid"
	Mass		7.89319640757914e-12
	Radius		1.5392017455863412

	Orbit
	{
		Epoch			2457395.5
		Period			0.005820138058308088
		Eccentricity	0.006304298457812989
		Inclination		18.088964488957252
		AscendingNode	156.82870099316412
		ArgOfPericen	340.1323968756691
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 126"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.9515342701756285e-08
	Radius		21.1360856042908

	RotationPeriod	6.023041591796502

	Obliquity		235.77253429524035

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.411679364201078
		Eccentricity	0.7957456319499018
		Inclination		-44.38300189262205
		AscendingNode	284.9664059569221
		ArgOfPericen	347.45983934329314
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 127"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.627607981722893
		Eccentricity	0.9118223974715975
		Inclination		-17.015075350911065
		AscendingNode	215.2643423523106
		ArgOfPericen	52.59825386680751
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 127 A"
{
	ParentBody	"HeliosB 127"
	Class		"Asteroid"
	Mass		2.240688417813588e-08
	Radius		22.007782484799385

	Orbit
	{
		Epoch			2457395.5
		Period			0.002643233254671828
		Eccentricity	0.007572751332914723
		Inclination		90.5806122550304
		AscendingNode	188.7502292053934
		ArgOfPericen	322.6785522925692
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 127 B"
{
	ParentBody	"HeliosB 127"
	Class		"Asteroid"
	Mass		1.0114579024765542e-08
	Radius		16.88230462985945

	Orbit
	{
		Epoch			2457395.5
		Period			0.002643233254671828
		Eccentricity	0.007572751332914723
		Inclination		90.5806122550304
		AscendingNode	188.7502292053934
		ArgOfPericen	142.67855229256918
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 128"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.617006000814163e-09
	Radius		13.538587058714835

	RotationPeriod	9.063416542643928

	Obliquity		22.95026203547119

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.628227165248099
		Eccentricity	0.5892594809944075
		Inclination		36.09496113010706
		AscendingNode	109.11449753255603
		ArgOfPericen	345.3240149242608
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 129"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.772288147364058
		Eccentricity	0.5052256250808724
		Inclination		-28.90642269517076
		AscendingNode	57.8469211424533
		ArgOfPericen	303.90192756152027
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 129 A"
{
	ParentBody	"HeliosB 129"
	Class		"Asteroid"
	Mass		8.603433718450874e-09
	Radius		14.832728393250619

	Orbit
	{
		Epoch			2457395.5
		Period			0.004085583079021365
		Eccentricity	0.006227249473547896
		Inclination		192.79203477244207
		AscendingNode	241.0989845350517
		ArgOfPericen	23.582309892101833
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 129 B"
{
	ParentBody	"HeliosB 129"
	Class		"Asteroid"
	Mass		1.9074646799666238e-09
	Radius		8.977373073038935

	Orbit
	{
		Epoch			2457395.5
		Period			0.004085583079021365
		Eccentricity	0.006227249473547896
		Inclination		192.79203477244207
		AscendingNode	241.0989845350517
		ArgOfPericen	203.58230989210182
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 130"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.3276848112240052e-10
	Radius		3.819493380551437

	RotationPeriod	6.438674129595709

	Obliquity		189.27478830097002

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.287585609297208
		Eccentricity	0.4271826386048272
		Inclination		-130.88484708505405
		AscendingNode	96.53203528126366
		ArgOfPericen	266.74351610743423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 131"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.710095077988794e-09
	Radius		13.299960492687944

	RotationPeriod	6.161443711393836

	Obliquity		293.9080276176266

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.295522967553936
		Eccentricity	0.4885689875307259
		Inclination		-79.17552153717118
		AscendingNode	286.4054695806444
		ArgOfPericen	79.18182013535218
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 132"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.375862776924458e-09
	Radius		11.575886882048026

	RotationPeriod	2.0248079668399273

	Obliquity		83.5921163382694

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.696953721386231
		Eccentricity	0.49885861468265663
		Inclination		26.243273082942537
		AscendingNode	86.35622508661497
		ArgOfPericen	322.2260508292528
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 133"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.392524279966809e-09
	Radius		14.498329641114491

	RotationPeriod	7.629834484557248

	Obliquity		88.86137035893178

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.911974429001095
		Eccentricity	0.607006728550123
		Inclination		-21.495027012524062
		AscendingNode	168.82146267502284
		ArgOfPericen	186.5633002977853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 134"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.4956087301977695e-09
	Radius		14.240758258977305

	RotationPeriod	6.538905684970531

	Obliquity		176.5075719815755

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.58409970151944
		Eccentricity	0.36761067779546985
		Inclination		60.05939130725964
		AscendingNode	354.6334044560107
		ArgOfPericen	62.197368224597206
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 135"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1436036449598435e-08
	Radius		18.304266521927307

	RotationPeriod	6.4191650439374754

	Obliquity		149.2897040953218

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.575506475982642
		Eccentricity	0.6688652903559963
		Inclination		-5.7154550773069035
		AscendingNode	64.9345291045888
		ArgOfPericen	339.833901483626
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 136"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.801729872968772e-09
	Radius		15.871710231965297

	RotationPeriod	5.464397702134995

	Obliquity		119.78337947867604

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.585995004959253
		Eccentricity	0.24251259501020672
		Inclination		32.44367234816757
		AscendingNode	307.2989680397137
		ArgOfPericen	41.026819790789276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 137"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.439470561347894e-09
	Radius		16.89759859040141

	RotationPeriod	7.462164524081419

	Obliquity		22.81721879854732

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.708418197852831
		Eccentricity	0.2653997055422844
		Inclination		131.1548942499213
		AscendingNode	315.7844534728227
		ArgOfPericen	128.3349351823582
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 138"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.593454437502146
		Eccentricity	0.6129320349658592
		Inclination		25.705247213909956
		AscendingNode	243.40600537401787
		ArgOfPericen	275.5112105738946
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 138 A"
{
	ParentBody	"HeliosB 138"
	Class		"Asteroid"
	Mass		3.1081637319543147e-09
	Radius		11.717249992164682

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008964861334827194
		Eccentricity	0.007050727893226574
		Inclination		356.0409626232465
		AscendingNode	138.13930242317747
		ArgOfPericen	266.7317980031344
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 138 B"
{
	ParentBody	"HeliosB 138"
	Class		"Asteroid"
	Mass		9.036528074519824e-10
	Radius		7.762321035835711

	Orbit
	{
		Epoch			2457395.5
		Period			0.0008964861334827194
		Eccentricity	0.007050727893226574
		Inclination		356.0409626232465
		AscendingNode	138.13930242317747
		ArgOfPericen	86.73179800313437
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 139"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.630093091760491
		Eccentricity	0.4886483522045709
		Inclination		28.344188095026226
		AscendingNode	65.91018371933257
		ArgOfPericen	197.72119733917089
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 139 A"
{
	ParentBody	"HeliosB 139"
	Class		"Asteroid"
	Mass		2.0846264904521767e-08
	Radius		20.68590935658017

	Orbit
	{
		Epoch			2457395.5
		Period			0.001349231267613807
		Eccentricity	0.00579683785157609
		Inclination		15.555607569052533
		AscendingNode	192.0723073465546
		ArgOfPericen	29.936030609289816
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 139 B"
{
	ParentBody	"HeliosB 139"
	Class		"Asteroid"
	Mass		1.908913475919902e-08
	Radius		20.08756435721701

	Orbit
	{
		Epoch			2457395.5
		Period			0.001349231267613807
		Eccentricity	0.00579683785157609
		Inclination		15.555607569052533
		AscendingNode	192.0723073465546
		ArgOfPericen	209.93603060928982
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 140"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.374483587099768
		Eccentricity	0.6154513875259352
		Inclination		-46.011452164702305
		AscendingNode	91.48948121303646
		ArgOfPericen	37.964928423342556
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 140 A"
{
	ParentBody	"HeliosB 140"
	Class		"Asteroid"
	Mass		5.2841076726863845e-09
	Radius		12.615124836105203

	Orbit
	{
		Epoch			2457395.5
		Period			0.005605130703035163
		Eccentricity	0.002719542870539195
		Inclination		155.77936282111062
		AscendingNode	38.53004568703058
		ArgOfPericen	255.93803893319011
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 140 B"
{
	ParentBody	"HeliosB 140"
	Class		"Asteroid"
	Mass		4.804873952896893e-09
	Radius		12.221607518262005

	Orbit
	{
		Epoch			2457395.5
		Period			0.005605130703035163
		Eccentricity	0.002719542870539195
		Inclination		155.77936282111062
		AscendingNode	38.53004568703058
		ArgOfPericen	75.93803893319011
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 141"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.231059095967441e-10
	Radius		7.358449349584893

	RotationPeriod	4.379796262635803

	Obliquity		63.02481985216845

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.922441346709984
		Eccentricity	0.7305320389640637
		Inclination		-93.7686609436376
		AscendingNode	306.37773689757057
		ArgOfPericen	57.26376975081837
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 142"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.205875311098106e-09
	Radius		15.02193295015539

	RotationPeriod	11.167254704197022

	Obliquity		288.38673765529137

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.55472434901221
		Eccentricity	0.3346042490091084
		Inclination		-9.811162767832444
		AscendingNode	345.9636281932205
		ArgOfPericen	355.6669632033396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 143"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.1864410012138074e-09
	Radius		10.304481823782703

	RotationPeriod	8.352939342763102

	Obliquity		9.950135950892541

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.179883599661638
		Eccentricity	0.3190874050164221
		Inclination		110.17458239519883
		AscendingNode	250.56914488216123
		ArgOfPericen	7.334175684296156
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 144"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.422996560221976e-09
	Radius		12.923310740675948

	RotationPeriod	8.950076921197612

	Obliquity		206.16934623625025

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.48757134957268
		Eccentricity	0.6028812554879198
		Inclination		53.02051133852095
		AscendingNode	278.6050072833987
		ArgOfPericen	315.7555000661878
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 145"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.7283386929381975e-09
	Radius		10.733311014147706

	RotationPeriod	5.555574062932951

	Obliquity		65.562187444281

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.462227502694317
		Eccentricity	0.46496095200825377
		Inclination		11.254514360023546
		AscendingNode	261.70629561884584
		ArgOfPericen	102.80844110669283
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 146"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.197043627699728e-09
	Radius		14.270660324489938

	RotationPeriod	8.179286855547277

	Obliquity		54.915324001003796

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.216626420846362
		Eccentricity	0.37996865116509104
		Inclination		8.839477772613579
		AscendingNode	10.645574267809339
		ArgOfPericen	61.59122899845074
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 147"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.565944179507527e-09
	Radius		13.58361264491765

	RotationPeriod	5.833736147027951

	Obliquity		240.6404900996828

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.315744029643213
		Eccentricity	0.5964253090315061
		Inclination		60.0712766681352
		AscendingNode	34.68989026595911
		ArgOfPericen	66.10015944603089
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 148"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.0550018716913097e-08
	Radius		17.341876659353005

	RotationPeriod	8.011696709974517

	Obliquity		127.99047080508579

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.735022020322548
		Eccentricity	0.6926486632264937
		Inclination		17.48287413953924
		AscendingNode	205.78217963291846
		ArgOfPericen	250.69356806407447
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 149"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.180788972128937
		Eccentricity	0.10604982902383048
		Inclination		22.417765230960303
		AscendingNode	258.32504718744923
		ArgOfPericen	125.03984205236281
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 149 A"
{
	ParentBody	"HeliosB 149"
	Class		"Asteroid"
	Mass		1.919659761572011e-09
	Radius		9.931487151557011

	Orbit
	{
		Epoch			2457395.5
		Period			0.007308722444165033
		Eccentricity	0.0038590278452371035
		Inclination		307.699738479817
		AscendingNode	58.70536699757107
		ArgOfPericen	336.8540255072207
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 149 B"
{
	ParentBody	"HeliosB 149"
	Class		"Asteroid"
	Mass		4.323563820627499e-10
	Radius		6.042548652537497

	Orbit
	{
		Epoch			2457395.5
		Period			0.007308722444165033
		Eccentricity	0.0038590278452371035
		Inclination		307.699738479817
		AscendingNode	58.70536699757107
		ArgOfPericen	156.85402550722074
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 150"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.620892869838626e-11
	Radius		3.0429396055431575

	RotationPeriod	9.731741610656176

	Obliquity		257.23862867326375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.543906020094225
		Eccentricity	0.566866292351078
		Inclination		63.656886250115186
		AscendingNode	327.69290711227495
		ArgOfPericen	148.8123743948193
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 151"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.829805970554947e-09
	Radius		11.96194201439151

	RotationPeriod	9.730252207980726

	Obliquity		307.5334472841777

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.671999112296447
		Eccentricity	0.4680435871845672
		Inclination		42.99767703676827
		AscendingNode	282.58227863598006
		ArgOfPericen	147.05574683622473
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 152"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.869918333678848e-09
	Radius		13.041404247002433

	RotationPeriod	6.5169440094074265

	Obliquity		67.47687852011057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.770947821459813
		Eccentricity	0.4060517715426396
		Inclination		-16.817963872541398
		AscendingNode	0.5517526514840299
		ArgOfPericen	40.83371526940139
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 153"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.388373980698638
		Eccentricity	0.7775299586587734
		Inclination		-69.31679990635983
		AscendingNode	100.45361695039762
		ArgOfPericen	68.35602518920997
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 153 A"
{
	ParentBody	"HeliosB 153"
	Class		"Asteroid"
	Mass		5.01403268032852e-09
	Radius		12.907815342971068

	Orbit
	{
		Epoch			2457395.5
		Period			0.005808346827072011
		Eccentricity	0.004388893931863731
		Inclination		255.46350206320355
		AscendingNode	239.12993163481076
		ArgOfPericen	272.822998934135
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 153 B"
{
	ParentBody	"HeliosB 153"
	Class		"Asteroid"
	Mass		1.9409554684156854e-09
	Radius		9.40723978813495

	Orbit
	{
		Epoch			2457395.5
		Period			0.005808346827072011
		Eccentricity	0.004388893931863731
		Inclination		255.46350206320355
		AscendingNode	239.12993163481076
		ArgOfPericen	92.822998934135
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 154"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.9887029098268504e-09
	Radius		15.333137146762365

	RotationPeriod	7.752597709639012

	Obliquity		29.573699572408295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.714416480072966
		Eccentricity	0.7544678389269335
		Inclination		-72.79939633862321
		AscendingNode	291.6016536437593
		ArgOfPericen	295.69192930250654
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 155"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.631679590521902e-09
	Radius		13.748137232099955

	RotationPeriod	6.1757980751521355

	Obliquity		182.4173859638066

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.385257391760895
		Eccentricity	0.5205929008968139
		Inclination		-133.22298007464587
		AscendingNode	63.89198880256716
		ArgOfPericen	16.816107859026165
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 156"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7727291181640784e-09
	Radius		9.917319410698756

	RotationPeriod	3.5977332845913956

	Obliquity		27.09270764739291

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.668506206280556
		Eccentricity	0.6610616082395881
		Inclination		-7.603882255287825
		AscendingNode	38.26435480078119
		ArgOfPericen	261.3830885833136
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 157"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.892337956714344e-09
	Radius		13.738071922276204

	RotationPeriod	2.8175912869551443

	Obliquity		185.2156967252392

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.6825489060488
		Eccentricity	0.47416779560532785
		Inclination		96.96002337631823
		AscendingNode	69.73040647304808
		ArgOfPericen	44.068420735075065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 158"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.993302137019998e-10
	Radius		7.5593000723798145

	RotationPeriod	6.288327050296691

	Obliquity		200.27781034163775

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.719672779015161
		Eccentricity	0.6172901631371343
		Inclination		-9.712257623586865
		AscendingNode	164.05878056730464
		ArgOfPericen	195.40115512025187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 159"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		4.412547914629036e-09
	Radius		12.458131697376299

	RotationPeriod	4.932108937679212

	Obliquity		317.7390058930494

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.964111278417658
		Eccentricity	0.4229723806940705
		Inclination		-43.72286567274267
		AscendingNode	340.24615638802567
		ArgOfPericen	177.83524586752685
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 160"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7869469061901722e-09
	Radius		8.857279229877276

	RotationPeriod	4.838217419274626

	Obliquity		116.89500779606065

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.440908645635453
		Eccentricity	0.8179007461495063
		Inclination		-81.22978371098745
		AscendingNode	244.1255331139337
		ArgOfPericen	162.75819960096058
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 161"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.222020969345567e-09
	Radius		11.11871763760567

	RotationPeriod	5.240749126921615

	Obliquity		218.5601536738069

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.580330268955773
		Eccentricity	0.32829752542439655
		Inclination		29.34024551383643
		AscendingNode	142.29721526832478
		ArgOfPericen	159.2829231144014
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 162"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.44314257659245e-10
	Radius		7.513690907203929

	RotationPeriod	9.237073988279402

	Obliquity		210.56542726963562

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.257888763467014
		Eccentricity	0.6144856180932813
		Inclination		100.08339519699601
		AscendingNode	182.78707562545384
		ArgOfPericen	279.0212588565335
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 163"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		8.320472551981318e-09
	Radius		15.75769380647329

	RotationPeriod	5.688518273146702

	Obliquity		173.80446921676446

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.111181679654065
		Eccentricity	0.5268194758896533
		Inclination		54.81233785846036
		AscendingNode	14.216295998720021
		ArgOfPericen	36.07494554095249
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 164"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.1630361691620496e-09
	Radius		9.855265589718817

	RotationPeriod	3.72654959834028

	Obliquity		102.30015505019857

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.24217726147716
		Eccentricity	0.5132971919804185
		Inclination		17.70756158836454
		AscendingNode	49.704510779027636
		ArgOfPericen	357.4818887696838
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 165"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.830587240720234e-10
	Radius		7.566244724473729

	RotationPeriod	8.63663852876479

	Obliquity		105.14324348634781

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.053418592458407
		Eccentricity	0.5400683013713756
		Inclination		-89.84872640450624
		AscendingNode	70.88171399062195
		ArgOfPericen	280.2824914909405
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 166"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.5813717254663295
		Eccentricity	0.3279089584299107
		Inclination		5.358610855935088
		AscendingNode	277.2346675241599
		ArgOfPericen	118.9610073719634
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 166 A"
{
	ParentBody	"HeliosB 166"
	Class		"Asteroid"
	Mass		6.448662606949617e-09
	Radius		13.98597862493835

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009442867403859034
		Eccentricity	0.004824183090725729
		Inclination		163.58110010749158
		AscendingNode	220.47953809443098
		ArgOfPericen	235.06191129659044
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 166 B"
{
	ParentBody	"HeliosB 166"
	Class		"Asteroid"
	Mass		1.3831081939473096e-09
	Radius		8.371854910456928

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009442867403859034
		Eccentricity	0.004824183090725729
		Inclination		163.58110010749158
		AscendingNode	220.47953809443098
		ArgOfPericen	55.06191129659044
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 167"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.34053510270517
		Eccentricity	0.5045563180595569
		Inclination		39.09594669001555
		AscendingNode	105.1181968515272
		ArgOfPericen	29.962191974407336
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 167 A"
{
	ParentBody	"HeliosB 167"
	Class		"Asteroid"
	Mass		1.0424041520323945e-08
	Radius		17.312743031827946

	Orbit
	{
		Epoch			2457395.5
		Period			0.006200216617066962
		Eccentricity	0.004156099217907757
		Inclination		335.2903157738303
		AscendingNode	330.6913916385906
		ArgOfPericen	60.1626275554652
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 167 B"
{
	ParentBody	"HeliosB 167"
	Class		"Asteroid"
	Mass		3.4407984121470165e-09
	Radius		11.964840544833601

	Orbit
	{
		Epoch			2457395.5
		Period			0.006200216617066962
		Eccentricity	0.004156099217907757
		Inclination		335.2903157738303
		AscendingNode	330.6913916385906
		ArgOfPericen	240.1626275554652
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 168"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2019172344015646e-08
	Radius		18.353922986036974

	RotationPeriod	7.368882718280119

	Obliquity		63.898402729292016

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.181425922912023
		Eccentricity	0.4866096237007064
		Inclination		6.422503577979292
		AscendingNode	48.28952647020783
		ArgOfPericen	117.3869292873151
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 169"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.954256339658148e-09
	Radius		9.2214617839271

	RotationPeriod	5.0052181224439165

	Obliquity		117.80104645745428

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.864235143837171
		Eccentricity	0.463145295294814
		Inclination		116.72976541034477
		AscendingNode	1.453457561788425
		ArgOfPericen	218.4881176058966
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 170"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.7766917263980005e-09
	Radius		14.2273517390407

	RotationPeriod	12

	Obliquity		115.72770833770241

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.897826733916288
		Eccentricity	0.5605102943848747
		Inclination		-10.072888895931527
		AscendingNode	123.97256970679355
		ArgOfPericen	91.90635094915875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 171"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.340887001665728e-10
	Radius		4.649081609354666

	RotationPeriod	5.300155898743474

	Obliquity		295.06441274622745

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.04112292319586
		Eccentricity	0.6525437216680902
		Inclination		79.31568611782441
		AscendingNode	316.60390684487606
		ArgOfPericen	126.63031596741564
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 172"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.59546335053182e-09
	Radius		15.216723841885294

	RotationPeriod	7.9321995165279

	Obliquity		1.4541798361047409

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.409207201717638
		Eccentricity	0.6040271278593027
		Inclination		-36.1653697058879
		AscendingNode	353.88149344682523
		ArgOfPericen	7.026629131240529
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 173"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.633617517692613e-09
	Radius		14.840548756523255

	RotationPeriod	2.7259027433769467

	Obliquity		116.09536860074127

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.347051896141274
		Eccentricity	0.3416373426161565
		Inclination		32.09138653885001
		AscendingNode	24.173300987696777
		ArgOfPericen	226.6748395232608
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 174"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.5886051640418172e-09
	Radius		11.135869508597281

	RotationPeriod	2.4696184949635223

	Obliquity		257.10459724662655

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.578635815763526
		Eccentricity	0.4866374464524682
		Inclination		-11.716084117020284
		AscendingNode	261.3311243408365
		ArgOfPericen	96.1144784579944
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 175"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.5975073459427485e-09
	Radius		11.89809005878472

	RotationPeriod	3.327712726091337

	Obliquity		76.7010254924135

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.447665408349714
		Eccentricity	0.29497189250485845
		Inclination		103.90648443928288
		AscendingNode	223.26930076240856
		ArgOfPericen	128.42389353297588
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 176"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.040923543421565
		Eccentricity	0.2143045409254351
		Inclination		46.10733730840574
		AscendingNode	89.38476180718177
		ArgOfPericen	246.6403849639505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 176 A"
{
	ParentBody	"HeliosB 176"
	Class		"Asteroid"
	Mass		2.1393320296712793e-09
	Radius		9.951039950728251

	Orbit
	{
		Epoch			2457395.5
		Period			0.002417211761084617
		Eccentricity	0.0052913239073987955
		Inclination		261.6717773200574
		AscendingNode	72.28284123819698
		ArgOfPericen	172.97040830061212
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 176 B"
{
	ParentBody	"HeliosB 176"
	Class		"Asteroid"
	Mass		1.9028937818313722e-09
	Radius		9.570043702020374

	Orbit
	{
		Epoch			2457395.5
		Period			0.002417211761084617
		Eccentricity	0.0052913239073987955
		Inclination		261.6717773200574
		AscendingNode	72.28284123819698
		ArgOfPericen	352.9704083006121
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 177"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.794174447921383
		Eccentricity	0.45384768443222834
		Inclination		-36.122100623776475
		AscendingNode	248.36920421369632
		ArgOfPericen	318.6644428381808
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 177 A"
{
	ParentBody	"HeliosB 177"
	Class		"Asteroid"
	Mass		5.383895255432265e-09
	Radius		12.962879622336647

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014318108344913746
		Eccentricity	0.00428818128204121
		Inclination		15.695686108923459
		AscendingNode	147.95040515420283
		ArgOfPericen	112.92161592146303
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 177 B"
{
	ParentBody	"HeliosB 177"
	Class		"Asteroid"
	Mass		2.092063625398171e-10
	Radius		4.3906375119823

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014318108344913746
		Eccentricity	0.00428818128204121
		Inclination		15.695686108923459
		AscendingNode	147.95040515420283
		ArgOfPericen	292.92161592146306
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 178"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.014290117664258
		Eccentricity	0.46348308129978066
		Inclination		-42.285042730997205
		AscendingNode	158.6419912511873
		ArgOfPericen	92.97138146277713
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 178 A"
{
	ParentBody	"HeliosB 178"
	Class		"Asteroid"
	Mass		1.3540960273306338e-08
	Radius		19.376838717831216

	Orbit
	{
		Epoch			2457395.5
		Period			0.0062809340910616775
		Eccentricity	0.004813389740007812
		Inclination		357.4886219211462
		AscendingNode	251.47585705469305
		ArgOfPericen	332.28097819137395
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 178 B"
{
	ParentBody	"HeliosB 178"
	Class		"Asteroid"
	Mass		9.37216271354227e-10
	Radius		7.95572402947221

	Orbit
	{
		Epoch			2457395.5
		Period			0.0062809340910616775
		Eccentricity	0.004813389740007812
		Inclination		357.4886219211462
		AscendingNode	251.47585705469305
		ArgOfPericen	152.28097819137395
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 179"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.50188260066967e-09
	Radius		14.787499573334905

	RotationPeriod	7.84916695599757

	Obliquity		198.38226027189572

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	1.0624744573846368
		Eccentricity	0.5670405858757839
		Inclination		65.7832909491274
		AscendingNode	122.37968598890421
		ArgOfPericen	311.7748577815031
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 180"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.742238139652007e-09
	Radius		12.619874602709743

	RotationPeriod	8.368762365800851

	Obliquity		169.66102989429334

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.402037802209692
		Eccentricity	0.6671737597063491
		Inclination		-29.09449049072783
		AscendingNode	65.39073903949652
		ArgOfPericen	92.80117045397138
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 181"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.829428273178754
		Eccentricity	0.7506248634735877
		Inclination		-32.53376863453869
		AscendingNode	319.43514877342454
		ArgOfPericen	115.68915097951812
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 181 A"
{
	ParentBody	"HeliosB 181"
	Class		"Asteroid"
	Mass		1.4284557902402702e-09
	Radius		9.134499320941547

	Orbit
	{
		Epoch			2457395.5
		Period			0.006461488378344752
		Eccentricity	0.006178250552453969
		Inclination		195.3903920812158
		AscendingNode	63.917359730285185
		ArgOfPericen	195.33499704942875
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 181 B"
{
	ParentBody	"HeliosB 181"
	Class		"Asteroid"
	Mass		1.4180852986624708e-10
	Radius		4.229573712028189

	Orbit
	{
		Epoch			2457395.5
		Period			0.006461488378344752
		Eccentricity	0.006178250552453969
		Inclination		195.3903920812158
		AscendingNode	63.917359730285185
		ArgOfPericen	15.33499704942875
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 182"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.9771704814518823e-09
	Radius		10.594176644628654

	RotationPeriod	6.398323497200983

	Obliquity		171.08897554009627

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.520901244170112
		Eccentricity	0.31563242680831494
		Inclination		-2.2338227145194436
		AscendingNode	122.70771295567533
		ArgOfPericen	200.25128868303258
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 183"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.2692347832701684e-08
	Radius		17.852711900145348

	RotationPeriod	7.0276094581550295

	Obliquity		73.23456188832978

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.533808352724684
		Eccentricity	0.4034933383875182
		Inclination		-106.89263803688759
		AscendingNode	104.42057281327615
		ArgOfPericen	200.60825459356582
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 184"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.3931946902611993e-09
	Radius		10.208260806576373

	RotationPeriod	9.389938683383066

	Obliquity		288.64802946638395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.911825067505205
		Eccentricity	0.5393486692044454
		Inclination		-54.46944381881023
		AscendingNode	278.79592128221964
		ArgOfPericen	20.683708282543343
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 185"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.825105210820923e-09
	Radius		15.629024554425088

	RotationPeriod	3.508854146163139

	Obliquity		199.3087869942608

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.475649643236965
		Eccentricity	0.518844559964166
		Inclination		3.5626784882093374
		AscendingNode	5.464208377516266
		ArgOfPericen	323.2497931323397
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 186"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		2.2874501026483995e-09
	Radius		10.167978258507686

	RotationPeriod	7.626777709065355

	Obliquity		2.876073298365154

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.802531664608098
		Eccentricity	0.3075268664204855
		Inclination		-51.912162913949984
		AscendingNode	129.13080318665274
		ArgOfPericen	225.32049498041224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 187"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.596540697616577
		Eccentricity	0.3156099499853669
		Inclination		22.898396531926213
		AscendingNode	159.3408055361151
		ArgOfPericen	264.6371762230737
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 187 A"
{
	ParentBody	"HeliosB 187"
	Class		"Asteroid"
	Mass		2.3633669054254525e-10
	Radius		4.517048802195877

	Orbit
	{
		Epoch			2457395.5
		Period			0.005396849021947561
		Eccentricity	0.004921244684550054
		Inclination		16.011704074252634
		AscendingNode	67.03246655728002
		ArgOfPericen	321.8228058377892
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 187 B"
{
	ParentBody	"HeliosB 187"
	Class		"Asteroid"
	Mass		1.1271956885093973e-10
	Radius		3.529210037718606

	Orbit
	{
		Epoch			2457395.5
		Period			0.005396849021947561
		Eccentricity	0.004921244684550054
		Inclination		16.011704074252634
		AscendingNode	67.03246655728002
		ArgOfPericen	141.8228058377892
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 188"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.8817614351741887e-09
	Radius		10.020961018249135

	RotationPeriod	5.958021894714683

	Obliquity		108.09613229526654

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.227873658284324
		Eccentricity	0.5401219966681223
		Inclination		40.16071538114713
		AscendingNode	30.12809711662859
		ArgOfPericen	24.247592255638505
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 189"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		6.734443906087232e-09
	Radius		14.247755406773448

	RotationPeriod	4.062305173057959

	Obliquity		239.64717989670166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.374092794493494
		Eccentricity	0.3241615041096607
		Inclination		3.4016719811325697
		AscendingNode	119.68440854309945
		ArgOfPericen	103.4029850911175
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 190"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.705215351020016
		Eccentricity	0.272748235850867
		Inclination		148.67496644560822
		AscendingNode	219.2708229450579
		ArgOfPericen	318.1389663948101
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 190 A"
{
	ParentBody	"HeliosB 190"
	Class		"Asteroid"
	Mass		4.158790984241253e-09
	Radius		12.523470376735833

	Orbit
	{
		Epoch			2457395.5
		Period			0.0058139563467851955
		Eccentricity	0.0062168078672100256
		Inclination		22.61772358366447
		AscendingNode	76.03008291970451
		ArgOfPericen	198.67992220122022
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 190 B"
{
	ParentBody	"HeliosB 190"
	Class		"Asteroid"
	Mass		9.733362375624727e-11
	Radius		3.5822560576279208

	Orbit
	{
		Epoch			2457395.5
		Period			0.0058139563467851955
		Eccentricity	0.0062168078672100256
		Inclination		22.61772358366447
		AscendingNode	76.03008291970451
		ArgOfPericen	18.679922201220222
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 191"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.6617019791376713e-09
	Radius		11.288799924771519

	RotationPeriod	7.729628504818889

	Obliquity		192.24637874717914

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.89909895203979
		Eccentricity	0.41482076188602324
		Inclination		-25.668918425920015
		AscendingNode	240.3065341247866
		ArgOfPericen	205.86467576866764
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 192"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		3.3056715326644333e-09
	Radius		11.355794508997947

	RotationPeriod	11.91315330987414

	Obliquity		227.73306941552121

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.063061936920898
		Eccentricity	0.27917093376458285
		Inclination		-63.189076053915784
		AscendingNode	252.76268012238862
		ArgOfPericen	77.18381236247893
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 193"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		9.696595940884344e-09
	Radius		16.427788308861963

	RotationPeriod	7.789024724329279

	Obliquity		157.03623083996106

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.024756518670898
		Eccentricity	0.5906708578440877
		Inclination		31.085601737637884
		AscendingNode	15.636111297630627
		ArgOfPericen	112.5079329425003
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 194"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.064078308554239e-09
	Radius		13.075035547952023

	RotationPeriod	4.288468460150838

	Obliquity		254.90800800495654

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.380229393054012
		Eccentricity	0.19534152186355958
		Inclination		-0.3157689494496154
		AscendingNode	163.32535493172549
		ArgOfPericen	77.65917766118446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 195"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.7785532910757447e-08
	Radius		19.979463419709138

	RotationPeriod	5.498279726102662

	Obliquity		148.59338691590577

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.650747271377559
		Eccentricity	0.6164719180773468
		Inclination		5.722200347003804
		AscendingNode	109.49983128320656
		ArgOfPericen	146.9759278571397
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 196"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.970420365700407e-08
	Radius		20.38041481636172

	RotationPeriod	7.0000413407547075

	Obliquity		257.51332505233444

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.986417787820474
		Eccentricity	0.38527020349640173
		Inclination		13.791900157700152
		AscendingNode	137.03223737327332
		ArgOfPericen	291.29914399954015
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 197"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		5.961616946204963e-09
	Radius		13.749118717086972

	RotationPeriod	7.805502261113274

	Obliquity		130.7997637662502

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.144881387199961
		Eccentricity	0.7340223840758334
		Inclination		-47.01462455064494
		AscendingNode	213.9341033284229
		ArgOfPericen	199.19880160582662
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 198"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		1.1411385880758731e-08
	Radius		18.78301031936791

	RotationPeriod	6.513244239768515

	Obliquity		317.19673294804943

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.220492368298405
		Eccentricity	0.31167362813885435
		Inclination		-10.043485601034778
		AscendingNode	319.6071259407759
		ArgOfPericen	291.929280003456
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 199"
{
	ParentBody	"Helios BET"
	Class		"Asteroid"
	Mass		7.373393592048117e-09
	Radius		15.097575137541693

	RotationPeriod	6.1074972479120335

	Obliquity		298.79575800964363

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.61314956614352
		Eccentricity	0.6263358659162255
		Inclination		6.596313417052022
		AscendingNode	318.5563090503103
		ArgOfPericen	34.0152448616881
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosB 200"
{
	ParentBody	"Helios BET"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.293136475741557
		Eccentricity	0.45003572771653233
		Inclination		58.58335543123394
		AscendingNode	204.48870063140214
		ArgOfPericen	87.208316001985
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosB 200 A"
{
	ParentBody	"HeliosB 200"
	Class		"Asteroid"
	Mass		1.1366509348480117e-08
	Radius		18.062606508874065

	Orbit
	{
		Epoch			2457395.5
		Period			0.002104125105955085
		Eccentricity	0.0037750897079935706
		Inclination		342.5065116895087
		AscendingNode	88.47108494033026
		ArgOfPericen	100.49673511072143
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosB 200 B"
{
	ParentBody	"HeliosB 200"
	Class		"Asteroid"
	Mass		2.88351080367658e-09
	Radius		11.43436129979127

	Orbit
	{
		Epoch			2457395.5
		Period			0.002104125105955085
		Eccentricity	0.0037750897079935706
		Inclination		342.5065116895087
		AscendingNode	88.47108494033026
		ArgOfPericen	280.49673511072143
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Helios Gamma comets ---------------------------------------------------------
//------------------------------------------------------------------------------
Barycenter "HeliosC 1"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.198494763558324
		Eccentricity	0.3314678422233879
		Inclination		58.74703269437756
		AscendingNode	89.75815511537095
		ArgOfPericen	240.23123092093644
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 1 A"
{
	ParentBody	"HeliosC 1"
	Class		"Asteroid"
	Mass		9.932910136207214e-11
	Radius		3.4346213293506604

	Orbit
	{
		Epoch			2457395.5
		Period			0.002684245879983551
		Eccentricity	0.0047310204977695424
		Inclination		29.42987392879772
		AscendingNode	291.47976846610084
		ArgOfPericen	138.77273068778536
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 1 B"
{
	ParentBody	"HeliosC 1"
	Class		"Asteroid"
	Mass		2.16412827199163e-11
	Radius		2.0667170707744043

	Orbit
	{
		Epoch			2457395.5
		Period			0.002684245879983551
		Eccentricity	0.0047310204977695424
		Inclination		29.42987392879772
		AscendingNode	291.47976846610084
		ArgOfPericen	318.7727306877854
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 2"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.983246795259754e-10
	Radius		7.580910593556529

	RotationPeriod	3.7780257761592457

	Obliquity		114.02596585906824

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.663056660000162
		Eccentricity	1.0
		Inclination		-83.47073721048002
		AscendingNode	122.54527287178271
		ArgOfPericen	323.71027522734147
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 3"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.287720008287868e-09
	Radius		15.77252559198616

	RotationPeriod	4.404283811651919

	Obliquity		248.30273564865408

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.310061588533074
		Eccentricity	0.5850849179820975
		Inclination		22.268643651767345
		AscendingNode	200.72079753253703
		ArgOfPericen	46.01395535705039
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 4"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.405154358270877e-09
	Radius		12.56209357314147

	RotationPeriod	5.717510247784033

	Obliquity		132.8140000070858

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.578739090792055
		Eccentricity	0.5412577377253374
		Inclination		-11.011684679820045
		AscendingNode	287.42777921517586
		ArgOfPericen	46.93558093047153
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 5"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.72710286783722
		Eccentricity	0.5145360176169717
		Inclination		-50.37205731577889
		AscendingNode	33.50251342942747
		ArgOfPericen	335.2053293604152
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 5 A"
{
	ParentBody	"HeliosC 5"
	Class		"Asteroid"
	Mass		3.313622928015353e-09
	Radius		11.424105119762485

	Orbit
	{
		Epoch			2457395.5
		Period			0.007695127163355981
		Eccentricity	0.005494602084413981
		Inclination		341.6536266533007
		AscendingNode	274.28798766267926
		ArgOfPericen	182.4190049249946
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 5 B"
{
	ParentBody	"HeliosC 5"
	Class		"Asteroid"
	Mass		1.0259186597682285e-09
	Radius		7.72844531188126

	Orbit
	{
		Epoch			2457395.5
		Period			0.007695127163355981
		Eccentricity	0.005494602084413981
		Inclination		341.6536266533007
		AscendingNode	274.28798766267926
		ArgOfPericen	2.419004924994624
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 6"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4544281416427304e-08
	Radius		18.55256236603793

	RotationPeriod	7.325892288197731

	Obliquity		269.0886342025103

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.408950093135502
		Eccentricity	0.42917046792682645
		Inclination		39.23434867384343
		AscendingNode	293.91817964989207
		ArgOfPericen	284.8928293562537
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 7"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.248823292875718e-09
	Radius		13.84743380714386

	RotationPeriod	7.1189348364057174

	Obliquity		337.00704414827754

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.333993452579715
		Eccentricity	0.49499220056678234
		Inclination		-93.5691960664706
		AscendingNode	256.1127795523299
		ArgOfPericen	105.58029953304616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 8"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6885216026795635e-09
	Radius		9.355406420503822

	RotationPeriod	7.687789116642816

	Obliquity		60.92016786752734

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.038804818865799
		Eccentricity	0.6921259875247091
		Inclination		-23.530676522765244
		AscendingNode	175.77421444099554
		ArgOfPericen	35.36439462949306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 9"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.861722412962314e-09
	Radius		15.276055627267839

	RotationPeriod	7.076718837035622

	Obliquity		315.31891842271824

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.287587652035672
		Eccentricity	0.4174479163727377
		Inclination		16.15946303815705
		AscendingNode	289.8508458854691
		ArgOfPericen	199.0603859314766
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 10"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4418982885764476e-08
	Radius		18.40137170382447

	RotationPeriod	4.837417514297832

	Obliquity		127.79749900937104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.67891463959188
		Eccentricity	0.45207093995302017
		Inclination		-36.05962011801509
		AscendingNode	270.89126457154964
		ArgOfPericen	209.5155231773555
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 11"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.727204690502308
		Eccentricity	0.46254958572129873
		Inclination		9.526264586378286
		AscendingNode	171.6796423962203
		ArgOfPericen	290.63153555385395
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 11 A"
{
	ParentBody	"HeliosC 11"
	Class		"Asteroid"
	Mass		8.47133766750765e-09
	Radius		16.34470112568707

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015514898438406123
		Eccentricity	0.005771716953735539
		Inclination		192.1087065910979
		AscendingNode	140.72954395584156
		ArgOfPericen	51.336607089111006
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 11 B"
{
	ParentBody	"HeliosC 11"
	Class		"Asteroid"
	Mass		6.247188997961616e-10
	Radius		6.854164672946739

	Orbit
	{
		Epoch			2457395.5
		Period			0.0015514898438406123
		Eccentricity	0.005771716953735539
		Inclination		192.1087065910979
		AscendingNode	140.72954395584156
		ArgOfPericen	231.336607089111
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 12"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.572880939172657e-10
	Radius		7.8075413929981465

	RotationPeriod	5.492110536730906

	Obliquity		87.10974096153777

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.786332144028432
		Eccentricity	0.30147487016660607
		Inclination		-32.496747506603135
		AscendingNode	211.062179684758
		ArgOfPericen	93.71980666130018
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 13"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.055570567842134e-09
	Radius		14.323155886015426

	RotationPeriod	6.956371320558082

	Obliquity		289.2755548929958

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.552233308687086
		Eccentricity	0.6718335680986461
		Inclination		-57.08148230748967
		AscendingNode	226.02947559062383
		ArgOfPericen	196.9815509821025
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 14"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.74880194179775e-09
	Radius		12.161518669640689

	RotationPeriod	6.761390313261543

	Obliquity		339.2782859963555

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.284859724449262
		Eccentricity	0.4775086107409924
		Inclination		-83.09757761365043
		AscendingNode	58.56291465343323
		ArgOfPericen	167.5212287736371
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 15"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2880788095975056e-09
	Radius		10.25919908659621

	RotationPeriod	6.075658929709126

	Obliquity		197.7427244416107

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.673376186706804
		Eccentricity	0.5393037735595363
		Inclination		-3.8577146339767157
		AscendingNode	243.87662785242156
		ArgOfPericen	0.3410335864934222
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 16"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9269516683583067e-09
	Radius		9.651330366538293

	RotationPeriod	4.224590214347744

	Obliquity		162.48134452484487

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.485859355645474
		Eccentricity	0.8204758644230934
		Inclination		-68.44536202348219
		AscendingNode	272.52076225384275
		ArgOfPericen	273.5009248002556
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 17"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.015938882154167e-09
	Radius		13.747134992935143

	RotationPeriod	4.121101663680033

	Obliquity		47.117747375538414

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.304426384897063
		Eccentricity	0.3126743576513918
		Inclination		18.704149032054172
		AscendingNode	116.1545459125807
		ArgOfPericen	188.78071373304755
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 18"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.233783676430528e-09
	Radius		11.094774020384737

	RotationPeriod	5.966966109642414

	Obliquity		296.11032699553823

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.686370740436235
		Eccentricity	0.25662314743835163
		Inclination		63.55273441269671
		AscendingNode	95.29327473931713
		ArgOfPericen	81.66552944628384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 19"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.572248499599292e-09
	Radius		17.105259778860233

	RotationPeriod	9.351101129480499

	Obliquity		222.1377673866104

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.956606420928814
		Eccentricity	0.599245659024398
		Inclination		24.238798886726833
		AscendingNode	60.67225732090138
		ArgOfPericen	214.20816364735143
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 20"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6226155470977456e-09
	Radius		9.352137450396095

	RotationPeriod	5.9103215090052545

	Obliquity		0.61052003748999

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.5084949794626
		Eccentricity	0.38804801458737037
		Inclination		-121.33374958112893
		AscendingNode	240.60888035991493
		ArgOfPericen	85.97230948071233
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 21"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5069308052616937e-09
	Radius		8.902032768500298

	RotationPeriod	6.019767422085523

	Obliquity		333.7808754960786

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.325829470646976
		Eccentricity	0.46473032960787103
		Inclination		-1.0544032642010048
		AscendingNode	101.58114619424128
		ArgOfPericen	293.64541847109945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 22"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.124246302247062
		Eccentricity	0.5470266034859069
		Inclination		-31.907875763165976
		AscendingNode	150.1084877577781
		ArgOfPericen	59.39633662055522
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 22 A"
{
	ParentBody	"HeliosC 22"
	Class		"Asteroid"
	Mass		2.3753513388847896e-09
	Radius		10.898993838289577

	Orbit
	{
		Epoch			2457395.5
		Period			0.006140214899922578
		Eccentricity	0.004782293532054967
		Inclination		220.7832180598282
		AscendingNode	142.31812983895117
		ArgOfPericen	257.81066640690466
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 22 B"
{
	ParentBody	"HeliosC 22"
	Class		"Asteroid"
	Mass		2.965992071263783e-10
	Radius		5.447540284364017

	Orbit
	{
		Epoch			2457395.5
		Period			0.006140214899922578
		Eccentricity	0.004782293532054967
		Inclination		220.7832180598282
		AscendingNode	142.31812983895117
		ArgOfPericen	77.81066640690466
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 23"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.950988865420854
		Eccentricity	0.607770063043046
		Inclination		49.78515687096756
		AscendingNode	138.14148421242436
		ArgOfPericen	249.25896618642446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 23 A"
{
	ParentBody	"HeliosC 23"
	Class		"Asteroid"
	Mass		4.68855316098776e-09
	Radius		13.6895830144182

	Orbit
	{
		Epoch			2457395.5
		Period			0.004264022528616903
		Eccentricity	0.004853858416011767
		Inclination		104.71947045586337
		AscendingNode	211.27632663695917
		ArgOfPericen	109.0392762266254
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 23 B"
{
	ParentBody	"HeliosC 23"
	Class		"Asteroid"
	Mass		4.09099149308124e-09
	Radius		13.081377048245562

	Orbit
	{
		Epoch			2457395.5
		Period			0.004264022528616903
		Eccentricity	0.004853858416011767
		Inclination		104.71947045586337
		AscendingNode	211.27632663695917
		ArgOfPericen	289.0392762266254
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 24"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.083882224686858e-09
	Radius		14.84283649270494

	RotationPeriod	5.428733414327083

	Obliquity		19.273742537422752

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.926165137757394
		Eccentricity	0.3610047869306737
		Inclination		41.937815749867426
		AscendingNode	152.30766673704693
		ArgOfPericen	210.615765238993
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 25"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1630569810317831e-08
	Radius		18.47820351735679

	RotationPeriod	7.710306004212068

	Obliquity		121.05217856298711

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.376426459280983
		Eccentricity	0.5861933400925969
		Inclination		55.77758276812623
		AscendingNode	153.50093576318642
		ArgOfPericen	323.8572681330259
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 26"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.812196540428976e-09
	Radius		14.00508095395693

	RotationPeriod	3.888019539583596

	Obliquity		159.06029337981096

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.02796457957143
		Eccentricity	0.4135786876108901
		Inclination		-75.21656961639287
		AscendingNode	258.1702089462954
		ArgOfPericen	141.42645475144457
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 27"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.7145709380810883e-09
	Radius		10.730822824883276

	RotationPeriod	2.2009016421094576

	Obliquity		233.94834560387375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.423691224690877
		Eccentricity	0.5463264818225002
		Inclination		-42.82597305360869
		AscendingNode	64.08440215949331
		ArgOfPericen	345.26599456297043
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 28"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.2635573521504175e-09
	Radius		14.53709779034091

	RotationPeriod	4.310990792043016

	Obliquity		45.34508480567546

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.964703489327153
		Eccentricity	0.5750082941893329
		Inclination		14.894917781112987
		AscendingNode	251.30216429926108
		ArgOfPericen	0.20690077448866973
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 29"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0802465958620433e-08
	Radius		17.168439492735725

	RotationPeriod	5.987200364051796

	Obliquity		289.55146878307886

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.7909015063195
		Eccentricity	0.8337614046172892
		Inclination		-3.366840556490264
		AscendingNode	325.43114922538047
		ArgOfPericen	100.59098111166666
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 30"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2849257254004147e-09
	Radius		10.557352257654859

	RotationPeriod	7.020348158443116

	Obliquity		2.1513550042715224

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.02104854527854
		Eccentricity	0.34001860723380584
		Inclination		-86.70769390727746
		AscendingNode	140.70719227481496
		ArgOfPericen	356.83796899827627
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 31"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4272969365317584e-08
	Radius		18.46670068942529

	RotationPeriod	7.617243395027618

	Obliquity		249.54295939404057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.503612418964657
		Eccentricity	0.3090394497349028
		Inclination		32.0673646483713
		AscendingNode	28.75700147336054
		ArgOfPericen	158.20054738632786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 32"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.17377227811017e-08
	Radius		17.73744212209506

	RotationPeriod	3.76478624162099

	Obliquity		353.89286175144167

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.09371764122744
		Eccentricity	0.27514190481057976
		Inclination		58.598833415046336
		AscendingNode	322.05317033611016
		ArgOfPericen	261.0487624128896
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 33"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.25723049605549
		Eccentricity	0.3119769556008413
		Inclination		-65.92147722980155
		AscendingNode	66.86654738143483
		ArgOfPericen	218.16966065899436
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 33 A"
{
	ParentBody	"HeliosC 33"
	Class		"Asteroid"
	Mass		1.1950601419286851e-09
	Radius		8.611768341725158

	Orbit
	{
		Epoch			2457395.5
		Period			0.0073607365994678665
		Eccentricity	0.0045960641430183085
		Inclination		47.885523863565204
		AscendingNode	248.26408294818773
		ArgOfPericen	57.64232639077014
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 33 B"
{
	ParentBody	"HeliosC 33"
	Class		"Asteroid"
	Mass		5.413619789578983e-10
	Radius		6.613910825567257

	Orbit
	{
		Epoch			2457395.5
		Period			0.0073607365994678665
		Eccentricity	0.0045960641430183085
		Inclination		47.885523863565204
		AscendingNode	248.26408294818773
		ArgOfPericen	237.64232639077014
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 34"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.293922295581092e-08
	Radius		18.802810646416074

	RotationPeriod	6.397604477965964

	Obliquity		225.69260870943248

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.64632202390151
		Eccentricity	0.49392258322560745
		Inclination		76.08912936972474
		AscendingNode	16.4461152180596
		ArgOfPericen	69.69486084518424
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 35"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.696378049404975e-09
	Radius		15.69824207953729

	RotationPeriod	7.343617120806069

	Obliquity		36.18652814017125

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.009012999789046
		Eccentricity	0.4059559460873021
		Inclination		72.09772010980542
		AscendingNode	14.40292180395863
		ArgOfPericen	286.1058609324597
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 36"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.048985564600692e-09
	Radius		14.52957557160944

	RotationPeriod	8.034522720347889

	Obliquity		168.74684146425173

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.128481388402843
		Eccentricity	0.7948085403388557
		Inclination		13.577770540408448
		AscendingNode	173.8715292875372
		ArgOfPericen	312.59127790031323
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 37"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.180586285237254
		Eccentricity	0.5526790292449183
		Inclination		32.43383789279328
		AscendingNode	44.52175086512106
		ArgOfPericen	220.3838229144108
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 37 A"
{
	ParentBody	"HeliosC 37"
	Class		"Asteroid"
	Mass		6.114802608408587e-09
	Radius		14.701970087649883

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024363353790888254
		Eccentricity	0.005316012860438027
		Inclination		239.50203757425467
		AscendingNode	287.5987864729232
		ArgOfPericen	300.28333368472886
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 37 B"
{
	ParentBody	"HeliosC 37"
	Class		"Asteroid"
	Mass		4.279465189857143e-09
	Radius		13.053026512089673

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024363353790888254
		Eccentricity	0.005316012860438027
		Inclination		239.50203757425467
		AscendingNode	287.5987864729232
		ArgOfPericen	120.28333368472886
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 38"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1833534950877111e-09
	Radius		8.033424123132512

	RotationPeriod	6.159736704363354

	Obliquity		219.20470051501167

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.78776179372841
		Eccentricity	0.4080737172414498
		Inclination		-22.975809587438665
		AscendingNode	332.6619823192283
		ArgOfPericen	343.60000360162917
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 39"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.256721643159487
		Eccentricity	0.17407085156160934
		Inclination		-12.141937626828051
		AscendingNode	169.29971349314405
		ArgOfPericen	210.0985742698588
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 39 A"
{
	ParentBody	"HeliosC 39"
	Class		"Asteroid"
	Mass		1.2485848597916345e-08
	Radius		17.162333698324908

	Orbit
	{
		Epoch			2457395.5
		Period			0.00590457266119929
		Eccentricity	0.006133905712860478
		Inclination		3.8175094990112868
		AscendingNode	128.41255716486666
		ArgOfPericen	322.3479417644229
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 39 B"
{
	ParentBody	"HeliosC 39"
	Class		"Asteroid"
	Mass		2.7549024646320325e-10
	Radius		4.813626577584856

	Orbit
	{
		Epoch			2457395.5
		Period			0.00590457266119929
		Eccentricity	0.006133905712860478
		Inclination		3.8175094990112868
		AscendingNode	128.41255716486666
		ArgOfPericen	142.3479417644229
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 40"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.060836897741446
		Eccentricity	0.184005440732174
		Inclination		-121.86925145895218
		AscendingNode	140.40435437134926
		ArgOfPericen	281.315435191273
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 40 A"
{
	ParentBody	"HeliosC 40"
	Class		"Asteroid"
	Mass		7.976204743824491e-09
	Radius		14.34179634797166

	Orbit
	{
		Epoch			2457395.5
		Period			0.005676490051361749
		Eccentricity	0.005044020488926212
		Inclination		218.57110794146166
		AscendingNode	324.9536714930717
		ArgOfPericen	232.30586790188428
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 40 B"
{
	ParentBody	"HeliosC 40"
	Class		"Asteroid"
	Mass		1.9651151399688637e-10
	Radius		4.173183234695888

	Orbit
	{
		Epoch			2457395.5
		Period			0.005676490051361749
		Eccentricity	0.005044020488926212
		Inclination		218.57110794146166
		AscendingNode	324.9536714930717
		ArgOfPericen	52.30586790188431
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 41"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.540497272646307e-09
	Radius		13.617231788955321

	RotationPeriod	7.241822025800115

	Obliquity		267.38565776192115

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.856255359855936
		Eccentricity	0.897953546660478
		Inclination		14.383689304355924
		AscendingNode	271.8775531655949
		ArgOfPericen	110.16904344221159
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 42"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.562419507285721e-09
	Radius		9.925875542528852

	RotationPeriod	5.491881778851563

	Obliquity		237.35752894327723

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.26184116136897
		Eccentricity	0.37403750359567034
		Inclination		-11.341059311526251
		AscendingNode	231.43390200901763
		ArgOfPericen	79.56977178556767
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 43"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.391949177312627e-11
	Radius		2.9990716487738958

	RotationPeriod	4.781649090905395

	Obliquity		314.06736920461464

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.436764040052783
		Eccentricity	0.40030821927630605
		Inclination		84.52959343923268
		AscendingNode	229.05742242649163
		ArgOfPericen	208.7892444932006
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 44"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.599145315190802e-10
	Radius		7.32932535892537

	RotationPeriod	7.6502085106234965

	Obliquity		271.6054822943874

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.48604518007718
		Eccentricity	0.36233826720985823
		Inclination		46.24669648404283
		AscendingNode	149.7018945556164
		ArgOfPericen	353.7556738912402
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 45"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.14197764528945
		Eccentricity	0.6627414443710125
		Inclination		70.68244720985825
		AscendingNode	94.73077284763066
		ArgOfPericen	148.1032947429093
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 45 A"
{
	ParentBody	"HeliosC 45"
	Class		"Asteroid"
	Mass		2.8377496828834655e-10
	Radius		5.1416216127530925

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012544065957921467
		Eccentricity	0.005337174823636268
		Inclination		152.52176798821966
		AscendingNode	87.26407199250922
		ArgOfPericen	49.78348617279358
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 45 B"
{
	ParentBody	"HeliosC 45"
	Class		"Asteroid"
	Mass		2.741000652107575e-11
	Radius		2.359093374036145

	Orbit
	{
		Epoch			2457395.5
		Period			0.0012544065957921467
		Eccentricity	0.005337174823636268
		Inclination		152.52176798821966
		AscendingNode	87.26407199250922
		ArgOfPericen	229.78348617279357
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 46"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.823783316970354e-08
	Radius		20.404637952675262

	RotationPeriod	5.498022304199351

	Obliquity		45.990818825935825

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.410166794929722
		Eccentricity	0.36380018512599177
		Inclination		90.97265898972711
		AscendingNode	209.28641998640435
		ArgOfPericen	178.80273126413852
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 47"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.333605790648724
		Eccentricity	0.9723178244691362
		Inclination		28.35219273936571
		AscendingNode	293.65154666304176
		ArgOfPericen	192.78990191330334
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 47 A"
{
	ParentBody	"HeliosC 47"
	Class		"Asteroid"
	Mass		2.037976518699375e-09
	Radius		10.039058239857802

	Orbit
	{
		Epoch			2457395.5
		Period			0.007909976974047616
		Eccentricity	0.002873942044382679
		Inclination		359.5943867729088
		AscendingNode	82.67517917530505
		ArgOfPericen	3.561226494601901
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 47 B"
{
	ParentBody	"HeliosC 47"
	Class		"Asteroid"
	Mass		3.793181555386444e-10
	Radius		5.73184527389226

	Orbit
	{
		Epoch			2457395.5
		Period			0.007909976974047616
		Eccentricity	0.002873942044382679
		Inclination		359.5943867729088
		AscendingNode	82.67517917530505
		ArgOfPericen	183.5612264946019
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 48"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.743926048414952e-09
	Radius		16.06469722018057

	RotationPeriod	6.457656117690275

	Obliquity		217.26864119517603

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.69564526291107
		Eccentricity	0.4218839704839585
		Inclination		-2.8385952536895362
		AscendingNode	138.16386531711578
		ArgOfPericen	59.487654466680475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 49"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.533815980371596
		Eccentricity	0.5783918626842736
		Inclination		18.50230438340691
		AscendingNode	246.63177660184348
		ArgOfPericen	144.01729597486738
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 49 A"
{
	ParentBody	"HeliosC 49"
	Class		"Asteroid"
	Mass		2.5492802476384202e-09
	Radius		11.396434616004482

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024471958160927967
		Eccentricity	0.005486527110152906
		Inclination		62.40978430247199
		AscendingNode	156.3012995223258
		ArgOfPericen	114.04439022572853
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 49 B"
{
	ParentBody	"HeliosC 49"
	Class		"Asteroid"
	Mass		1.3848305259001157e-10
	Radius		4.316138301245066

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024471958160927967
		Eccentricity	0.005486527110152906
		Inclination		62.40978430247199
		AscendingNode	156.3012995223258
		ArgOfPericen	294.04439022572853
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 50"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.311457200588542e-12
	Radius		1.476402991604827

	RotationPeriod	7.603684527870297

	Obliquity		60.09999101600725

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.810964775505642
		Eccentricity	0.4723509352638925
		Inclination		-64.40532870503341
		AscendingNode	216.6270348393938
		ArgOfPericen	228.9072604801631
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 51"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4642995313711646e-08
	Radius		19.273251707476412

	RotationPeriod	5.031690138839451

	Obliquity		3.325296105702318

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.72931970048448
		Eccentricity	0.2653850423271286
		Inclination		71.12788556535935
		AscendingNode	117.18743791489743
		ArgOfPericen	189.19027568405204
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 52"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.446277797819102e-09
	Radius		12.148163802550332

	RotationPeriod	4.715878981596774

	Obliquity		48.56823216312772

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.842886615691956
		Eccentricity	0.6173828636654491
		Inclination		-101.20314004922453
		AscendingNode	240.70154354024967
		ArgOfPericen	148.28920570503908
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 53"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.3116805160155206e-10
	Radius		4.947511264798566

	RotationPeriod	3.5544244121571937

	Obliquity		120.07157693793202

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.8045865670331
		Eccentricity	0.6210153591162993
		Inclination		-71.61033903384796
		AscendingNode	17.78062166815221
		ArgOfPericen	285.75543106726406
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 54"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.314047460058704e-10
	Radius		5.2922330814151275

	RotationPeriod	4.8062370173677404

	Obliquity		112.81383276713507

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.54411257003764
		Eccentricity	0.524010493790984
		Inclination		-43.256481245703775
		AscendingNode	302.8796867139941
		ArgOfPericen	265.96141334967956
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 55"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.129940516300959e-08
	Radius		21.89094058287487

	RotationPeriod	10.409064366640983

	Obliquity		279.92690679405655

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.29613500177848
		Eccentricity	0.5984991696865913
		Inclination		-14.165378196035574
		AscendingNode	257.5256891085998
		ArgOfPericen	144.36524177787356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 56"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.785895704064934
		Eccentricity	0.4769128061334814
		Inclination		-9.062738303158456
		AscendingNode	63.28838408822613
		ArgOfPericen	149.95855269425323
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 56 A"
{
	ParentBody	"HeliosC 56"
	Class		"Asteroid"
	Mass		1.5321118316257286e-10
	Radius		4.212831770287972

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024438820917516767
		Eccentricity	0.004461178530542408
		Inclination		128.73432972286457
		AscendingNode	99.04404033436367
		ArgOfPericen	242.01027358129053
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 56 B"
{
	ParentBody	"HeliosC 56"
	Class		"Asteroid"
	Mass		4.317219471368442e-12
	Radius		1.2819723860893837

	Orbit
	{
		Epoch			2457395.5
		Period			0.0024438820917516767
		Eccentricity	0.004461178530542408
		Inclination		128.73432972286457
		AscendingNode	99.04404033436367
		ArgOfPericen	62.01027358129056
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 57"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.24353250512649
		Eccentricity	0.6695567576483797
		Inclination		9.59212517673216
		AscendingNode	221.69140940702655
		ArgOfPericen	261.37767076595003
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 57 A"
{
	ParentBody	"HeliosC 57"
	Class		"Asteroid"
	Mass		1.3357472776745435e-10
	Radius		3.905279367737217

	Orbit
	{
		Epoch			2457395.5
		Period			0.002967656952380769
		Eccentricity	0.0056811616386591044
		Inclination		28.391272073486284
		AscendingNode	227.51172855476585
		ArgOfPericen	194.59712683526803
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 57 B"
{
	ParentBody	"HeliosC 57"
	Class		"Asteroid"
	Mass		2.3265492891882657e-11
	Radius		2.180961974526904

	Orbit
	{
		Epoch			2457395.5
		Period			0.002967656952380769
		Eccentricity	0.0056811616386591044
		Inclination		28.391272073486284
		AscendingNode	227.51172855476585
		ArgOfPericen	14.597126835268
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 58"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6096347329836313e-09
	Radius		8.988452973565922

	RotationPeriod	8.865854260897693

	Obliquity		248.63399418695488

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.868967790221422
		Eccentricity	0.5516520153309171
		Inclination		69.26175960752647
		AscendingNode	75.71726399753591
		ArgOfPericen	13.075914210846552
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 59"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8094752142072257e-09
	Radius		9.350762315282983

	RotationPeriod	0.2384052535968486

	Obliquity		58.95126789052835

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.463916203530474
		Eccentricity	0.5248908949564958
		Inclination		-119.34518103923223
		AscendingNode	329.90291463282944
		ArgOfPericen	184.67254831118345
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 60"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0008505320535032e-08
	Radius		16.506862399392872

	RotationPeriod	7.8394197445411775

	Obliquity		86.88702491048787

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.205122963359045
		Eccentricity	0.771855150271939
		Inclination		18.20135412414651
		AscendingNode	110.1065488186125
		ArgOfPericen	40.42091122811202
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 61"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3900102772811124e-09
	Radius		8.395635095495543

	RotationPeriod	8.928883143026926

	Obliquity		125.4218319573761

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	47.19362701049039
		Eccentricity	0.13547133745682788
		Inclination		33.01267688689877
		AscendingNode	279.09277927074
		ArgOfPericen	133.6485697108474
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 62"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.971976734173386e-09
	Radius		15.554534204048487

	RotationPeriod	4.4087291448482

	Obliquity		218.03344824964827

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.263485199440524
		Eccentricity	0.30913734866645115
		Inclination		-8.093318296296436
		AscendingNode	354.84488118703086
		ArgOfPericen	260.460707130725
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 63"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3841927983462205e-08
	Radius		19.164600986526228

	RotationPeriod	6.592405799810979

	Obliquity		192.77419666687996

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.263904615809366
		Eccentricity	0.1996773288973886
		Inclination		55.835016959284545
		AscendingNode	181.20820149155983
		ArgOfPericen	51.75713474555042
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 64"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.858609759828038
		Eccentricity	0.3868865822113142
		Inclination		-36.81397753055376
		AscendingNode	295.70654064182224
		ArgOfPericen	11.16108746612188
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 64 A"
{
	ParentBody	"HeliosC 64"
	Class		"Asteroid"
	Mass		2.5122857349964948e-09
	Radius		10.478198605268524

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010426450422391606
		Eccentricity	0.00354578009983492
		Inclination		289.3845190503367
		AscendingNode	157.26135128908612
		ArgOfPericen	62.99256591666258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 64 B"
{
	ParentBody	"HeliosC 64"
	Class		"Asteroid"
	Mass		5.538356817227663e-10
	Radius		6.329808810917061

	Orbit
	{
		Epoch			2457395.5
		Period			0.0010426450422391606
		Eccentricity	0.00354578009983492
		Inclination		289.3845190503367
		AscendingNode	157.26135128908612
		ArgOfPericen	242.99256591666258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 65"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.862214092459903e-09
	Radius		17.21947648853841

	RotationPeriod	5.623352828912415

	Obliquity		103.07279886720073

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.222155184144704
		Eccentricity	0.5599774292143683
		Inclination		107.076581260079
		AscendingNode	245.69217852044542
		ArgOfPericen	113.1018813537759
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 66"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.250905711710642
		Eccentricity	0.4607305503523798
		Inclination		-34.35234784874655
		AscendingNode	61.873938633340316
		ArgOfPericen	51.97815403730666
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 66 A"
{
	ParentBody	"HeliosC 66"
	Class		"Asteroid"
	Mass		2.8558535423029637e-09
	Radius		11.425204231522255

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003390371555676439
		Eccentricity	0.005242662595507768
		Inclination		133.22362400540874
		AscendingNode	228.4054717719396
		ArgOfPericen	258.59324022837586
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 66 B"
{
	ParentBody	"HeliosC 66"
	Class		"Asteroid"
	Mass		5.202484092786264e-11
	Radius		3.0062303051247126

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003390371555676439
		Eccentricity	0.005242662595507768
		Inclination		133.22362400540874
		AscendingNode	228.4054717719396
		ArgOfPericen	78.59324022837586
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 67"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.306125808350364
		Eccentricity	0.3435595398189465
		Inclination		26.860690847081578
		AscendingNode	263.9852236262692
		ArgOfPericen	183.32367650762646
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 67 A"
{
	ParentBody	"HeliosC 67"
	Class		"Asteroid"
	Mass		2.184130583783406e-08
	Radius		21.54650693951716

	Orbit
	{
		Epoch			2457395.5
		Period			0.007286773758052299
		Eccentricity	0.005056650331411228
		Inclination		290.3297578039867
		AscendingNode	324.19667832857647
		ArgOfPericen	217.92898664203585
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 67 B"
{
	ParentBody	"HeliosC 67"
	Class		"Asteroid"
	Mass		1.2169461558862078e-09
	Radius		8.229519170151459

	Orbit
	{
		Epoch			2457395.5
		Period			0.007286773758052299
		Eccentricity	0.005056650331411228
		Inclination		290.3297578039867
		AscendingNode	324.19667832857647
		ArgOfPericen	37.92898664203585
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 68"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.076429280034633e-09
	Radius		15.259645054045034

	RotationPeriod	5.095421263425844

	Obliquity		9.20082466577179

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.067246308707674
		Eccentricity	0.37104442126622517
		Inclination		26.96405393596882
		AscendingNode	310.1410010048654
		ArgOfPericen	280.20634682983075
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 69"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.504036329922247e-08
	Radius		18.13514934556204

	RotationPeriod	5.771736609589614

	Obliquity		55.30895520598121

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.793955744720849
		Eccentricity	0.12536361292450582
		Inclination		44.935965758195
		AscendingNode	119.56821657639719
		ArgOfPericen	177.4172930077085
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 70"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0838369736234762e-08
	Radius		16.782289249846954

	RotationPeriod	2.423546819606453

	Obliquity		218.41681182115738

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.48259417782893
		Eccentricity	0.5317020975793219
		Inclination		24.08360450101887
		AscendingNode	193.42313615504116
		ArgOfPericen	293.02663559514053
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 71"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.159455631021412
		Eccentricity	0.49457580387665
		Inclination		27.90132334105312
		AscendingNode	57.99105661587313
		ArgOfPericen	31.201258323889007
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 71 A"
{
	ParentBody	"HeliosC 71"
	Class		"Asteroid"
	Mass		2.792323155820065e-09
	Radius		11.051670611450813

	Orbit
	{
		Epoch			2457395.5
		Period			0.002484018191720867
		Eccentricity	0.0060499337842778176
		Inclination		267.0864036087901
		AscendingNode	72.83326034285444
		ArgOfPericen	126.16708592245679
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 71 B"
{
	ParentBody	"HeliosC 71"
	Class		"Asteroid"
	Mass		6.057345355143514e-10
	Radius		6.64049037773783

	Orbit
	{
		Epoch			2457395.5
		Period			0.002484018191720867
		Eccentricity	0.0060499337842778176
		Inclination		267.0864036087901
		AscendingNode	72.83326034285444
		ArgOfPericen	306.1670859224568
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 72"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.9559283281582335e-09
	Radius		11.531922352139418

	RotationPeriod	7.881164620083109

	Obliquity		81.94744337920906

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.899594601519745
		Eccentricity	0.5712924638911278
		Inclination		-24.76391217951516
		AscendingNode	181.24144319568478
		ArgOfPericen	347.778094100805
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 73"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.171387193219367e-09
	Radius		13.472326452706493

	RotationPeriod	8.651345583657715

	Obliquity		231.6335837724273

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.465360724040522
		Eccentricity	0.7073003165778551
		Inclination		14.672763397962912
		AscendingNode	246.5096165914522
		ArgOfPericen	200.3001236209519
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 74"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.974366390985665
		Eccentricity	0.4189330831450069
		Inclination		-14.811702833528855
		AscendingNode	29.54698303396195
		ArgOfPericen	192.35545525873408
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 74 A"
{
	ParentBody	"HeliosC 74"
	Class		"Asteroid"
	Mass		2.5331545215152393e-09
	Radius		10.58880933085576

	Orbit
	{
		Epoch			2457395.5
		Period			0.000524722066599033
		Eccentricity	0.003968021194884647
		Inclination		132.11062713069586
		AscendingNode	156.95963218736438
		ArgOfPericen	262.1540640121058
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 74 B"
{
	ParentBody	"HeliosC 74"
	Class		"Asteroid"
	Mass		9.331690973014867e-10
	Radius		7.590668351554481

	Orbit
	{
		Epoch			2457395.5
		Period			0.000524722066599033
		Eccentricity	0.003968021194884647
		Inclination		132.11062713069586
		AscendingNode	156.95963218736438
		ArgOfPericen	82.15406401210578
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 75"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.59823430734001
		Eccentricity	0.4244058393127745
		Inclination		28.781219186577207
		AscendingNode	211.13457173538967
		ArgOfPericen	225.82629307140917
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 75 A"
{
	ParentBody	"HeliosC 75"
	Class		"Asteroid"
	Mass		1.9887225612352288e-09
	Radius		9.787397028990519

	Orbit
	{
		Epoch			2457395.5
		Period			0.00287555480672997
		Eccentricity	0.0040536309127081225
		Inclination		243.89142212175653
		AscendingNode	187.16589254444844
		ArgOfPericen	199.83381730679207
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 75 B"
{
	ParentBody	"HeliosC 75"
	Class		"Asteroid"
	Mass		1.7350735020872579e-09
	Radius		9.352228261765761

	Orbit
	{
		Epoch			2457395.5
		Period			0.00287555480672997
		Eccentricity	0.0040536309127081225
		Inclination		243.89142212175653
		AscendingNode	187.16589254444844
		ArgOfPericen	19.83381730679207
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 76"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5253379741733281e-09
	Radius		9.441233048150599

	RotationPeriod	4.933100879227423

	Obliquity		263.8133510956037

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.944632772627486
		Eccentricity	0.467981157415527
		Inclination		-5.0235486822231685
		AscendingNode	175.84714033134642
		ArgOfPericen	169.87141184527584
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 77"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.945759320385853e-09
	Radius		15.122852630307005

	RotationPeriod	6.625139855218402

	Obliquity		213.9299695093015

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.27911139468058
		Eccentricity	0.41382320630364094
		Inclination		-8.942168152896564
		AscendingNode	339.81900690617636
		ArgOfPericen	137.2483894370396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 78"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.725795731663915
		Eccentricity	0.4990073648192651
		Inclination		-99.8861346577054
		AscendingNode	58.323610983837554
		ArgOfPericen	174.78576071155808
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 78 A"
{
	ParentBody	"HeliosC 78"
	Class		"Asteroid"
	Mass		2.9961834717352916e-09
	Radius		11.705377181941131

	Orbit
	{
		Epoch			2457395.5
		Period			0.006655507178716873
		Eccentricity	0.008251087164449764
		Inclination		27.78610352671282
		AscendingNode	193.6891892980029
		ArgOfPericen	179.3075508194013
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 78 B"
{
	ParentBody	"HeliosC 78"
	Class		"Asteroid"
	Mass		1.7487368174798917e-10
	Radius		4.540504346589951

	Orbit
	{
		Epoch			2457395.5
		Period			0.006655507178716873
		Eccentricity	0.008251087164449764
		Inclination		27.78610352671282
		AscendingNode	193.6891892980029
		ArgOfPericen	359.3075508194013
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 79"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0414399472593316e-08
	Radius		16.75712497341219

	RotationPeriod	5.7829563730473055

	Obliquity		84.34078738385045

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.467969526929988
		Eccentricity	0.37303048560589186
		Inclination		-43.070217696124885
		AscendingNode	251.8645254564256
		ArgOfPericen	291.6782608598798
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 80"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.499725165139662
		Eccentricity	0.3002243202205204
		Inclination		76.29374920306051
		AscendingNode	125.5968700217294
		ArgOfPericen	29.92330666252724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 80 A"
{
	ParentBody	"HeliosC 80"
	Class		"Asteroid"
	Mass		3.707906530971924e-09
	Radius		11.700873595471162

	Orbit
	{
		Epoch			2457395.5
		Period			0.005816438389564836
		Eccentricity	0.0058160601161106095
		Inclination		200.82774995801608
		AscendingNode	304.1054961832064
		ArgOfPericen	54.084314721558535
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 80 B"
{
	ParentBody	"HeliosC 80"
	Class		"Asteroid"
	Mass		1.6216779434112437e-10
	Radius		4.122527534674754

	Orbit
	{
		Epoch			2457395.5
		Period			0.005816438389564836
		Eccentricity	0.0058160601161106095
		Inclination		200.82774995801608
		AscendingNode	304.1054961832064
		ArgOfPericen	234.08431472155854
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 81"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.656427707996153e-09
	Radius		12.092623143906458

	RotationPeriod	1.8107563427885278

	Obliquity		127.5967393019829

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.6896744636307
		Eccentricity	0.3587097915685712
		Inclination		-50.26853015383726
		AscendingNode	205.36383905508674
		ArgOfPericen	280.45426541727943
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 82"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.609824365715863
		Eccentricity	0.16614591018463915
		Inclination		133.491637217596
		AscendingNode	313.6586152671957
		ArgOfPericen	104.08807209115429
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 82 A"
{
	ParentBody	"HeliosC 82"
	Class		"Asteroid"
	Mass		3.5597285026333808e-09
	Radius		11.855837275287943

	Orbit
	{
		Epoch			2457395.5
		Period			0.000415048037262295
		Eccentricity	0.0036945255178163676
		Inclination		41.273989164946556
		AscendingNode	159.40610922598907
		ArgOfPericen	278.784484312882
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 82 B"
{
	ParentBody	"HeliosC 82"
	Class		"Asteroid"
	Mass		1.0092780178988166e-09
	Radius		7.788674289283519

	Orbit
	{
		Epoch			2457395.5
		Period			0.000415048037262295
		Eccentricity	0.0036945255178163676
		Inclination		41.273989164946556
		AscendingNode	159.40610922598907
		ArgOfPericen	98.784484312882
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 83"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.551445507629732e-09
	Radius		13.185990413904694

	RotationPeriod	7.622329661555643

	Obliquity		244.0163218389077

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.37289809674016
		Eccentricity	0.5644260063251664
		Inclination		-107.87240748983831
		AscendingNode	239.07424780884284
		ArgOfPericen	31.78750873641952
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 84"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.36719274231949
		Eccentricity	0.5091690722108204
		Inclination		18.233018277104655
		AscendingNode	222.8730138474999
		ArgOfPericen	261.4275321876445
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 84 A"
{
	ParentBody	"HeliosC 84"
	Class		"Asteroid"
	Mass		2.9640659837478657e-10
	Radius		5.454883746115335

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018432381325710135
		Eccentricity	0.0037379214671377442
		Inclination		35.75135499320431
		AscendingNode	310.4025536917908
		ArgOfPericen	20.420894651841934
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 84 B"
{
	ParentBody	"HeliosC 84"
	Class		"Asteroid"
	Mass		2.2867168173380588e-10
	Radius		5.002959711082006

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018432381325710135
		Eccentricity	0.0037379214671377442
		Inclination		35.75135499320431
		AscendingNode	310.4025536917908
		ArgOfPericen	200.42089465184193
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 85"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.080987119102252e-09
	Radius		16.84333585834007

	RotationPeriod	7.3631835084747665

	Obliquity		239.01257752576728

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.16248567878576
		Eccentricity	0.669890481856407
		Inclination		27.557470613775013
		AscendingNode	114.07246537982815
		ArgOfPericen	39.6254621950129
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 86"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.1348117128780704e-08
	Radius		25.0

	RotationPeriod	2.393292976019221

	Obliquity		308.87519754915695

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.257628465284338
		Eccentricity	0.40493699927274907
		Inclination		60.42696207583828
		AscendingNode	309.47125455885146
		ArgOfPericen	276.249520712956
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 87"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.249679687777403e-10
	Radius		6.758491044913787

	RotationPeriod	3.635496443544722

	Obliquity		98.80095135677325

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.29517883468643
		Eccentricity	0.549288004955234
		Inclination		-5.9074306831678625
		AscendingNode	83.49700057986009
		ArgOfPericen	123.27093752999205
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 88"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.113312452300476e-09
	Radius		10.16142350172941

	RotationPeriod	7.6248726866462855

	Obliquity		198.21750670757837

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.851014364695114
		Eccentricity	0.6023601362759641
		Inclination		-60.032803151726284
		AscendingNode	248.25748151790484
		ArgOfPericen	246.44940318464253
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 89"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.73766476229439
		Eccentricity	0.6856136090462501
		Inclination		93.37144094183974
		AscendingNode	214.57627141284513
		ArgOfPericen	12.033272193283686
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 89 A"
{
	ParentBody	"HeliosC 89"
	Class		"Asteroid"
	Mass		2.5711798080574747e-09
	Radius		10.797993180983077

	Orbit
	{
		Epoch			2457395.5
		Period			0.007891365568205544
		Eccentricity	0.0031292744136524704
		Inclination		8.844998317525592
		AscendingNode	257.3341905712596
		ArgOfPericen	269.4610013542848
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 89 B"
{
	ParentBody	"HeliosC 89"
	Class		"Asteroid"
	Mass		1.1158705602928122e-09
	Radius		8.175296375001533

	Orbit
	{
		Epoch			2457395.5
		Period			0.007891365568205544
		Eccentricity	0.0031292744136524704
		Inclination		8.844998317525592
		AscendingNode	257.3341905712596
		ArgOfPericen	89.4610013542848
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 90"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3578330465908967e-08
	Radius		18.51356942980891

	RotationPeriod	8.347470359702253

	Obliquity		40.477314500157064

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.282898778509152
		Eccentricity	0.32342225933104557
		Inclination		-76.48485850467361
		AscendingNode	305.14368260419684
		ArgOfPericen	307.6752112898876
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 91"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.802116386745089e-09
	Radius		18.437417455582533

	RotationPeriod	9.196983505657377

	Obliquity		321.5290587150463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.281447035925666
		Eccentricity	0.5010986895661844
		Inclination		60.00039966910449
		AscendingNode	44.32194079889162
		ArgOfPericen	132.26991013363974
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 92"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2544512701717455e-08
	Radius		18.117928944251805

	RotationPeriod	5.593829930379461

	Obliquity		334.12280049145625

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.259362769859424
		Eccentricity	0.6179868637552572
		Inclination		-110.48038835312168
		AscendingNode	3.0947962668488627
		ArgOfPericen	321.26181340348427
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 93"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1734565775073443e-08
	Radius		18.022985395915303

	RotationPeriod	12

	Obliquity		269.88381171150394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.761019924596418
		Eccentricity	0.5223165175144581
		Inclination		-14.452701353211532
		AscendingNode	94.06476988250523
		ArgOfPericen	304.2133349840228
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 94"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0987365413853058e-09
	Radius		7.963015837644791

	RotationPeriod	3.2631666610553522

	Obliquity		113.65818875243012

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.801167073910214
		Eccentricity	0.6454737562647425
		Inclination		-12.140845946886142
		AscendingNode	48.22937039227874
		ArgOfPericen	101.92756478313694
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 95"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2450426093719343e-09
	Radius		8.311642270108731

	RotationPeriod	7.709484731512337

	Obliquity		270.1818241998148

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.79206032799333
		Eccentricity	0.5361317476875703
		Inclination		-45.47617279273857
		AscendingNode	146.98158274023262
		ArgOfPericen	143.4139640157069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 96"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.35672442185587
		Eccentricity	0.48825599557574556
		Inclination		83.78125435126171
		AscendingNode	300.5756837569383
		ArgOfPericen	166.15398540809838
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 96 A"
{
	ParentBody	"HeliosC 96"
	Class		"Asteroid"
	Mass		1.9865907001965733e-09
	Radius		9.66974213869887

	Orbit
	{
		Epoch			2457395.5
		Period			0.006567878850549326
		Eccentricity	0.0019241839856456856
		Inclination		171.58385293253653
		AscendingNode	338.970876349483
		ArgOfPericen	225.81454956397175
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 96 B"
{
	ParentBody	"HeliosC 96"
	Class		"Asteroid"
	Mass		2.101873623277481e-10
	Radius		4.5734888752027745

	Orbit
	{
		Epoch			2457395.5
		Period			0.006567878850549326
		Eccentricity	0.0019241839856456856
		Inclination		171.58385293253653
		AscendingNode	338.970876349483
		ArgOfPericen	45.81454956397175
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 97"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.200701393372112e-08
	Radius		17.312247788776272

	RotationPeriod	3.1185823025069324

	Obliquity		353.5201000032808

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.247483714510146
		Eccentricity	0.44445071898806177
		Inclination		-102.7275114989187
		AscendingNode	279.74928864141145
		ArgOfPericen	293.971852101887
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 98"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.0262501077157648e-08
	Radius		20.36321046329082

	RotationPeriod	2.6117800399492013

	Obliquity		291.30858428792436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.386446838975445
		Eccentricity	0.2337140577353644
		Inclination		-125.36063110949351
		AscendingNode	227.07032011432034
		ArgOfPericen	8.515825669469823
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 99"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3271102399518668e-09
	Radius		8.261811988591795

	RotationPeriod	4.158254671456898

	Obliquity		9.447646310552296

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.934401589400572
		Eccentricity	0.47662529821449234
		Inclination		-63.0068264645014
		AscendingNode	225.6998153895155
		ArgOfPericen	111.9445763998231
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 100"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.015148465533772e-10
	Radius		6.175077731548034

	RotationPeriod	5.366076398780831

	Obliquity		213.8596812602557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.379246087576835
		Eccentricity	0.5341746524208638
		Inclination		-59.13466508377981
		AscendingNode	128.29397778324196
		ArgOfPericen	338.6649919434217
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 101"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.9313920859672267e-09
	Radius		11.094143855882562

	RotationPeriod	5.958208466237693

	Obliquity		213.86932489273545

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.46085775198673
		Eccentricity	0.5571865818707951
		Inclination		60.27914662716472
		AscendingNode	272.49387161752895
		ArgOfPericen	144.55930619711202
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 102"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9172740209182e-09
	Radius		9.402042462553881

	RotationPeriod	5.633192476365892

	Obliquity		300.11310602692964

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.78715722116776
		Eccentricity	0.44564042860513486
		Inclination		28.34752810165519
		AscendingNode	184.0724647888664
		ArgOfPericen	261.07087284523635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 103"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.277023226164162e-10
	Radius		6.758976066911209

	RotationPeriod	5.98847168119058

	Obliquity		343.8636044993952

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.788934931119346
		Eccentricity	0.6155139981585133
		Inclination		89.58236880394543
		AscendingNode	266.20651474359636
		ArgOfPericen	38.525580392029866
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 104"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.591692464511566e-09
	Radius		13.127450920773658

	RotationPeriod	6.151715301878284

	Obliquity		252.77404970219226

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.947485367440553
		Eccentricity	0.6074190165267389
		Inclination		56.09171776326514
		AscendingNode	295.8891436361634
		ArgOfPericen	240.89005154298147
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 105"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.440000362015304e-09
	Radius		10.124089850286584

	RotationPeriod	8.488975135477787

	Obliquity		300.5366008128038

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.043677638463084
		Eccentricity	0.1424246706340861
		Inclination		13.123982584244139
		AscendingNode	194.03166208854907
		ArgOfPericen	60.587031158534586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 106"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.218841546791696e-09
	Radius		12.55007861862156

	RotationPeriod	6.4360517440019525

	Obliquity		54.28995550068652

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.073296198248666
		Eccentricity	0.6557385489774993
		Inclination		-9.563586842956765
		AscendingNode	261.5590255625162
		ArgOfPericen	201.53458858051246
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 107"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4351400964573636e-09
	Radius		9.010504090461069

	RotationPeriod	11.065408216836177

	Obliquity		10.603950069303906

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.945782780392413
		Eccentricity	0.25716099340706366
		Inclination		7.232682205424847
		AscendingNode	220.35956780429888
		ArgOfPericen	10.599368379926615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 108"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.082402217268593e-09
	Radius		13.157370008754192

	RotationPeriod	5.35756703660901

	Obliquity		210.80340471481696

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.337672036760612
		Eccentricity	0.49703115839673345
		Inclination		-5.897059166756425
		AscendingNode	325.1669447247803
		ArgOfPericen	161.287409988644
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 109"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.3568711751760263e-10
	Radius		4.9010924048422995

	RotationPeriod	7.831654765797998

	Obliquity		186.25312022607525

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.708284031433049
		Eccentricity	0.4893978371069059
		Inclination		111.92200416549245
		AscendingNode	204.92573539592854
		ArgOfPericen	186.0659435968313
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 110"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.540809143747359e-09
	Radius		15.157152658276367

	RotationPeriod	5.979093986449729

	Obliquity		188.687328761625

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.355951353557238
		Eccentricity	0.5488970028808073
		Inclination		-72.25787439785552
		AscendingNode	236.8974946828987
		ArgOfPericen	63.8280443187938
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 111"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.73552185471904
		Eccentricity	0.4563577853037736
		Inclination		-35.38806367969622
		AscendingNode	18.248664725877504
		ArgOfPericen	165.3743340615835
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 111 A"
{
	ParentBody	"HeliosC 111"
	Class		"Asteroid"
	Mass		6.744139555563098e-09
	Radius		15.129562798369745

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005234687293675841
		Eccentricity	0.003191669162548949
		Inclination		301.8689198369425
		AscendingNode	72.41445903589667
		ArgOfPericen	157.9860997979267
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 111 B"
{
	ParentBody	"HeliosC 111"
	Class		"Asteroid"
	Mass		1.5891463870208322e-09
	Radius		9.344846323321683

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005234687293675841
		Eccentricity	0.003191669162548949
		Inclination		301.8689198369425
		AscendingNode	72.41445903589667
		ArgOfPericen	337.9860997979267
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 112"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3712932411392025e-09
	Radius		12.068268833848112

	RotationPeriod	7.0168894216984565

	Obliquity		69.57617378141722

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.333020051944544
		Eccentricity	0.6768958334970089
		Inclination		-53.13844492629603
		AscendingNode	46.22493276436673
		ArgOfPericen	114.63217763147986
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 113"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1902083288425292e-09
	Radius		8.605173785762982

	RotationPeriod	6.684327632263491

	Obliquity		309.47817519471556

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.146451176484028
		Eccentricity	0.4592109807935225
		Inclination		76.6038846056193
		AscendingNode	28.660077113035705
		ArgOfPericen	238.32989133039183
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 114"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.643687207219571e-09
	Radius		16.709568397082474

	RotationPeriod	5.32508849293856

	Obliquity		187.88140376391274

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.200606482883067
		Eccentricity	0.3679148127542682
		Inclination		-14.548525365552758
		AscendingNode	96.72601646372004
		ArgOfPericen	8.54575972525437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 115"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.875558286978467
		Eccentricity	0.5667595238286489
		Inclination		-60.16551538682254
		AscendingNode	262.25255380214793
		ArgOfPericen	213.26672035108356
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 115 A"
{
	ParentBody	"HeliosC 115"
	Class		"Asteroid"
	Mass		6.913595326232837e-10
	Radius		7.073082442569528

	Orbit
	{
		Epoch			2457395.5
		Period			0.004512659361119769
		Eccentricity	0.003194379941482409
		Inclination		205.9270524615744
		AscendingNode	36.76951438743472
		ArgOfPericen	333.3352631020765
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 115 B"
{
	ParentBody	"HeliosC 115"
	Class		"Asteroid"
	Mass		5.094807534944808e-10
	Radius		6.388761306035882

	Orbit
	{
		Epoch			2457395.5
		Period			0.004512659361119769
		Eccentricity	0.003194379941482409
		Inclination		205.9270524615744
		AscendingNode	36.76951438743472
		ArgOfPericen	153.3352631020765
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 116"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.5037071569383928e-09
	Radius		10.802380039398642

	RotationPeriod	5.847221116734052

	Obliquity		6.495480665102464

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.446565676957285
		Eccentricity	0.3949763527225666
		Inclination		-44.63556220988923
		AscendingNode	207.21420897490526
		ArgOfPericen	103.10304581514423
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 117"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0548203389557483e-08
	Radius		16.797772128476012

	RotationPeriod	10.673484548533173

	Obliquity		340.4605280271359

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.114248709140746
		Eccentricity	0.5392812303937591
		Inclination		58.83741199289026
		AscendingNode	96.24764284864776
		ArgOfPericen	317.27714883564823
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 118"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.660171587651792
		Eccentricity	0.7042104538835379
		Inclination		-40.38923293156463
		AscendingNode	287.14751794369346
		ArgOfPericen	13.018903248037237
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 118 A"
{
	ParentBody	"HeliosC 118"
	Class		"Asteroid"
	Mass		1.4533372812343419e-08
	Radius		19.128373620664483

	Orbit
	{
		Epoch			2457395.5
		Period			0.00795048798802981
		Eccentricity	0.00557128450704894
		Inclination		189.794113817908
		AscendingNode	109.07430479360349
		ArgOfPericen	241.84550133357627
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 118 B"
{
	ParentBody	"HeliosC 118"
	Class		"Asteroid"
	Mass		4.898920530643802e-10
	Radius		6.179064178487931

	Orbit
	{
		Epoch			2457395.5
		Period			0.00795048798802981
		Eccentricity	0.00557128450704894
		Inclination		189.794113817908
		AscendingNode	109.07430479360349
		ArgOfPericen	61.845501333576294
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 119"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.621268023348807e-10
	Radius		7.563471636444829

	RotationPeriod	6.2252899266846935

	Obliquity		240.09102123255562

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.811956791236597
		Eccentricity	0.37999372572904466
		Inclination		78.91959619539338
		AscendingNode	140.10415414095658
		ArgOfPericen	214.33687102118023
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 120"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0542811483276848e-08
	Radius		16.55229717268767

	RotationPeriod	8.9686075830092

	Obliquity		288.23909406095925

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.216438409681718
		Eccentricity	0.6907871810069564
		Inclination		29.24292859859425
		AscendingNode	162.54625587383268
		ArgOfPericen	207.44423098315679
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 121"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.36427323841211
		Eccentricity	0.5874155393844468
		Inclination		-54.567657365745426
		AscendingNode	32.6624053513442
		ArgOfPericen	4.7403790839546645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 121 A"
{
	ParentBody	"HeliosC 121"
	Class		"Asteroid"
	Mass		5.99796295227002e-09
	Radius		13.751651482704096

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025299003039408806
		Eccentricity	0.005772847559752993
		Inclination		233.28630924772844
		AscendingNode	99.84132151522181
		ArgOfPericen	241.8614153168695
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 121 B"
{
	ParentBody	"HeliosC 121"
	Class		"Asteroid"
	Mass		1.0421250732076695e-09
	Radius		7.673500856031614

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025299003039408806
		Eccentricity	0.005772847559752993
		Inclination		233.28630924772844
		AscendingNode	99.84132151522181
		ArgOfPericen	61.86141531686951
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 122"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.378325381604903
		Eccentricity	0.4727678018422748
		Inclination		18.044187921313096
		AscendingNode	312.5696301926734
		ArgOfPericen	108.1432750376604
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 122 A"
{
	ParentBody	"HeliosC 122"
	Class		"Asteroid"
	Mass		4.864524182470262e-09
	Radius		13.157916059977394

	Orbit
	{
		Epoch			2457395.5
		Period			0.006820952098402671
		Eccentricity	0.004489945998846559
		Inclination		84.74956392154832
		AscendingNode	105.21348599805299
		ArgOfPericen	351.09598946073896
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 122 B"
{
	ParentBody	"HeliosC 122"
	Class		"Asteroid"
	Mass		1.0366935545541487e-09
	Radius		7.859419235198881

	Orbit
	{
		Epoch			2457395.5
		Period			0.006820952098402671
		Eccentricity	0.004489945998846559
		Inclination		84.74956392154832
		AscendingNode	105.21348599805299
		ArgOfPericen	171.09598946073902
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 123"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.938661077530735
		Eccentricity	0.2127277563132946
		Inclination		-94.22887665565364
		AscendingNode	102.66277205432908
		ArgOfPericen	35.18717183144118
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 123 A"
{
	ParentBody	"HeliosC 123"
	Class		"Asteroid"
	Mass		1.3719189507268389e-09
	Radius		8.68098630683372

	Orbit
	{
		Epoch			2457395.5
		Period			0.006727554061921881
		Eccentricity	0.002246357079442067
		Inclination		252.81542081119852
		AscendingNode	25.771892440149347
		ArgOfPericen	128.07613412634365
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 123 B"
{
	ParentBody	"HeliosC 123"
	Class		"Asteroid"
	Mass		8.587655931972049e-10
	Radius		7.425934793834818

	Orbit
	{
		Epoch			2457395.5
		Period			0.006727554061921881
		Eccentricity	0.002246357079442067
		Inclination		252.81542081119852
		AscendingNode	25.771892440149347
		ArgOfPericen	308.0761341263436
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 124"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.229292253753794
		Eccentricity	0.44112342020284695
		Inclination		-172.37472297089732
		AscendingNode	111.80143894951108
		ArgOfPericen	246.34958763098427
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 124 A"
{
	ParentBody	"HeliosC 124"
	Class		"Asteroid"
	Mass		7.20165149066319e-09
	Radius		14.789376516591489

	Orbit
	{
		Epoch			2457395.5
		Period			0.004909336095007628
		Eccentricity	0.008583291235729462
		Inclination		92.42302105263776
		AscendingNode	195.90587435692075
		ArgOfPericen	107.11697411176188
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 124 B"
{
	ParentBody	"HeliosC 124"
	Class		"Asteroid"
	Mass		2.4550706539766825e-09
	Radius		10.33143141679704

	Orbit
	{
		Epoch			2457395.5
		Period			0.004909336095007628
		Eccentricity	0.008583291235729462
		Inclination		92.42302105263776
		AscendingNode	195.90587435692075
		ArgOfPericen	287.11697411176186
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 125"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.45563757151746
		Eccentricity	0.3964615854208039
		Inclination		40.12073479847414
		AscendingNode	93.44130686549386
		ArgOfPericen	204.33384903136886
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 125 A"
{
	ParentBody	"HeliosC 125"
	Class		"Asteroid"
	Mass		6.320262331032364e-09
	Radius		15.395501638405502

	Orbit
	{
		Epoch			2457395.5
		Period			0.006258925753206858
		Eccentricity	0.0044610490236377765
		Inclination		77.0742919065236
		AscendingNode	194.4740796036996
		ArgOfPericen	206.89134394286762
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 125 B"
{
	ParentBody	"HeliosC 125"
	Class		"Asteroid"
	Mass		2.11991037559331e-09
	Radius		10.696818893567642

	Orbit
	{
		Epoch			2457395.5
		Period			0.006258925753206858
		Eccentricity	0.0044610490236377765
		Inclination		77.0742919065236
		AscendingNode	194.4740796036996
		ArgOfPericen	26.891343942867593
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 126"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.033953140207537e-09
	Radius		9.709592658585231

	RotationPeriod	6.897434324276917

	Obliquity		176.92750791611417

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.11336630029323
		Eccentricity	0.38120369485340727
		Inclination		19.347125963545892
		AscendingNode	269.7869527936491
		ArgOfPericen	323.2809347700199
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 127"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.998093060131289e-09
	Radius		17.10344466406168

	RotationPeriod	6.8983224196152815

	Obliquity		176.8495095544333

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.868855219400956
		Eccentricity	0.4950249305139246
		Inclination		-15.359637944286984
		AscendingNode	299.31736160687643
		ArgOfPericen	63.5550686161021
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 128"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.395643199235247e-10
	Radius		6.468468610956683

	RotationPeriod	4.002656739756068

	Obliquity		316.2342355681455

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.093160811231066
		Eccentricity	0.38193496479797145
		Inclination		-49.49566936071947
		AscendingNode	70.59857926270867
		ArgOfPericen	94.109050227915
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 129"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.952737600124126e-10
	Radius		6.590169168149262

	RotationPeriod	5.73249552742068

	Obliquity		18.93292536275287

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.32010154383849
		Eccentricity	0.5809729931920119
		Inclination		-41.73475533294155
		AscendingNode	79.53095749498354
		ArgOfPericen	299.79812336833214
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 130"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0128684850638313e-08
	Radius		17.0070816351812

	RotationPeriod	4.669376686147099

	Obliquity		281.92748857189736

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.903694458036185
		Eccentricity	0.42614654071378666
		Inclination		128.6804419498646
		AscendingNode	117.53728103594774
		ArgOfPericen	291.78769180142115
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 131"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8007587987073697e-09
	Radius		9.450543345345565

	RotationPeriod	5.789634007327628

	Obliquity		264.9401227525527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.44351739282616
		Eccentricity	0.3370875958775845
		Inclination		-25.09154518382914
		AscendingNode	147.6553267211663
		ArgOfPericen	109.65883285061508
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 132"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.301895017653736e-10
	Radius		4.291791561453104

	RotationPeriod	7.051659160202778

	Obliquity		76.21432441982341

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.32507863938427
		Eccentricity	0.4825417539208558
		Inclination		-11.430852037168338
		AscendingNode	20.10237953341577
		ArgOfPericen	211.62389807735303
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 133"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.573917762121006
		Eccentricity	0.5634892576798654
		Inclination		104.68156046646156
		AscendingNode	82.17199431133221
		ArgOfPericen	139.5031193556755
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 133 A"
{
	ParentBody	"HeliosC 133"
	Class		"Asteroid"
	Mass		2.8306213921455326e-10
	Radius		4.985400892078464

	Orbit
	{
		Epoch			2457395.5
		Period			0.00602878961224878
		Eccentricity	0.002832309750422146
		Inclination		93.7330857621136
		AscendingNode	205.59797083697185
		ArgOfPericen	313.0766813041799
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 133 B"
{
	ParentBody	"HeliosC 133"
	Class		"Asteroid"
	Mass		6.753907475379546e-11
	Radius		3.0921308317637095

	Orbit
	{
		Epoch			2457395.5
		Period			0.00602878961224878
		Eccentricity	0.002832309750422146
		Inclination		93.7330857621136
		AscendingNode	205.59797083697185
		ArgOfPericen	133.07668130417989
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 134"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8849037849593046e-08
	Radius		19.660519381282725

	RotationPeriod	6.116371619452966

	Obliquity		146.93625154193387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.884273157203264
		Eccentricity	0.6326884827366209
		Inclination		-42.69201852995459
		AscendingNode	237.06532760368205
		ArgOfPericen	165.41223840001368
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 135"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.7742229398830929e-09
	Radius		9.535049437699515

	RotationPeriod	7.553015750557023

	Obliquity		139.00887304245046

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.899363947254923
		Eccentricity	0.4845049717073201
		Inclination		-1.1042364325930731
		AscendingNode	342.37609944126956
		ArgOfPericen	357.59017758682893
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 136"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.857523795565184e-09
	Radius		15.342127276196544

	RotationPeriod	3.3444051747292676

	Obliquity		104.83816587065374

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.54230783082726
		Eccentricity	0.37578866364882313
		Inclination		23.726628601902167
		AscendingNode	150.06423597958445
		ArgOfPericen	146.9135878011269
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 137"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.3616098370827e-09
	Radius		17.34143372562876

	RotationPeriod	5.687991264429671

	Obliquity		83.44608943442773

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.699331964788232
		Eccentricity	0.6944824492624344
		Inclination		72.6506051942516
		AscendingNode	171.63654149837058
		ArgOfPericen	160.19208915660323
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 138"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.4496742226232496e-10
	Radius		5.884493249761107

	RotationPeriod	2.9902778398633445

	Obliquity		98.20816422366836

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.008882717149993
		Eccentricity	0.4755519517019515
		Inclination		34.74862515904717
		AscendingNode	247.07125542771294
		ArgOfPericen	61.28756316749722
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 139"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.289830908414193e-09
	Radius		10.504857110583236

	RotationPeriod	7.93514509459904

	Obliquity		75.81591579098304

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.22352412308403
		Eccentricity	0.49016000816005784
		Inclination		-2.011512059195527
		AscendingNode	260.978566839017
		ArgOfPericen	264.60309357672077
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 140"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3214896102807534e-09
	Radius		8.682175254638388

	RotationPeriod	5.9546290833944004

	Obliquity		14.021591196569908

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.174985605475337
		Eccentricity	0.21077676371654247
		Inclination		-65.45637651270344
		AscendingNode	276.42549662998294
		ArgOfPericen	306.27344403537063
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 141"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0863754425913833e-08
	Radius		16.67233392672052

	RotationPeriod	8.519315669712295

	Obliquity		150.84705259790334

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.48505457641849
		Eccentricity	0.5978080307623285
		Inclination		-11.310877551137363
		AscendingNode	305.7545645908119
		ArgOfPericen	346.99297194868507
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 142"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.53514314316938
		Eccentricity	0.4425001146770568
		Inclination		22.11944838465619
		AscendingNode	213.61200879698683
		ArgOfPericen	188.5684412742175
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 142 A"
{
	ParentBody	"HeliosC 142"
	Class		"Asteroid"
	Mass		2.1268116985264734e-09
	Radius		9.889804669020805

	Orbit
	{
		Epoch			2457395.5
		Period			0.008162446589223868
		Eccentricity	0.002791294666153633
		Inclination		82.46772395288133
		AscendingNode	297.8994534023056
		ArgOfPericen	258.4005080609746
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 142 B"
{
	ParentBody	"HeliosC 142"
	Class		"Asteroid"
	Mass		8.290520965630791e-10
	Radius		7.224458619584943

	Orbit
	{
		Epoch			2457395.5
		Period			0.008162446589223868
		Eccentricity	0.002791294666153633
		Inclination		82.46772395288133
		AscendingNode	297.8994534023056
		ArgOfPericen	78.40050806097457
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 143"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.371713535147719e-08
	Radius		19.099848380723824

	RotationPeriod	6.455864330484908

	Obliquity		335.04617405268306

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.633325392830066
		Eccentricity	0.5217163553500194
		Inclination		37.53388439730416
		AscendingNode	60.276644588113044
		ArgOfPericen	43.10641855038665
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 144"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.037942373007995e-09
	Radius		9.670155802397007

	RotationPeriod	7.286964833534517

	Obliquity		138.03103796088348

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.56689602822627
		Eccentricity	0.7871297004387975
		Inclination		15.194913086237465
		AscendingNode	59.44023298388458
		ArgOfPericen	283.6997257191275
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 145"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.486063977519992e-09
	Radius		13.060802212024516

	RotationPeriod	8.827207541480579

	Obliquity		357.3987069002369

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.291312979898407
		Eccentricity	0.5412065055295145
		Inclination		161.0363333992111
		AscendingNode	179.23133215555785
		ArgOfPericen	318.526928301161
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 146"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.483856130069636
		Eccentricity	0.4154341073009258
		Inclination		1.1185438557648644
		AscendingNode	26.12853350694373
		ArgOfPericen	97.74903017590498
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 146 A"
{
	ParentBody	"HeliosC 146"
	Class		"Asteroid"
	Mass		5.56912967298963e-09
	Radius		13.433661983035307

	Orbit
	{
		Epoch			2457395.5
		Period			0.008110056889712629
		Eccentricity	0.005059438776690345
		Inclination		275.03322907048425
		AscendingNode	292.0210373019739
		ArgOfPericen	10.53882549302131
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 146 B"
{
	ParentBody	"HeliosC 146"
	Class		"Asteroid"
	Mass		3.5523564112710067e-09
	Radius		11.563895289187432

	Orbit
	{
		Epoch			2457395.5
		Period			0.008110056889712629
		Eccentricity	0.005059438776690345
		Inclination		275.03322907048425
		AscendingNode	292.0210373019739
		ArgOfPericen	190.5388254930213
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 147"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.0013805426597274e-09
	Radius		13.64420668393816

	RotationPeriod	7.874833014568698

	Obliquity		137.92743184310262

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.74050913336143
		Eccentricity	0.4479095668247315
		Inclination		120.3961731494175
		AscendingNode	269.82087341499175
		ArgOfPericen	120.53559284161692
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 148"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.117748739577393e-10
	Radius		6.259113033138771

	RotationPeriod	8.231632010304727

	Obliquity		74.87601753643975

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.325875427616282
		Eccentricity	0.7045204130343026
		Inclination		-28.117399355806075
		AscendingNode	122.5590591038833
		ArgOfPericen	83.92352769347475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 149"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.175846628545785e-08
	Radius		18.068167030533345

	RotationPeriod	2.673686121138893

	Obliquity		356.56501407507704

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.63795590825011
		Eccentricity	0.4798411530133382
		Inclination		18.382846935266738
		AscendingNode	258.5636490140653
		ArgOfPericen	139.2046277639412
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 150"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.2055721386450906e-09
	Radius		13.226951734086576

	RotationPeriod	5.945404177652596

	Obliquity		354.73802120781426

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.45592988573391
		Eccentricity	0.7761552835817219
		Inclination		12.265517008468992
		AscendingNode	175.22563218054557
		ArgOfPericen	188.20319463837487
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 151"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.12269351341977e-09
	Radius		16.215117732115715

	RotationPeriod	5.38180889099973

	Obliquity		331.2460661738731

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.55648169159365
		Eccentricity	0.5514777117551735
		Inclination		-25.468595835714922
		AscendingNode	251.73557308266248
		ArgOfPericen	268.6553965993669
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 152"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.820429865499386e-09
	Radius		12.616852180911938

	RotationPeriod	4.844945682823994

	Obliquity		156.97911208826739

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.10597794029915
		Eccentricity	0.4029024836952257
		Inclination		136.99262398021438
		AscendingNode	87.55084348510398
		ArgOfPericen	57.10414589523945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 153"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.66290199237613e-09
	Radius		15.052015921962422

	RotationPeriod	8.224820097109427

	Obliquity		114.21124526397311

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.658725646811924
		Eccentricity	0.34749282000298937
		Inclination		100.50916560980232
		AscendingNode	142.79185289561318
		ArgOfPericen	216.6645437930959
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 154"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6113352951556004e-09
	Radius		12.047903664072573

	RotationPeriod	4.363333077091312

	Obliquity		140.38313627774963

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.14863251189945
		Eccentricity	0.5350264661805686
		Inclination		26.77046598630134
		AscendingNode	86.12883180887131
		ArgOfPericen	68.55767773241108
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 155"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.0272628300983405e-09
	Radius		9.514698412100014

	RotationPeriod	4.373232588101747

	Obliquity		72.41106319144235

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.2677578295688
		Eccentricity	0.4126748499310854
		Inclination		-79.50653298090128
		AscendingNode	174.4574959796124
		ArgOfPericen	263.12718136318205
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 156"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.1526034966556964e-09
	Radius		10.425409696978667

	RotationPeriod	4.226507277427562

	Obliquity		180.7803388633617

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.0324756492529
		Eccentricity	0.3008588208504006
		Inclination		9.584412072805408
		AscendingNode	299.00714657937567
		ArgOfPericen	131.72690382675094
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 157"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.55596225375055e-09
	Radius		16.0181190297746

	RotationPeriod	6.116728473085057

	Obliquity		74.4432598800733

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.46292445784934
		Eccentricity	0.5731719005481725
		Inclination		-8.658223859931725
		AscendingNode	5.6185909531329825
		ArgOfPericen	216.5572153538355
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 158"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.77690814251749e-10
	Radius		7.169978056516974

	RotationPeriod	7.236009817374989

	Obliquity		111.18897727250656

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.201806075611405
		Eccentricity	0.3450571096355064
		Inclination		-29.433216681836598
		AscendingNode	276.9485045463649
		ArgOfPericen	105.75913094898921
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 159"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0578044182287113e-08
	Radius		16.817675696752904

	RotationPeriod	9.902952802825926

	Obliquity		347.8436586600505

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.741019205426664
		Eccentricity	0.46220232424269886
		Inclination		40.45827632435608
		AscendingNode	80.18227234449327
		ArgOfPericen	106.11967323571558
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 160"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3102868000773207e-09
	Radius		11.093846564156825

	RotationPeriod	3.8312804497503863

	Obliquity		309.0654612763088

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.291411364649775
		Eccentricity	0.6580123788795237
		Inclination		10.21208045066632
		AscendingNode	120.07790909781242
		ArgOfPericen	200.3252654987652
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 161"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8092268363513545e-09
	Radius		9.683172923295558

	RotationPeriod	7.341091367236534

	Obliquity		91.3926192958907

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.808120677440378
		Eccentricity	0.38788118923684367
		Inclination		11.866718721762812
		AscendingNode	234.9230950120895
		ArgOfPericen	215.6594353953757
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 162"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3358019132812388e-08
	Radius		17.13066951528631

	RotationPeriod	7.316521388480597

	Obliquity		226.53107732728097

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	4.697311670196484
		Eccentricity	0.43467818162059824
		Inclination		-139.1676917678474
		AscendingNode	206.14276962121244
		ArgOfPericen	236.31404198709146
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 163"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.7787904692169685e-08
	Radius		24.751386569427197

	RotationPeriod	5.548333522417707

	Obliquity		62.29205893584258

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	45.973997781436836
		Eccentricity	0.39865088053392966
		Inclination		25.044621460701975
		AscendingNode	283.7147535912816
		ArgOfPericen	216.24640701069595
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 164"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.033734165320185e-08
	Radius		16.71583510604541

	RotationPeriod	4.536695762660082

	Obliquity		49.14999249056306

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.662614784120315
		Eccentricity	0.5622110308482776
		Inclination		25.48164996755941
		AscendingNode	4.828077714533543
		ArgOfPericen	223.66575459579113
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 165"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.767795064619305e-09
	Radius		15.756965939625726

	RotationPeriod	6.212272513141167

	Obliquity		51.30576981358742

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.688470426169026
		Eccentricity	0.5986691752803953
		Inclination		44.663758113401954
		AscendingNode	143.36952805954317
		ArgOfPericen	129.48960965103535
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 166"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8536033899538652e-08
	Radius		19.83782971794495

	RotationPeriod	3.688279002324213

	Obliquity		291.30141380880247

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.371010245357265
		Eccentricity	0.09911640920262987
		Inclination		7.5781849562806824
		AscendingNode	335.3526550695949
		ArgOfPericen	100.11460828431044
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 167"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.635131974697252e-09
	Radius		10.584548821383517

	RotationPeriod	3.454083220935513

	Obliquity		208.12287104242924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.889491620880182
		Eccentricity	0.30983436168647954
		Inclination		2.5247922851106774
		AscendingNode	39.042929366148854
		ArgOfPericen	162.33707631479368
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 168"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9808246516028308e-09
	Radius		9.368070860076521

	RotationPeriod	4.585844987242503

	Obliquity		312.1620925166334

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.11471833633763
		Eccentricity	0.47235650539130963
		Inclination		31.134862888479333
		AscendingNode	1.670715103819429
		ArgOfPericen	148.65864496176485
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 169"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.327296289627367e-10
	Radius		4.88039912767438

	RotationPeriod	4.717953699027598

	Obliquity		248.6795167447214

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.50799231995459
		Eccentricity	0.5298994688784768
		Inclination		-37.57507998555056
		AscendingNode	292.3357365771643
		ArgOfPericen	232.65809527671078
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 170"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.002220416943613
		Eccentricity	0.2515618671793292
		Inclination		-23.52920591378364
		AscendingNode	174.85948974912296
		ArgOfPericen	341.7696969096523
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 170 A"
{
	ParentBody	"HeliosC 170"
	Class		"Asteroid"
	Mass		3.0735866725444115e-09
	Radius		11.432642435163299

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007365302670852584
		Eccentricity	0.006070070084016433
		Inclination		92.60364487200422
		AscendingNode	139.5021260883886
		ArgOfPericen	173.07032101651393
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 170 B"
{
	ParentBody	"HeliosC 170"
	Class		"Asteroid"
	Mass		5.890985198373798e-10
	Radius		6.591649552273408

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007365302670852584
		Eccentricity	0.006070070084016433
		Inclination		92.60364487200422
		AscendingNode	139.5021260883886
		ArgOfPericen	353.07032101651396
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 171"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.483919581494394e-10
	Radius		7.5563269441613246

	RotationPeriod	8.06792458397329

	Obliquity		127.63395691300637

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.41683049177439
		Eccentricity	0.7369330179454132
		Inclination		-50.33681035657396
		AscendingNode	215.28159194115904
		ArgOfPericen	119.61891275077251
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 172"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.624540172194609e-09
	Radius		14.42732253186707

	RotationPeriod	4.201381459177523

	Obliquity		124.77706351860076

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.67860041895808
		Eccentricity	0.29561097980100354
		Inclination		-121.4390660417815
		AscendingNode	27.224513340783734
		ArgOfPericen	247.0845574741301
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 173"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.95451993608627
		Eccentricity	0.5118370272781569
		Inclination		-53.92508627226365
		AscendingNode	42.34400011263209
		ArgOfPericen	28.328716298988816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 173 A"
{
	ParentBody	"HeliosC 173"
	Class		"Asteroid"
	Mass		2.328629345457336e-09
	Radius		10.654840467861654

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021465213288703517
		Eccentricity	0.003222493223975921
		Inclination		238.477695187248
		AscendingNode	286.1260839011831
		ArgOfPericen	113.7774169653129
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 173 B"
{
	ParentBody	"HeliosC 173"
	Class		"Asteroid"
	Mass		1.077917246283515e-10
	Radius		3.825679962828306

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021465213288703517
		Eccentricity	0.003222493223975921
		Inclination		238.477695187248
		AscendingNode	286.1260839011831
		ArgOfPericen	293.7774169653129
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 174"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9008490085795386e-08
	Radius		22.148451116520818

	RotationPeriod	4.037933775925882

	Obliquity		1.0239188200424376

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.055413999212167
		Eccentricity	0.3454167488668781
		Inclination		41.392089811170386
		AscendingNode	306.18059761857955
		ArgOfPericen	266.71925319233924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 175"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.421188350783743e-10
	Radius		7.569977718034606

	RotationPeriod	4.582690619876328

	Obliquity		128.7763542691121

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.36146365535509
		Eccentricity	0.5476010932692403
		Inclination		-90.3894126194595
		AscendingNode	33.47189571836481
		ArgOfPericen	28.821332556158133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 176"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.068048152619903e-09
	Radius		7.735323477632071

	RotationPeriod	10.40623690514316

	Obliquity		37.636426409625805

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.246132679606372
		Eccentricity	0.6433375124289434
		Inclination		-36.991236579903216
		AscendingNode	331.0005232632478
		ArgOfPericen	18.141359901623325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 177"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.682757729650598e-09
	Radius		13.397337573211846

	RotationPeriod	5.406690189758254

	Obliquity		234.03543802432137

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.0859448729575
		Eccentricity	0.6061426319996743
		Inclination		-56.69812638444037
		AscendingNode	342.05512434512906
		ArgOfPericen	61.25064210914408
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 178"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.3623125587664966e-10
	Radius		4.941125204513706

	RotationPeriod	7.382468550655399

	Obliquity		142.95335853775848

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.72038911694397
		Eccentricity	0.8986688761890954
		Inclination		66.74273893849838
		AscendingNode	349.0069633204833
		ArgOfPericen	82.79918371487909
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 179"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.989888107006392e-09
	Radius		12.0740829290019

	RotationPeriod	3.6541276783688037

	Obliquity		106.5711417948685

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.86671293391472
		Eccentricity	0.41954861456614434
		Inclination		23.042327829656898
		AscendingNode	53.14564806448628
		ArgOfPericen	350.2692803666283
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 180"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6344244123116228e-09
	Radius		12.903038347637573

	RotationPeriod	8.155644274255204

	Obliquity		333.00644556192765

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.526614825722014
		Eccentricity	0.39754503772869476
		Inclination		-18.54052483210723
		AscendingNode	164.91654439360218
		ArgOfPericen	131.77218255400726
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 181"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.569690942882417
		Eccentricity	0.6908858611541933
		Inclination		65.27016226592305
		AscendingNode	62.89775498476557
		ArgOfPericen	264.5559219866022
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 181 A"
{
	ParentBody	"HeliosC 181"
	Class		"Asteroid"
	Mass		6.195828566659235e-09
	Radius		14.303346595648415

	Orbit
	{
		Epoch			2457395.5
		Period			0.006184186922392918
		Eccentricity	0.007158566886558519
		Inclination		321.95109342107855
		AscendingNode	71.82295422916685
		ArgOfPericen	105.59841443063776
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 181 B"
{
	ParentBody	"HeliosC 181"
	Class		"Asteroid"
	Mass		2.9463764909435953e-09
	Radius		11.164362906840834

	Orbit
	{
		Epoch			2457395.5
		Period			0.006184186922392918
		Eccentricity	0.007158566886558519
		Inclination		321.95109342107855
		AscendingNode	71.82295422916685
		ArgOfPericen	285.5984144306378
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 182"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.640582165161074
		Eccentricity	0.37983108252799913
		Inclination		-87.17900956489547
		AscendingNode	59.18802444993618
		ArgOfPericen	176.55930237977353
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 182 A"
{
	ParentBody	"HeliosC 182"
	Class		"Asteroid"
	Mass		1.2139684998913201e-08
	Radius		17.510328064391164

	Orbit
	{
		Epoch			2457395.5
		Period			0.003883441213814246
		Eccentricity	0.00580436901664103
		Inclination		219.8349000705879
		AscendingNode	145.04705343957113
		ArgOfPericen	134.59479847791783
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 182 B"
{
	ParentBody	"HeliosC 182"
	Class		"Asteroid"
	Mass		1.0966051351102641e-08
	Radius		16.926814520821928

	Orbit
	{
		Epoch			2457395.5
		Period			0.003883441213814246
		Eccentricity	0.00580436901664103
		Inclination		219.8349000705879
		AscendingNode	145.04705343957113
		ArgOfPericen	314.59479847791783
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 183"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3713125485545874e-09
	Radius		8.379813442678824

	RotationPeriod	7.679941497589832

	Obliquity		82.98348564144685

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.798072713988134
		Eccentricity	0.40129522391461303
		Inclination		-58.57115916025629
		AscendingNode	36.45041490803879
		ArgOfPericen	82.4057524878832
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 184"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.44135674819293
		Eccentricity	0.5079966282932566
		Inclination		49.885761933770645
		AscendingNode	157.86733337807073
		ArgOfPericen	290.1425085314836
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 184 A"
{
	ParentBody	"HeliosC 184"
	Class		"Asteroid"
	Mass		3.656736380034592e-09
	Radius		11.52354850866674

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022362235728758673
		Eccentricity	0.0030274376986740674
		Inclination		113.93342300030545
		AscendingNode	339.1386089274114
		ArgOfPericen	99.0984800204283
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 184 B"
{
	ParentBody	"HeliosC 184"
	Class		"Asteroid"
	Mass		1.1459072114911686e-09
	Radius		7.827171223758414

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022362235728758673
		Eccentricity	0.0030274376986740674
		Inclination		113.93342300030545
		AscendingNode	339.1386089274114
		ArgOfPericen	279.09848002042827
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 185"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.797116522953274e-09
	Radius		15.962523605330135

	RotationPeriod	5.910111837038374

	Obliquity		263.2492351444689

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.65960592184617
		Eccentricity	0.4585206274387506
		Inclination		-17.605141778400608
		AscendingNode	168.2939236105568
		ArgOfPericen	252.8000536854144
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 186"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.153094214251475e-09
	Radius		11.581843298744266

	RotationPeriod	4.057167711071621

	Obliquity		203.20751769517344

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.38932616715062
		Eccentricity	0.44099098326419117
		Inclination		46.97198372706969
		AscendingNode	7.050502555381133
		ArgOfPericen	324.89762877745676
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 187"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.453519469050473
		Eccentricity	0.5638952440159475
		Inclination		-14.533229310355841
		AscendingNode	57.76941549780684
		ArgOfPericen	319.07720358690125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 187 A"
{
	ParentBody	"HeliosC 187"
	Class		"Asteroid"
	Mass		3.2251501447671457e-09
	Radius		11.843365723429429

	Orbit
	{
		Epoch			2457395.5
		Period			0.002843394132215087
		Eccentricity	0.0011866799652449364
		Inclination		306.66980718320605
		AscendingNode	51.141763358056906
		ArgOfPericen	160.97072691029962
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 187 B"
{
	ParentBody	"HeliosC 187"
	Class		"Asteroid"
	Mass		2.639040004564995e-10
	Radius		5.141704960350457

	Orbit
	{
		Epoch			2457395.5
		Period			0.002843394132215087
		Eccentricity	0.0011866799652449364
		Inclination		306.66980718320605
		AscendingNode	51.141763358056906
		ArgOfPericen	340.9707269102996
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 188"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.7409202540092935e-08
	Radius		22.461781359235303

	RotationPeriod	6.442498686372822

	Obliquity		79.7691161027124

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	6.307199707055069
		Eccentricity	0.36054465283632287
		Inclination		-18.99286165913136
		AscendingNode	23.906510260896916
		ArgOfPericen	221.72855750104708
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 189"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2193318038915116e-09
	Radius		8.056694697834613

	RotationPeriod	0.1

	Obliquity		338.5567421215607

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.251629656440002
		Eccentricity	0.5423375043343315
		Inclination		4.5448020066262425
		AscendingNode	187.07252960780463
		ArgOfPericen	245.68126232455182
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 190"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.032750700458381e-10
	Radius		5.669952195805883

	RotationPeriod	6.052748853904137

	Obliquity		331.99237240794656

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.076079217095206
		Eccentricity	0.4016543172187082
		Inclination		-75.96929807233121
		AscendingNode	173.06334801996562
		ArgOfPericen	46.71980467872996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 191"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.2596073995060715e-09
	Radius		14.967521398205953

	RotationPeriod	5.434726243979052

	Obliquity		320.7824758162397

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.478330092009884
		Eccentricity	0.42985419678212444
		Inclination		37.29666810617441
		AscendingNode	170.76613377943687
		ArgOfPericen	58.074374291058945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 192"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.683610452723855e-09
	Radius		8.971853655915904

	RotationPeriod	2.239569401503792

	Obliquity		162.65461244193312

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.19183480618441
		Eccentricity	0.2294546217749428
		Inclination		-51.7507201489737
		AscendingNode	228.97289749823466
		ArgOfPericen	26.14772209050518
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 193"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.161940075420614e-09
	Radius		15.137604061667963

	RotationPeriod	6.8684336307814

	Obliquity		305.7704563218222

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.974389913880284
		Eccentricity	0.36435759023673975
		Inclination		46.40754116522093
		AscendingNode	90.45488977295761
		ArgOfPericen	185.9560224173351
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 194"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.05947699979666
		Eccentricity	0.6733458812636364
		Inclination		-6.0510704659432974
		AscendingNode	183.74681978805899
		ArgOfPericen	165.63266458796375
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 194 A"
{
	ParentBody	"HeliosC 194"
	Class		"Asteroid"
	Mass		1.4397551213939817e-08
	Radius		18.268691467417863

	Orbit
	{
		Epoch			2457395.5
		Period			0.003859136229563335
		Eccentricity	0.005541129376754567
		Inclination		296.03960372051876
		AscendingNode	252.16915559186558
		ArgOfPericen	44.39596226817406
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 194 B"
{
	ParentBody	"HeliosC 194"
	Class		"Asteroid"
	Mass		1.172062533031578e-09
	Radius		7.917623111306709

	Orbit
	{
		Epoch			2457395.5
		Period			0.003859136229563335
		Eccentricity	0.005541129376754567
		Inclination		296.03960372051876
		AscendingNode	252.16915559186558
		ArgOfPericen	224.39596226817406
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 195"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.199062342376798e-09
	Radius		11.699867228119256

	RotationPeriod	6.235783930554744

	Obliquity		211.05016043532336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.29695521099349
		Eccentricity	0.256257198578844
		Inclination		-123.16975726719784
		AscendingNode	85.44334454243547
		ArgOfPericen	145.9190577532486
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 196"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.269767548071183e-10
	Radius		6.248988540446186

	RotationPeriod	7.846601140281771

	Obliquity		43.23585734659562

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.011508881654235
		Eccentricity	0.7919430686730797
		Inclination		-12.119844409395359
		AscendingNode	100.3919552938181
		ArgOfPericen	122.67047574589851
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 197"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.030629822526544e-09
	Radius		14.90384437085733

	RotationPeriod	6.059854059736274

	Obliquity		119.82881871690984

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.105791873234812
		Eccentricity	0.16452496097563157
		Inclination		-75.45704762390338
		AscendingNode	117.11365336234807
		ArgOfPericen	354.8029020616525
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 198"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.944722274678274
		Eccentricity	0.3156960259939171
		Inclination		86.09376175980917
		AscendingNode	312.4792966952763
		ArgOfPericen	189.08572864141018
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 198 A"
{
	ParentBody	"HeliosC 198"
	Class		"Asteroid"
	Mass		1.6577537440474025e-09
	Radius		9.296438472918789

	Orbit
	{
		Epoch			2457395.5
		Period			0.00679206488815813
		Eccentricity	0.0044260312199198674
		Inclination		63.11571415064003
		AscendingNode	201.34848015565456
		ArgOfPericen	163.04807531689426
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 198 B"
{
	ParentBody	"HeliosC 198"
	Class		"Asteroid"
	Mass		1.5888689128363832e-10
	Radius		4.254409431945212

	Orbit
	{
		Epoch			2457395.5
		Period			0.00679206488815813
		Eccentricity	0.0044260312199198674
		Inclination		63.11571415064003
		AscendingNode	201.34848015565456
		ArgOfPericen	343.04807531689426
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 199"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.236050744320681e-10
	Radius		4.756586156488329

	RotationPeriod	6.425752755799721

	Obliquity		179.552087175812

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.03585763481138
		Eccentricity	0.44268591520337985
		Inclination		-47.60438106633609
		AscendingNode	321.75939571582404
		ArgOfPericen	100.02107175732883
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 200"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.074689165488172e-09
	Radius		8.708404656833771

	RotationPeriod	6.3966321709336285

	Obliquity		335.26589505914495

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	0.1
		Eccentricity	0.10670288381330018
		Inclination		-92.35194883506985
		AscendingNode	1.6939627678883529
		ArgOfPericen	119.90183125753477
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 201"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1206064081845796e-08
	Radius		15.867684124161528

	RotationPeriod	3.6535122501672244

	Obliquity		224.85628280991418

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.17512782477771
		Eccentricity	0.6253341543216955
		Inclination		46.758525534734346
		AscendingNode	161.72414182125752
		ArgOfPericen	115.3827044680348
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 202"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.986328605309064e-09
	Radius		14.266302900098284

	RotationPeriod	7.096378713664212

	Obliquity		83.52956803694437

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.25598820309841
		Eccentricity	0.48429108911474744
		Inclination		8.47556728585402
		AscendingNode	3.335242996681842
		ArgOfPericen	71.1131005710132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 203"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.649585722556418
		Eccentricity	0.41588244553551096
		Inclination		45.13610041182092
		AscendingNode	231.13827191958478
		ArgOfPericen	162.64802788308992
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 203 A"
{
	ParentBody	"HeliosC 203"
	Class		"Asteroid"
	Mass		2.371876179899835e-09
	Radius		10.572314207652388

	Orbit
	{
		Epoch			2457395.5
		Period			0.006108448775578263
		Eccentricity	0.0037735102177631763
		Inclination		69.4578721432825
		AscendingNode	85.59806356431287
		ArgOfPericen	11.48192881660902
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 203 B"
{
	ParentBody	"HeliosC 203"
	Class		"Asteroid"
	Mass		4.97341071856779e-10
	Radius		6.280933075613316

	Orbit
	{
		Epoch			2457395.5
		Period			0.006108448775578263
		Eccentricity	0.0037735102177631763
		Inclination		69.4578721432825
		AscendingNode	85.59806356431287
		ArgOfPericen	191.481928816609
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 204"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.574985266535795e-10
	Radius		7.390103179892792

	RotationPeriod	6.156474072458964

	Obliquity		130.1167250305923

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.002557204290504
		Eccentricity	0.6928768217508581
		Inclination		53.86128683119302
		AscendingNode	40.82323953880676
		ArgOfPericen	182.42941880253053
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 205"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.534440890781955e-09
	Radius		12.294422725027658

	RotationPeriod	2.2966268244384413

	Obliquity		210.63604793448965

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.59911174166717
		Eccentricity	0.4151976373373294
		Inclination		-100.12101205041
		AscendingNode	69.31982560891132
		ArgOfPericen	295.9714278855752
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 206"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.05359488337412e-09
	Radius		15.783612303032392

	RotationPeriod	5.986749610993892

	Obliquity		336.13960238440467

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.55286357678537
		Eccentricity	0.5171422746122151
		Inclination		-91.31763782569564
		AscendingNode	313.48091233685784
		ArgOfPericen	169.81707111856707
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 207"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.766365196371499e-09
	Radius		14.517985826385939

	RotationPeriod	7.2974420186143645

	Obliquity		267.0438377614878

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.143966149517578
		Eccentricity	0.49157755375065415
		Inclination		-89.49275436094598
		AscendingNode	242.2965909532824
		ArgOfPericen	156.3365955123538
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 208"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.8916952123837325e-09
	Radius		10.86597572350703

	RotationPeriod	7.3135011190085155

	Obliquity		346.6546627188726

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.600896183799172
		Eccentricity	0.5933360621729826
		Inclination		-24.97759212492258
		AscendingNode	58.79800854371189
		ArgOfPericen	213.95667364661213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 209"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.55181443042494e-09
	Radius		13.548114620388038

	RotationPeriod	2.973676462556757

	Obliquity		324.14920433498406

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.26711096528331
		Eccentricity	0.7175768760994489
		Inclination		19.03467458306797
		AscendingNode	111.81482968536844
		ArgOfPericen	123.77810311492938
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 210"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.309213203747916
		Eccentricity	0.1701423562562172
		Inclination		22.22879415126018
		AscendingNode	277.1312167446208
		ArgOfPericen	188.43397545782125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 210 A"
{
	ParentBody	"HeliosC 210"
	Class		"Asteroid"
	Mass		2.2899157275316903e-09
	Radius		10.096290850556647

	Orbit
	{
		Epoch			2457395.5
		Period			0.003278642905833578
		Eccentricity	0.0030807862823202495
		Inclination		302.64097461024977
		AscendingNode	279.55909682182
		ArgOfPericen	268.6133123798797
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 210 B"
{
	ParentBody	"HeliosC 210"
	Class		"Asteroid"
	Mass		1.2726616071698447e-09
	Radius		8.300922019804299

	Orbit
	{
		Epoch			2457395.5
		Period			0.003278642905833578
		Eccentricity	0.0030807862823202495
		Inclination		302.64097461024977
		AscendingNode	279.55909682182
		ArgOfPericen	88.61331237987969
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 211"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.936920007888547e-09
	Radius		15.361981330399166

	RotationPeriod	5.903583389577439

	Obliquity		95.85882616054438

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.010135376725167
		Eccentricity	0.40521911382042786
		Inclination		0.06648792732112543
		AscendingNode	66.65602869003006
		ArgOfPericen	71.00847641462327
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 212"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.94790556905065
		Eccentricity	0.47263448726579155
		Inclination		-16.388521362436904
		AscendingNode	356.35050881532663
		ArgOfPericen	264.1940158676791
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 212 A"
{
	ParentBody	"HeliosC 212"
	Class		"Asteroid"
	Mass		8.558450517167385e-09
	Radius		15.84245403004418

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016282778079261973
		Eccentricity	0.0037440470854083153
		Inclination		45.69305825597431
		AscendingNode	345.8362526049831
		ArgOfPericen	190.12342574703882
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 212 B"
{
	ParentBody	"HeliosC 212"
	Class		"Asteroid"
	Mass		5.37570084766916e-09
	Radius		13.567581482440577

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016282778079261973
		Eccentricity	0.0037440470854083153
		Inclination		45.69305825597431
		AscendingNode	345.8362526049831
		ArgOfPericen	10.123425747038823
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 213"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.679605386339304
		Eccentricity	0.4251040926628029
		Inclination		7.305567198501433
		AscendingNode	227.2548145870689
		ArgOfPericen	264.2646695205239
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 213 A"
{
	ParentBody	"HeliosC 213"
	Class		"Asteroid"
	Mass		1.8815445950174142e-09
	Radius		9.635892465644815

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025416955156916726
		Eccentricity	0.005763654346991143
		Inclination		51.66873917883334
		AscendingNode	342.5428156364757
		ArgOfPericen	16.61302892838705
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 213 B"
{
	ParentBody	"HeliosC 213"
	Class		"Asteroid"
	Mass		2.965668295130511e-10
	Radius		5.2050866553357915

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025416955156916726
		Eccentricity	0.005763654346991143
		Inclination		51.66873917883334
		AscendingNode	342.5428156364757
		ArgOfPericen	196.61302892838705
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 214"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.228418797482191e-10
	Radius		5.53114245357158

	RotationPeriod	5.21204116946109

	Obliquity		174.71142448672342

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.66253580794097
		Eccentricity	0.4908714906860698
		Inclination		28.861997920144507
		AscendingNode	47.899731568989
		ArgOfPericen	3.871797115711657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 215"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0511710864148856e-08
	Radius		17.683348841661797

	RotationPeriod	4.801470067779256

	Obliquity		167.0154334311579

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.16522225463248
		Eccentricity	0.6754242266514741
		Inclination		-37.393551559769044
		AscendingNode	237.3794536826921
		ArgOfPericen	40.674905799076065
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 216"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.45713494998492
		Eccentricity	0.4412053841850686
		Inclination		56.14743771692448
		AscendingNode	122.82834141366413
		ArgOfPericen	136.92090343356983
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 216 A"
{
	ParentBody	"HeliosC 216"
	Class		"Asteroid"
	Mass		2.7018781366597055e-09
	Radius		11.275229067163067

	Orbit
	{
		Epoch			2457395.5
		Period			0.005388304169386943
		Eccentricity	0.005151476466731655
		Inclination		98.17764446121596
		AscendingNode	209.95604485223825
		ArgOfPericen	114.36108048887601
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 216 B"
{
	ParentBody	"HeliosC 216"
	Class		"Asteroid"
	Mass		5.952129279439942e-10
	Radius		6.809693628340742

	Orbit
	{
		Epoch			2457395.5
		Period			0.005388304169386943
		Eccentricity	0.005151476466731655
		Inclination		98.17764446121596
		AscendingNode	209.95604485223825
		ArgOfPericen	294.36108048887604
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 217"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.400468889787541e-09
	Radius		12.211468223388836

	RotationPeriod	6.715838504602543

	Obliquity		227.21221870790274

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.2855768736999
		Eccentricity	0.3079464098461215
		Inclination		40.77148732485
		AscendingNode	233.66823633317892
		ArgOfPericen	145.02675697436462
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 218"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.641172362613487e-09
	Radius		10.59781668033099

	RotationPeriod	1.9259690504995035

	Obliquity		172.16313595472053

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.13542965520278
		Eccentricity	0.7334650408589143
		Inclination		-24.731932366590335
		AscendingNode	125.95079989047524
		ArgOfPericen	70.45268469577726
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 219"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.02501384443674
		Eccentricity	0.2318502804664841
		Inclination		-60.00724868847611
		AscendingNode	206.9338482217195
		ArgOfPericen	342.7707253338285
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 219 A"
{
	ParentBody	"HeliosC 219"
	Class		"Asteroid"
	Mass		1.504456141469144e-08
	Radius		19.261256452068103

	Orbit
	{
		Epoch			2457395.5
		Period			0.00586660610444546
		Eccentricity	0.004633201154450431
		Inclination		337.87874592469024
		AscendingNode	116.40009453375296
		ArgOfPericen	24.236700140753197
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 219 B"
{
	ParentBody	"HeliosC 219"
	Class		"Asteroid"
	Mass		1.0704334934133433e-09
	Radius		7.981380206494601

	Orbit
	{
		Epoch			2457395.5
		Period			0.00586660610444546
		Eccentricity	0.004633201154450431
		Inclination		337.87874592469024
		AscendingNode	116.40009453375296
		ArgOfPericen	204.2367001407532
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 220"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.693013380352664
		Eccentricity	0.44663057405806483
		Inclination		12.68970652417006
		AscendingNode	286.49089129333686
		ArgOfPericen	221.87392006664336
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 220 A"
{
	ParentBody	"HeliosC 220"
	Class		"Asteroid"
	Mass		4.159441011909665e-09
	Radius		13.029343122686944

	Orbit
	{
		Epoch			2457395.5
		Period			0.007462152349824603
		Eccentricity	0.006368702419593985
		Inclination		310.8032023447627
		AscendingNode	109.47558735745332
		ArgOfPericen	203.56023523157273
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 220 B"
{
	ParentBody	"HeliosC 220"
	Class		"Asteroid"
	Mass		6.499202279543917e-10
	Radius		7.0177444490914995

	Orbit
	{
		Epoch			2457395.5
		Period			0.007462152349824603
		Eccentricity	0.006368702419593985
		Inclination		310.8032023447627
		AscendingNode	109.47558735745332
		ArgOfPericen	23.560235231572733
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 221"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.789064533194388e-09
	Radius		12.326240259259631

	RotationPeriod	7.52617973032509

	Obliquity		48.302773552671326

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.28284270314468
		Eccentricity	0.5089712070808098
		Inclination		4.213301765752549
		AscendingNode	95.55092759285472
		ArgOfPericen	332.85017203593236
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 222"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.51731071015965
		Eccentricity	0.45746139661947227
		Inclination		-53.815310864552615
		AscendingNode	35.67839517306935
		ArgOfPericen	169.43637806979697
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 222 A"
{
	ParentBody	"HeliosC 222"
	Class		"Asteroid"
	Mass		6.8465573857500094e-09
	Radius		14.65314472186085

	Orbit
	{
		Epoch			2457395.5
		Period			0.003651665365417749
		Eccentricity	0.007231301542697903
		Inclination		36.70378811278607
		AscendingNode	235.0413567241419
		ArgOfPericen	192.77593984821442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 222 B"
{
	ParentBody	"HeliosC 222"
	Class		"Asteroid"
	Mass		6.481033389866593e-10
	Radius		6.678129569919495

	Orbit
	{
		Epoch			2457395.5
		Period			0.003651665365417749
		Eccentricity	0.007231301542697903
		Inclination		36.70378811278607
		AscendingNode	235.0413567241419
		ArgOfPericen	12.77593984821442
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 223"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.132624822328918
		Eccentricity	0.7543800442982557
		Inclination		-69.12248448738247
		AscendingNode	86.19905639224375
		ArgOfPericen	57.99011975194681
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 223 A"
{
	ParentBody	"HeliosC 223"
	Class		"Asteroid"
	Mass		2.4256103175837674e-09
	Radius		10.176627693839112

	Orbit
	{
		Epoch			2457395.5
		Period			0.004614377236214945
		Eccentricity	0.0037014996986612565
		Inclination		121.81439517357725
		AscendingNode	5.095063868615002
		ArgOfPericen	355.30096403713657
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 223 B"
{
	ParentBody	"HeliosC 223"
	Class		"Asteroid"
	Mass		3.5621164951907353e-10
	Radius		5.369076378630315

	Orbit
	{
		Epoch			2457395.5
		Period			0.004614377236214945
		Eccentricity	0.0037014996986612565
		Inclination		121.81439517357725
		AscendingNode	5.095063868615002
		ArgOfPericen	175.3009640371365
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 224"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.3834257402108065e-09
	Radius		13.088601072207107

	RotationPeriod	5.166602184757267

	Obliquity		331.91638692659586

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	50.0
		Eccentricity	0.45527228957644783
		Inclination		11.785508134351968
		AscendingNode	227.88083456807857
		ArgOfPericen	351.4714241559208
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 225"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.681881812761402
		Eccentricity	0.31340324106585626
		Inclination		169.97123143413262
		AscendingNode	139.5264270357746
		ArgOfPericen	121.01181437532433
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 225 A"
{
	ParentBody	"HeliosC 225"
	Class		"Asteroid"
	Mass		1.3356701031715065e-08
	Radius		18.1844583651112

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016975286906767287
		Eccentricity	0.003602894019870434
		Inclination		25.416672897114587
		AscendingNode	277.96369863536574
		ArgOfPericen	336.87446203229734
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 225 B"
{
	ParentBody	"HeliosC 225"
	Class		"Asteroid"
	Mass		1.12499835334959e-08
	Radius		17.17320142311882

	Orbit
	{
		Epoch			2457395.5
		Period			0.0016975286906767287
		Eccentricity	0.003602894019870434
		Inclination		25.416672897114587
		AscendingNode	277.96369863536574
		ArgOfPericen	156.8744620322973
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 226"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1849831851514786e-08
	Radius		17.24010166398058

	RotationPeriod	8.884741066781949

	Obliquity		26.701881992764687

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.565021860576344
		Eccentricity	0.553756572412951
		Inclination		47.33340273605318
		AscendingNode	239.11090501575936
		ArgOfPericen	158.5423546164069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 227"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.4815849449385387e-09
	Radius		12.31404325753302

	RotationPeriod	6.895328499732744

	Obliquity		162.67464803357166

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.541068144317084
		Eccentricity	0.5410014840189913
		Inclination		-73.35837699528189
		AscendingNode	332.34125398151144
		ArgOfPericen	280.3893513310817
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 228"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.536770349634759e-08
	Radius		18.94541826548086

	RotationPeriod	10.260099877336891

	Obliquity		104.02917680959715

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.644657815393469
		Eccentricity	0.6660005526754292
		Inclination		48.00407959743818
		AscendingNode	139.81246847106576
		ArgOfPericen	236.48755056582266
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 229"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.79052884784694e-09
	Radius		14.81623805278858

	RotationPeriod	6.2750597595134305

	Obliquity		133.1288358905226

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.657669584485614
		Eccentricity	0.5214437922600487
		Inclination		50.03044518223438
		AscendingNode	276.45581670775266
		ArgOfPericen	308.65081230502943
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 230"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.077583644564607e-09
	Radius		13.683959285998847

	RotationPeriod	8.245039745919808

	Obliquity		107.93266078176003

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.614595588053103
		Eccentricity	0.833232331258474
		Inclination		145.6673287200697
		AscendingNode	303.8247624596642
		ArgOfPericen	344.44553400510284
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 231"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.055547819769658e-09
	Radius		17.061820326544783

	RotationPeriod	5.987784268010225

	Obliquity		109.57012616360068

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.71560009602897
		Eccentricity	0.4940735219782738
		Inclination		-22.202830600366767
		AscendingNode	355.70667246227646
		ArgOfPericen	90.99720099249227
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 232"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1955335057735637e-09
	Radius		8.43543170015856

	RotationPeriod	7.149468094654127

	Obliquity		262.74140425262635

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.234481696816843
		Eccentricity	0.7420494732594525
		Inclination		47.93144037003595
		AscendingNode	257.65263695083235
		ArgOfPericen	144.97384973305876
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 233"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.8325196768728698e-09
	Radius		9.334581115197395

	RotationPeriod	6.213010806908735

	Obliquity		157.07248684011716

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.723651122469324
		Eccentricity	0.41913000471242706
		Inclination		-79.99798572044544
		AscendingNode	126.49229928516735
		ArgOfPericen	224.494887151853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 234"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.5268053199965934e-09
	Radius		10.769018834477276

	RotationPeriod	8.144822654070193

	Obliquity		357.2775404077321

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.596256217782916
		Eccentricity	0.6581489832569478
		Inclination		51.73620645187694
		AscendingNode	140.6965433610851
		ArgOfPericen	170.90118503171738
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 235"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.0079968881282423e-08
	Radius		17.652645865956927

	RotationPeriod	7.914363508645534

	Obliquity		49.055635409243486

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.86958467816929
		Eccentricity	0.5117669655559307
		Inclination		-60.416697846443256
		AscendingNode	24.278319837241227
		ArgOfPericen	8.060289662438041
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 236"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.35278090730788
		Eccentricity	0.4655200847921188
		Inclination		13.800923714318321
		AscendingNode	78.86504982640048
		ArgOfPericen	191.5807478815953
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 236 A"
{
	ParentBody	"HeliosC 236"
	Class		"Asteroid"
	Mass		2.0389578753995037e-09
	Radius		9.69811241689718

	Orbit
	{
		Epoch			2457395.5
		Period			0.0038657623227278306
		Eccentricity	0.00430657589102143
		Inclination		286.7902976985483
		AscendingNode	26.688220486478013
		ArgOfPericen	320.5533258968358
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 236 B"
{
	ParentBody	"HeliosC 236"
	Class		"Asteroid"
	Mass		1.6360739773371628e-09
	Radius		9.011950034793799

	Orbit
	{
		Epoch			2457395.5
		Period			0.0038657623227278306
		Eccentricity	0.00430657589102143
		Inclination		286.7902976985483
		AscendingNode	26.688220486478013
		ArgOfPericen	140.55332589683582
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 237"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.708605036290552e-10
	Radius		7.466086213902201

	RotationPeriod	5.367813702919884

	Obliquity		211.38949864837923

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.228367172590985
		Eccentricity	0.3865980142484342
		Inclination		30.685587054629664
		AscendingNode	249.09857137231774
		ArgOfPericen	33.3513858250192
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 238"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.121767513762254e-10
	Radius		8.109254222793357

	RotationPeriod	6.488334978460248

	Obliquity		40.83199257538271

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.807335461347883
		Eccentricity	0.21655479689054258
		Inclination		6.17176225965403
		AscendingNode	335.05827170414705
		ArgOfPericen	66.7628878337247
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 239"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.021859556605726e-09
	Radius		16.047108366462375

	RotationPeriod	4.25789776573679

	Obliquity		204.31152271846642

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.64205805646239
		Eccentricity	0.44965989761210706
		Inclination		-33.049741120976854
		AscendingNode	108.98615868630094
		ArgOfPericen	333.12623631636114
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 240"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.08938579342002
		Eccentricity	0.3746204465068037
		Inclination		1.1374814092991812
		AscendingNode	53.213888946377594
		ArgOfPericen	15.977034390621704
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 240 A"
{
	ParentBody	"HeliosC 240"
	Class		"Asteroid"
	Mass		1.4137226101917142e-09
	Radius		9.111451137252937

	Orbit
	{
		Epoch			2457395.5
		Period			0.002899069433536279
		Eccentricity	0.0028472954272953706
		Inclination		117.47811022367095
		AscendingNode	106.74945382872686
		ArgOfPericen	195.92324168247308
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 240 B"
{
	ParentBody	"HeliosC 240"
	Class		"Asteroid"
	Mass		4.7924517669185016e-11
	Radius		2.9488458197401606

	Orbit
	{
		Epoch			2457395.5
		Period			0.002899069433536279
		Eccentricity	0.0028472954272953706
		Inclination		117.47811022367095
		AscendingNode	106.74945382872686
		ArgOfPericen	15.923241682473076
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 241"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.7728158684236344e-09
	Radius		10.085894573371483

	RotationPeriod	6.978040998379497

	Obliquity		298.9410925766509

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.665638922129055
		Eccentricity	0.4922142671589552
		Inclination		-1.709998966818207
		AscendingNode	23.89367770239094
		ArgOfPericen	152.70396512538943
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 242"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6484106270899184e-09
	Radius		9.669701051104138

	RotationPeriod	0.30550657212910437

	Obliquity		2.922975942981947

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.860138142057746
		Eccentricity	0.532268053932639
		Inclination		13.915293185508753
		AscendingNode	328.51062534356714
		ArgOfPericen	33.17997005871605
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 243"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.44312513961205e-09
	Radius		9.932340332179658

	RotationPeriod	8.094493165637893

	Obliquity		86.27013586825024

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.99145756617512
		Eccentricity	0.6533532042885949
		Inclination		-33.690866685602046
		AscendingNode	9.92794808539228
		ArgOfPericen	194.3082400350999
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 244"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3062194361155423e-09
	Radius		8.696382586675748

	RotationPeriod	6.826866592138586

	Obliquity		230.92488806118763

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.61429876176016
		Eccentricity	0.3381684473102301
		Inclination		-55.01601949411006
		AscendingNode	19.62123287809741
		ArgOfPericen	289.72191198065764
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 245"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.587400899356126e-09
	Radius		13.515975553204086

	RotationPeriod	5.581020075021631

	Obliquity		345.56858963293803

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.0368442858425
		Eccentricity	0.580701329250757
		Inclination		13.786498265719098
		AscendingNode	109.00403201241775
		ArgOfPericen	96.40704878038865
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 246"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	42.0938098578588
		Eccentricity	0.47580291659745366
		Inclination		-70.44291074855114
		AscendingNode	359.3149390475575
		ArgOfPericen	196.9263746550444
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 246 A"
{
	ParentBody	"HeliosC 246"
	Class		"Asteroid"
	Mass		6.780724623818814e-10
	Radius		7.235449228674457

	Orbit
	{
		Epoch			2457395.5
		Period			0.002497872142436369
		Eccentricity	0.005062072783763962
		Inclination		185.1310957466497
		AscendingNode	101.14289817214967
		ArgOfPericen	99.40320305565183
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 246 B"
{
	ParentBody	"HeliosC 246"
	Class		"Asteroid"
	Mass		2.9502427061653134e-10
	Radius		5.482677655964287

	Orbit
	{
		Epoch			2457395.5
		Period			0.002497872142436369
		Eccentricity	0.005062072783763962
		Inclination		185.1310957466497
		AscendingNode	101.14289817214967
		ArgOfPericen	279.40320305565183
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 247"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.028620665323757
		Eccentricity	0.3027984129497498
		Inclination		26.51804844165207
		AscendingNode	149.89996323545796
		ArgOfPericen	174.2211976323482
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 247 A"
{
	ParentBody	"HeliosC 247"
	Class		"Asteroid"
	Mass		8.906874437391288e-10
	Radius		7.48742517444482

	Orbit
	{
		Epoch			2457395.5
		Period			0.0039138830891629756
		Eccentricity	0.004543007958519763
		Inclination		335.23043832278046
		AscendingNode	239.0202998390725
		ArgOfPericen	181.31486169299117
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 247 B"
{
	ParentBody	"HeliosC 247"
	Class		"Asteroid"
	Mass		3.622371570802765e-10
	Radius		5.547385975308745

	Orbit
	{
		Epoch			2457395.5
		Period			0.0039138830891629756
		Eccentricity	0.004543007958519763
		Inclination		335.23043832278046
		AscendingNode	239.0202998390725
		ArgOfPericen	1.314861692991144
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 248"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.039684170325586
		Eccentricity	0.328154034323397
		Inclination		-9.741599642199397
		AscendingNode	29.810172174412415
		ArgOfPericen	99.87824302872176
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 248 A"
{
	ParentBody	"HeliosC 248"
	Class		"Asteroid"
	Mass		5.880172574322544e-10
	Radius		6.3014056681878055

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029764367773560956
		Eccentricity	0.005285369993841129
		Inclination		98.2290737377268
		AscendingNode	134.24335124227935
		ArgOfPericen	178.89885171367797
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 248 B"
{
	ParentBody	"HeliosC 248"
	Class		"Asteroid"
	Mass		4.133999206991266e-10
	Radius		5.603132314841912

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029764367773560956
		Eccentricity	0.005285369993841129
		Inclination		98.2290737377268
		AscendingNode	134.24335124227935
		ArgOfPericen	358.89885171367797
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 249"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.8101213263588446e-09
	Radius		11.69756773066389

	RotationPeriod	8.755004823593648

	Obliquity		2.835457394902101

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.364441550596496
		Eccentricity	0.23953463273011766
		Inclination		49.96460136052202
		AscendingNode	59.462850482308475
		ArgOfPericen	205.48112413611616
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 250"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1287533547817981e-08
	Radius		17.280328548311907

	RotationPeriod	7.271871400007517

	Obliquity		5.244211798764109

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.068809694019205
		Eccentricity	0.49283903429424414
		Inclination		36.79431798190285
		AscendingNode	304.48471260031306
		ArgOfPericen	131.74928385987928
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 251"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.3304415278503627e-08
	Radius		18.012246398881928

	RotationPeriod	5.641754974330828

	Obliquity		127.75348783920627

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.748624504145667
		Eccentricity	0.6178284156061375
		Inclination		-149.59452099838907
		AscendingNode	191.45208899493525
		ArgOfPericen	295.92630177382927
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 252"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.043899187882347e-10
	Radius		7.766416012309524

	RotationPeriod	10.8066881623116

	Obliquity		180.18991156200323

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.71004289689472
		Eccentricity	0.2566740863686048
		Inclination		-37.9267382439468
		AscendingNode	173.85006167158502
		ArgOfPericen	88.02150050024511
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 253"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.689375186443677e-09
	Radius		16.18526698829297

	RotationPeriod	7.958026574754286

	Obliquity		11.761911966224968

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.63979415972004
		Eccentricity	0.3805105984654314
		Inclination		-25.800398855280516
		AscendingNode	101.58788766964555
		ArgOfPericen	78.70906793558034
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 254"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.455778463045173e-09
	Radius		10.64298341295156

	RotationPeriod	3.6950288950743713

	Obliquity		185.15475913345045

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.274482695494076
		Eccentricity	0.6832884851941634
		Inclination		-37.43374121777445
		AscendingNode	308.73004874114923
		ArgOfPericen	249.42980752550335
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 255"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4751199611010436e-10
	Radius		4.4961290150581

	RotationPeriod	4.86820503174693

	Obliquity		273.0297181759214

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.28460367900773
		Eccentricity	0.6571471963351153
		Inclination		20.026183623785457
		AscendingNode	54.19766664959623
		ArgOfPericen	147.5329599533911
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 256"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		8.28016067407138e-09
	Radius		16.852455642303255

	RotationPeriod	7.4648595283239185

	Obliquity		55.19977548651739

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.165741810281375
		Eccentricity	0.350213309472284
		Inclination		53.08493258393585
		AscendingNode	188.7567829004203
		ArgOfPericen	13.109559126781182
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 257"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.025925868134628e-09
	Radius		10.613194517360192

	RotationPeriod	5.422291576487396

	Obliquity		235.38271083743348

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.11103269550477
		Eccentricity	0.3262419405118152
		Inclination		62.8709076644741
		AscendingNode	145.7411494508672
		ArgOfPericen	100.63991675968332
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 258"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.04492020668109e-08
	Radius		23.867493186665904

	RotationPeriod	7.74083586671538

	Obliquity		4.958636320262948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.74982464721071
		Eccentricity	0.4682595089389667
		Inclination		-31.83971135314988
		AscendingNode	263.754968949371
		ArgOfPericen	80.68902944560494
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 259"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.39609624428975
		Eccentricity	0.6579817134951222
		Inclination		-73.00219921538363
		AscendingNode	186.1732547347266
		ArgOfPericen	72.27068033247954
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 259 A"
{
	ParentBody	"HeliosC 259"
	Class		"Asteroid"
	Mass		9.624839088921777e-09
	Radius		17.86409907343177

	Orbit
	{
		Epoch			2457395.5
		Period			0.005225092291403111
		Eccentricity	0.0044486919687547
		Inclination		248.3296304424392
		AscendingNode	75.77543928007285
		ArgOfPericen	319.7803417954584
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 259 B"
{
	ParentBody	"HeliosC 259"
	Class		"Asteroid"
	Mass		1.6337190618184803e-10
	Radius		4.591018944928748

	Orbit
	{
		Epoch			2457395.5
		Period			0.005225092291403111
		Eccentricity	0.0044486919687547
		Inclination		248.3296304424392
		AscendingNode	75.77543928007285
		ArgOfPericen	139.7803417954584
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 260"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.297029291320442e-09
	Radius		16.80640627185021

	RotationPeriod	9.432554008486935

	Obliquity		112.35679407665681

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.469577750119043
		Eccentricity	0.5443478290230986
		Inclination		17.996138927294403
		AscendingNode	321.7560588936727
		ArgOfPericen	204.04830871351683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 261"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.39815181416577
		Eccentricity	0.2751375869565621
		Inclination		-148.5132748173888
		AscendingNode	223.02135836678931
		ArgOfPericen	210.07073405689076
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 261 A"
{
	ParentBody	"HeliosC 261"
	Class		"Asteroid"
	Mass		3.0529296240597905e-09
	Radius		11.24976645845994

	Orbit
	{
		Epoch			2457395.5
		Period			0.0020068134142095756
		Eccentricity	0.0016334275512403353
		Inclination		261.5913700040237
		AscendingNode	320.5157468545868
		ArgOfPericen	261.0603719821145
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 261 B"
{
	ParentBody	"HeliosC 261"
	Class		"Asteroid"
	Mass		3.103042617291711e-10
	Radius		5.250094924828191

	Orbit
	{
		Epoch			2457395.5
		Period			0.0020068134142095756
		Eccentricity	0.0016334275512403353
		Inclination		261.5913700040237
		AscendingNode	320.5157468545868
		ArgOfPericen	81.06037198211448
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 262"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.897287884729852e-09
	Radius		13.451391568310262

	RotationPeriod	6.79648586653268

	Obliquity		170.34186779773577

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.302386763901826
		Eccentricity	0.4019351049864114
		Inclination		-31.45320495493301
		AscendingNode	358.52098781649244
		ArgOfPericen	4.10931633543171
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 263"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.65491601641712e-09
	Radius		12.847078719376137

	RotationPeriod	3.0422226443585223

	Obliquity		74.53121771634245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.244346371466772
		Eccentricity	0.48575395158209894
		Inclination		64.23021068512334
		AscendingNode	61.15470423998592
		ArgOfPericen	332.9402813812359
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 264"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.982586347376166e-09
	Radius		16.082114484807896

	RotationPeriod	5.441426153038078

	Obliquity		307.7547472438399

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.35370709893219
		Eccentricity	0.6376646429977568
		Inclination		22.361598149287325
		AscendingNode	109.32596410861396
		ArgOfPericen	184.46450628597273
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 265"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.401947914724293e-09
	Radius		13.432182270584091

	RotationPeriod	8.375887732272755

	Obliquity		236.19642505857212

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.74061371055637
		Eccentricity	0.496906827575631
		Inclination		9.169230493200946
		AscendingNode	138.5482952259689
		ArgOfPericen	44.3620417098633
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 266"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.1810537641037933e-08
	Radius		18.45730136253562

	RotationPeriod	7.22900323289226

	Obliquity		64.0086373043253

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.50169957935786
		Eccentricity	0.6075300496226257
		Inclination		5.939703259880968
		AscendingNode	337.0315069875965
		ArgOfPericen	313.88731395901976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 267"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.223596061327272e-08
	Radius		25.0

	RotationPeriod	6.49026253594633

	Obliquity		303.15820619060224

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.798102402075052
		Eccentricity	0.3564522866968515
		Inclination		-58.430934042505896
		AscendingNode	261.11969930068335
		ArgOfPericen	170.70451610109419
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 268"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.0040308030113614e-09
	Radius		10.1190584600856

	RotationPeriod	4.557878337964669

	Obliquity		123.40351370794035

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.444057252455437
		Eccentricity	0.5977710367538913
		Inclination		-11.871599916956649
		AscendingNode	223.8066008559337
		ArgOfPericen	99.06740190783191
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 269"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.571784169675275e-08
	Radius		19.71550358010838

	RotationPeriod	3.8239787464707335

	Obliquity		310.0050443984046

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.40635220243096
		Eccentricity	0.49950262424764574
		Inclination		-0.7714736325859777
		AscendingNode	54.53325258088027
		ArgOfPericen	56.837834485083924
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 270"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.548453907566633e-09
	Radius		15.58052943230569

	RotationPeriod	5.597960957785212

	Obliquity		319.9149334913879

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.011160487828942
		Eccentricity	0.23145064963365403
		Inclination		37.27949271778637
		AscendingNode	70.87240241321027
		ArgOfPericen	323.41251782717023
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 271"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.265870042750173e-08
	Radius		18.539330005299032

	RotationPeriod	4.080818853177725

	Obliquity		34.906372219005036

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.38081207951342
		Eccentricity	0.6468584402195585
		Inclination		67.2984583947963
		AscendingNode	67.73242567893546
		ArgOfPericen	220.60980325268488
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 272"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.6196145213560832e-09
	Radius		9.080533103448321

	RotationPeriod	5.479349598471701

	Obliquity		249.33112462314034

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.474946598641864
		Eccentricity	0.4706752775151747
		Inclination		58.03466045206221
		AscendingNode	221.23486904658805
		ArgOfPericen	354.982475586281
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 273"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		7.451294207474994e-10
	Radius		7.308114970733778

	RotationPeriod	9.731801890628056

	Obliquity		247.47000566722318

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.40240133997635
		Eccentricity	0.5428594620444035
		Inclination		68.40460459538136
		AscendingNode	20.445697424427497
		ArgOfPericen	96.06428301652218
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 274"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.84406376332163e-09
	Radius		12.136870581286754

	RotationPeriod	5.841914716056744

	Obliquity		316.5977916193698

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.571162254360033
		Eccentricity	0.46780536886657104
		Inclination		-45.29031151331035
		AscendingNode	31.279889286482693
		ArgOfPericen	291.3313047870854
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 275"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.172624217222612e-09
	Radius		12.601557137754064

	RotationPeriod	6.369462111110006

	Obliquity		152.68924904449784

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.749123411900968
		Eccentricity	0.6314974790763963
		Inclination		8.636595947903109
		AscendingNode	186.36460481733334
		ArgOfPericen	252.0994529806524
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 276"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.38906215815852e-09
	Radius		12.455636856909774

	RotationPeriod	6.587218391924749

	Obliquity		28.409777649955572

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.27502279741678
		Eccentricity	0.5787996909714662
		Inclination		67.29960630102318
		AscendingNode	176.2908846149385
		ArgOfPericen	342.7583849763144
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 277"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.0973423058660247e-10
	Radius		5.2535492409106865

	RotationPeriod	8.575535469066615

	Obliquity		43.944134008475714

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.433798044280167
		Eccentricity	0.4693181202183929
		Inclination		52.52160799180594
		AscendingNode	262.0238562174736
		ArgOfPericen	259.9202632062866
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 278"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.5729841281522065e-09
	Radius		11.487690588238591

	RotationPeriod	5.804152178533359

	Obliquity		109.6773750639517

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.1324242466699
		Eccentricity	0.33616856414781454
		Inclination		23.446587969209812
		AscendingNode	59.14858138310518
		ArgOfPericen	354.7341177284934
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 279"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.2665274703380113e-09
	Radius		8.94513504859343

	RotationPeriod	8.817433243987502

	Obliquity		301.0848447827396

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.200983492666865
		Eccentricity	0.3006510620702699
		Inclination		15.211381866937325
		AscendingNode	48.24187588634966
		ArgOfPericen	283.1486004619164
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 280"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.599920323194003e-09
	Radius		15.932019741948858

	RotationPeriod	8.598592575100922

	Obliquity		287.5578427158987

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.73696744032607
		Eccentricity	0.24692315000546894
		Inclination		-123.89202112417414
		AscendingNode	152.24840379809118
		ArgOfPericen	155.19666710166317
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 281"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.954340335746375e-08
	Radius		20.564221037574562

	RotationPeriod	10.242915051916514

	Obliquity		219.5062286848973

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.202086963436134
		Eccentricity	0.7397308601138197
		Inclination		60.03671382024236
		AscendingNode	20.0137654496731
		ArgOfPericen	53.90918290213325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 282"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		2.2969125219319884e-09
	Radius		9.68389570067457

	RotationPeriod	4.459708311974316

	Obliquity		4.722837691468991

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.45216119473585
		Eccentricity	0.4091398479924793
		Inclination		77.20389094217951
		AscendingNode	344.23673599825565
		ArgOfPericen	147.53791152757734
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 283"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.965679858618282e-09
	Radius		10.714228928408993

	RotationPeriod	4.417742222913766

	Obliquity		321.01105478883306

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.820919644467708
		Eccentricity	0.2411065732013335
		Inclination		-33.94038625729511
		AscendingNode	137.67757051532826
		ArgOfPericen	146.49489916459834
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 284"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.4121768973348834e-08
	Radius		18.627621270689712

	RotationPeriod	5.926295610726199

	Obliquity		38.28704415959353

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.277138629741629
		Eccentricity	0.4477216880511565
		Inclination		62.254503105587126
		AscendingNode	289.9184629651831
		ArgOfPericen	125.52620777958374
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 285"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.9712575841254496e-09
	Radius		9.682851296072004

	RotationPeriod	8.895813038318249

	Obliquity		205.1332591334201

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.040715621737323
		Eccentricity	0.5429824361367999
		Inclination		36.07931530933628
		AscendingNode	229.126856367712
		ArgOfPericen	326.6030325285138
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 286"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.328517894090112e-09
	Radius		12.455403993361031

	RotationPeriod	6.554521440452962

	Obliquity		33.32500058356729

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.220352662916849
		Eccentricity	0.24179152699586476
		Inclination		-30.678147105250765
		AscendingNode	143.71269946274816
		ArgOfPericen	144.88053314846096
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 287"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.740408101006195e-09
	Radius		14.595528548670519

	RotationPeriod	6.813865348964112

	Obliquity		306.6325239422922

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.532775847534914
		Eccentricity	0.7549047466754468
		Inclination		-49.70666166352213
		AscendingNode	169.2646210057928
		ArgOfPericen	124.27542998618625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 288"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.754812864637628e-09
	Radius		11.665390204133887

	RotationPeriod	5.657464241556851

	Obliquity		270.3751925343474

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	45.89143150363145
		Eccentricity	0.5021295873998227
		Inclination		48.36552400977631
		AscendingNode	253.8631425404204
		ArgOfPericen	18.57884799110306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 289"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.6905565133721727e-09
	Radius		12.41355652702363

	RotationPeriod	6.770209421744814

	Obliquity		256.85156520418747

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.33962859252562
		Eccentricity	0.4638304701651587
		Inclination		-127.63924103159245
		AscendingNode	105.84209050225883
		ArgOfPericen	13.463626843099895
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 290"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.3382480028938375e-09
	Radius		10.791412245912554

	RotationPeriod	7.979337512264813

	Obliquity		329.7693975088626

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.262100311266806
		Eccentricity	0.4734920184354512
		Inclination		52.45992214998542
		AscendingNode	158.7265404670134
		ArgOfPericen	154.67552449117494
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 291"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.092242812974587e-09
	Radius		14.371195913277043

	RotationPeriod	5.9100733563744035

	Obliquity		339.65870115842245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.583080085476126
		Eccentricity	0.21496349472064413
		Inclination		-23.879350357416673
		AscendingNode	59.92508132928776
		ArgOfPericen	324.7656310165173
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 292"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		6.158533001767988e-10
	Radius		7.061025985754805

	RotationPeriod	5.66607504873696

	Obliquity		76.82075200329761

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.934016170872972
		Eccentricity	0.8393638970031054
		Inclination		-44.881247091895744
		AscendingNode	145.71907623450386
		ArgOfPericen	64.27786083305203
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 293"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.3976699831308944e-09
	Radius		12.691278415107059

	RotationPeriod	7.825536921945926

	Obliquity		332.81413735001973

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.622687475679623
		Eccentricity	0.28594688186799705
		Inclination		58.307175190559896
		AscendingNode	61.0423603513485
		ArgOfPericen	278.1372050404743
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 294"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		9.77500818237682e-09
	Radius		18.242406362075492

	RotationPeriod	6.544767425338063

	Obliquity		6.181711529232259

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.6238904970637
		Eccentricity	0.442162966048435
		Inclination		-23.12570213338833
		AscendingNode	116.23623126390736
		ArgOfPericen	84.16760690393434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 295"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.87297539628438
		Eccentricity	0.5376864156006382
		Inclination		66.29236293861274
		AscendingNode	195.47608897059493
		ArgOfPericen	105.10783363374564
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 295 A"
{
	ParentBody	"HeliosC 295"
	Class		"Asteroid"
	Mass		7.78180139684466e-10
	Radius		7.434392142297041

	Orbit
	{
		Epoch			2457395.5
		Period			0.003702905949257528
		Eccentricity	0.004917364281480607
		Inclination		5.70023754264005
		AscendingNode	99.36360224551497
		ArgOfPericen	100.09636899374483
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 295 B"
{
	ParentBody	"HeliosC 295"
	Class		"Asteroid"
	Mass		7.623140523470764e-10
	Radius		7.3835189307043745

	Orbit
	{
		Epoch			2457395.5
		Period			0.003702905949257528
		Eccentricity	0.004917364281480607
		Inclination		5.70023754264005
		AscendingNode	99.36360224551497
		ArgOfPericen	280.0963689937448
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 296"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		1.5793130325932775e-08
	Radius		20.02014893672355

	RotationPeriod	5.903582875411274

	Obliquity		289.62324067005676

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.205401413253696
		Eccentricity	0.6782018116337574
		Inclination		-87.48189268478676
		AscendingNode	352.90048684130386
		ArgOfPericen	157.77193872467916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosC 297"
{
	ParentBody	"Helios GAM"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.0879397370363
		Eccentricity	0.4656162286703146
		Inclination		-62.90031263916289
		AscendingNode	343.68699570815835
		ArgOfPericen	137.9787332922945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 297 A"
{
	ParentBody	"HeliosC 297"
	Class		"Asteroid"
	Mass		1.88415849953583e-09
	Radius		9.642844523186929

	Orbit
	{
		Epoch			2457395.5
		Period			0.004562863320385388
		Eccentricity	0.009707040412309995
		Inclination		320.1725435440579
		AscendingNode	295.1052847322068
		ArgOfPericen	296.7733488837737
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosC 297 B"
{
	ParentBody	"HeliosC 297"
	Class		"Asteroid"
	Mass		3.6338611651593124e-10
	Radius		5.571286128683008

	Orbit
	{
		Epoch			2457395.5
		Period			0.004562863320385388
		Eccentricity	0.009707040412309995
		Inclination		320.1725435440579
		AscendingNode	295.1052847322068
		ArgOfPericen	116.77334888377368
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 298"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		5.610731023265718e-09
	Radius		13.212396804518342

	RotationPeriod	5.154076965323074

	Obliquity		213.2595974304466

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.038742749833904
		Eccentricity	0.49633300094242144
		Inclination		93.39234883156841
		AscendingNode	221.73841689580524
		ArgOfPericen	335.00130408868523
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 299"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		3.149939328508858e-09
	Radius		11.544233921233197

	RotationPeriod	9.66128724744343

	Obliquity		26.68471046856377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.142339951754956
		Eccentricity	0.39471831068262936
		Inclination		-7.994729567972135
		AscendingNode	253.95287833605636
		ArgOfPericen	315.959260199412
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosC 300"
{
	ParentBody	"Helios GAM"
	Class		"Asteroid"
	Mass		4.0328869186969155e-09
	Radius		13.051123448425152

	RotationPeriod	3.3017514678209823

	Obliquity		171.6020692104567

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.68584680646167
		Eccentricity	0.5686715187938003
		Inclination		25.46717174086599
		AscendingNode	51.31997901019958
		ArgOfPericen	357.94868975561434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
// Helios Delta comets ---------------------------------------------------------
//------------------------------------------------------------------------------
Comet "HeliosD 1"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4796313998253434e-09
	Radius		10.94025543085149

	RotationPeriod	4.134692469263795

	Obliquity		240.74567514447915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.93925172166607
		Eccentricity	0.6725068924914971
		Inclination		9.304533208238869
		AscendingNode	226.71791581219782
		ArgOfPericen	250.57631015242515
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 2"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.2835982063378565e-09
	Radius		14.567759751805712

	RotationPeriod	7.09799829296973

	Obliquity		105.63149985431019

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.986836716751895
		Eccentricity	0.4359422954210575
		Inclination		57.79458629774575
		AscendingNode	88.72105921730619
		ArgOfPericen	266.50879854265645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 3"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0347583539132208e-08
	Radius		16.953131742780858

	RotationPeriod	5.1279423470675125

	Obliquity		283.4770634954832

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	41.43808974823928
		Eccentricity	0.7025914905868456
		Inclination		-62.67507219930778
		AscendingNode	125.12243587345432
		ArgOfPericen	304.40110781554694
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 4"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5241232201994837e-09
	Radius		10.587451704641937

	RotationPeriod	7.444221577673069

	Obliquity		167.28651407012376

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.99250120027382
		Eccentricity	0.35455388052924863
		Inclination		-56.87120775439977
		AscendingNode	83.19866866341616
		ArgOfPericen	66.31008931658816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 5"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.943702357079682e-10
	Radius		7.9622342391709955

	RotationPeriod	7.680797492728655

	Obliquity		237.47660241924532

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.523265129715824
		Eccentricity	0.5583622815647805
		Inclination		-8.528834931933556
		AscendingNode	196.76623609924235
		ArgOfPericen	62.183331923390995
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 6"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9893727856416072e-09
	Radius		10.112639490266787

	RotationPeriod	3.225549278369522

	Obliquity		97.00218957238478

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.47823949763437
		Eccentricity	0.45273553185974197
		Inclination		-11.80658142516668
		AscendingNode	342.83539022814296
		ArgOfPericen	38.434910246404044
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 7"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.44052190089063e-10
	Radius		7.8408621343392415

	RotationPeriod	6.995854222846893

	Obliquity		244.57074855087458

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.087568352936806
		Eccentricity	0.7825606015546742
		Inclination		36.12793871933899
		AscendingNode	69.72982058488809
		ArgOfPericen	58.993119317439515
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 8"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.005489304323567e-09
	Radius		15.568385289859316

	RotationPeriod	8.581641964501577

	Obliquity		125.51793123630733

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.775748119091602
		Eccentricity	0.5734990396244397
		Inclination		36.931878673921
		AscendingNode	28.402815988723887
		ArgOfPericen	84.66564144053899
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 9"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.77591288259045
		Eccentricity	0.6285181082869298
		Inclination		25.93097596376917
		AscendingNode	61.06218599093848
		ArgOfPericen	144.46895309086432
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 9 A"
{
	ParentBody	"HeliosD 9"
	Class		"Asteroid"
	Mass		6.7590213555325145e-09
	Radius		15.239437531318597

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011499199901115306
		Eccentricity	0.005731808971617763
		Inclination		24.06221666337808
		AscendingNode	120.01259760278631
		ArgOfPericen	297.3578908052936
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 9 B"
{
	ParentBody	"HeliosD 9"
	Class		"Asteroid"
	Mass		2.5336893571158164e-10
	Radius		5.1002577080428875

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011499199901115306
		Eccentricity	0.005731808971617763
		Inclination		24.06221666337808
		AscendingNode	120.01259760278631
		ArgOfPericen	117.35789080529361
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 10"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8766741597876927e-09
	Radius		9.948367052590324

	RotationPeriod	4.660019555308752

	Obliquity		164.5870297023546

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.523817972018874
		Eccentricity	0.47049013605731427
		Inclination		-51.14363293321832
		AscendingNode	183.10545252546922
		ArgOfPericen	320.72421021975674
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 11"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.828602364774209e-09
	Radius		15.381197304056837

	RotationPeriod	5.512451627673157

	Obliquity		311.0268790428105

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.82152307239107
		Eccentricity	0.6086576806591552
		Inclination		-78.21308319794876
		AscendingNode	140.35473843353486
		ArgOfPericen	77.21906114694903
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 12"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.730164300033017e-10
	Radius		4.504846948306691

	RotationPeriod	6.160931242376684

	Obliquity		29.863256100432615

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.51635631873853
		Eccentricity	0.42912944761631105
		Inclination		-15.546586474984123
		AscendingNode	21.203513700038524
		ArgOfPericen	157.9667323532172
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 13"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.070902837301763e-09
	Radius		13.048549092208146

	RotationPeriod	6.893890529197844

	Obliquity		312.45877315330534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.81702001584944
		Eccentricity	0.4457548052514058
		Inclination		-58.70610594581893
		AscendingNode	262.83475057735114
		ArgOfPericen	0.7469713763609587
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 14"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.99988036872331e-09
	Radius		16.051658842628242

	RotationPeriod	7.403178026331859

	Obliquity		301.3984023738927

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	41.237979602974235
		Eccentricity	0.6760612329607325
		Inclination		24.07799112527662
		AscendingNode	236.96822131186403
		ArgOfPericen	272.15194950643223
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 15"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.870186358510257e-09
	Radius		15.613965104077709

	RotationPeriod	6.487125763047744

	Obliquity		194.9216325137091

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.01823027921777
		Eccentricity	0.6488546766097407
		Inclination		-39.26610122091421
		AscendingNode	116.90251675941887
		ArgOfPericen	328.3949316093313
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 16"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0212682279942688e-08
	Radius		17.329242268156378

	RotationPeriod	6.032565006392512

	Obliquity		237.3845318997793

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.35507929787361
		Eccentricity	0.5573992321184915
		Inclination		8.73508418143304
		AscendingNode	183.9246881995116
		ArgOfPericen	272.5000630308133
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 17"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.16143218577582
		Eccentricity	0.41114878834444024
		Inclination		18.464615498070042
		AscendingNode	16.78904281605146
		ArgOfPericen	333.236316092762
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 17 A"
{
	ParentBody	"HeliosD 17"
	Class		"Asteroid"
	Mass		7.622316395660399e-09
	Radius		15.55159018789875

	Orbit
	{
		Epoch			2457395.5
		Period			0.001456880616496179
		Eccentricity	0.004450389534966171
		Inclination		68.3440966782429
		AscendingNode	235.60561878791057
		ArgOfPericen	91.31386656948546
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 17 B"
{
	ParentBody	"HeliosD 17"
	Class		"Asteroid"
	Mass		9.191835385777177e-10
	Radius		7.683278200653234

	Orbit
	{
		Epoch			2457395.5
		Period			0.001456880616496179
		Eccentricity	0.004450389534966171
		Inclination		68.3440966782429
		AscendingNode	235.60561878791057
		ArgOfPericen	271.31386656948547
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 18"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.74983167177368
		Eccentricity	0.5607954003250742
		Inclination		-33.947705711371796
		AscendingNode	358.2992456622013
		ArgOfPericen	18.486401088124357
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 18 A"
{
	ParentBody	"HeliosD 18"
	Class		"Asteroid"
	Mass		1.0430144190366658e-09
	Radius		7.732307701288272

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014691433709893215
		Eccentricity	0.007251660486443838
		Inclination		318.15666368801396
		AscendingNode	39.57441488593555
		ArgOfPericen	3.180989025878884
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 18 B"
{
	ParentBody	"HeliosD 18"
	Class		"Asteroid"
	Mass		1.9102927545151577e-10
	Radius		4.391157355502758

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014691433709893215
		Eccentricity	0.007251660486443838
		Inclination		318.15666368801396
		AscendingNode	39.57441488593555
		ArgOfPericen	183.1809890258789
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 19"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.761883195764072e-10
	Radius		5.254219244109401

	RotationPeriod	5.999121336841315

	Obliquity		335.2580810996407

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.648440285609666
		Eccentricity	0.5596915094306314
		Inclination		-30.068329336080154
		AscendingNode	128.48098727073122
		ArgOfPericen	337.68024560499236
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 20"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.909099642538199e-09
	Radius		13.540775055798399

	RotationPeriod	7.70025456934032

	Obliquity		68.70762167082937

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.5985239533253
		Eccentricity	0.47563332110186246
		Inclination		-34.30664998741672
		AscendingNode	268.5473131787639
		ArgOfPericen	101.05266620969508
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 21"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5842249247755344e-08
	Radius		22.11938682514959

	RotationPeriod	10.941861444548291

	Obliquity		105.86799334341164

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.42230824359619
		Eccentricity	0.23905983418602905
		Inclination		45.121260361714235
		AscendingNode	220.8786864792716
		ArgOfPericen	359.29126142533295
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 22"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0452950502650887e-09
	Radius		10.358393144410302

	RotationPeriod	4.213888752973965

	Obliquity		201.55618457193506

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.05096631132223
		Eccentricity	0.7203815239891745
		Inclination		46.97536075974446
		AscendingNode	150.21437576120857
		ArgOfPericen	136.04636869428623
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 23"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.5820736001249197e-09
	Radius		11.683031910945425

	RotationPeriod	6.253778975355532

	Obliquity		113.30226209739817

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.903711889793932
		Eccentricity	0.3340295957090015
		Inclination		44.151882450149294
		AscendingNode	241.72288123459668
		ArgOfPericen	283.79485220709046
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 24"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.028719946053407e-09
	Radius		12.309533631920457

	RotationPeriod	6.084617399097419

	Obliquity		134.77757563537418

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.89802679698957
		Eccentricity	0.6696366487674055
		Inclination		62.25439556248971
		AscendingNode	264.57178983242267
		ArgOfPericen	179.8390579224229
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 25"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.142070860834927e-09
	Radius		8.602852417090332

	RotationPeriod	3.6951150837593945

	Obliquity		22.82999759312147

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.07615069571456
		Eccentricity	0.2842092002548994
		Inclination		24.717451844540246
		AscendingNode	321.89651656412417
		ArgOfPericen	98.44711151792396
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 26"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.563070618855325e-09
	Radius		14.490179664515109

	RotationPeriod	6.472480330582458

	Obliquity		330.15650988928513

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	40.61945860789908
		Eccentricity	0.4995713675919598
		Inclination		25.203329817519105
		AscendingNode	333.7641951212981
		ArgOfPericen	290.76563103415776
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 27"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.646461120189553
		Eccentricity	0.5954043088016417
		Inclination		-32.95896672721508
		AscendingNode	168.39926840093543
		ArgOfPericen	279.71415257758383
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 27 A"
{
	ParentBody	"HeliosD 27"
	Class		"Asteroid"
	Mass		1.6157847929355578e-10
	Radius		4.411266326376394

	Orbit
	{
		Epoch			2457395.5
		Period			0.004856910063096531
		Eccentricity	0.006541124354697981
		Inclination		69.8888974674317
		AscendingNode	163.24579489601115
		ArgOfPericen	217.62728063213592
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 27 B"
{
	ParentBody	"HeliosD 27"
	Class		"Asteroid"
	Mass		2.630542196617579e-11
	Radius		2.4087063866109686

	Orbit
	{
		Epoch			2457395.5
		Period			0.004856910063096531
		Eccentricity	0.006541124354697981
		Inclination		69.8888974674317
		AscendingNode	163.24579489601115
		ArgOfPericen	37.62728063213592
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 28"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.313475818805212
		Eccentricity	0.5399092604547593
		Inclination		102.76064492304198
		AscendingNode	99.96931159237654
		ArgOfPericen	84.05712972284773
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 28 A"
{
	ParentBody	"HeliosD 28"
	Class		"Asteroid"
	Mass		2.6541781917076804e-10
	Radius		5.224574620131198

	Orbit
	{
		Epoch			2457395.5
		Period			0.005932056656291958
		Eccentricity	0.003114664527985241
		Inclination		3.225333917392881
		AscendingNode	306.64978869505785
		ArgOfPericen	160.41307125406166
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 28 B"
{
	ParentBody	"HeliosD 28"
	Class		"Asteroid"
	Mass		5.48661449882743e-12
	Radius		1.4338676277398668

	Orbit
	{
		Epoch			2457395.5
		Period			0.005932056656291958
		Eccentricity	0.003114664527985241
		Inclination		3.225333917392881
		AscendingNode	306.64978869505785
		ArgOfPericen	340.41307125406166
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 29"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3339904946398167e-08
	Radius		18.634572186844665

	RotationPeriod	4.573171151475022

	Obliquity		35.96270820883708

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.125423005480089
		Eccentricity	0.3509666457644561
		Inclination		-36.130706539239156
		AscendingNode	100.69456644422696
		ArgOfPericen	4.27663756461286
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 30"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.032242706933594
		Eccentricity	0.27361131758066315
		Inclination		-26.393712226786295
		AscendingNode	180.88376307899526
		ArgOfPericen	196.87450987560166
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 30 A"
{
	ParentBody	"HeliosD 30"
	Class		"Asteroid"
	Mass		2.088802534381761e-08
	Radius		21.7362401710849

	Orbit
	{
		Epoch			2457395.5
		Period			0.005743902466143245
		Eccentricity	0.0038930971176170965
		Inclination		291.09156054561015
		AscendingNode	193.54976287720757
		ArgOfPericen	287.5845485958765
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 30 B"
{
	ParentBody	"HeliosD 30"
	Class		"Asteroid"
	Mass		3.430872470306098e-10
	Radius		5.525269770243977

	Orbit
	{
		Epoch			2457395.5
		Period			0.005743902466143245
		Eccentricity	0.0038930971176170965
		Inclination		291.09156054561015
		AscendingNode	193.54976287720757
		ArgOfPericen	107.58454859587653
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 31"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.659003373996902e-09
	Radius		13.244965684380047

	RotationPeriod	3.695960426877994

	Obliquity		299.88088170833583

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.45698218226593
		Eccentricity	0.2931491113400558
		Inclination		-40.65375235845108
		AscendingNode	59.11326991164377
		ArgOfPericen	342.1981719602103
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 32"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.612055914643653e-09
	Radius		15.917764557808471

	RotationPeriod	4.437965208043231

	Obliquity		23.869972218077578

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.97870092050525
		Eccentricity	0.628399968886774
		Inclination		49.14392808849334
		AscendingNode	338.03130271395656
		ArgOfPericen	50.5795692074659
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 33"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.259582193169443
		Eccentricity	0.4326198037569408
		Inclination		112.10736200713995
		AscendingNode	126.9001258817207
		ArgOfPericen	220.55740991355785
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 33 A"
{
	ParentBody	"HeliosD 33"
	Class		"Asteroid"
	Mass		4.238914630664252e-09
	Radius		12.676803760181338

	Orbit
	{
		Epoch			2457395.5
		Period			0.007975600310258096
		Eccentricity	0.007881266690022254
		Inclination		87.59307092594022
		AscendingNode	211.51394719704342
		ArgOfPericen	230.98179031901785
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 33 B"
{
	ParentBody	"HeliosD 33"
	Class		"Asteroid"
	Mass		1.3432483009188361e-09
	Radius		8.642584690245936

	Orbit
	{
		Epoch			2457395.5
		Period			0.007975600310258096
		Eccentricity	0.007881266690022254
		Inclination		87.59307092594022
		AscendingNode	211.51394719704342
		ArgOfPericen	50.98179031901782
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 34"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0477042341517335e-09
	Radius		9.633662654816419

	RotationPeriod	6.83545612023816

	Obliquity		91.91794820158574

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.270820889191118
		Eccentricity	0.5242352940028232
		Inclination		-27.615149526886714
		AscendingNode	138.7316784103954
		ArgOfPericen	163.17998451826048
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 35"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.958942437623512e-09
	Radius		12.131968211246173

	RotationPeriod	7.635373022935387

	Obliquity		87.33205233530448

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.58387899954787
		Eccentricity	0.4729046709250516
		Inclination		27.04874608689957
		AscendingNode	278.02435673818314
		ArgOfPericen	171.77956179256336
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 36"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.546389484675117
		Eccentricity	0.36984974806248416
		Inclination		-40.59918354924422
		AscendingNode	174.64501367006005
		ArgOfPericen	79.87003493153996
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 36 A"
{
	ParentBody	"HeliosD 36"
	Class		"Asteroid"
	Mass		1.1424755446650239e-10
	Radius		3.573196786345912

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030442990736701107
		Eccentricity	0.00184141685445258
		Inclination		276.01843133892453
		AscendingNode	317.043401948619
		ArgOfPericen	328.8476235240001
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 36 B"
{
	ParentBody	"HeliosD 36"
	Class		"Asteroid"
	Mass		2.8631097233698323e-12
	Radius		1.0456522938472548

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030442990736701107
		Eccentricity	0.00184141685445258
		Inclination		276.01843133892453
		AscendingNode	317.043401948619
		ArgOfPericen	148.84762352400008
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 37"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.284482962544441e-09
	Radius		13.43336701003852

	RotationPeriod	4.0459064516096115

	Obliquity		281.0707714677829

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.85366371944214
		Eccentricity	0.6159530830374704
		Inclination		-15.355975711768934
		AscendingNode	50.541225475367106
		ArgOfPericen	21.967520610655132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 38"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0576467813909095e-09
	Radius		9.577162945561772

	RotationPeriod	7.3428344385652515

	Obliquity		246.2983742670878

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.46174244132411
		Eccentricity	0.711640415990512
		Inclination		-6.781252340013417
		AscendingNode	273.40863043310515
		ArgOfPericen	65.71700184326137
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 39"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.3712316997785846e-09
	Radius		12.135286595485532

	RotationPeriod	7.2273270624256725

	Obliquity		242.944288045527

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.21085604104394
		Eccentricity	0.2815897868739187
		Inclination		-13.629209098743777
		AscendingNode	107.58630559050097
		ArgOfPericen	328.0768901723911
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 40"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5049055439539996e-09
	Radius		10.607982752636183

	RotationPeriod	5.647701810261333

	Obliquity		239.7294559519935

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.061722409282664
		Eccentricity	0.5172823401952655
		Inclination		42.800866055547786
		AscendingNode	137.7761289382855
		ArgOfPericen	3.903674265108976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 41"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.109996921449233e-09
	Radius		15.19482486818913

	RotationPeriod	3.1809791587983054

	Obliquity		70.90411606063854

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.035899496641459
		Eccentricity	0.6041754011480469
		Inclination		-76.79056788652846
		AscendingNode	81.06720582878368
		ArgOfPericen	352.4040123541101
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 42"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.0047761554613624e-09
	Radius		11.232989181907037

	RotationPeriod	7.652007405219624

	Obliquity		132.2261513679407

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.609146048574242
		Eccentricity	0.5524607122161299
		Inclination		-142.47039015310528
		AscendingNode	44.121210144140484
		ArgOfPericen	298.92031331412164
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 43"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0967174974493652e-08
	Radius		18.334321880926993

	RotationPeriod	7.244330086036574

	Obliquity		37.66316994562031

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.93570223249222
		Eccentricity	0.7453773609567264
		Inclination		-55.78929713786297
		AscendingNode	10.441473282364356
		ArgOfPericen	134.52166233919323
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 44"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8401890177632246e-09
	Radius		12.018279205509913

	RotationPeriod	3.667212578916902

	Obliquity		220.7285927531071

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.785476066155855
		Eccentricity	0.3874280457897532
		Inclination		-5.491484575012661
		AscendingNode	336.6264232150465
		ArgOfPericen	291.54821819736975
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 45"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.4744797377904097e-10
	Radius		4.6219648156059705

	RotationPeriod	3.44632811149739

	Obliquity		256.848568854068

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.275105385308525
		Eccentricity	0.29466914177581166
		Inclination		0.7036338635492997
		AscendingNode	114.07559522624481
		ArgOfPericen	327.12671585976994
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 46"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.0792819315783036e-08
	Radius		24.531341175858998

	RotationPeriod	7.686826718752547

	Obliquity		307.24327278433367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.919428924414397
		Eccentricity	0.35465932787584886
		Inclination		-47.44154822349559
		AscendingNode	75.79865785295371
		ArgOfPericen	266.70024768302017
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 47"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8536852520812248e-08
	Radius		20.123913421571867

	RotationPeriod	0.4505851517625281

	Obliquity		106.1834827583335

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	43.0719589172204
		Eccentricity	0.8331821615625251
		Inclination		28.840814042484272
		AscendingNode	63.77049341385572
		ArgOfPericen	199.98978045641084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 48"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.020826781450116e-09
	Radius		14.013693308875823

	RotationPeriod	7.1921537739924135

	Obliquity		176.03530376941887

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.14753611735019
		Eccentricity	0.5557573102612354
		Inclination		-7.696335792085478
		AscendingNode	281.1792309034129
		ArgOfPericen	233.5012202513641
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 49"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.2777630009336325e-09
	Radius		9.981364327099755

	RotationPeriod	3.7893266253886444

	Obliquity		89.97841500725566

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.913288019122383
		Eccentricity	0.6514135710352533
		Inclination		-104.96188796852987
		AscendingNode	240.2465174366736
		ArgOfPericen	188.33993240036486
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 50"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1184439264397704e-08
	Radius		18.319630842540775

	RotationPeriod	4.125127398717066

	Obliquity		125.65376387643323

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.800181212674527
		Eccentricity	0.6868675558719841
		Inclination		91.2590203388582
		AscendingNode	232.6917798566464
		ArgOfPericen	233.53601914967058
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 51"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.143714551036245e-10
	Radius		6.875751761817628

	RotationPeriod	2.939203664155838

	Obliquity		320.7578984374318

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	42.6722007962296
		Eccentricity	0.41279984689469956
		Inclination		95.15384488679621
		AscendingNode	106.28091578665389
		ArgOfPericen	200.02484934670125
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 52"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3562544586623286e-09
	Radius		10.544167668364713

	RotationPeriod	7.22209859709438

	Obliquity		197.25836418929094

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.77710548516623
		Eccentricity	0.6283240833670011
		Inclination		22.577935198532415
		AscendingNode	252.97897701787537
		ArgOfPericen	123.66657462285471
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 53"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.4436812658056655e-09
	Radius		13.938763685070853

	RotationPeriod	1.262195236331995

	Obliquity		197.23005398991666

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	43.30130538985818
		Eccentricity	0.44018766093414236
		Inclination		50.37421835083168
		AscendingNode	149.9781250160185
		ArgOfPericen	251.178662337393
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 54"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.0062462395990644e-09
	Radius		13.384395467352288

	RotationPeriod	3.724291017362555

	Obliquity		98.41534436788933

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.31213961536435
		Eccentricity	0.678547293100419
		Inclination		13.28324171147064
		AscendingNode	76.9719603576985
		ArgOfPericen	98.2536572826618
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 55"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.2201542458933033e-09
	Radius		8.294445386024298

	RotationPeriod	4.137658992275261

	Obliquity		143.49216765531048

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.97723773595477
		Eccentricity	0.33420779279045965
		Inclination		-7.240004218586952
		AscendingNode	76.42277769107639
		ArgOfPericen	204.533601964364
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 56"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7369375383354529e-09
	Radius		9.34010454864864

	RotationPeriod	8.160939760429503

	Obliquity		57.18492171989881

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.073123289776227
		Eccentricity	0.5563006427093129
		Inclination		25.637913286503668
		AscendingNode	282.9546696435612
		ArgOfPericen	60.65320482862445
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 57"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.707905913554685e-09
	Radius		13.259532486157232

	RotationPeriod	4.404007946895434

	Obliquity		125.29792207393743

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.046472443774284
		Eccentricity	0.4708045685521531
		Inclination		6.398359433187374
		AscendingNode	133.95459184332654
		ArgOfPericen	45.8342509399849
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 58"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.6619151683087373e-09
	Radius		11.52959274936675

	RotationPeriod	4.900382324012417

	Obliquity		130.67591708803295

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.72275498238275
		Eccentricity	0.7592521524592107
		Inclination		68.6423421081902
		AscendingNode	78.23853016811933
		ArgOfPericen	298.5522972044651
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 59"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.782197729071264
		Eccentricity	0.7587768352305995
		Inclination		-41.141335064349875
		AscendingNode	235.6742608870145
		ArgOfPericen	319.1392265269271
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 59 A"
{
	ParentBody	"HeliosD 59"
	Class		"Asteroid"
	Mass		1.1429094593438928e-09
	Radius		8.443701996052154

	Orbit
	{
		Epoch			2457395.5
		Period			0.002415198677943883
		Eccentricity	0.0027491245654642396
		Inclination		290.13934330863896
		AscendingNode	286.2895178257747
		ArgOfPericen	267.08434013238235
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 59 B"
{
	ParentBody	"HeliosD 59"
	Class		"Asteroid"
	Mass		6.677108520540247e-11
	Radius		3.2763611419712824

	Orbit
	{
		Epoch			2457395.5
		Period			0.002415198677943883
		Eccentricity	0.0027491245654642396
		Inclination		290.13934330863896
		AscendingNode	286.2895178257747
		ArgOfPericen	87.08434013238235
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 60"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.3600495875370945e-09
	Radius		12.595232614121928

	RotationPeriod	6.415516084814503

	Obliquity		139.06466460677163

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.9503335570229
		Eccentricity	0.4542608054300978
		Inclination		-3.89982903289181
		AscendingNode	160.49724448480774
		ArgOfPericen	245.13977687002986
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 61"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.2627145889879684e-09
	Radius		10.101954811236888

	RotationPeriod	4.100840701555738

	Obliquity		6.916421818278571

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.574107119542575
		Eccentricity	0.7348792263362584
		Inclination		-9.469399968781214
		AscendingNode	282.64781449999435
		ArgOfPericen	125.4701626417852
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 62"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.5159524542918997e-09
	Radius		8.871735740597272

	RotationPeriod	4.593055109255605

	Obliquity		232.61295015095595

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.550359679878195
		Eccentricity	0.8165563660080601
		Inclination		-18.540692952245475
		AscendingNode	12.058934376596353
		ArgOfPericen	4.3106096755336365
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 63"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.584935830392892e-10
	Radius		5.039581149161271

	RotationPeriod	6.449846587431063

	Obliquity		283.63626394285035

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.293101825589986
		Eccentricity	0.40217143246192466
		Inclination		-37.11206011877292
		AscendingNode	136.64246530185133
		ArgOfPericen	91.86254363860645
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 64"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.321266331224667
		Eccentricity	0.3512589129257616
		Inclination		51.845537441457
		AscendingNode	240.349837236351
		ArgOfPericen	281.6702526890051
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 64 A"
{
	ParentBody	"HeliosD 64"
	Class		"Asteroid"
	Mass		4.863112358489542e-09
	Radius		13.698939405698047

	Orbit
	{
		Epoch			2457395.5
		Period			0.004624296634334137
		Eccentricity	0.0021986538464620026
		Inclination		49.98522742950611
		AscendingNode	291.8728209658307
		ArgOfPericen	334.544535331102
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 64 B"
{
	ParentBody	"HeliosD 64"
	Class		"Asteroid"
	Mass		2.1153212441509702e-10
	Radius		4.817713322338021

	Orbit
	{
		Epoch			2457395.5
		Period			0.004624296634334137
		Eccentricity	0.0021986538464620026
		Inclination		49.98522742950611
		AscendingNode	291.8728209658307
		ArgOfPericen	154.544535331102
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 65"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.161207256803211e-09
	Radius		14.563761813911016

	RotationPeriod	7.591832648779751

	Obliquity		66.85070221558722

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.342351710334306
		Eccentricity	0.7396087427093296
		Inclination		129.0435623332689
		AscendingNode	241.3464457092261
		ArgOfPericen	195.7351903921345
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 66"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.024893554076264
		Eccentricity	0.47546989071714496
		Inclination		2.0308281228065086
		AscendingNode	217.8513734669988
		ArgOfPericen	31.99885931411098
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 66 A"
{
	ParentBody	"HeliosD 66"
	Class		"Asteroid"
	Mass		9.216489984933654e-10
	Radius		7.521534265042427

	Orbit
	{
		Epoch			2457395.5
		Period			0.005093271977853673
		Eccentricity	0.004834082420959556
		Inclination		358.5637516124488
		AscendingNode	196.3415001902719
		ArgOfPericen	117.17953831218543
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 66 B"
{
	ParentBody	"HeliosD 66"
	Class		"Asteroid"
	Mass		5.689758989055215e-10
	Radius		6.404460380622334

	Orbit
	{
		Epoch			2457395.5
		Period			0.005093271977853673
		Eccentricity	0.004834082420959556
		Inclination		358.5637516124488
		AscendingNode	196.3415001902719
		ArgOfPericen	297.1795383121854
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 67"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.60952241202655
		Eccentricity	0.6541871173201208
		Inclination		-14.800298625199648
		AscendingNode	32.60906854201958
		ArgOfPericen	152.41159687603272
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 67 A"
{
	ParentBody	"HeliosD 67"
	Class		"Asteroid"
	Mass		4.12545599968567e-09
	Radius		12.562336759732093

	Orbit
	{
		Epoch			2457395.5
		Period			0.00815844483566392
		Eccentricity	0.004389546977639016
		Inclination		185.03714604896024
		AscendingNode	5.690073509007547
		ArgOfPericen	313.49641679733696
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 67 B"
{
	ParentBody	"HeliosD 67"
	Class		"Asteroid"
	Mass		9.979812997142775e-11
	Radius		3.6331827712362705

	Orbit
	{
		Epoch			2457395.5
		Period			0.00815844483566392
		Eccentricity	0.004389546977639016
		Inclination		185.03714604896024
		AscendingNode	5.690073509007547
		ArgOfPericen	133.49641679733696
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 68"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.415481449186425e-09
	Radius		13.79448708427258

	RotationPeriod	4.88233396848327

	Obliquity		35.739343010574544

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.39286648966955
		Eccentricity	0.3710483850952211
		Inclination		40.764651697806876
		AscendingNode	56.509599021333756
		ArgOfPericen	186.9007963554415
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 69"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.035647655628319e-09
	Radius		12.66345982358108

	RotationPeriod	3.3245348642347636

	Obliquity		150.6119252878293

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.17570716617151
		Eccentricity	0.4672744506201014
		Inclination		-91.65095790346439
		AscendingNode	112.23823390097307
		ArgOfPericen	113.46601022589087
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 70"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.833714237218443e-09
	Radius		13.762183104700398

	RotationPeriod	3.5055887731549094

	Obliquity		88.3371813291416

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.01176369611116
		Eccentricity	0.7495380787623829
		Inclination		-95.41877286970505
		AscendingNode	173.58057971116685
		ArgOfPericen	38.74088688833713
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 71"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.1267291596585856e-09
	Radius		15.45333847859903

	RotationPeriod	8.552761807112255

	Obliquity		89.50770244907719

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.087107158612206
		Eccentricity	0.5847650788472989
		Inclination		28.474578270534014
		AscendingNode	108.05234994835429
		ArgOfPericen	102.24463055422775
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 72"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.288900833985682
		Eccentricity	0.49141247094336715
		Inclination		31.364246385871763
		AscendingNode	181.50262255520846
		ArgOfPericen	92.9961252891359
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 72 A"
{
	ParentBody	"HeliosD 72"
	Class		"Asteroid"
	Mass		1.243095785492339e-08
	Radius		20.603089711435864

	Orbit
	{
		Epoch			2457395.5
		Period			0.007598148661458324
		Eccentricity	0.004979816214021698
		Inclination		26.674546578136876
		AscendingNode	120.94277581157716
		ArgOfPericen	343.8521097181116
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 72 B"
{
	ParentBody	"HeliosD 72"
	Class		"Asteroid"
	Mass		1.00612169219377e-09
	Radius		8.912119333493614

	Orbit
	{
		Epoch			2457395.5
		Period			0.007598148661458324
		Eccentricity	0.004979816214021698
		Inclination		26.674546578136876
		AscendingNode	120.94277581157716
		ArgOfPericen	163.8521097181116
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 73"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.190583986535066e-09
	Radius		8.366292191277733

	RotationPeriod	3.758029387278936

	Obliquity		127.10447203039573

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.751491545883027
		Eccentricity	0.6293828610829773
		Inclination		59.22901800571609
		AscendingNode	78.9249131290814
		ArgOfPericen	352.6677653521879
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 74"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.001918493065829e-09
	Radius		11.559686269825802

	RotationPeriod	0.1

	Obliquity		184.55586905797702

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.6602213759194
		Eccentricity	0.21054291788876273
		Inclination		83.15429985298658
		AscendingNode	85.99199813182084
		ArgOfPericen	307.61471005730897
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 75"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.321872673792846e-09
	Radius		14.423406411313554

	RotationPeriod	2.3196386788297017

	Obliquity		73.66309918346057

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.63067983345233
		Eccentricity	0.6129700146848835
		Inclination		-108.52361576108649
		AscendingNode	247.9958165852444
		ArgOfPericen	75.60721051349195
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 76"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.417218108815547
		Eccentricity	0.5267050909572736
		Inclination		-35.29388190809086
		AscendingNode	42.07364914752326
		ArgOfPericen	138.66476238410786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 76 A"
{
	ParentBody	"HeliosD 76"
	Class		"Asteroid"
	Mass		2.727825721090045e-09
	Radius		11.375837453642038

	Orbit
	{
		Epoch			2457395.5
		Period			0.00806765882084997
		Eccentricity	0.005328148344388621
		Inclination		172.184972434147
		AscendingNode	333.06982686081017
		ArgOfPericen	95.4954397544731
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 76 B"
{
	ParentBody	"HeliosD 76"
	Class		"Asteroid"
	Mass		5.179591592537459e-10
	Radius		6.538473134453785

	Orbit
	{
		Epoch			2457395.5
		Period			0.00806765882084997
		Eccentricity	0.005328148344388621
		Inclination		172.184972434147
		AscendingNode	333.06982686081017
		ArgOfPericen	275.49543975447307
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 77"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.9781710170220305e-09
	Radius		11.836183391505061

	RotationPeriod	5.977131352847907

	Obliquity		178.19756548614052

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.439667625591678
		Eccentricity	0.6112873346932397
		Inclination		53.511173420378306
		AscendingNode	112.06720851052785
		ArgOfPericen	156.62883676627678
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 78"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.188897095159597e-09
	Radius		15.107097221034488

	RotationPeriod	5.061029364833252

	Obliquity		337.7228938001924

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.59433874620687
		Eccentricity	0.547890274521862
		Inclination		-9.2952030188188
		AscendingNode	272.9145813180906
		ArgOfPericen	173.46237176743472
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 79"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.8212719512732395e-10
	Radius		5.571387998842959

	RotationPeriod	7.030261644677583

	Obliquity		15.888170697459415

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.975741845333665
		Eccentricity	0.34399345910057877
		Inclination		-45.19014178784253
		AscendingNode	117.86919628204573
		ArgOfPericen	296.38435701682124
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 80"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.274373234993487
		Eccentricity	0.2868031695094484
		Inclination		16.945686724775033
		AscendingNode	146.46304745036932
		ArgOfPericen	96.08477310382872
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 80 A"
{
	ParentBody	"HeliosD 80"
	Class		"Asteroid"
	Mass		9.129351461113994e-09
	Radius		15.313030553479853

	Orbit
	{
		Epoch			2457395.5
		Period			0.004948878087056122
		Eccentricity	0.004206100040419564
		Inclination		237.38383156535377
		AscendingNode	196.86190083167375
		ArgOfPericen	250.08118189966396
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 80 B"
{
	ParentBody	"HeliosD 80"
	Class		"Asteroid"
	Mass		2.646109595639822e-10
	Radius		4.703817346365112

	Orbit
	{
		Epoch			2457395.5
		Period			0.004948878087056122
		Eccentricity	0.004206100040419564
		Inclination		237.38383156535377
		AscendingNode	196.86190083167375
		ArgOfPericen	70.08118189966399
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 81"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.192455381230536e-09
	Radius		14.336129424687368

	RotationPeriod	6.942990523337718

	Obliquity		310.8991420665575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.37344108821908
		Eccentricity	0.4625560895841592
		Inclination		-19.987433324976614
		AscendingNode	15.762035892538325
		ArgOfPericen	340.62992963954224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 82"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.491160884143982e-09
	Radius		16.155124849897305

	RotationPeriod	4.6287067657739716

	Obliquity		91.0779993537915

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	45.42415430476012
		Eccentricity	0.4105523601830887
		Inclination		57.362126516986315
		AscendingNode	330.9749688078481
		ArgOfPericen	255.93825135860868
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 83"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.269983656945861e-09
	Radius		12.39544386058333

	RotationPeriod	4.765038905506502

	Obliquity		67.74746734798629

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.681141750469656
		Eccentricity	0.509445367263516
		Inclination		-71.2583368117914
		AscendingNode	338.6985347197992
		ArgOfPericen	329.43308429226846
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 84"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.45069974318297e-09
	Radius		15.253943901763218

	RotationPeriod	5.26313157513943

	Obliquity		4.053593395585802

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.297516267877574
		Eccentricity	0.7070814779468154
		Inclination		-64.74188219007502
		AscendingNode	243.1657502263531
		ArgOfPericen	329.74640863856456
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 85"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.118057475829288e-09
	Radius		10.188439687893881

	RotationPeriod	9.130409079588055

	Obliquity		217.8941848234428

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.356725120405386
		Eccentricity	0.3916558142756706
		Inclination		-30.934828950803052
		AscendingNode	211.31989480117127
		ArgOfPericen	68.15037411142782
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 86"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.34528527223268e-09
	Radius		12.218946098768308

	RotationPeriod	2.8259004004671207

	Obliquity		330.9328783378387

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.871390963113875
		Eccentricity	0.5350691487958129
		Inclination		69.84272246080091
		AscendingNode	32.278510380608644
		ArgOfPericen	277.09973423500696
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 87"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.097174077248244e-08
	Radius		20.587863259945003

	RotationPeriod	4.613634368528119

	Obliquity		231.1357385967592

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.14528960980259
		Eccentricity	0.5551571693130198
		Inclination		-51.069695120571744
		AscendingNode	157.9262345842331
		ArgOfPericen	207.60579149066132
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 88"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.861597372907337
		Eccentricity	0.11569780536693164
		Inclination		-11.878109561416741
		AscendingNode	46.68276795145889
		ArgOfPericen	68.76968841600188
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 88 A"
{
	ParentBody	"HeliosD 88"
	Class		"Asteroid"
	Mass		4.3749800771322005e-09
	Radius		12.875109439873933

	Orbit
	{
		Epoch			2457395.5
		Period			0.006233427633390074
		Eccentricity	0.006231112261059206
		Inclination		318.55411036772756
		AscendingNode	10.780672888662988
		ArgOfPericen	133.30602823629934
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 88 B"
{
	ParentBody	"HeliosD 88"
	Class		"Asteroid"
	Mass		8.343711987995615e-10
	Radius		7.411031699473826

	Orbit
	{
		Epoch			2457395.5
		Period			0.006233427633390074
		Eccentricity	0.006231112261059206
		Inclination		318.55411036772756
		AscendingNode	10.780672888662988
		ArgOfPericen	313.3060282362993
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 89"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.78539504653984e-09
	Radius		9.44365882358776

	RotationPeriod	5.040649637526469

	Obliquity		103.02774914867838

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.621375896434635
		Eccentricity	0.4807507540510851
		Inclination		-29.10611231962978
		AscendingNode	243.52894493040972
		ArgOfPericen	337.3187612774723
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 90"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.431627443283178e-09
	Radius		11.477534563613935

	RotationPeriod	1.9193315101720785

	Obliquity		118.47600739287881

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.420207694650493
		Eccentricity	0.5255692938655362
		Inclination		73.41304027778322
		AscendingNode	33.82729666656602
		ArgOfPericen	118.46471533140434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 91"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.025328299455808
		Eccentricity	0.09773774827292814
		Inclination		-40.85405634067657
		AscendingNode	202.96568714509587
		ArgOfPericen	289.14344982976365
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 91 A"
{
	ParentBody	"HeliosD 91"
	Class		"Asteroid"
	Mass		1.7025790547129467e-08
	Radius		19.790638059163115

	Orbit
	{
		Epoch			2457395.5
		Period			0.006603823218269949
		Eccentricity	0.006128885217953125
		Inclination		129.48584027972228
		AscendingNode	227.8246217733971
		ArgOfPericen	265.19077156561934
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 91 B"
{
	ParentBody	"HeliosD 91"
	Class		"Asteroid"
	Mass		1.416182286646953e-09
	Radius		8.639005559732302

	Orbit
	{
		Epoch			2457395.5
		Period			0.006603823218269949
		Eccentricity	0.006128885217953125
		Inclination		129.48584027972228
		AscendingNode	227.8246217733971
		ArgOfPericen	85.19077156561934
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 92"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3761224399113126e-09
	Radius		10.054409795720794

	RotationPeriod	9.147839549911609

	Obliquity		297.22434847690886

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	44.4917199192561
		Eccentricity	0.7443580033991872
		Inclination		38.858644265294416
		AscendingNode	199.0374875606502
		ArgOfPericen	47.067047835300635
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 93"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.2012006459746197e-10
	Radius		5.8474188898423405

	RotationPeriod	8.93894324056979

	Obliquity		114.59963960968521

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.609511218591905
		Eccentricity	0.23112606153574589
		Inclination		38.30384277521433
		AscendingNode	206.31804701304037
		ArgOfPericen	211.42608681828688
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 94"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.606835553659199e-08
	Radius		18.59069540536281

	RotationPeriod	7.940232787476844

	Obliquity		353.0789850278203

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	10.948076620745761
		Eccentricity	0.32082572352299626
		Inclination		-36.60073280358908
		AscendingNode	48.709752223177745
		ArgOfPericen	278.94951814388213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 95"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.959036848692824
		Eccentricity	0.26161204318351416
		Inclination		60.14251184647756
		AscendingNode	76.22535568054103
		ArgOfPericen	215.37099087369495
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 95 A"
{
	ParentBody	"HeliosD 95"
	Class		"Asteroid"
	Mass		4.218076568751962e-09
	Radius		12.770979443035625

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005952257517284678
		Eccentricity	0.001316234071763375
		Inclination		2.3033228760402435
		AscendingNode	343.363208716878
		ArgOfPericen	314.1811415684023
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 95 B"
{
	ParentBody	"HeliosD 95"
	Class		"Asteroid"
	Mass		1.6430636008220252e-09
	Radius		9.32690409424665

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005952257517284678
		Eccentricity	0.001316234071763375
		Inclination		2.3033228760402435
		AscendingNode	343.363208716878
		ArgOfPericen	134.18114156840232
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 96"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.78362855208198e-09
	Radius		14.876261158401382

	RotationPeriod	8.401383442846987

	Obliquity		70.22145228583446

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.33935192753295
		Eccentricity	0.5538597658321366
		Inclination		20.69138183705302
		AscendingNode	241.73989504992082
		ArgOfPericen	223.38126403909433
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 97"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8484950223207436e-08
	Radius		20.24359173449499

	RotationPeriod	6.61035688148828

	Obliquity		243.32532607978143

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.773545780446014
		Eccentricity	0.6005258453674379
		Inclination		26.607856154702766
		AscendingNode	141.23054014915064
		ArgOfPericen	79.44943522035234
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 98"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.416595470372466e-09
	Radius		15.750266491561797

	RotationPeriod	7.203851154372668

	Obliquity		217.09356581450308

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.68635245218498
		Eccentricity	0.7016358464644967
		Inclination		1.6553378217713066
		AscendingNode	80.35325312902057
		ArgOfPericen	106.72437438699066
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 99"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0975271538892426e-09
	Radius		10.262502068220462

	RotationPeriod	4.413256624776727

	Obliquity		325.32617812752557

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.980499537069445
		Eccentricity	0.27258125352015333
		Inclination		45.47289959824959
		AscendingNode	170.50059388125146
		ArgOfPericen	206.68721866753856
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 100"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.7525991497147205e-09
	Radius		12.22679962437142

	RotationPeriod	2.3519483362500617

	Obliquity		359.07984325118395

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.108528474317353
		Eccentricity	0.3785104065332887
		Inclination		45.80544500510709
		AscendingNode	340.5694789310973
		ArgOfPericen	288.43653662106675
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 101"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.985416626807274e-09
	Radius		15.925509976495373

	RotationPeriod	3.1622688135890282

	Obliquity		183.12346884324973

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.059484505753154
		Eccentricity	0.7008655781638347
		Inclination		-7.476593170992216
		AscendingNode	320.64951616633624
		ArgOfPericen	180.1173497853393
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 102"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.932355029622805
		Eccentricity	0.5141872073933098
		Inclination		29.59264735706927
		AscendingNode	199.3001540020431
		ArgOfPericen	357.8603532632061
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 102 A"
{
	ParentBody	"HeliosD 102"
	Class		"Asteroid"
	Mass		1.365064476421458e-09
	Radius		8.876969186120094

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066109164443893175
		Eccentricity	0.007328359508108535
		Inclination		272.3450836392601
		AscendingNode	177.4848122388011
		ArgOfPericen	102.9701695421852
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 102 B"
{
	ParentBody	"HeliosD 102"
	Class		"Asteroid"
	Mass		1.0863969495846083e-09
	Radius		8.22640026004445

	Orbit
	{
		Epoch			2457395.5
		Period			0.0066109164443893175
		Eccentricity	0.007328359508108535
		Inclination		272.3450836392601
		AscendingNode	177.4848122388011
		ArgOfPericen	282.9701695421852
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 103"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.327316292281396e-09
	Radius		15.35893605646698

	RotationPeriod	5.3583054749155385

	Obliquity		70.54752288787253

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.509996686391208
		Eccentricity	0.4118005938102365
		Inclination		11.06971658530386
		AscendingNode	236.41644901949724
		ArgOfPericen	356.9800791603622
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 104"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.688239150668248e-09
	Radius		14.312384984392354

	RotationPeriod	5.607334883158851

	Obliquity		141.3225680387594

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.132181249198752
		Eccentricity	0.5263527202584173
		Inclination		-95.55374566617951
		AscendingNode	6.066443015347898
		ArgOfPericen	350.8779802413256
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 105"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.617464663568797e-09
	Radius		15.277058880853227

	RotationPeriod	4.906284809248691

	Obliquity		13.1865376811696

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.873029862929332
		Eccentricity	0.6066728143454445
		Inclination		-39.705540807633504
		AscendingNode	350.4616188308257
		ArgOfPericen	232.83973137902302
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 106"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7236183699060652e-09
	Radius		9.38821695692614

	RotationPeriod	5.930953400156428

	Obliquity		53.60071861165121

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.70407852033414
		Eccentricity	0.7143491734842216
		Inclination		-31.775345619714287
		AscendingNode	201.98635651985364
		ArgOfPericen	116.99019373163758
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 107"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0927783264191978e-09
	Radius		7.86440851166036

	RotationPeriod	9.068870608965703

	Obliquity		37.92429743541474

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.67437927726941
		Eccentricity	0.6381965613750611
		Inclination		-54.43873280449685
		AscendingNode	237.89530366228814
		ArgOfPericen	136.30374655568878
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 108"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6799873273667787e-09
	Radius		8.830472070816485

	RotationPeriod	3.7742203333959226

	Obliquity		40.78415026929336

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.424675998420412
		Eccentricity	0.669904636282925
		Inclination		-40.67353306444296
		AscendingNode	153.67996213852092
		ArgOfPericen	104.64784499223055
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 109"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.065310722637975
		Eccentricity	0.5332333433122834
		Inclination		-0.15521653807200342
		AscendingNode	251.68033461091483
		ArgOfPericen	185.39841213248187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 109 A"
{
	ParentBody	"HeliosD 109"
	Class		"Asteroid"
	Mass		1.2562320589303196e-08
	Radius		18.23760169845389

	Orbit
	{
		Epoch			2457395.5
		Period			0.005793821152850632
		Eccentricity	0.003832922525144354
		Inclination		315.3620852754183
		AscendingNode	157.1149837894905
		ArgOfPericen	25.244132675104574
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 109 B"
{
	ParentBody	"HeliosD 109"
	Class		"Asteroid"
	Mass		7.585011298546751e-09
	Radius		15.414514356119858

	Orbit
	{
		Epoch			2457395.5
		Period			0.005793821152850632
		Eccentricity	0.003832922525144354
		Inclination		315.3620852754183
		AscendingNode	157.1149837894905
		ArgOfPericen	205.24413267510457
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 110"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.940930890705867e-11
	Radius		3.1903613965615296

	RotationPeriod	6.016797449046001

	Obliquity		165.29684240338216

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.939695055755124
		Eccentricity	0.4499699753886992
		Inclination		17.201639621264356
		AscendingNode	55.83660588721105
		ArgOfPericen	147.42130145208816
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 111"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7130683317627555e-10
	Radius		4.300194415527008

	RotationPeriod	4.334196641933221

	Obliquity		272.85879383191434

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.706584389640819
		Eccentricity	0.465733532161443
		Inclination		74.63850745886519
		AscendingNode	38.14712098920192
		ArgOfPericen	344.4321535638373
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 112"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1080493034658455e-08
	Radius		16.795500154518113

	RotationPeriod	5.576059402627816

	Obliquity		39.13633452918954

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.8515279497424
		Eccentricity	0.34140930199310277
		Inclination		51.28054490374923
		AscendingNode	203.80633482146288
		ArgOfPericen	99.89555179282519
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 113"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.225321213738543e-09
	Radius		12.72690961385576

	RotationPeriod	6.741181786274828

	Obliquity		51.46552053242639

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.710187578418655
		Eccentricity	0.6006861149033915
		Inclination		9.828764088371317
		AscendingNode	320.87530219663455
		ArgOfPericen	279.3221284593116
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 114"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.76608641599193e-09
	Radius		14.247274123965344

	RotationPeriod	7.060462104978804

	Obliquity		37.335237227763855

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	9.592717911287508
		Eccentricity	0.5794992032066286
		Inclination		97.82389963768111
		AscendingNode	144.73280458040915
		ArgOfPericen	101.33446661636218
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 115"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.511059112399239e-09
	Radius		16.3566955461082

	RotationPeriod	5.987518686320759

	Obliquity		87.07919463718902

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.69285387545979
		Eccentricity	0.42594977760881547
		Inclination		-96.5538232240304
		AscendingNode	306.05893075838935
		ArgOfPericen	334.404856786321
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 116"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.699405274723792e-09
	Radius		12.947451135335479

	RotationPeriod	9.278147594680355

	Obliquity		330.03051354483443

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	5.004727941576842
		Eccentricity	0.5675304673254351
		Inclination		-99.6285451804191
		AscendingNode	204.56106884552347
		ArgOfPericen	297.90534591576153
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 117"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0241751595531241e-08
	Radius		16.919642352995712

	RotationPeriod	5.396177443815847

	Obliquity		308.6996198338844

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.01335982186894
		Eccentricity	0.37201563819036204
		Inclination		-117.9509749208847
		AscendingNode	313.8680400542752
		ArgOfPericen	312.8289181109089
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 118"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.014428505156148e-09
	Radius		13.782920305314196

	RotationPeriod	2.5468751062806287

	Obliquity		43.96829472040383

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.885197681714587
		Eccentricity	0.43594620722157007
		Inclination		-10.224515043868
		AscendingNode	290.3705238798231
		ArgOfPericen	317.1326822501061
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 119"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.9892084595383755e-09
	Radius		13.272302937620914

	RotationPeriod	6.16598708029826

	Obliquity		265.79834127652

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.00496961505186
		Eccentricity	0.49816628768514504
		Inclination		-60.68439536439902
		AscendingNode	359.5449934385819
		ArgOfPericen	159.65061570866288
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 120"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.218522773841729e-09
	Radius		15.426155775310823

	RotationPeriod	3.2435648762294704

	Obliquity		294.99627292183555

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.484835671777066
		Eccentricity	0.4028737440820014
		Inclination		39.521865004151216
		AscendingNode	241.11944259283806
		ArgOfPericen	3.9240123770047886
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 121"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.668954723502438
		Eccentricity	0.7619611366330166
		Inclination		64.8609320069468
		AscendingNode	219.0944133077258
		ArgOfPericen	19.31868418337961
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 121 A"
{
	ParentBody	"HeliosD 121"
	Class		"Asteroid"
	Mass		1.0693228025920562e-08
	Radius		17.74341191681763

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009033691442977165
		Eccentricity	0.001931545775903776
		Inclination		86.60574732138116
		AscendingNode	240.40611702732315
		ArgOfPericen	153.34438667865632
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 121 B"
{
	ParentBody	"HeliosD 121"
	Class		"Asteroid"
	Mass		7.183641184052108e-09
	Radius		15.539930403167519

	Orbit
	{
		Epoch			2457395.5
		Period			0.0009033691442977165
		Eccentricity	0.001931545775903776
		Inclination		86.60574732138116
		AscendingNode	240.40611702732315
		ArgOfPericen	333.3443866786563
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 122"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.074651258177501e-10
	Radius		6.807354424801482

	RotationPeriod	6.601376601908748

	Obliquity		305.9945244391342

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.1555366194234
		Eccentricity	0.6473796795257583
		Inclination		-22.914707571892404
		AscendingNode	27.75095599876709
		ArgOfPericen	50.469657494880636
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 123"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.66089976986197
		Eccentricity	0.5666532470580675
		Inclination		-26.199188671649882
		AscendingNode	326.08626891984363
		ArgOfPericen	28.558892679369023
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 123 A"
{
	ParentBody	"HeliosD 123"
	Class		"Asteroid"
	Mass		6.762224947078757e-09
	Radius		15.15940935199886

	Orbit
	{
		Epoch			2457395.5
		Period			0.007525172356424531
		Eccentricity	0.00369048027586538
		Inclination		77.35440970211995
		AscendingNode	152.8588046943366
		ArgOfPericen	345.67375863336144
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 123 B"
{
	ParentBody	"HeliosD 123"
	Class		"Asteroid"
	Mass		1.1621023505050374e-10
	Radius		3.9120152200557277

	Orbit
	{
		Epoch			2457395.5
		Period			0.007525172356424531
		Eccentricity	0.00369048027586538
		Inclination		77.35440970211995
		AscendingNode	152.8588046943366
		ArgOfPericen	165.67375863336144
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 124"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.774913327766925e-08
	Radius		20.22745899283929

	RotationPeriod	9.835644443339614

	Obliquity		209.9684052346895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.74788837052734
		Eccentricity	0.48855200859421966
		Inclination		19.060071070016633
		AscendingNode	230.11258520455752
		ArgOfPericen	148.3476127319775
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 125"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.342486951215721e-09
	Radius		11.591307963668354

	RotationPeriod	4.734022261616101

	Obliquity		66.41003985852078

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.357734739652912
		Eccentricity	0.47516272246701907
		Inclination		-101.56652162527779
		AscendingNode	94.78916071865234
		ArgOfPericen	158.6317318712407
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 126"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.976427298421465e-09
	Radius		13.012100477148786

	RotationPeriod	6.01987692632598

	Obliquity		254.59422959013986

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.28150605048924
		Eccentricity	0.32170004450148804
		Inclination		-17.471386270110045
		AscendingNode	206.54816491323334
		ArgOfPericen	91.9385932780916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 127"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.325123367530459e-09
	Radius		10.390684173858672

	RotationPeriod	8.652933793384488

	Obliquity		291.3939967463016

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.728468716809108
		Eccentricity	0.48112822409493117
		Inclination		-35.624127022085446
		AscendingNode	7.785537300861285
		ArgOfPericen	21.83540599635094
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 128"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.958768877077526e-09
	Radius		13.684490473780475

	RotationPeriod	7.565982362008617

	Obliquity		218.04713425359245

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	41.55562356560628
		Eccentricity	0.4874629968718799
		Inclination		22.801701876496605
		AscendingNode	221.77566947367427
		ArgOfPericen	136.32119799607085
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 129"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.64512221729441e-09
	Radius		13.827179206310799

	RotationPeriod	7.0078312300233785

	Obliquity		213.89833282927506

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.184577940040743
		Eccentricity	0.39941161032771055
		Inclination		91.64003480075641
		AscendingNode	94.20772285243277
		ArgOfPericen	202.53687231398948
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 130"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8193868483212422e-09
	Radius		9.461098763119654

	RotationPeriod	4.8153484304663285

	Obliquity		133.82535908964275

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.022079446852974
		Eccentricity	0.37794361525093517
		Inclination		-70.55886739012233
		AscendingNode	213.6558760528217
		ArgOfPericen	114.35060020589428
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 131"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.355053945974468e-10
	Radius		6.969403632577525

	RotationPeriod	6.449524976914169

	Obliquity		197.46477703465268

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.481390301469265
		Eccentricity	0.5840778319692862
		Inclination		-16.387690085913768
		AscendingNode	89.37548008570477
		ArgOfPericen	149.56720495236615
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 132"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.885862108684331e-10
	Radius		5.977813681065031

	RotationPeriod	5.168782555773178

	Obliquity		90.50608887479616

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.420175179601085
		Eccentricity	0.696099484637401
		Inclination		7.039873125957575
		AscendingNode	213.18840095254512
		ArgOfPericen	84.44217789238219
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 133"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0980236787019939e-08
	Radius		17.508469139398017

	RotationPeriod	7.001349435299163

	Obliquity		292.47076701459093

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.50469754448648
		Eccentricity	0.19016883627862186
		Inclination		4.3134253400365195
		AscendingNode	3.398823825440145
		ArgOfPericen	72.3164401506214
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 134"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.9175891924897295e-09
	Radius		14.695056083652798

	RotationPeriod	7.697277241140895

	Obliquity		88.5639616303327

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.78895751706651
		Eccentricity	0.5357951258263677
		Inclination		-118.62579846146384
		AscendingNode	102.61167332527147
		ArgOfPericen	19.859890274554242
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 135"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.58794601967812
		Eccentricity	0.46630883214764196
		Inclination		5.850277144538698
		AscendingNode	241.24895680998068
		ArgOfPericen	206.67370616652084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 135 A"
{
	ParentBody	"HeliosD 135"
	Class		"Asteroid"
	Mass		1.6025470387042595e-10
	Radius		4.222428843035736

	Orbit
	{
		Epoch			2457395.5
		Period			0.004917205341773114
		Eccentricity	0.00599906958497418
		Inclination		60.25542405249102
		AscendingNode	248.08953719488667
		ArgOfPericen	247.62374386060637
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 135 B"
{
	ParentBody	"HeliosD 135"
	Class		"Asteroid"
	Mass		7.482122241446205e-11
	Radius		3.27567151370602

	Orbit
	{
		Epoch			2457395.5
		Period			0.004917205341773114
		Eccentricity	0.00599906958497418
		Inclination		60.25542405249102
		AscendingNode	248.08953719488667
		ArgOfPericen	67.6237438606064
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 136"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.07435574347403e-10
	Radius		7.2184950346207115

	RotationPeriod	5.429135955385818

	Obliquity		213.02331969173449

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.530877349956825
		Eccentricity	0.36383822628073986
		Inclination		-13.948657365777672
		AscendingNode	104.05971534922747
		ArgOfPericen	278.95917539745784
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 137"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.32830190838338e-09
	Radius		16.492640017069697

	RotationPeriod	5.253686035894383

	Obliquity		283.05699162917307

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.83096328281288
		Eccentricity	0.31326321074230135
		Inclination		30.04264645889444
		AscendingNode	250.6417150792944
		ArgOfPericen	295.60033917446384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 138"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.086502899916371e-09
	Radius		13.310454044817526

	RotationPeriod	5.683066174177962

	Obliquity		332.0124115101871

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.758053547209215
		Eccentricity	0.28157484952450035
		Inclination		28.041283768560323
		AscendingNode	203.5025253674153
		ArgOfPericen	279.0509157903073
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 139"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.51590848321159
		Eccentricity	0.30888417511894284
		Inclination		-25.636203997741
		AscendingNode	169.34973245146256
		ArgOfPericen	263.86863580201
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 139 A"
{
	ParentBody	"HeliosD 139"
	Class		"Asteroid"
	Mass		1.4885268560045502e-09
	Radius		8.62149213149455

	Orbit
	{
		Epoch			2457395.5
		Period			0.001962421022671193
		Eccentricity	0.0035132400493814017
		Inclination		52.41616538904256
		AscendingNode	159.25327304903604
		ArgOfPericen	47.93939437558274
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 139 B"
{
	ParentBody	"HeliosD 139"
	Class		"Asteroid"
	Mass		4.2903893494231357e-10
	Radius		5.695026901959166

	Orbit
	{
		Epoch			2457395.5
		Period			0.001962421022671193
		Eccentricity	0.0035132400493814017
		Inclination		52.41616538904256
		AscendingNode	159.25327304903604
		ArgOfPericen	227.93939437558274
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 140"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.695803402880358
		Eccentricity	0.6987556669586186
		Inclination		-82.63621069108463
		AscendingNode	286.6419644134371
		ArgOfPericen	290.06496681211786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 140 A"
{
	ParentBody	"HeliosD 140"
	Class		"Asteroid"
	Mass		2.980330564160671e-09
	Radius		11.435551016669018

	Orbit
	{
		Epoch			2457395.5
		Period			0.002437286454690155
		Eccentricity	0.0053045138587040665
		Inclination		171.4074583652168
		AscendingNode	162.99711214889848
		ArgOfPericen	209.430556994406
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 140 B"
{
	ParentBody	"HeliosD 140"
	Class		"Asteroid"
	Mass		3.375542961894986e-10
	Radius		5.5328661432391515

	Orbit
	{
		Epoch			2457395.5
		Period			0.002437286454690155
		Eccentricity	0.0053045138587040665
		Inclination		171.4074583652168
		AscendingNode	162.99711214889848
		ArgOfPericen	29.430556994406004
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 141"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.403070125540083
		Eccentricity	0.6149097570453664
		Inclination		12.247391482512112
		AscendingNode	111.21265568888414
		ArgOfPericen	15.217824102328187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 141 A"
{
	ParentBody	"HeliosD 141"
	Class		"Asteroid"
	Mass		4.537371607296247e-09
	Radius		13.08298622761979

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025784116600850683
		Eccentricity	0.007341070914129513
		Inclination		33.112576514823935
		AscendingNode	333.41896778504724
		ArgOfPericen	270.2835357601164
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 141 B"
{
	ParentBody	"HeliosD 141"
	Class		"Asteroid"
	Mass		3.9039311732562434e-09
	Radius		12.443412129113236

	Orbit
	{
		Epoch			2457395.5
		Period			0.0025784116600850683
		Eccentricity	0.007341070914129513
		Inclination		33.112576514823935
		AscendingNode	333.41896778504724
		ArgOfPericen	90.28353576011642
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 142"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.143776386359664e-09
	Radius		10.469070992153537

	RotationPeriod	6.944076240929043

	Obliquity		348.05303085909355

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.86661827514879
		Eccentricity	0.6449547410942662
		Inclination		15.470836534869793
		AscendingNode	112.09414207615538
		ArgOfPericen	85.8177973438747
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 143"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.330734606626967e-10
	Radius		7.264204826894007

	RotationPeriod	7.183374820328551

	Obliquity		124.0373467476127

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.119459272893074
		Eccentricity	0.6549326044766248
		Inclination		1.7118618517416386
		AscendingNode	208.00362283655897
		ArgOfPericen	51.454687175428276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 144"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.891078182955876e-10
	Radius		6.5110595769312845

	RotationPeriod	6.459097297175828

	Obliquity		31.22623469581859

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.282452575181317
		Eccentricity	0.6124690652052658
		Inclination		7.290519090508274
		AscendingNode	136.22211833102082
		ArgOfPericen	32.35579672212869
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 145"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.6675087558612385e-09
	Radius		13.07682676024275

	RotationPeriod	10.058451130008866

	Obliquity		169.81291112273502

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.08967925034328
		Eccentricity	0.5966867486817761
		Inclination		-42.0453139700514
		AscendingNode	16.553246431785347
		ArgOfPericen	183.38828703773916
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 146"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.429291606986868e-08
	Radius		18.879192693547637

	RotationPeriod	2.7946880966862104

	Obliquity		359.4250361411995

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.815503664573907
		Eccentricity	0.2615939250143705
		Inclination		103.187600677432
		AscendingNode	101.74843949962563
		ArgOfPericen	92.57372151506983
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 147"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.963279304023707e-09
	Radius		12.679865153173719

	RotationPeriod	5.536636722605296

	Obliquity		154.22713451662594

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.4359580049434
		Eccentricity	0.42977723766417064
		Inclination		1.0714155382944024
		AscendingNode	5.466926884646872
		ArgOfPericen	225.09519862398525
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 148"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.031084479682
		Eccentricity	0.6700124863802354
		Inclination		-32.15040662502058
		AscendingNode	61.806063443809954
		ArgOfPericen	230.62395780637732
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 148 A"
{
	ParentBody	"HeliosD 148"
	Class		"Asteroid"
	Mass		8.98633108542696e-10
	Radius		7.783606052131141

	Orbit
	{
		Epoch			2457395.5
		Period			0.002169931933858675
		Eccentricity	0.00675765275411171
		Inclination		287.0688331482273
		AscendingNode	238.6797887956582
		ArgOfPericen	298.6077025661578
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 148 B"
{
	ParentBody	"HeliosD 148"
	Class		"Asteroid"
	Mass		1.6384019825466055e-10
	Radius		4.41360568381387

	Orbit
	{
		Epoch			2457395.5
		Period			0.002169931933858675
		Eccentricity	0.00675765275411171
		Inclination		287.0688331482273
		AscendingNode	238.6797887956582
		ArgOfPericen	118.6077025661578
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 149"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.710477869897746e-09
	Radius		12.68868039246294

	RotationPeriod	6.165085222410343

	Obliquity		219.1911672955373

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.27440528733762
		Eccentricity	0.3096906200119179
		Inclination		-86.99112452766452
		AscendingNode	47.79907000466834
		ArgOfPericen	34.26241708751476
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 150"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.534380589708718e-09
	Radius		13.291057943147429

	RotationPeriod	3.220188230370975

	Obliquity		5.155239655062114

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.04860224549062
		Eccentricity	0.6321437716593429
		Inclination		-48.0587684426673
		AscendingNode	121.05022043444995
		ArgOfPericen	56.038435520160625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 151"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.693299312498186e-08
	Radius		20.05905895788317

	RotationPeriod	5.140817285401269

	Obliquity		121.27369183477875

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.2793069587053
		Eccentricity	0.053824971345428185
		Inclination		12.975829538965852
		AscendingNode	51.956906790575154
		ArgOfPericen	83.23960533356195
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 152"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.227480184622206e-09
	Radius		16.27951577766521

	RotationPeriod	10.957322886889127

	Obliquity		219.1184728180103

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.584852023633918
		Eccentricity	0.4641870603561042
		Inclination		17.878703070686548
		AscendingNode	301.76393557809473
		ArgOfPericen	20.666249188169875
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 153"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.4757246039223985e-09
	Radius		12.02368432399146

	RotationPeriod	5.35892685893479

	Obliquity		260.25589900028774

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.019773689738926
		Eccentricity	0.4098461605456778
		Inclination		-69.20772420363832
		AscendingNode	168.3150590778951
		ArgOfPericen	248.6861976137941
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 154"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.359554190690742e-09
	Radius		10.421064117986754

	RotationPeriod	5.529916134318941

	Obliquity		176.90162661843553

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.91818116234826
		Eccentricity	0.629102504299327
		Inclination		-95.88075422708876
		AscendingNode	66.90365972729455
		ArgOfPericen	214.94481976242858
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 155"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.06414999702784
		Eccentricity	0.22902933401297293
		Inclination		53.68544686864403
		AscendingNode	290.9404884693102
		ArgOfPericen	90.26735661162662
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 155 A"
{
	ParentBody	"HeliosD 155"
	Class		"Asteroid"
	Mass		5.521857215669896e-09
	Radius		13.7327568382861

	Orbit
	{
		Epoch			2457395.5
		Period			0.001344540090761884
		Eccentricity	0.0028999302424553754
		Inclination		127.34740959473707
		AscendingNode	24.78723008044545
		ArgOfPericen	226.04855118372762
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 155 B"
{
	ParentBody	"HeliosD 155"
	Class		"Asteroid"
	Mass		2.311439301992314e-09
	Radius		10.272831638810931

	Orbit
	{
		Epoch			2457395.5
		Period			0.001344540090761884
		Eccentricity	0.0028999302424553754
		Inclination		127.34740959473707
		AscendingNode	24.78723008044545
		ArgOfPericen	46.048551183727625
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 156"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7219114079804654e-09
	Radius		8.8131009681464

	RotationPeriod	7.089578346239843

	Obliquity		187.13821962639923

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.24619576680277
		Eccentricity	0.6141791815182928
		Inclination		-19.146912349319948
		AscendingNode	330.69940014812414
		ArgOfPericen	174.631802166757
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 157"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.2039637054265445e-09
	Radius		13.455281789767458

	RotationPeriod	5.700820994506732

	Obliquity		158.8672629753832

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.47064200349432
		Eccentricity	0.6139919906691336
		Inclination		34.87458436793049
		AscendingNode	224.59272872528607
		ArgOfPericen	173.08918889182902
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 158"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.738398694503236e-09
	Radius		10.760985360564941

	RotationPeriod	7.3434195071689095

	Obliquity		299.5658754475954

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.8678484043853
		Eccentricity	0.6526020948899607
		Inclination		-15.63925821801978
		AscendingNode	323.1285701663065
		ArgOfPericen	269.3049862452207
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 159"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.6711594049247
		Eccentricity	0.3337162335940683
		Inclination		-56.65646691382055
		AscendingNode	286.6086118750227
		ArgOfPericen	147.95766225367325
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 159 A"
{
	ParentBody	"HeliosD 159"
	Class		"Asteroid"
	Mass		3.392429959365308e-09
	Radius		12.851641485919217

	Orbit
	{
		Epoch			2457395.5
		Period			0.00792796420635985
		Eccentricity	0.00781679760976713
		Inclination		201.63456790745366
		AscendingNode	251.86840682310972
		ArgOfPericen	48.00887796448396
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 159 B"
{
	ParentBody	"HeliosD 159"
	Class		"Asteroid"
	Mass		1.1504936550577067e-09
	Radius		8.96223610846755

	Orbit
	{
		Epoch			2457395.5
		Period			0.00792796420635985
		Eccentricity	0.00781679760976713
		Inclination		201.63456790745366
		AscendingNode	251.86840682310972
		ArgOfPericen	228.00887796448396
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 160"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.647846053726692e-09
	Radius		13.125575973029619

	RotationPeriod	4.485850274939098

	Obliquity		69.9075610346026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.1965332961371
		Eccentricity	0.6536727295399327
		Inclination		5.588525673258912
		AscendingNode	55.29837145644792
		ArgOfPericen	316.43055651615515
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 161"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.3443873945880815e-09
	Radius		13.655475039380512

	RotationPeriod	7.358846908831158

	Obliquity		292.42426676787716

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.854282814537996
		Eccentricity	0.15567957603467897
		Inclination		160.9461347830435
		AscendingNode	2.7415759374691273
		ArgOfPericen	276.3152874096752
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 162"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	44.73777288227537
		Eccentricity	0.4643882700640193
		Inclination		-25.488310326720907
		AscendingNode	105.17246176895695
		ArgOfPericen	76.00011851164683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 162 A"
{
	ParentBody	"HeliosD 162"
	Class		"Asteroid"
	Mass		2.38742424997584e-09
	Radius		10.356337460618109

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021504852336833393
		Eccentricity	0.003899341611053493
		Inclination		239.09009898859637
		AscendingNode	223.80049062405092
		ArgOfPericen	214.71345773152035
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 162 B"
{
	ParentBody	"HeliosD 162"
	Class		"Asteroid"
	Mass		7.180017018202716e-10
	Radius		6.938594130098488

	Orbit
	{
		Epoch			2457395.5
		Period			0.0021504852336833393
		Eccentricity	0.003899341611053493
		Inclination		239.09009898859637
		AscendingNode	223.80049062405092
		ArgOfPericen	34.71345773152035
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 163"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.358143975477148
		Eccentricity	0.5007760025853647
		Inclination		20.538844095250393
		AscendingNode	99.77287309462946
		ArgOfPericen	238.963044773115
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 163 A"
{
	ParentBody	"HeliosD 163"
	Class		"Asteroid"
	Mass		2.193225267559048e-09
	Radius		10.37275088447559

	Orbit
	{
		Epoch			2457395.5
		Period			0.006974464406696693
		Eccentricity	0.004187723414955148
		Inclination		247.86347130840508
		AscendingNode	345.85782738408165
		ArgOfPericen	277.79103970236605
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 163 B"
{
	ParentBody	"HeliosD 163"
	Class		"Asteroid"
	Mass		1.3272167650499376e-10
	Radius		4.072366166379243

	Orbit
	{
		Epoch			2457395.5
		Period			0.006974464406696693
		Eccentricity	0.004187723414955148
		Inclination		247.86347130840508
		AscendingNode	345.85782738408165
		ArgOfPericen	97.79103970236605
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 164"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.853893977673697e-09
	Radius		15.588999962553903

	RotationPeriod	3.9523738204366197

	Obliquity		196.9344169084899

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.9787888065662
		Eccentricity	0.8316573498112758
		Inclination		-66.7015054030433
		AscendingNode	263.4212731472825
		ArgOfPericen	322.3059032558039
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 165"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.112563729988591e-10
	Radius		7.522713817183653

	RotationPeriod	8.995713512815378

	Obliquity		33.337028983695895

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.325310909462118
		Eccentricity	0.383755028034496
		Inclination		-35.5213356010203
		AscendingNode	77.018619991218
		ArgOfPericen	95.90471033213238
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 166"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.493074237110445
		Eccentricity	0.6224913079040882
		Inclination		-98.52389929044479
		AscendingNode	33.30745382744092
		ArgOfPericen	207.19404426686555
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 166 A"
{
	ParentBody	"HeliosD 166"
	Class		"Asteroid"
	Mass		6.9836635054059216e-09
	Radius		14.726146999194384

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011492734563777582
		Eccentricity	0.004102067138492257
		Inclination		127.80307960968625
		AscendingNode	9.572407945148061
		ArgOfPericen	140.14466597566613
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 166 B"
{
	ParentBody	"HeliosD 166"
	Class		"Asteroid"
	Mass		4.194587719459624e-09
	Radius		12.42484910788437

	Orbit
	{
		Epoch			2457395.5
		Period			0.0011492734563777582
		Eccentricity	0.004102067138492257
		Inclination		127.80307960968625
		AscendingNode	9.572407945148061
		ArgOfPericen	320.14466597566616
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 167"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.295886529671653e-08
	Radius		19.576185366316796

	RotationPeriod	9.114989049772642

	Obliquity		39.87390475425382

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.625589906324254
		Eccentricity	0.47228040833566626
		Inclination		82.81200818688954
		AscendingNode	39.6173464168631
		ArgOfPericen	249.62887485991243
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 168"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.254106828708904e-08
	Radius		21.966038444165765

	RotationPeriod	6.088244701944642

	Obliquity		54.78882379747645

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.627603346371934
		Eccentricity	0.5599602157001992
		Inclination		36.377275140247754
		AscendingNode	129.9922353083843
		ArgOfPericen	66.30447764456953
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 169"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.492121038516105e-10
	Radius		7.434909312710448

	RotationPeriod	7.597155193996146

	Obliquity		242.60862440025363

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.90935416106128
		Eccentricity	0.5843527879102799
		Inclination		-47.38047364523352
		AscendingNode	356.6042652653656
		ArgOfPericen	248.6226587721835
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 170"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.558954103073702
		Eccentricity	0.7064299921567004
		Inclination		-18.56115595897793
		AscendingNode	68.23004810211252
		ArgOfPericen	146.3889371345735
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 170 A"
{
	ParentBody	"HeliosD 170"
	Class		"Asteroid"
	Mass		4.504481051206934e-09
	Radius		12.458075293642986

	Orbit
	{
		Epoch			2457395.5
		Period			0.005579266479083842
		Eccentricity	0.00677563567657152
		Inclination		249.5781070939367
		AscendingNode	100.25003097443502
		ArgOfPericen	231.97800978585764
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 170 B"
{
	ParentBody	"HeliosD 170"
	Class		"Asteroid"
	Mass		1.047427566942389e-09
	Radius		7.660857130546926

	Orbit
	{
		Epoch			2457395.5
		Period			0.005579266479083842
		Eccentricity	0.00677563567657152
		Inclination		249.5781070939367
		AscendingNode	100.25003097443502
		ArgOfPericen	51.97800978585764
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 171"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.025332708149843
		Eccentricity	0.3822943212881394
		Inclination		-28.88496301348834
		AscendingNode	7.818326952785224
		ArgOfPericen	97.57611197144779
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 171 A"
{
	ParentBody	"HeliosD 171"
	Class		"Asteroid"
	Mass		2.265106223727924e-09
	Radius		10.439987389686447

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005464506291589804
		Eccentricity	0.00567151187561415
		Inclination		356.2787468512568
		AscendingNode	286.48214723806126
		ArgOfPericen	17.190726733298646
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 171 B"
{
	ParentBody	"HeliosD 171"
	Class		"Asteroid"
	Mass		3.3644704125983315e-10
	Radius		5.52895031760421

	Orbit
	{
		Epoch			2457395.5
		Period			0.0005464506291589804
		Eccentricity	0.00567151187561415
		Inclination		356.2787468512568
		AscendingNode	286.48214723806126
		ArgOfPericen	197.19072673329865
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 172"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.234627647449876e-09
	Radius		16.151161344573126

	RotationPeriod	4.890684162049736

	Obliquity		333.02956800971356

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	41.43194347468099
		Eccentricity	0.730880837251084
		Inclination		3.495534092292777
		AscendingNode	184.55420418878904
		ArgOfPericen	271.17274433677426
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 173"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.6988431363640022e-09
	Radius		13.03314274852336

	RotationPeriod	10.523419268892244

	Obliquity		98.4501292074788

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.66897307034779
		Eccentricity	0.47459835279876705
		Inclination		70.29711552956908
		AscendingNode	260.0984325295841
		ArgOfPericen	213.05204135204625
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 174"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.84623217630096
		Eccentricity	0.5616554176121674
		Inclination		86.97984758719231
		AscendingNode	266.2473936831444
		ArgOfPericen	101.60079237431194
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 174 A"
{
	ParentBody	"HeliosD 174"
	Class		"Asteroid"
	Mass		6.828277758767426e-09
	Radius		14.77021712926868

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029567054540574223
		Eccentricity	0.008759862007690432
		Inclination		8.742669920040157
		AscendingNode	265.9926070895999
		ArgOfPericen	208.72491454869422
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 174 B"
{
	ParentBody	"HeliosD 174"
	Class		"Asteroid"
	Mass		8.522446546870755e-10
	Radius		7.381385976270244

	Orbit
	{
		Epoch			2457395.5
		Period			0.0029567054540574223
		Eccentricity	0.008759862007690432
		Inclination		8.742669920040157
		AscendingNode	265.9926070895999
		ArgOfPericen	28.724914548694187
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 175"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.847617374281603e-09
	Radius		13.349575061691084

	RotationPeriod	4.301585510797679

	Obliquity		130.7393715556006

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.278024044272218
		Eccentricity	0.44300471238922057
		Inclination		29.843905059077347
		AscendingNode	339.78797411799695
		ArgOfPericen	128.87496400258823
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 176"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.811626296452207e-09
	Radius		12.953871173593079

	RotationPeriod	5.850409181020556

	Obliquity		260.1053176192507

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.33887803007187
		Eccentricity	0.10827894831852536
		Inclination		-148.46840996810323
		AscendingNode	180.61494960517877
		ArgOfPericen	357.4066369731855
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 177"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.6311363972431395e-09
	Radius		10.69606132763383

	RotationPeriod	6.220739164823249

	Obliquity		248.76744834969347

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.42127746960545
		Eccentricity	0.5176682058697277
		Inclination		-25.57737735687762
		AscendingNode	216.20638699210465
		ArgOfPericen	53.03055232476973
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 178"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.308472933263714e-09
	Radius		10.359783417346584

	RotationPeriod	6.7430934185865326

	Obliquity		20.444153276667677

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.61801305276422
		Eccentricity	0.4412090333991576
		Inclination		-29.295913128360212
		AscendingNode	90.64094185817989
		ArgOfPericen	154.7931047636684
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 179"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0081081355617484e-09
	Radius		9.887081490859758

	RotationPeriod	3.5219146466206195

	Obliquity		44.96816905516438

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.038790317758947
		Eccentricity	0.8087584333081632
		Inclination		-64.75895122859801
		AscendingNode	355.1556580839273
		ArgOfPericen	2.261065387547121
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 180"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.9477145819526015e-09
	Radius		12.056092896169659

	RotationPeriod	6.324529373847969

	Obliquity		312.3557578476801

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.407366527590362
		Eccentricity	0.4522431780321889
		Inclination		-46.86640552824641
		AscendingNode	212.14418600554188
		ArgOfPericen	329.51473181108264
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 181"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1148268259805637e-09
	Radius		8.726796054150638

	RotationPeriod	7.65733157367531

	Obliquity		268.7028739464575

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.669534618624326
		Eccentricity	0.7854245679661934
		Inclination		-51.488568418582794
		AscendingNode	184.27548630389313
		ArgOfPericen	119.08950985999239
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 182"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.9538116555187467e-09
	Radius		11.431852728572311

	RotationPeriod	4.507209238319326

	Obliquity		276.710210211636

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.860178860293853
		Eccentricity	0.7404478415249266
		Inclination		52.568584837038344
		AscendingNode	335.0468557091469
		ArgOfPericen	71.25083156996187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 183"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.296481149627609e-09
	Radius		12.171817030779316

	RotationPeriod	3.5053746813634348

	Obliquity		357.64862048321424

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.61160688622639
		Eccentricity	0.45084814265913103
		Inclination		-75.28403468321996
		AscendingNode	188.43360611831923
		ArgOfPericen	193.037904582898
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 184"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.246023834499344
		Eccentricity	0.6666848866664246
		Inclination		-23.53507308411082
		AscendingNode	98.5816061539106
		ArgOfPericen	61.28628248027671
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 184 A"
{
	ParentBody	"HeliosD 184"
	Class		"Asteroid"
	Mass		5.099134679418149e-09
	Radius		12.770222442259511

	Orbit
	{
		Epoch			2457395.5
		Period			0.0052334673595715595
		Eccentricity	0.004834504634734405
		Inclination		267.5296856545776
		AscendingNode	206.210535995497
		ArgOfPericen	248.89435517424192
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 184 B"
{
	ParentBody	"HeliosD 184"
	Class		"Asteroid"
	Mass		4.498723898425452e-10
	Radius		5.684986197329346

	Orbit
	{
		Epoch			2457395.5
		Period			0.0052334673595715595
		Eccentricity	0.004834504634734405
		Inclination		267.5296856545776
		AscendingNode	206.210535995497
		ArgOfPericen	68.89435517424192
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 185"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.68682006555765e-09
	Radius		15.751312532187772

	RotationPeriod	6.6710814001394265

	Obliquity		33.724171471041274

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.705123825328034
		Eccentricity	0.8544857126314324
		Inclination		16.774433574449866
		AscendingNode	64.2143716824185
		ArgOfPericen	351.0749137754665
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 186"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.812798378773145e-09
	Radius		14.798062929956071

	RotationPeriod	6.693302874403437

	Obliquity		144.49633228713535

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.933102509291382
		Eccentricity	0.4624022856284751
		Inclination		-35.721387143508544
		AscendingNode	166.48839705648203
		ArgOfPericen	232.31623069478368
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 187"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.060925166460084
		Eccentricity	0.6713548230385653
		Inclination		-37.53759323245206
		AscendingNode	172.57087841381406
		ArgOfPericen	153.92445287158762
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 187 A"
{
	ParentBody	"HeliosD 187"
	Class		"Asteroid"
	Mass		9.975057382036103e-10
	Radius		8.412073791908554

	Orbit
	{
		Epoch			2457395.5
		Period			0.006029864526699905
		Eccentricity	0.0051771433898340794
		Inclination		290.33635718131296
		AscendingNode	342.86745958780585
		ArgOfPericen	36.21819158310228
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 187 B"
{
	ParentBody	"HeliosD 187"
	Class		"Asteroid"
	Mass		1.0495689120019735e-10
	Radius		3.9713203907428594

	Orbit
	{
		Epoch			2457395.5
		Period			0.006029864526699905
		Eccentricity	0.0051771433898340794
		Inclination		290.33635718131296
		AscendingNode	342.86745958780585
		ArgOfPericen	216.21819158310228
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 188"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.3241834472670697e-09
	Radius		10.347911166582971

	RotationPeriod	5.714605777929697

	Obliquity		14.210975027081801

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.840199485123623
		Eccentricity	0.8201128658843185
		Inclination		108.52823905066467
		AscendingNode	13.934437550665017
		ArgOfPericen	285.05045833803683
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 189"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.402217836377306e-08
	Radius		22.229099446160717

	RotationPeriod	7.615091951654236

	Obliquity		355.30586394111555

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.66930353979726
		Eccentricity	0.2887625995482951
		Inclination		-9.776732201285467
		AscendingNode	67.95459321887975
		ArgOfPericen	154.21367449878608
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 190"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	37.600939367108666
		Eccentricity	0.6671803393133393
		Inclination		-62.104913405006705
		AscendingNode	136.74346193094624
		ArgOfPericen	352.8708845297574
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 190 A"
{
	ParentBody	"HeliosD 190"
	Class		"Asteroid"
	Mass		7.385405736884763e-10
	Radius		7.016764279316608

	Orbit
	{
		Epoch			2457395.5
		Period			0.007582390101200108
		Eccentricity	0.003980902994950954
		Inclination		297.48883424741456
		AscendingNode	50.79081532170487
		ArgOfPericen	139.7996292167655
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 190 B"
{
	ParentBody	"HeliosD 190"
	Class		"Asteroid"
	Mass		1.860329535797605e-11
	Radius		2.056878921944448

	Orbit
	{
		Epoch			2457395.5
		Period			0.007582390101200108
		Eccentricity	0.003980902994950954
		Inclination		297.48883424741456
		AscendingNode	50.79081532170487
		ArgOfPericen	319.79962921676554
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 191"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6386454890755375e-09
	Radius		9.672345571661381

	RotationPeriod	7.4151820483733255

	Obliquity		270.31778582616323

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.954384756924977
		Eccentricity	0.5292519531879329
		Inclination		-33.322563151034146
		AscendingNode	243.70825759616858
		ArgOfPericen	229.3219238903513
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 192"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.978408230910006e-08
	Radius		22.19914589924639

	RotationPeriod	7.44546655878931

	Obliquity		317.0627585595911

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.151797764577424
		Eccentricity	0.5126944755838136
		Inclination		16.485884403919247
		AscendingNode	271.9391545313909
		ArgOfPericen	323.75605919456433
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 193"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.25662166860594e-09
	Radius		15.177380430140321

	RotationPeriod	9.691072103462178

	Obliquity		59.18729563993375

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.031382193759967
		Eccentricity	0.4867140185788637
		Inclination		-41.71103677813602
		AscendingNode	242.16075936967832
		ArgOfPericen	142.99672642781002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 194"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.164810617680175e-09
	Radius		15.47576853648534

	RotationPeriod	8.93169563173007

	Obliquity		307.14779538091756

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.16049582357059
		Eccentricity	0.5106462776676279
		Inclination		-80.67152550777314
		AscendingNode	165.37246833327237
		ArgOfPericen	125.9547165193654
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 195"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0423987404867877e-09
	Radius		7.924186996356302

	RotationPeriod	7.5695400289207395

	Obliquity		92.14740881898366

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.12373660032315
		Eccentricity	0.6935372980635011
		Inclination		-133.65249851746665
		AscendingNode	126.89984745111157
		ArgOfPericen	79.2819456936613
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 196"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.079233555314545e-09
	Radius		11.793446456617788

	RotationPeriod	7.0447855085161315

	Obliquity		233.9991431112783

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.053424649968083
		Eccentricity	0.3255103198142993
		Inclination		87.09502401412391
		AscendingNode	163.49096900862773
		ArgOfPericen	216.79285511653006
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 197"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6274102453358387e-09
	Radius		9.416572052500097

	RotationPeriod	10.615968151606372

	Obliquity		31.262030017571675

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	31.94729462422367
		Eccentricity	0.4039926402949988
		Inclination		21.064057067637577
		AscendingNode	36.003477292385504
		ArgOfPericen	255.40377466626944
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 198"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.63855351466234e-09
	Radius		15.597062221063663

	RotationPeriod	6.866442397079157

	Obliquity		186.81845666665822

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.028880837259134
		Eccentricity	0.38143150907672874
		Inclination		44.17890446178943
		AscendingNode	22.839069369015554
		ArgOfPericen	93.69821304139437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 199"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8350808980756961e-09
	Radius		9.721907826085067

	RotationPeriod	10.293565330212738

	Obliquity		16.22647199738524

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	11.689807618091255
		Eccentricity	0.4440342192723812
		Inclination		21.966183341884886
		AscendingNode	161.7514227612844
		ArgOfPericen	154.31184132337597
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 200"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1772546902687909e-08
	Radius		17.500073082512003

	RotationPeriod	5.09236988072978

	Obliquity		166.56203311969747

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.80512096762869
		Eccentricity	0.37077873931675315
		Inclination		106.28682947916762
		AscendingNode	309.1943899494912
		ArgOfPericen	13.958214475393
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 201"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.46934887643224
		Eccentricity	0.19076195336717428
		Inclination		-38.12908915991846
		AscendingNode	239.6222080266199
		ArgOfPericen	196.41622198994213
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 201 A"
{
	ParentBody	"HeliosD 201"
	Class		"Asteroid"
	Mass		1.2996776054019336e-08
	Radius		18.49925635532171

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018739480035060393
		Eccentricity	0.0030107068179024304
		Inclination		31.62450709536348
		AscendingNode	185.81710436043895
		ArgOfPericen	291.2301678787771
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 201 B"
{
	ParentBody	"HeliosD 201"
	Class		"Asteroid"
	Mass		3.3802008168431636e-10
	Radius		5.4809590785511055

	Orbit
	{
		Epoch			2457395.5
		Period			0.0018739480035060393
		Eccentricity	0.0030107068179024304
		Inclination		31.62450709536348
		AscendingNode	185.81710436043895
		ArgOfPericen	111.23016787877708
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 202"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3543070140116126e-08
	Radius		18.646086179488016

	RotationPeriod	4.625169810680355

	Obliquity		17.393675161474846

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.86941433663115
		Eccentricity	0.24659779241304924
		Inclination		-47.471826292248444
		AscendingNode	206.3281817397889
		ArgOfPericen	324.6162917701946
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 203"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.580141171544348
		Eccentricity	0.4326239392327187
		Inclination		-66.32703409541071
		AscendingNode	348.99597875038233
		ArgOfPericen	51.58815588109047
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 203 A"
{
	ParentBody	"HeliosD 203"
	Class		"Asteroid"
	Mass		8.621303221067601e-09
	Radius		15.83523046028251

	Orbit
	{
		Epoch			2457395.5
		Period			0.004824917625774276
		Eccentricity	0.00848471243179482
		Inclination		295.270965534426
		AscendingNode	101.02322765329397
		ArgOfPericen	284.0014005107464
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 203 B"
{
	ParentBody	"HeliosD 203"
	Class		"Asteroid"
	Mass		5.9759061073972445e-09
	Radius		14.01419007073493

	Orbit
	{
		Epoch			2457395.5
		Period			0.004824917625774276
		Eccentricity	0.00848471243179482
		Inclination		295.270965534426
		AscendingNode	101.02322765329397
		ArgOfPericen	104.00140051074641
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 204"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.6846514525548165e-09
	Radius		12.981456040798285

	RotationPeriod	5.248010924987001

	Obliquity		298.37985908227137

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.276595202929165
		Eccentricity	0.5850902547967869
		Inclination		71.67631986717089
		AscendingNode	45.85732580830915
		ArgOfPericen	154.1236702895592
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 205"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.481679429219114e-09
	Radius		14.700092296756427

	RotationPeriod	8.493372000666561

	Obliquity		268.4728122484389

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.96819674498598
		Eccentricity	0.7472942973974002
		Inclination		57.4853483915039
		AscendingNode	306.2574882455519
		ArgOfPericen	73.2361942949869
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 206"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.337260645051026e-09
	Radius		15.16163119538881

	RotationPeriod	5.0839024746522465

	Obliquity		25.013390779714463

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.985308706841067
		Eccentricity	0.7483931108357312
		Inclination		-33.485918642003895
		AscendingNode	56.41347335038248
		ArgOfPericen	9.785618953231662
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 207"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8029250406682378e-08
	Radius		20.092417016150932

	RotationPeriod	7.398868588435791

	Obliquity		321.9618393172352

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	49.962321687807986
		Eccentricity	0.5038637674098081
		Inclination		61.37529137764905
		AscendingNode	169.12517207892807
		ArgOfPericen	264.15827931564945
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 208"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.2364612437611708e-09
	Radius		12.33372673802356

	RotationPeriod	3.807880586593338

	Obliquity		196.7147164821045

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.313348539863412
		Eccentricity	0.3848123948207045
		Inclination		-4.056170858049451
		AscendingNode	79.00802553052047
		ArgOfPericen	205.5204398939139
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 209"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.047940081071774e-10
	Radius		6.234409100572087

	RotationPeriod	3.8388721922471674

	Obliquity		163.61633671463946

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.904106179777603
		Eccentricity	0.4532148260145597
		Inclination		91.43773041623358
		AscendingNode	171.06515802896206
		ArgOfPericen	100.139185710523
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 210"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.698008291189349e-09
	Radius		10.587698145990132

	RotationPeriod	6.565489708667895

	Obliquity		160.44555116204296

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.633664774963634
		Eccentricity	0.43307060398492714
		Inclination		1.6212951500845185
		AscendingNode	21.43390079576902
		ArgOfPericen	100.69288528910377
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 211"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.055658260463169e-09
	Radius		11.01349479903677

	RotationPeriod	6.794841806565174

	Obliquity		294.9578413917135

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.200036122617373
		Eccentricity	0.5029196215217666
		Inclination		44.94096667856439
		AscendingNode	237.0117809400981
		ArgOfPericen	118.35212790165835
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 212"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1096730768610284e-08
	Radius		17.12318213420069

	RotationPeriod	6.84174223422603

	Obliquity		221.91368777882948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.838641093200298
		Eccentricity	0.40448783837289115
		Inclination		-29.14098587142402
		AscendingNode	322.9653304082302
		ArgOfPericen	37.360808589262014
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 213"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.219172414440614e-09
	Radius		15.720867112745445

	RotationPeriod	4.072178121370727

	Obliquity		332.2969261656198

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.97768522994701
		Eccentricity	0.4293870370482761
		Inclination		19.539382191958925
		AscendingNode	193.74416249217415
		ArgOfPericen	80.32836099804967
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 214"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.036308311724632e-09
	Radius		8.26636481945924

	RotationPeriod	10.383635802075654

	Obliquity		285.67602335973675

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.7732502848239
		Eccentricity	0.7795122649916939
		Inclination		5.0173776708513245
		AscendingNode	170.2183614536576
		ArgOfPericen	250.3161676048069
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 215"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1475420702192219e-08
	Radius		17.342247812126324

	RotationPeriod	8.29526727227449

	Obliquity		335.0308393288402

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.487932319797311
		Eccentricity	0.8409022327597326
		Inclination		68.5390701934957
		AscendingNode	37.453979091547474
		ArgOfPericen	225.77562001786208
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 216"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.373778574784639e-09
	Radius		14.029331860571427

	RotationPeriod	7.607481312645741

	Obliquity		204.68404159096474

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.057527133965115
		Eccentricity	0.36192830759297046
		Inclination		-19.146825189855363
		AscendingNode	306.155646809929
		ArgOfPericen	355.64044635380947
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 217"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.910458082166347e-09
	Radius		11.140815138249355

	RotationPeriod	4.917206994920196

	Obliquity		224.42618669424627

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	16.337336752557007
		Eccentricity	0.5338002740609534
		Inclination		-77.98158287778996
		AscendingNode	14.313459492829068
		ArgOfPericen	259.10981711443384
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 218"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.7164479406259853e-09
	Radius		13.192135466943856

	RotationPeriod	7.3346317220117925

	Obliquity		15.825963383781545

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.802468646782135
		Eccentricity	0.4700805497714447
		Inclination		47.10887573282248
		AscendingNode	10.008489904401344
		ArgOfPericen	188.28618998713475
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 219"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.596027892954123
		Eccentricity	0.5643006101628076
		Inclination		92.21301170194955
		AscendingNode	325.78485987352394
		ArgOfPericen	17.65694917306035
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 219 A"
{
	ParentBody	"HeliosD 219"
	Class		"Asteroid"
	Mass		6.804392306127815e-09
	Radius		14.807276082266554

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030419376456977333
		Eccentricity	0.0036167108663736564
		Inclination		248.31214745370616
		AscendingNode	182.32241025365184
		ArgOfPericen	264.141989435619
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 219 B"
{
	ParentBody	"HeliosD 219"
	Class		"Asteroid"
	Mass		1.7987446047841473e-10
	Radius		4.410981405936981

	Orbit
	{
		Epoch			2457395.5
		Period			0.0030419376456977333
		Eccentricity	0.0036167108663736564
		Inclination		248.31214745370616
		AscendingNode	182.32241025365184
		ArgOfPericen	84.141989435619
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 220"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8113597893009866e-08
	Radius		20.220501975423446

	RotationPeriod	7.416808377301097

	Obliquity		257.2920599757682

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.527742693865548
		Eccentricity	0.548144101866406
		Inclination		88.37301618063704
		AscendingNode	65.11586933929543
		ArgOfPericen	211.4497189190002
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 221"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.4682323204254605e-10
	Radius		5.887582058317036

	RotationPeriod	7.012178663617696

	Obliquity		46.238858015917955

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.78485464261796
		Eccentricity	0.5922540899546301
		Inclination		-3.073733964933632
		AscendingNode	138.3233357953888
		ArgOfPericen	31.09347675697112
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 222"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.246005882551323
		Eccentricity	0.6762328322856841
		Inclination		-61.069115858838494
		AscendingNode	276.19949930119856
		ArgOfPericen	115.18731256391409
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 222 A"
{
	ParentBody	"HeliosD 222"
	Class		"Asteroid"
	Mass		2.048740054406602e-08
	Radius		21.913989502583675

	Orbit
	{
		Epoch			2457395.5
		Period			0.00048682266489216187
		Eccentricity	0.003534957432590212
		Inclination		165.0997031612499
		AscendingNode	173.76092544497246
		ArgOfPericen	142.01125687067562
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 222 B"
{
	ParentBody	"HeliosD 222"
	Class		"Asteroid"
	Mass		1.0876355592503848e-09
	Radius		8.236075058239782

	Orbit
	{
		Epoch			2457395.5
		Period			0.00048682266489216187
		Eccentricity	0.003534957432590212
		Inclination		165.0997031612499
		AscendingNode	173.76092544497246
		ArgOfPericen	322.01125687067565
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 223"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.294986043561913e-09
	Radius		12.311723507468402

	RotationPeriod	7.376150912597682

	Obliquity		71.24175165997707

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.214467998601663
		Eccentricity	0.4332275454044449
		Inclination		39.265715253016396
		AscendingNode	220.96453713539853
		ArgOfPericen	217.39962178319786
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 224"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.741311300844231e-09
	Radius		12.392508571130575

	RotationPeriod	10.038360972123908

	Obliquity		261.5310000125587

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.51073807840623
		Eccentricity	0.21735148498224094
		Inclination		122.50945734557764
		AscendingNode	182.86149788264763
		ArgOfPericen	141.85979490834035
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 225"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.8307360768984607e-08
	Radius		19.85017535127912

	RotationPeriod	4.573748411149818

	Obliquity		216.13835452659117

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.42662351551865
		Eccentricity	0.4049707933368377
		Inclination		-33.319706417497024
		AscendingNode	204.90499729830736
		ArgOfPericen	105.95653958902335
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 226"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.84763191431093e-08
	Radius		21.119751926223046

	RotationPeriod	8.646615002276386

	Obliquity		309.96258569922367

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	36.491827261667694
		Eccentricity	0.7832944478536468
		Inclination		-91.30335275333375
		AscendingNode	119.63641013173468
		ArgOfPericen	113.055760032723
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 227"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.889619805920066
		Eccentricity	0.6260023662063592
		Inclination		29.639043771830504
		AscendingNode	85.8307035750424
		ArgOfPericen	273.97482584882295
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 227 A"
{
	ParentBody	"HeliosD 227"
	Class		"Asteroid"
	Mass		7.178394598649109e-09
	Radius		15.2342740405331

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028451135664263236
		Eccentricity	0.007345022289291184
		Inclination		350.61683197284003
		AscendingNode	62.2441769056868
		ArgOfPericen	17.486995932235647
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 227 B"
{
	ParentBody	"HeliosD 227"
	Class		"Asteroid"
	Mass		2.3595969372600275e-10
	Radius		4.880061129879962

	Orbit
	{
		Epoch			2457395.5
		Period			0.0028451135664263236
		Eccentricity	0.007345022289291184
		Inclination		350.61683197284003
		AscendingNode	62.2441769056868
		ArgOfPericen	197.48699593223566
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 228"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.5492533744811356e-09
	Radius		11.562829974468103

	RotationPeriod	3.7011343919998927

	Obliquity		110.59593468045534

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.064632299955097
		Eccentricity	0.7258640880930995
		Inclination		39.91204034807522
		AscendingNode	16.069296729165153
		ArgOfPericen	334.9565659371549
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 229"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.525943107710985e-09
	Radius		13.41327992080981

	RotationPeriod	8.910963989639157

	Obliquity		65.77580986810507

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.95508030064552
		Eccentricity	0.15044733242176023
		Inclination		-88.51177449455302
		AscendingNode	63.85708339086653
		ArgOfPericen	105.37688021428603
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 230"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.501067503269915e-09
	Radius		10.652177099260031

	RotationPeriod	6.964772918150891

	Obliquity		182.33359430922337

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.79353772316095
		Eccentricity	0.697333553157138
		Inclination		-13.121315299300587
		AscendingNode	163.06502400122858
		ArgOfPericen	288.27918072581116
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 231"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.848081597562847e-09
	Radius		17.175693000505404

	RotationPeriod	3.031910567665963

	Obliquity		171.0125510784343

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.944649941679724
		Eccentricity	0.48145360112659746
		Inclination		50.299964665542085
		AscendingNode	233.78363132506166
		ArgOfPericen	92.22486579202437
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 232"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.071710027741052e-09
	Radius		10.13909440662446

	RotationPeriod	6.187775088176656

	Obliquity		252.45639590693116

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.86781121072722
		Eccentricity	0.5987206946415128
		Inclination		-27.892541339603415
		AscendingNode	45.05141982564554
		ArgOfPericen	160.380266684789
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 233"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.327467877249426e-09
	Radius		8.559357442950864

	RotationPeriod	6.333904491974327

	Obliquity		215.18470267461134

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.15166117881371
		Eccentricity	0.6715401081255238
		Inclination		26.094143932281106
		AscendingNode	103.87542188940606
		ArgOfPericen	107.74255476536109
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 234"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.449336258547902
		Eccentricity	0.4583069282011123
		Inclination		18.01756676700893
		AscendingNode	123.89624471358539
		ArgOfPericen	11.2985987950467
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 234 A"
{
	ParentBody	"HeliosD 234"
	Class		"Asteroid"
	Mass		1.025154102740442e-08
	Radius		17.61436395069207

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003826552656709182
		Eccentricity	0.004411103760086295
		Inclination		83.67371132106464
		AscendingNode	297.7699970046697
		ArgOfPericen	102.02502049752584
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 234 B"
{
	ParentBody	"HeliosD 234"
	Class		"Asteroid"
	Mass		2.6037514437731228e-09
	Radius		11.155021768136878

	Orbit
	{
		Epoch			2457395.5
		Period			0.0003826552656709182
		Eccentricity	0.004411103760086295
		Inclination		83.67371132106464
		AscendingNode	297.7699970046697
		ArgOfPericen	282.0250204975258
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 235"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.0115042252688875e-09
	Radius		14.275145836923306

	RotationPeriod	3.6172765922691013

	Obliquity		15.90469744460686

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.77491643743247
		Eccentricity	0.7485615482162583
		Inclination		-73.74432354820004
		AscendingNode	102.35706030405625
		ArgOfPericen	240.86077665441888
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 236"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0919905542657164e-08
	Radius		17.413957251278617

	RotationPeriod	3.5446769528085

	Obliquity		11.620557958744993

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.149297991256876
		Eccentricity	0.39171450087736354
		Inclination		-89.39374712576854
		AscendingNode	86.15106757562722
		ArgOfPericen	70.93153214726662
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 237"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.23210082417891e-09
	Radius		14.779162384595905

	RotationPeriod	5.52838111712013

	Obliquity		128.39116014774788

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.260826100569332
		Eccentricity	0.5244995934822319
		Inclination		17.709098980169234
		AscendingNode	65.0575396481812
		ArgOfPericen	116.04063988217206
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 238"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.144109025007882e-09
	Radius		9.671848548174912

	RotationPeriod	4.289019372330465

	Obliquity		34.923137301471364

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.96720350092488
		Eccentricity	0.46881002430064134
		Inclination		10.909003221977207
		AscendingNode	230.2522355880716
		ArgOfPericen	250.61894581988238
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 239"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.85283181643602e-09
	Radius		11.948425232743983

	RotationPeriod	7.208942002465589

	Obliquity		147.77632652926283

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.57065875141665
		Eccentricity	0.5015087513140178
		Inclination		93.04916542511434
		AscendingNode	157.98848251232297
		ArgOfPericen	339.19526899830976
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 240"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3223839720019699e-09
	Radius		8.640187251389863

	RotationPeriod	5.789514532288159

	Obliquity		233.8790263217131

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.515467260104995
		Eccentricity	0.6403618992804858
		Inclination		32.89831512095813
		AscendingNode	19.745058466626716
		ArgOfPericen	338.24358662767446
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 241"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.178905769200647e-09
	Radius		15.750914466408247

	RotationPeriod	5.677137606988719

	Obliquity		284.95119622965746

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.834111791628775
		Eccentricity	0.3987680462518822
		Inclination		-56.5224339694922
		AscendingNode	61.721605282834325
		ArgOfPericen	58.54397179854527
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 242"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.0510122382158315e-09
	Radius		14.097324585686298

	RotationPeriod	3.099714530205152

	Obliquity		339.3801730148377

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	39.22358477223973
		Eccentricity	0.5928775942730469
		Inclination		2.67039075524595
		AscendingNode	223.16885273323226
		ArgOfPericen	237.08378380786607
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 243"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.691002085969948e-08
	Radius		20.252205788952583

	RotationPeriod	7.953032373167155

	Obliquity		115.36580451173018

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	8.082451786343142
		Eccentricity	0.8380960995103739
		Inclination		-1.8955878066839729
		AscendingNode	239.36180828252998
		ArgOfPericen	36.44902011226243
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 244"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.858975104296257e-10
	Radius		5.460022559264752

	RotationPeriod	6.520303487056399

	Obliquity		89.06231439323874

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.05747389764687
		Eccentricity	0.47800117019902416
		Inclination		-1.2780694715263259
		AscendingNode	87.52184839116795
		ArgOfPericen	347.30553865921206
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 245"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.110853136941169e-08
	Radius		17.747978777181963

	RotationPeriod	5.18602022722802

	Obliquity		113.37910455517948

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.65892809890601
		Eccentricity	0.5653453359888763
		Inclination		27.890818533929973
		AscendingNode	25.082825250895308
		ArgOfPericen	176.05528250732934
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 246"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0425777949652457e-09
	Radius		8.093089420384844

	RotationPeriod	4.024691080452053

	Obliquity		269.7035933733026

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.985763916007613
		Eccentricity	0.5800550431486057
		Inclination		147.32099491890295
		AscendingNode	61.74209801526695
		ArgOfPericen	158.8195597557657
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 247"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.6961472519373164e-09
	Radius		11.659559549395269

	RotationPeriod	6.836203098138466

	Obliquity		346.06017405083804

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.09859096255553
		Eccentricity	0.31222697519422815
		Inclination		52.81725676918988
		AscendingNode	255.89233108153869
		ArgOfPericen	117.77372155250724
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 248"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.83999293104898e-09
	Radius		14.171586221387887

	RotationPeriod	5.0135906268763195

	Obliquity		324.2052880705618

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.633245904068104
		Eccentricity	0.5409257419749143
		Inclination		-37.615225157088446
		AscendingNode	97.20234694600471
		ArgOfPericen	120.13334803315182
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 249"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.176685502405372
		Eccentricity	0.48602394430644014
		Inclination		-28.937057749095665
		AscendingNode	217.88999388537383
		ArgOfPericen	87.87083468868181
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 249 A"
{
	ParentBody	"HeliosD 249"
	Class		"Asteroid"
	Mass		1.0062776499585682e-08
	Radius		17.90991688057003

	Orbit
	{
		Epoch			2457395.5
		Period			0.002563426310622832
		Eccentricity	0.007608445980342746
		Inclination		267.06144092738975
		AscendingNode	45.23934050868554
		ArgOfPericen	71.39157497587735
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 249 B"
{
	ParentBody	"HeliosD 249"
	Class		"Asteroid"
	Mass		1.7548118581812278e-09
	Radius		10.006091766793169

	Orbit
	{
		Epoch			2457395.5
		Period			0.002563426310622832
		Eccentricity	0.007608445980342746
		Inclination		267.06144092738975
		AscendingNode	45.23934050868554
		ArgOfPericen	251.39157497587735
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 250"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.002520180029143e-08
	Radius		16.220678519805574

	RotationPeriod	8.743117613470039

	Obliquity		215.82493806645263

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.345786473405983
		Eccentricity	0.5397524592743606
		Inclination		-8.319927096762482
		AscendingNode	248.10383836727792
		ArgOfPericen	106.44610916225554
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 251"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.065806290020538e-09
	Radius		15.167876155223508

	RotationPeriod	4.545043880385316

	Obliquity		81.8771477584702

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.780375449641674
		Eccentricity	0.5565914818107826
		Inclination		-76.31052814164073
		AscendingNode	18.752123515587463
		ArgOfPericen	140.54395871632084
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 252"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1114246468450354e-08
	Radius		17.77658372169644

	RotationPeriod	4.115500226347104

	Obliquity		207.11311887981944

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.92140975494049
		Eccentricity	0.4466946972029556
		Inclination		-21.27044621733361
		AscendingNode	76.27358643530724
		ArgOfPericen	359.17689736813026
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 253"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.590825061343602e-09
	Radius		13.737411552434969

	RotationPeriod	4.774151740996098

	Obliquity		191.33643597140747

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.859264545719233
		Eccentricity	0.40863401110531455
		Inclination		-14.464481323653311
		AscendingNode	214.12149479979865
		ArgOfPericen	171.93185077421361
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 254"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0019228954306757e-08
	Radius		16.66935542153705

	RotationPeriod	3.0517753188744043

	Obliquity		117.1374116516365

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	7.958374413666089
		Eccentricity	0.31449212375238456
		Inclination		-43.35443924672504
		AscendingNode	310.2094997291733
		ArgOfPericen	359.6676293457109
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 255"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.0415099134119719e-08
	Radius		16.950567676113486

	RotationPeriod	6.264272547566003

	Obliquity		235.6305941213493

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.91612340708717
		Eccentricity	0.5024475390038303
		Inclination		-21.805197081097347
		AscendingNode	33.27259966352307
		ArgOfPericen	123.77043317629361
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 256"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.770203835977373e-09
	Radius		11.831480240280971

	RotationPeriod	6.8872885149263565

	Obliquity		228.13386044546056

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.13675997565868
		Eccentricity	0.5498526511171843
		Inclination		101.1677050436818
		AscendingNode	300.6545762885244
		ArgOfPericen	197.5906915167036
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 257"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	29.617144046683137
		Eccentricity	0.3188583945108482
		Inclination		-12.855655830741313
		AscendingNode	186.1933739595008
		ArgOfPericen	209.39556155978744
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 257 A"
{
	ParentBody	"HeliosD 257"
	Class		"Asteroid"
	Mass		3.1908095281500708e-09
	Radius		11.166947534452873

	Orbit
	{
		Epoch			2457395.5
		Period			0.00638690778958986
		Eccentricity	0.003961857245849078
		Inclination		191.65582496708518
		AscendingNode	313.24570995889206
		ArgOfPericen	277.33649943398757
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 257 B"
{
	ParentBody	"HeliosD 257"
	Class		"Asteroid"
	Mass		6.040339826325585e-10
	Radius		6.411918198660935

	Orbit
	{
		Epoch			2457395.5
		Period			0.00638690778958986
		Eccentricity	0.003961857245849078
		Inclination		191.65582496708518
		AscendingNode	313.24570995889206
		ArgOfPericen	97.33649943398757
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 258"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.406826827852054e-09
	Radius		16.702534443912192

	RotationPeriod	7.314968760694226

	Obliquity		157.25636303421493

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.895224583182745
		Eccentricity	0.3623610428097823
		Inclination		135.52397018842592
		AscendingNode	240.65825425729105
		ArgOfPericen	149.328009284323
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 259"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.75332122141818
		Eccentricity	0.343313280398516
		Inclination		-69.33668104133994
		AscendingNode	202.9110851840248
		ArgOfPericen	140.23535112192306
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 259 A"
{
	ParentBody	"HeliosD 259"
	Class		"Asteroid"
	Mass		4.795628445485249e-09
	Radius		13.024676680184685

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022509612387100423
		Eccentricity	0.002678526288859908
		Inclination		341.6785827036571
		AscendingNode	209.60428531997923
		ArgOfPericen	60.72064768546541
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 259 B"
{
	ParentBody	"HeliosD 259"
	Class		"Asteroid"
	Mass		4.678615198692345e-09
	Radius		12.917869253802456

	Orbit
	{
		Epoch			2457395.5
		Period			0.0022509612387100423
		Eccentricity	0.002678526288859908
		Inclination		341.6785827036571
		AscendingNode	209.60428531997923
		ArgOfPericen	240.7206476854654
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 260"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.347068810980686e-09
	Radius		11.662508292721537

	RotationPeriod	5.01042779536543

	Obliquity		341.94741395551114

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	12.156143967020267
		Eccentricity	0.4009204751931842
		Inclination		-48.483232471529746
		AscendingNode	171.4243536311818
		ArgOfPericen	273.40823618921223
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 261"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1586129663674233e-09
	Radius		7.869675148386411

	RotationPeriod	6.923298545848964

	Obliquity		92.15291683369459

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	41.17214440819789
		Eccentricity	0.44695444963850695
		Inclination		-77.40699803990137
		AscendingNode	187.1819145923934
		ArgOfPericen	193.2276449575809
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 262"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.9867052005845775e-09
	Radius		13.192039316909042

	RotationPeriod	4.363269886022329

	Obliquity		23.752048140987686

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.62956404381753
		Eccentricity	0.4761885826671376
		Inclination		6.600239022196577
		AscendingNode	293.31923309699346
		ArgOfPericen	287.3387151866276
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 263"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	14.853813954222188
		Eccentricity	0.4084050006696969
		Inclination		22.08818434835407
		AscendingNode	0.5630882229507961
		ArgOfPericen	280.5311041136853
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 263 A"
{
	ParentBody	"HeliosD 263"
	Class		"Asteroid"
	Mass		4.525313397335585e-09
	Radius		13.536168240005711

	Orbit
	{
		Epoch			2457395.5
		Period			0.007845007070728088
		Eccentricity	0.004733347377597504
		Inclination		115.40486148721592
		AscendingNode	36.207694433189545
		ArgOfPericen	232.21631339382873
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 263 B"
{
	ParentBody	"HeliosD 263"
	Class		"Asteroid"
	Mass		1.1111823193328113e-09
	Radius		8.476332100558382

	Orbit
	{
		Epoch			2457395.5
		Period			0.007845007070728088
		Eccentricity	0.004733347377597504
		Inclination		115.40486148721592
		AscendingNode	36.207694433189545
		ArgOfPericen	52.21631339382873
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 264"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.347395200653805e-10
	Radius		7.205124794465619

	RotationPeriod	3.9524071811947397

	Obliquity		245.8832500080477

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.392371164409248
		Eccentricity	0.26529215904560627
		Inclination		-102.39939629883351
		AscendingNode	306.78197385803253
		ArgOfPericen	16.03337476061806
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 265"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.422400989159554e-09
	Radius		13.278978413855928

	RotationPeriod	9.825519303822047

	Obliquity		297.77637392959764

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.16892506276791
		Eccentricity	0.8648993905858703
		Inclination		53.117416040542075
		AscendingNode	353.8182114405214
		ArgOfPericen	128.4535892377007
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 266"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.0036425729732556e-10
	Radius		4.46083556068756

	RotationPeriod	5.647340535052225

	Obliquity		317.2228694340014

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.805672373877954
		Eccentricity	0.4638589578855562
		Inclination		96.57598623284738
		AscendingNode	172.7687317343273
		ArgOfPericen	34.327662810539955
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 267"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.042053188452515e-08
	Radius		16.626321780777904

	RotationPeriod	4.887620198319436

	Obliquity		86.53988552261187

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	35.14521206307683
		Eccentricity	0.1565499633933255
		Inclination		-67.69762637438323
		AscendingNode	195.33679275529613
		ArgOfPericen	288.7229813976521
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 268"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.195114115648691e-09
	Radius		11.498580223762588

	RotationPeriod	9.74543061771512

	Obliquity		154.60388493484777

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.207940123770186
		Eccentricity	1.0
		Inclination		-19.82542714110587
		AscendingNode	204.7747711981524
		ArgOfPericen	236.72332442291628
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 269"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.9698114340975927e-10
	Radius		4.462064809031439

	RotationPeriod	5.888688017735731

	Obliquity		105.28495228361909

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.41929994046516
		Eccentricity	0.5997301790680173
		Inclination		17.591034950365938
		AscendingNode	125.70210822893281
		ArgOfPericen	86.20342271421337
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 270"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.134633359099577e-09
	Radius		12.560010642717447

	RotationPeriod	9.656153417825863

	Obliquity		355.2727204582884

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.515007546261252
		Eccentricity	0.23471978397550408
		Inclination		141.20279973493712
		AscendingNode	221.41020468069757
		ArgOfPericen	312.9693023295969
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 271"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.47265773385106e-09
	Radius		12.79284309790355

	RotationPeriod	9.334894762311203

	Obliquity		119.82051102622633

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.597806184722174
		Eccentricity	0.387315631057384
		Inclination		46.602740969340964
		AscendingNode	174.1239527534553
		ArgOfPericen	337.846942499458
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 272"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.852180904728966e-09
	Radius		15.848899651305427

	RotationPeriod	4.784675239733401

	Obliquity		202.15576573186306

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	20.811686694162688
		Eccentricity	0.4321434552786064
		Inclination		31.960753462669494
		AscendingNode	17.170663572986452
		ArgOfPericen	101.15469138090042
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 273"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.640903582579931e-09
	Radius		15.154024766492782

	RotationPeriod	8.094438672319768

	Obliquity		173.5711171165958

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.218764636953422
		Eccentricity	0.6468092545294635
		Inclination		-47.90571590764185
		AscendingNode	114.44461251838736
		ArgOfPericen	10.119737096184753
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 274"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.839262496938049e-09
	Radius		13.517775670674133

	RotationPeriod	5.3373875924546335

	Obliquity		229.5099182362445

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.247776212229791
		Eccentricity	0.574010344698602
		Inclination		55.017603902936045
		AscendingNode	333.07986956591816
		ArgOfPericen	105.04573964978877
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 275"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.23419199084406e-09
	Radius		12.182159378234934

	RotationPeriod	6.3896849492562895

	Obliquity		238.58291388666436

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.69151564745108
		Eccentricity	0.7524667535883589
		Inclination		70.1413995562641
		AscendingNode	105.49243799972889
		ArgOfPericen	346.7215899121965
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 276"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.3837763538826785e-09
	Radius		14.123456610597653

	RotationPeriod	6.671103996230192

	Obliquity		320.56375741408607

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	17.47544667930913
		Eccentricity	0.7499261981310528
		Inclination		79.80754158232561
		AscendingNode	11.725273660060687
		ArgOfPericen	45.90223572429588
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 277"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.436093987226387e-09
	Radius		16.31012725265563

	RotationPeriod	2.6679646897876745

	Obliquity		157.63086421582872

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.86162592189861
		Eccentricity	0.764405672465736
		Inclination		-44.25139699631641
		AscendingNode	69.92079432475064
		ArgOfPericen	192.68820963654434
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 278"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	34.60912433344603
		Eccentricity	0.3044884416157847
		Inclination		-61.81199985915858
		AscendingNode	44.2631394855912
		ArgOfPericen	217.76961125629649
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 278 A"
{
	ParentBody	"HeliosD 278"
	Class		"Asteroid"
	Mass		6.719999793287607e-09
	Radius		15.093509703388241

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007645956597913213
		Eccentricity	0.003919671301247155
		Inclination		212.76094315606522
		AscendingNode	259.3894593252481
		ArgOfPericen	77.88328330468306
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 278 B"
{
	ParentBody	"HeliosD 278"
	Class		"Asteroid"
	Mass		3.735853332274788e-09
	Radius		12.41072324103018

	Orbit
	{
		Epoch			2457395.5
		Period			0.0007645956597913213
		Eccentricity	0.003919671301247155
		Inclination		212.76094315606522
		AscendingNode	259.3894593252481
		ArgOfPericen	257.88328330468306
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 279"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		2.816185664175424e-09
	Radius		11.495528082644116

	RotationPeriod	3.119329228010647

	Obliquity		346.79718437426993

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	32.198436340334766
		Eccentricity	0.4235714278274142
		Inclination		-160.16908066720717
		AscendingNode	323.5475393027325
		ArgOfPericen	186.12803678947503
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 280"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		3.845508685273594e-09
	Radius		11.72688066405498

	RotationPeriod	9.245572507008035

	Obliquity		155.02257506924113

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	28.796689201991416
		Eccentricity	0.45422545403229003
		Inclination		-13.138213458823314
		AscendingNode	303.12839680788534
		ArgOfPericen	59.10827810224129
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 281"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.862603248298423e-10
	Radius		6.777895483049972

	RotationPeriod	7.5382655591530385

	Obliquity		227.30379171033786

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	15.187420607753785
		Eccentricity	0.318398874599079
		Inclination		133.67157808645274
		AscendingNode	98.68071500639668
		ArgOfPericen	139.72621898266422
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 282"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.127825452029874e-09
	Radius		14.165236247517061

	RotationPeriod	8.454245651899276

	Obliquity		279.49855648921357

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.993095435099058
		Eccentricity	0.7909184980171169
		Inclination		81.94655308591837
		AscendingNode	309.6473621046883
		ArgOfPericen	51.618028027067936
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 283"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.455127657360118e-08
	Radius		18.253316953255222

	RotationPeriod	8.05340602450844

	Obliquity		110.27200556213414

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.751992293719884
		Eccentricity	0.6061775171323676
		Inclination		2.645858703683549
		AscendingNode	9.801591432990161
		ArgOfPericen	299.7676519762429
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 284"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.147947030073482e-09
	Radius		13.333567073741795

	RotationPeriod	8.700531424072965

	Obliquity		49.11217286302689

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	22.557724577244468
		Eccentricity	0.26767876115187206
		Inclination		21.224888464974704
		AscendingNode	57.51995448230675
		ArgOfPericen	142.00560870407602
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 285"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.182458025976447e-09
	Radius		13.20934076825686

	RotationPeriod	4.169269504550982

	Obliquity		61.171605621185186

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.26534606298208
		Eccentricity	0.5579460034785882
		Inclination		27.847744419900465
		AscendingNode	26.736626607356975
		ArgOfPericen	205.14497127020448
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 286"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		8.202544122028345e-09
	Radius		15.483917562623988

	RotationPeriod	5.361644120983437

	Obliquity		21.1141604956548

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	21.99683026861514
		Eccentricity	0.4817265805075535
		Inclination		-112.17207020409549
		AscendingNode	309.1769641611367
		ArgOfPericen	290.74200281418666
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 287"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.1544698458356742e-09
	Radius		9.18250589836804

	RotationPeriod	6.236445065111407

	Obliquity		287.1510186793842

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.51549828749222
		Eccentricity	0.32188640637158183
		Inclination		21.03754234593625
		AscendingNode	197.16104806934254
		ArgOfPericen	241.1460930145525
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 288"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.563273932454268e-09
	Radius		16.739959575803123

	RotationPeriod	8.195448944624038

	Obliquity		295.2823618424054

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	30.779441599286265
		Eccentricity	0.5778204324278952
		Inclination		10.17888561397764
		AscendingNode	250.8309844371427
		ArgOfPericen	265.4830586871268
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 289"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		9.111666623775495e-10
	Radius		7.57248596361017

	RotationPeriod	6.630619801603021

	Obliquity		109.29665489890773

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.035048660104394
		Eccentricity	0.5111084000973546
		Inclination		29.352753094060294
		AscendingNode	148.93144683431552
		ArgOfPericen	21.312772809625145
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 290"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.334844363918684e-09
	Radius		8.972095770916606

	RotationPeriod	3.234558100818115

	Obliquity		185.47264806011833

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	25.81968831367815
		Eccentricity	0.5240785309958587
		Inclination		23.379736582870123
		AscendingNode	279.2136875445158
		ArgOfPericen	178.33834699258256
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 291"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		4.223154803573916e-09
	Radius		11.987289466544325

	RotationPeriod	1.9760267494498462

	Obliquity		57.04232854042302

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	18.34012543827619
		Eccentricity	0.05333178760114843
		Inclination		28.41900359192988
		AscendingNode	298.02912217244585
		ArgOfPericen	164.7506411444187
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 292"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.3510012388783161e-09
	Radius		8.988524232228135

	RotationPeriod	5.427522120697297

	Obliquity		156.04915547357876

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	26.21155366307095
		Eccentricity	0.2675813933882838
		Inclination		-59.79357036381676
		AscendingNode	332.03443151195086
		ArgOfPericen	54.36117548427609
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 293"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.4839759173995796e-09
	Radius		8.735087851151228

	RotationPeriod	1.1076705597840961

	Obliquity		275.2888046391677

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	13.004968412621018
		Eccentricity	0.8418516955888267
		Inclination		17.053235807712078
		AscendingNode	222.7371857457866
		ArgOfPericen	59.138642214912224
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 294"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		5.261510724490964e-10
	Radius		6.545608581503092

	RotationPeriod	4.080487237999773

	Obliquity		208.63063909334136

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.94783666098504
		Eccentricity	0.42561541957779153
		Inclination		-20.3219819806801
		AscendingNode	217.49592895988812
		ArgOfPericen	201.22522432313312
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 295"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.6473745528108038e-09
	Radius		9.247371121693341

	RotationPeriod	4.307379619548958

	Obliquity		207.19513651382394

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	23.526968086094683
		Eccentricity	0.49532062025475315
		Inclination		-49.12451586591591
		AscendingNode	75.12742808536476
		ArgOfPericen	132.11506472496563
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 296"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		7.871332629049685e-09
	Radius		15.095040433519388

	RotationPeriod	6.712180265826107

	Obliquity		21.462855315771883

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	24.54226986764474
		Eccentricity	0.2848249671572934
		Inclination		-15.319424982251379
		AscendingNode	203.63385074982483
		ArgOfPericen	107.30397633650244
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 297"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.7776846590125191e-09
	Radius		9.969130242989282

	RotationPeriod	4.718306961782776

	Obliquity		109.99744886855535

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	33.21240414135819
		Eccentricity	0.365390907788393
		Inclination		143.54546209956698
		AscendingNode	30.961278183275247
		ArgOfPericen	38.19849239460749
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 298"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		1.625640245387184e-09
	Radius		9.182298280289686

	RotationPeriod	5.175490974710978

	Obliquity		67.92134098367997

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	27.954987588724904
		Eccentricity	0.3410918009714184
		Inclination		88.28684636223932
		AscendingNode	252.34529485965194
		ArgOfPericen	203.92577828807586
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Barycenter "HeliosD 299"
{
	ParentBody	"Helios DEL"
	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	38.276177055299556
		Eccentricity	0.5223084275950005
		Inclination		-9.999459861211925
		AscendingNode	154.55492960114998
		ArgOfPericen	305.8292264353078
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 299 A"
{
	ParentBody	"HeliosD 299"
	Class		"Asteroid"
	Mass		3.0067708886625478e-09
	Radius		10.982360188939468

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014743419445536535
		Eccentricity	0.006395467888678199
		Inclination		347.25903029948
		AscendingNode	114.1966513797529
		ArgOfPericen	206.93086596433716
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}
Comet "HeliosD 299 B"
{
	ParentBody	"HeliosD 299"
	Class		"Asteroid"
	Mass		2.321736641298026e-09
	Radius		10.07549880984701

	Orbit
	{
		Epoch			2457395.5
		Period			0.0014743419445536535
		Eccentricity	0.006395467888678199
		Inclination		347.25903029948
		AscendingNode	114.1966513797529
		ArgOfPericen	26.93086596433716
		RefPlane		"Equator"
		MeanAnomaly		0.0
	}
}

Comet "HeliosD 300"
{
	ParentBody	"Helios DEL"
	Class		"Asteroid"
	Mass		6.1455645492316735e-09
	Radius		14.893094595750835

	RotationPeriod	4.311177179030133

	Obliquity		220.902607110308

	Orbit
	{
		Epoch			2457395.5
		SemiMajorAxis	19.88778399583252
		Eccentricity	0.7667681127721142
		Inclination		-51.601303470895395
		AscendingNode	0.1165106586336595
		ArgOfPericen	260.0232508224784
		RefPlane		"Extrasolar"
		MeanAnomaly		0.0
	}
}

//------------------------------------------------------------------------------
